{% extends "layout.html.j2" %}

{% block scripts %}
<script async src="{{ url_for('static', path=asset_url('member_display.js')) }}" type="module"></script>
{% endblock%}

{% block content %}
{% if message %}
<div class="alert alert-warning" role="alert">{{ message | safe }}</div>
{% endif %}
<div id="contentDiv"></div>
{% endblock %}
