{% extends "layout.html.j2" %}

{% block content %}
<div class="container">
    <div class="text-center mt-5">
        <h1 class="display-1">403</h1>
        <h2>Forbidden</h2>
        <p class="lead">You don't have permission to access this resource.</p>
        <a class="btn btn-primary" href="{{ url_for('index') }}">Go to Home</a>
    </div>
</div>
{% endblock %}

