// modules are defined as an array
// [ module function, map of requires ]
//
// map of requires is short require name -> numeric require
//
// anything defined in a previous bundle is accessed via the
// orig method which is the require for previous bundles

(function (
  modules,
  entry,
  mainEntry,
  parcelRequireName,
  externals,
  distDir,
  publicUrl,
  devServer
) {
  /* eslint-disable no-undef */
  var globalObject =
    typeof globalThis !== 'undefined'
      ? globalThis
      : typeof self !== 'undefined'
      ? self
      : typeof window !== 'undefined'
      ? window
      : typeof global !== 'undefined'
      ? global
      : {};
  /* eslint-enable no-undef */

  // Save the require from previous bundle to this closure if any
  var previousRequire =
    typeof globalObject[parcelRequireName] === 'function' &&
    globalObject[parcelRequireName];

  var importMap = previousRequire.i || {};
  var cache = previousRequire.cache || {};
  // Do not use `require` to prevent Webpack from trying to bundle this call
  var nodeRequire =
    typeof module !== 'undefined' &&
    typeof module.require === 'function' &&
    module.require.bind(module);

  function newRequire(name, jumped) {
    if (!cache[name]) {
      if (!modules[name]) {
        if (externals[name]) {
          return externals[name];
        }
        // if we cannot find the module within our internal map or
        // cache jump to the current global require ie. the last bundle
        // that was added to the page.
        var currentRequire =
          typeof globalObject[parcelRequireName] === 'function' &&
          globalObject[parcelRequireName];
        if (!jumped && currentRequire) {
          return currentRequire(name, true);
        }

        // If there are other bundles on this page the require from the
        // previous one is saved to 'previousRequire'. Repeat this as
        // many times as there are bundles until the module is found or
        // we exhaust the require chain.
        if (previousRequire) {
          return previousRequire(name, true);
        }

        // Try the node require function if it exists.
        if (nodeRequire && typeof name === 'string') {
          return nodeRequire(name);
        }

        var err = new Error("Cannot find module '" + name + "'");
        err.code = 'MODULE_NOT_FOUND';
        throw err;
      }

      localRequire.resolve = resolve;
      localRequire.cache = {};

      var module = (cache[name] = new newRequire.Module(name));

      modules[name][0].call(
        module.exports,
        localRequire,
        module,
        module.exports,
        globalObject
      );
    }

    return cache[name].exports;

    function localRequire(x) {
      var res = localRequire.resolve(x);
      if (res === false) {
        return {};
      }
      // Synthesize a module to follow re-exports.
      if (Array.isArray(res)) {
        var m = {__esModule: true};
        res.forEach(function (v) {
          var key = v[0];
          var id = v[1];
          var exp = v[2] || v[0];
          var x = newRequire(id);
          if (key === '*') {
            Object.keys(x).forEach(function (key) {
              if (
                key === 'default' ||
                key === '__esModule' ||
                Object.prototype.hasOwnProperty.call(m, key)
              ) {
                return;
              }

              Object.defineProperty(m, key, {
                enumerable: true,
                get: function () {
                  return x[key];
                },
              });
            });
          } else if (exp === '*') {
            Object.defineProperty(m, key, {
              enumerable: true,
              value: x,
            });
          } else {
            Object.defineProperty(m, key, {
              enumerable: true,
              get: function () {
                if (exp === 'default') {
                  return x.__esModule ? x.default : x;
                }
                return x[exp];
              },
            });
          }
        });
        return m;
      }
      return newRequire(res);
    }

    function resolve(x) {
      var id = modules[name][1][x];
      return id != null ? id : x;
    }
  }

  function Module(moduleName) {
    this.id = moduleName;
    this.bundle = newRequire;
    this.require = nodeRequire;
    this.exports = {};
  }

  newRequire.isParcelRequire = true;
  newRequire.Module = Module;
  newRequire.modules = modules;
  newRequire.cache = cache;
  newRequire.parent = previousRequire;
  newRequire.distDir = distDir;
  newRequire.publicUrl = publicUrl;
  newRequire.devServer = devServer;
  newRequire.i = importMap;
  newRequire.register = function (id, exports) {
    modules[id] = [
      function (require, module) {
        module.exports = exports;
      },
      {},
    ];
  };

  // Only insert newRequire.load when it is actually used.
  // The code in this file is linted against ES5, so dynamic import is not allowed.
  // INSERT_LOAD_HERE

  Object.defineProperty(newRequire, 'root', {
    get: function () {
      return globalObject[parcelRequireName];
    },
  });

  globalObject[parcelRequireName] = newRequire;

  for (var i = 0; i < entry.length; i++) {
    newRequire(entry[i]);
  }

  if (mainEntry) {
    // Expose entry point to Node, AMD or browser globals
    // Based on https://github.com/ForbesLindesay/umd/blob/master/template.js
    var mainExports = newRequire(mainEntry);

    // CommonJS
    if (typeof exports === 'object' && typeof module !== 'undefined') {
      module.exports = mainExports;

      // RequireJS
    } else if (typeof define === 'function' && define.amd) {
      define(function () {
        return mainExports;
      });
    }
  }
})({"ca6OP":[function(require,module,exports,__globalThis) {
var global = arguments[3];
var HMR_HOST = null;
var HMR_PORT = 1234;
var HMR_SERVER_PORT = 1234;
var HMR_SECURE = false;
var HMR_ENV_HASH = "d6ea1d42532a7575";
var HMR_USE_SSE = false;
module.bundle.HMR_BUNDLE_ID = "709cf0f77962262f";
"use strict";
/* global HMR_HOST, HMR_PORT, HMR_SERVER_PORT, HMR_ENV_HASH, HMR_SECURE, HMR_USE_SSE, chrome, browser, __parcel__import__, __parcel__importScripts__, ServiceWorkerGlobalScope */ /*::
import type {
  HMRAsset,
  HMRMessage,
} from '@parcel/reporter-dev-server/src/HMRServer.js';
interface ParcelRequire {
  (string): mixed;
  cache: {|[string]: ParcelModule|};
  hotData: {|[string]: mixed|};
  Module: any;
  parent: ?ParcelRequire;
  isParcelRequire: true;
  modules: {|[string]: [Function, {|[string]: string|}]|};
  HMR_BUNDLE_ID: string;
  root: ParcelRequire;
}
interface ParcelModule {
  hot: {|
    data: mixed,
    accept(cb: (Function) => void): void,
    dispose(cb: (mixed) => void): void,
    // accept(deps: Array<string> | string, cb: (Function) => void): void,
    // decline(): void,
    _acceptCallbacks: Array<(Function) => void>,
    _disposeCallbacks: Array<(mixed) => void>,
  |};
}
interface ExtensionContext {
  runtime: {|
    reload(): void,
    getURL(url: string): string;
    getManifest(): {manifest_version: number, ...};
  |};
}
declare var module: {bundle: ParcelRequire, ...};
declare var HMR_HOST: string;
declare var HMR_PORT: string;
declare var HMR_SERVER_PORT: string;
declare var HMR_ENV_HASH: string;
declare var HMR_SECURE: boolean;
declare var HMR_USE_SSE: boolean;
declare var chrome: ExtensionContext;
declare var browser: ExtensionContext;
declare var __parcel__import__: (string) => Promise<void>;
declare var __parcel__importScripts__: (string) => Promise<void>;
declare var globalThis: typeof self;
declare var ServiceWorkerGlobalScope: Object;
*/ var OVERLAY_ID = '__parcel__error__overlay__';
var OldModule = module.bundle.Module;
function Module(moduleName) {
    OldModule.call(this, moduleName);
    this.hot = {
        data: module.bundle.hotData[moduleName],
        _acceptCallbacks: [],
        _disposeCallbacks: [],
        accept: function(fn) {
            this._acceptCallbacks.push(fn || function() {});
        },
        dispose: function(fn) {
            this._disposeCallbacks.push(fn);
        }
    };
    module.bundle.hotData[moduleName] = undefined;
}
module.bundle.Module = Module;
module.bundle.hotData = {};
var checkedAssets /*: {|[string]: boolean|} */ , disposedAssets /*: {|[string]: boolean|} */ , assetsToDispose /*: Array<[ParcelRequire, string]> */ , assetsToAccept /*: Array<[ParcelRequire, string]> */ , bundleNotFound = false;
function getHostname() {
    return HMR_HOST || (typeof location !== 'undefined' && location.protocol.indexOf('http') === 0 ? location.hostname : 'localhost');
}
function getPort() {
    return HMR_PORT || (typeof location !== 'undefined' ? location.port : HMR_SERVER_PORT);
}
// eslint-disable-next-line no-redeclare
let WebSocket = globalThis.WebSocket;
if (!WebSocket && typeof module.bundle.root === 'function') try {
    // eslint-disable-next-line no-global-assign
    WebSocket = module.bundle.root('ws');
} catch  {
// ignore.
}
var hostname = getHostname();
var port = getPort();
var protocol = HMR_SECURE || typeof location !== 'undefined' && location.protocol === 'https:' && ![
    'localhost',
    '127.0.0.1',
    '0.0.0.0'
].includes(hostname) ? 'wss' : 'ws';
// eslint-disable-next-line no-redeclare
var parent = module.bundle.parent;
if (!parent || !parent.isParcelRequire) {
    // Web extension context
    var extCtx = typeof browser === 'undefined' ? typeof chrome === 'undefined' ? null : chrome : browser;
    // Safari doesn't support sourceURL in error stacks.
    // eval may also be disabled via CSP, so do a quick check.
    var supportsSourceURL = false;
    try {
        (0, eval)('throw new Error("test"); //# sourceURL=test.js');
    } catch (err) {
        supportsSourceURL = err.stack.includes('test.js');
    }
    var ws;
    if (HMR_USE_SSE) ws = new EventSource('/__parcel_hmr');
    else try {
        // If we're running in the dev server's node runner, listen for messages on the parent port.
        let { workerData, parentPort } = module.bundle.root('node:worker_threads') /*: any*/ ;
        if (workerData !== null && workerData !== void 0 && workerData.__parcel) {
            parentPort.on('message', async (message)=>{
                try {
                    await handleMessage(message);
                    parentPort.postMessage('updated');
                } catch  {
                    parentPort.postMessage('restart');
                }
            });
            // After the bundle has finished running, notify the dev server that the HMR update is complete.
            queueMicrotask(()=>parentPort.postMessage('ready'));
        }
    } catch  {
        if (typeof WebSocket !== 'undefined') try {
            ws = new WebSocket(protocol + '://' + hostname + (port ? ':' + port : '') + '/');
        } catch (err) {
            // Ignore cloudflare workers error.
            if (err.message && !err.message.includes('Disallowed operation called within global scope')) console.error(err.message);
        }
    }
    if (ws) {
        // $FlowFixMe
        ws.onmessage = async function(event /*: {data: string, ...} */ ) {
            var data /*: HMRMessage */  = JSON.parse(event.data);
            await handleMessage(data);
        };
        if (ws instanceof WebSocket) {
            ws.onerror = function(e) {
                if (e.message) console.error(e.message);
            };
            ws.onclose = function() {
                console.warn("[parcel] \uD83D\uDEA8 Connection to the HMR server was lost");
            };
        }
    }
}
async function handleMessage(data /*: HMRMessage */ ) {
    checkedAssets = {} /*: {|[string]: boolean|} */ ;
    disposedAssets = {} /*: {|[string]: boolean|} */ ;
    assetsToAccept = [];
    assetsToDispose = [];
    bundleNotFound = false;
    if (data.type === 'reload') fullReload();
    else if (data.type === 'update') {
        // Remove error overlay if there is one
        if (typeof document !== 'undefined') removeErrorOverlay();
        let assets = data.assets;
        // Handle HMR Update
        let handled = assets.every((asset)=>{
            return asset.type === 'css' || asset.type === 'js' && hmrAcceptCheck(module.bundle.root, asset.id, asset.depsByBundle);
        });
        // Dispatch a custom event in case a bundle was not found. This might mean
        // an asset on the server changed and we should reload the page. This event
        // gives the client an opportunity to refresh without losing state
        // (e.g. via React Server Components). If e.preventDefault() is not called,
        // we will trigger a full page reload.
        if (handled && bundleNotFound && assets.some((a)=>a.envHash !== HMR_ENV_HASH) && typeof window !== 'undefined' && typeof CustomEvent !== 'undefined') handled = !window.dispatchEvent(new CustomEvent('parcelhmrreload', {
            cancelable: true
        }));
        if (handled) {
            console.clear();
            // Dispatch custom event so other runtimes (e.g React Refresh) are aware.
            if (typeof window !== 'undefined' && typeof CustomEvent !== 'undefined') window.dispatchEvent(new CustomEvent('parcelhmraccept'));
            await hmrApplyUpdates(assets);
            hmrDisposeQueue();
            // Run accept callbacks. This will also re-execute other disposed assets in topological order.
            let processedAssets = {};
            for(let i = 0; i < assetsToAccept.length; i++){
                let id = assetsToAccept[i][1];
                if (!processedAssets[id]) {
                    hmrAccept(assetsToAccept[i][0], id);
                    processedAssets[id] = true;
                }
            }
        } else fullReload();
    }
    if (data.type === 'error') {
        // Log parcel errors to console
        for (let ansiDiagnostic of data.diagnostics.ansi){
            let stack = ansiDiagnostic.codeframe ? ansiDiagnostic.codeframe : ansiDiagnostic.stack;
            console.error("\uD83D\uDEA8 [parcel]: " + ansiDiagnostic.message + '\n' + stack + '\n\n' + ansiDiagnostic.hints.join('\n'));
        }
        if (typeof document !== 'undefined') {
            // Render the fancy html overlay
            removeErrorOverlay();
            var overlay = createErrorOverlay(data.diagnostics.html);
            // $FlowFixMe
            document.body.appendChild(overlay);
        }
    }
}
function removeErrorOverlay() {
    var overlay = document.getElementById(OVERLAY_ID);
    if (overlay) {
        overlay.remove();
        console.log("[parcel] \u2728 Error resolved");
    }
}
function createErrorOverlay(diagnostics) {
    var overlay = document.createElement('div');
    overlay.id = OVERLAY_ID;
    let errorHTML = '<div style="background: black; opacity: 0.85; font-size: 16px; color: white; position: fixed; height: 100%; width: 100%; top: 0px; left: 0px; padding: 30px; font-family: Menlo, Consolas, monospace; z-index: 9999;">';
    for (let diagnostic of diagnostics){
        let stack = diagnostic.frames.length ? diagnostic.frames.reduce((p, frame)=>{
            return `${p}
<a href="${protocol === 'wss' ? 'https' : 'http'}://${hostname}:${port}/__parcel_launch_editor?file=${encodeURIComponent(frame.location)}" style="text-decoration: underline; color: #888" onclick="fetch(this.href); return false">${frame.location}</a>
${frame.code}`;
        }, '') : diagnostic.stack;
        errorHTML += `
      <div>
        <div style="font-size: 18px; font-weight: bold; margin-top: 20px;">
          \u{1F6A8} ${diagnostic.message}
        </div>
        <pre>${stack}</pre>
        <div>
          ${diagnostic.hints.map((hint)=>"<div>\uD83D\uDCA1 " + hint + '</div>').join('')}
        </div>
        ${diagnostic.documentation ? `<div>\u{1F4DD} <a style="color: violet" href="${diagnostic.documentation}" target="_blank">Learn more</a></div>` : ''}
      </div>
    `;
    }
    errorHTML += '</div>';
    overlay.innerHTML = errorHTML;
    return overlay;
}
function fullReload() {
    if (typeof location !== 'undefined' && 'reload' in location) location.reload();
    else if (typeof extCtx !== 'undefined' && extCtx && extCtx.runtime && extCtx.runtime.reload) extCtx.runtime.reload();
    else try {
        let { workerData, parentPort } = module.bundle.root('node:worker_threads') /*: any*/ ;
        if (workerData !== null && workerData !== void 0 && workerData.__parcel) parentPort.postMessage('restart');
    } catch (err) {
        console.error("[parcel] \u26A0\uFE0F An HMR update was not accepted. Please restart the process.");
    }
}
function getParents(bundle, id) /*: Array<[ParcelRequire, string]> */ {
    var modules = bundle.modules;
    if (!modules) return [];
    var parents = [];
    var k, d, dep;
    for(k in modules)for(d in modules[k][1]){
        dep = modules[k][1][d];
        if (dep === id || Array.isArray(dep) && dep[dep.length - 1] === id) parents.push([
            bundle,
            k
        ]);
    }
    if (bundle.parent) parents = parents.concat(getParents(bundle.parent, id));
    return parents;
}
function updateLink(link) {
    var href = link.getAttribute('href');
    if (!href) return;
    var newLink = link.cloneNode();
    newLink.onload = function() {
        if (link.parentNode !== null) // $FlowFixMe
        link.parentNode.removeChild(link);
    };
    newLink.setAttribute('href', // $FlowFixMe
    href.split('?')[0] + '?' + Date.now());
    // $FlowFixMe
    link.parentNode.insertBefore(newLink, link.nextSibling);
}
var cssTimeout = null;
function reloadCSS() {
    if (cssTimeout || typeof document === 'undefined') return;
    cssTimeout = setTimeout(function() {
        var links = document.querySelectorAll('link[rel="stylesheet"]');
        for(var i = 0; i < links.length; i++){
            // $FlowFixMe[incompatible-type]
            var href /*: string */  = links[i].getAttribute('href');
            var hostname = getHostname();
            var servedFromHMRServer = hostname === 'localhost' ? new RegExp('^(https?:\\/\\/(0.0.0.0|127.0.0.1)|localhost):' + getPort()).test(href) : href.indexOf(hostname + ':' + getPort());
            var absolute = /^https?:\/\//i.test(href) && href.indexOf(location.origin) !== 0 && !servedFromHMRServer;
            if (!absolute) updateLink(links[i]);
        }
        cssTimeout = null;
    }, 50);
}
function hmrDownload(asset) {
    if (asset.type === 'js') {
        if (typeof document !== 'undefined') {
            let script = document.createElement('script');
            script.src = asset.url + '?t=' + Date.now();
            if (asset.outputFormat === 'esmodule') script.type = 'module';
            return new Promise((resolve, reject)=>{
                var _document$head;
                script.onload = ()=>resolve(script);
                script.onerror = reject;
                (_document$head = document.head) === null || _document$head === void 0 || _document$head.appendChild(script);
            });
        } else if (typeof importScripts === 'function') {
            // Worker scripts
            if (asset.outputFormat === 'esmodule') return import(asset.url + '?t=' + Date.now());
            else return new Promise((resolve, reject)=>{
                try {
                    importScripts(asset.url + '?t=' + Date.now());
                    resolve();
                } catch (err) {
                    reject(err);
                }
            });
        }
    }
}
async function hmrApplyUpdates(assets) {
    global.parcelHotUpdate = Object.create(null);
    let scriptsToRemove;
    try {
        // If sourceURL comments aren't supported in eval, we need to load
        // the update from the dev server over HTTP so that stack traces
        // are correct in errors/logs. This is much slower than eval, so
        // we only do it if needed (currently just Safari).
        // https://bugs.webkit.org/show_bug.cgi?id=137297
        // This path is also taken if a CSP disallows eval.
        if (!supportsSourceURL) {
            let promises = assets.map((asset)=>{
                var _hmrDownload;
                return (_hmrDownload = hmrDownload(asset)) === null || _hmrDownload === void 0 ? void 0 : _hmrDownload.catch((err)=>{
                    // Web extension fix
                    if (extCtx && extCtx.runtime && extCtx.runtime.getManifest().manifest_version == 3 && typeof ServiceWorkerGlobalScope != 'undefined' && global instanceof ServiceWorkerGlobalScope) {
                        extCtx.runtime.reload();
                        return;
                    }
                    throw err;
                });
            });
            scriptsToRemove = await Promise.all(promises);
        }
        assets.forEach(function(asset) {
            hmrApply(module.bundle.root, asset);
        });
    } finally{
        delete global.parcelHotUpdate;
        if (scriptsToRemove) scriptsToRemove.forEach((script)=>{
            if (script) {
                var _document$head2;
                (_document$head2 = document.head) === null || _document$head2 === void 0 || _document$head2.removeChild(script);
            }
        });
    }
}
function hmrApply(bundle /*: ParcelRequire */ , asset /*:  HMRAsset */ ) {
    var modules = bundle.modules;
    if (!modules) return;
    if (asset.type === 'css') reloadCSS();
    else if (asset.type === 'js') {
        let deps = asset.depsByBundle[bundle.HMR_BUNDLE_ID];
        if (deps) {
            if (modules[asset.id]) {
                // Remove dependencies that are removed and will become orphaned.
                // This is necessary so that if the asset is added back again, the cache is gone, and we prevent a full page reload.
                let oldDeps = modules[asset.id][1];
                for(let dep in oldDeps)if (!deps[dep] || deps[dep] !== oldDeps[dep]) {
                    let id = oldDeps[dep];
                    let parents = getParents(module.bundle.root, id);
                    if (parents.length === 1) hmrDelete(module.bundle.root, id);
                }
            }
            if (supportsSourceURL) // Global eval. We would use `new Function` here but browser
            // support for source maps is better with eval.
            (0, eval)(asset.output);
            // $FlowFixMe
            let fn = global.parcelHotUpdate[asset.id];
            modules[asset.id] = [
                fn,
                deps
            ];
        }
        // Always traverse to the parent bundle, even if we already replaced the asset in this bundle.
        // This is required in case modules are duplicated. We need to ensure all instances have the updated code.
        if (bundle.parent) hmrApply(bundle.parent, asset);
    }
}
function hmrDelete(bundle, id) {
    let modules = bundle.modules;
    if (!modules) return;
    if (modules[id]) {
        // Collect dependencies that will become orphaned when this module is deleted.
        let deps = modules[id][1];
        let orphans = [];
        for(let dep in deps){
            let parents = getParents(module.bundle.root, deps[dep]);
            if (parents.length === 1) orphans.push(deps[dep]);
        }
        // Delete the module. This must be done before deleting dependencies in case of circular dependencies.
        delete modules[id];
        delete bundle.cache[id];
        // Now delete the orphans.
        orphans.forEach((id)=>{
            hmrDelete(module.bundle.root, id);
        });
    } else if (bundle.parent) hmrDelete(bundle.parent, id);
}
function hmrAcceptCheck(bundle /*: ParcelRequire */ , id /*: string */ , depsByBundle /*: ?{ [string]: { [string]: string } }*/ ) {
    checkedAssets = {};
    if (hmrAcceptCheckOne(bundle, id, depsByBundle)) return true;
    // Traverse parents breadth first. All possible ancestries must accept the HMR update, or we'll reload.
    let parents = getParents(module.bundle.root, id);
    let accepted = false;
    while(parents.length > 0){
        let v = parents.shift();
        let a = hmrAcceptCheckOne(v[0], v[1], null);
        if (a) // If this parent accepts, stop traversing upward, but still consider siblings.
        accepted = true;
        else if (a !== null) {
            // Otherwise, queue the parents in the next level upward.
            let p = getParents(module.bundle.root, v[1]);
            if (p.length === 0) {
                // If there are no parents, then we've reached an entry without accepting. Reload.
                accepted = false;
                break;
            }
            parents.push(...p);
        }
    }
    return accepted;
}
function hmrAcceptCheckOne(bundle /*: ParcelRequire */ , id /*: string */ , depsByBundle /*: ?{ [string]: { [string]: string } }*/ ) {
    var modules = bundle.modules;
    if (!modules) return;
    if (depsByBundle && !depsByBundle[bundle.HMR_BUNDLE_ID]) {
        // If we reached the root bundle without finding where the asset should go,
        // there's nothing to do. Mark as "accepted" so we don't reload the page.
        if (!bundle.parent) {
            bundleNotFound = true;
            return true;
        }
        return hmrAcceptCheckOne(bundle.parent, id, depsByBundle);
    }
    if (checkedAssets[id]) return null;
    checkedAssets[id] = true;
    var cached = bundle.cache[id];
    if (!cached) return true;
    assetsToDispose.push([
        bundle,
        id
    ]);
    if (cached && cached.hot && cached.hot._acceptCallbacks.length) {
        assetsToAccept.push([
            bundle,
            id
        ]);
        return true;
    }
    return false;
}
function hmrDisposeQueue() {
    // Dispose all old assets.
    for(let i = 0; i < assetsToDispose.length; i++){
        let id = assetsToDispose[i][1];
        if (!disposedAssets[id]) {
            hmrDispose(assetsToDispose[i][0], id);
            disposedAssets[id] = true;
        }
    }
    assetsToDispose = [];
}
function hmrDispose(bundle /*: ParcelRequire */ , id /*: string */ ) {
    var cached = bundle.cache[id];
    bundle.hotData[id] = {};
    if (cached && cached.hot) cached.hot.data = bundle.hotData[id];
    if (cached && cached.hot && cached.hot._disposeCallbacks.length) cached.hot._disposeCallbacks.forEach(function(cb) {
        cb(bundle.hotData[id]);
    });
    delete bundle.cache[id];
}
function hmrAccept(bundle /*: ParcelRequire */ , id /*: string */ ) {
    // Execute the module.
    bundle(id);
    // Run the accept callbacks in the new version of the module.
    var cached = bundle.cache[id];
    if (cached && cached.hot && cached.hot._acceptCallbacks.length) {
        let assetsToAlsoAccept = [];
        cached.hot._acceptCallbacks.forEach(function(cb) {
            let additionalAssets = cb(function() {
                return getParents(module.bundle.root, id);
            });
            if (Array.isArray(additionalAssets) && additionalAssets.length) assetsToAlsoAccept.push(...additionalAssets);
        });
        if (assetsToAlsoAccept.length) {
            let handled = assetsToAlsoAccept.every(function(a) {
                return hmrAcceptCheck(a[0], a[1]);
            });
            if (!handled) return fullReload();
            hmrDisposeQueue();
        }
    }
}

},{}],"bxZDA":[function(require,module,exports,__globalThis) {
var _base = require("./base");
var _d = require("./d");
var _member = require("./member");
var _events = require("./events");
var _utils = require("./utils");
var _bootstrap = require("bootstrap");
var _luxon = require("luxon");
class PasswordModal extends _base.Modal {
    token;
    email;
    password;
    constructor(el){
        super(el);
        this.modal_title.innerText = "Set your password";
        const form = _base.create_append(this.modal_body, "form", [
            "w-100"
        ]);
        this.email = _base.create_append(form, "input", [
            "form-control",
            "me-2",
            "mb-2"
        ], {
            name: "username"
        });
        this.email.disabled = true;
        this.password = _base.create_append(form, "input", [
            "form-control",
            "me-2",
            "mb-2"
        ], {
            type: "password",
            name: "new-password",
            autocomplete: "new-password",
            placeholder: "New Password"
        });
        _base.create_append(form, "button", [
            "btn",
            "btn-primary"
        ], {
            type: "submit"
        }).innerText = "Submit";
        form.addEventListener("submit", async (ev)=>{
            ev.preventDefault();
            await this.submit();
        });
        this.modal_div.addEventListener("shown.bs.modal", ()=>{
            this.password.focus();
        });
    }
    show(token, email) {
        this.token = token;
        this.email.value = email;
        this.modal.show();
    }
    async submit() {
        const res = await _base.do_fetch_with_token("/api/vekn/members/password", this.token, {
            method: "post",
            body: JSON.stringify({
                password: this.password.value
            })
        });
        if (res) this.modal.hide();
    }
}
class MemberDisplay {
    root;
    token;
    member;
    target;
    countries;
    cities;
    vekn_modal;
    password_modal;
    tooltips;
    // form
    name;
    email;
    whatsapp;
    country_select;
    city_select;
    constructor(root){
        this.root = root;
        this.vekn_modal = new _member.ExistingVeknModal(root, (member)=>this.reload_target(member));
        this.password_modal = new PasswordModal(root);
        this.tooltips = new _base.TooltipManager();
    }
    async init(token, url, countries) {
        this.token = token;
        if (countries) this.countries = new Map(countries.map((c)=>[
                c.country,
                c
            ]));
        else {
            const res = await _base.do_fetch("/api/vekn/country", {});
            const countries = await res.json();
            this.countries = new Map(countries.map((c)=>[
                    c.country,
                    c
                ]));
        }
        const user_id = _base.user_uid_from_token(token);
        const member_fetch = await _base.do_fetch_with_token(`/api/vekn/members/${user_id}`, token, {});
        this.member = await member_fetch.json();
        if (url.pathname.endsWith("display.html")) {
            const uid = url.pathname.split("/")[2];
            const res = await _base.do_fetch_with_token(`/api/vekn/members/${uid}`, token, {});
            this.target = await res.json();
        } else this.target = this.member;
        if (this.target.country) await this.load_cities();
        else this.cities = new Map();
        await this.vekn_modal.init(this.token, user_id, this.target.uid);
        this.display();
        // when coming from the reset password link, show the modal directly
        if (url.searchParams.has("reset")) this.password_modal.show(this.token, this.member.email ?? "");
    }
    display() {
        this.tooltips.dispose();
        _base.remove_children(this.root);
        const header = _base.create_append(this.root, "h1", [
            "mt-4",
            "mb-2",
            "d-md-flex",
            "align-items-center"
        ]);
        _base.create_append(header, "div", [
            "me-2",
            "mb-2"
        ]).innerText = `${this.target.name}`;
        if (this.target.vekn && this.target.vekn.length > 0) {
            const vekn_badge = _base.create_append(header, "span", [
                "badge",
                "me-2",
                "mb-2",
                "fs-5",
                "align-text-top",
                "text-bg-secondary"
            ]);
            _base.create_append(vekn_badge, "i", [
                "bi",
                "bi-person-check"
            ]);
            vekn_badge.append(document.createTextNode(` ${this.target.vekn}`));
            if (_member.can_change_vekn(this.member, this.target)) {
                const remove = _base.create_append(vekn_badge, "button", [
                    "btn",
                    "ms-2",
                    "btn-danger",
                    "rounded-pill",
                    "px-1",
                    "py-0",
                    "border-0"
                ], {
                    role: "button"
                });
                _base.create_append(remove, "i", [
                    "bi",
                    "bi-x"
                ]);
                this.tooltips.add(remove, "Disassociate VEKN ID#");
                remove.addEventListener("click", (ev)=>{
                    this.remove_vekn();
                });
            }
        } else {
            if (_member.can_organize(this.member)) {
                const sponsor = _base.create_append(header, "button", [
                    "btn",
                    "me-2",
                    "mb-2",
                    "btn-success"
                ], {
                    role: "button"
                });
                _base.create_append(sponsor, "i", [
                    "bi",
                    "bi-person-check"
                ]);
                sponsor.append(document.createTextNode(" New VEKN#"));
                sponsor.addEventListener("click", (ev)=>this.new_vekn());
            }
            if (_member.can_change_vekn(this.member, this.target)) {
                const assign = _base.create_append(header, "button", [
                    "btn",
                    "me-2",
                    "mb-2",
                    "btn-warning"
                ], {
                    role: "button"
                });
                _base.create_append(assign, "i", [
                    "bi",
                    "bi-person-check"
                ]);
                assign.append(document.createTextNode(" Existing VEKN#"));
                assign.addEventListener("click", (ev)=>this.vekn_modal.init(this.token, this.member.uid, this.target.uid).then(()=>this.vekn_modal.show()));
            }
        }
        if (this.target.uid == this.member.uid && this.target.email) {
            const logout = _base.create_append(header, "a", [
                "btn",
                "me-2",
                "mb-2",
                "btn-secondary",
                "align-text-top"
            ], {
                role: "button",
                href: "/auth/logout/"
            });
            _base.create_append(logout, "i", [
                "bi",
                "bi-box-arrow-left"
            ]);
            logout.append(document.createTextNode(" Logout"));
            const reset_password = _base.create_append(header, "button", [
                "btn",
                "me-2",
                "mb-2",
                "btn-secondary",
                "align-text-top"
            ]);
            reset_password.innerText = "Set Password";
            reset_password.addEventListener("click", (ev)=>this.password_modal.show(this.token, this.target.email));
        }
        const badges_row = _base.create_append(this.root, "div", [
            "d-md-flex",
            "align-items-center"
        ]);
        for (const role of this.target.roles){
            const role_badge = _base.create_append(badges_row, "div", [
                "badge",
                "me-2",
                "mb-2"
            ]);
            var remove_button;
            if (_member.can_change_role(this.member, this.target, role)) {
                role_badge.append(document.createTextNode(`${role} `));
                remove_button = _base.create_append(role_badge, "button", [
                    "btn",
                    "ms-1",
                    "p-0",
                    "border-0"
                ], {
                    role: "button"
                });
                _base.create_append(remove_button, "i", [
                    "bi",
                    "bi-x-circle-fill"
                ]);
                this.tooltips.add(remove_button, "Remove role");
                remove_button.addEventListener("click", (ev)=>{
                    this.remove_role(role);
                });
            } else role_badge.innerText = role;
            switch(role){
                case _d.MemberRole.ADMIN:
                    role_badge.classList.add("text-bg-primary");
                    if (remove_button) remove_button.classList.add("text-light");
                    break;
                case _d.MemberRole.NC:
                    role_badge.classList.add("text-bg-success");
                    if (remove_button) remove_button.classList.add("text-light");
                    break;
                case _d.MemberRole.JUDGE:
                    role_badge.classList.add("text-bg-warning");
                    break;
                case _d.MemberRole.RULEMONGER:
                    role_badge.classList.add("text-bg-warning");
                    break;
                case _d.MemberRole.PRINCE:
                    role_badge.classList.add("text-bg-info");
                    break;
                default:
                    role_badge.classList.add("text-bg-secondary");
                    if (remove_button) remove_button.classList.add("text-light");
                    break;
            }
        }
        const addable_roles = [
            ...Object.values(_d.MemberRole).filter((r)=>!this.target.roles.includes(r) && _member.can_change_role(this.member, this.target, r))
        ];
        if (addable_roles.length > 0) {
            const div = _base.create_append(badges_row, "div", [
                "dropdown"
            ]);
            const button = _base.create_append(div, "button", [
                "btn",
                "btn-primary",
                "dropdown-toggle",
                "me-2",
                "mb-2"
            ], {
                type: "button",
                "data-bs-toggle": "dropdown",
                "aria-expanded": "false"
            });
            _base.create_append(button, "i", [
                "bi",
                "bi-plus"
            ]);
            const list = _base.create_append(div, "ul", [
                "dropdown-menu"
            ]);
            for (const role of addable_roles){
                const li = _base.create_append(list, "li");
                const action = _base.create_append(li, "a", [
                    "dropdown-item"
                ], {
                    href: "#",
                    role: "button"
                });
                action.addEventListener("click", (ev)=>{
                    ev.preventDefault();
                    this.add_role(role);
                });
                action.innerText = role;
            }
        }
        const form = _base.create_append(this.root, "form");
        const cci = _member.can_change_info(this.member, this.target);
        // ________________________________________________________________________________________ Row 1: Personal info
        const row_1 = _base.create_append(form, "div", [
            "d-md-flex"
        ]);
        // ________________________________________________________________________________________________________ Name
        {
            const div = _base.create_append(row_1, "div", [
                "input-group",
                "form-floating",
                "me-2",
                "mb-2"
            ]);
            this.name = _base.create_append(div, "input", [
                "form-control"
            ], {
                type: "text",
                id: "memberFormName",
                name: "name",
                "aria-label": "Name",
                autocomplete: "name"
            });
            _base.create_append(div, "label", [
                "form-label"
            ], {
                for: "memberFormName"
            }).innerText = "Name";
            this.name.spellcheck = false;
            this.name.value = this.target.name;
            if (cci) this.name.addEventListener("change", _base.debounce((ev)=>this.change_info()));
            else this.name.disabled = true;
        }
        // _____________________________________________________________________________________________________ Country
        {
            const div = _base.create_append(row_1, "div", [
                "input-group",
                "form-floating",
                "me-2",
                "mb-2"
            ]);
            this.country_select = _base.create_append(div, "select", [
                "form-select"
            ], {
                name: "country",
                id: "selectCountry",
                "aria-label": "Country",
                autocomplete: "country-name"
            });
            _base.create_append(div, "label", [
                "form-label"
            ], {
                for: "selectCountry"
            }).innerText = "Country";
            const option = _base.create_element("option");
            option.value = "";
            option.label = "";
            this.country_select.options.add(option);
            for (const country of this.countries.values()){
                const option = _base.create_element("option");
                option.value = country.country;
                option.label = `${country.country} ${country.flag}`;
                if (this.target.country == country.country) option.selected = true;
                this.country_select.options.add(option);
            }
            if (cci) this.country_select.addEventListener("change", _base.debounce((ev)=>this.change_info()));
            else this.country_select.disabled = true;
        }
        // ________________________________________________________________________________________________________ City
        {
            const div = _base.create_append(row_1, "div", [
                "input-group",
                "form-floating",
                "me-2",
                "mb-2"
            ]);
            this.city_select = _base.create_append(div, "select", [
                "form-select"
            ], {
                name: "city",
                id: "selectCity",
                "aria-label": "City",
                autocomplete: "address-level2"
            });
            _base.create_append(div, "label", [
                "form-label"
            ], {
                for: "selectCity"
            }).innerText = "City";
            const option = _base.create_element("option");
            option.value = "";
            option.label = "";
            this.city_select.options.add(option);
            for (const city of this.cities.values()){
                const option = _base.create_element("option");
                option.value = city.unique_name;
                option.label = city.unique_name;
                if (this.target.city == city.unique_name) option.selected = true;
                this.city_select.options.add(option);
            }
            if (cci && this.cities.size > 0) this.city_select.addEventListener("change", _base.debounce((ev)=>this.change_info()));
            else this.city_select.disabled = true;
        }
        // _________________________________________________________________________________________ Row 2: Contact info
        if (_member.can_contact(this.member, this.target)) {
            const row_2 = _base.create_append(form, "div", [
                "d-md-flex"
            ]);
            // __________________________________________________________________________________________________ E-mail
            if (this.target.email || cci) {
                const div = _base.create_append(row_2, "div", [
                    "input-group",
                    "me-2",
                    "mb-2"
                ]);
                _base.create_append(div, "span", [
                    "input-group-text"
                ]).innerHTML = '<i class="bi bi-envelope"></i>';
                this.email = _base.create_append(div, "input", [
                    "form-control"
                ], {
                    type: "text",
                    placeholder: "Email",
                    name: "email",
                    "aria-label": "Email",
                    autocomplete: "email"
                });
                this.email.spellcheck = false;
                this.email.value = this.target.email ?? "";
                if (cci) this.email.addEventListener("change", _base.debounce((ev)=>this.change_info()));
                else this.email.disabled = true;
                if (cci && this.email.value && this.member.uid != this.target.uid) {
                    const reset_button = _base.create_append(row_2, "button", [
                        "btn",
                        "btn-primary",
                        "me-2",
                        "mb-2",
                        "text-nowrap"
                    ], {
                        type: "button"
                    });
                    reset_button.innerText = "Reset password";
                    const form_data = new FormData();
                    form_data.set("email", this.email.value);
                    reset_button.addEventListener("click", (ev)=>{
                        ev.preventDefault();
                        const res = _base.do_fetch("/auth/email/reset", {
                            method: "post",
                            body: form_data
                        });
                        if (res) {
                            reset_button.innerText = "Reset email sent";
                            reset_button.disabled = true;
                        }
                    });
                }
            }
            // _________________________________________________________________________________________________ Discord
            if (this.member.uid == this.target.uid) {
                if (this.target.discord?.id) {
                    const discord = _base.create_append(row_2, "button", [
                        "btn",
                        "btn-discord",
                        "me-2",
                        "mb-2",
                        "text-nowrap"
                    ], {
                        role: "button"
                    });
                    discord.innerHTML = '<i class="bi bi-discord"></i> Unlink Discord';
                    if (this.member.email) discord.addEventListener("click", async (ev)=>{
                        ev.preventDefault();
                        await this.unlink_discord();
                    });
                    else discord.disabled = true;
                } else {
                    const discord = _base.create_append(row_2, "button", [
                        "btn",
                        "btn-discord",
                        "me-2",
                        "mb-2",
                        "text-nowrap"
                    ], {
                        role: "button"
                    });
                    discord.innerHTML = '<i class="bi bi-discord"></i> Link Discord';
                    const meta = document.querySelector("meta[name='login-data']");
                    discord.addEventListener("click", async (ev)=>{
                        ev.preventDefault();
                        window.location.assign(meta.dataset.discordOauth);
                    });
                }
            } else if (this.target.discord?.id) {
                const discord = _base.create_append(row_2, "a", [
                    "btn",
                    "btn-discord",
                    "me-2",
                    "mb-2",
                    "text-nowrap"
                ], {
                    role: "button",
                    target: "_blank",
                    rel: "noopener noreferrer"
                });
                discord.href = `https://discordapp.com/users/${this.target.discord.id}/`;
                discord.innerHTML = '<i class="bi bi-discord"></i> Discord';
            }
            // ________________________________________________________________________________________________ Whatsapp
            if (cci) {
                const div = _base.create_append(row_2, "div", [
                    "input-group",
                    "me-2",
                    "mb-2"
                ]);
                _base.create_append(div, "span", [
                    "input-group-text"
                ]).innerHTML = '<i class="bi bi-whatsapp"></i>';
                this.whatsapp = _base.create_append(div, "input", [
                    "form-control"
                ], {
                    type: "text",
                    placeholder: "WhatsApp",
                    name: "whatsapp",
                    "aria-label": "Phone",
                    autocomplete: "mobile tel"
                });
                this.whatsapp.spellcheck = false;
                this.whatsapp.value = this.target.whatsapp ?? "";
                this.whatsapp.addEventListener("change", _base.debounce((ev)=>this.change_info()));
            } else if (this.target.whatsapp) {
                this.whatsapp = undefined;
                const whatsapp = _base.create_append(row_2, "a", [
                    "btn",
                    "btn-whatsapp",
                    "me-2",
                    "mb-2",
                    "text-nowrap"
                ], {
                    role: "button",
                    target: "_blank",
                    rel: "noopener noreferrer"
                });
                whatsapp.href = "https://wa.me/" + this.target.whatsapp.replaceAll("-", "").replace(/^[0|\D]*/, "");
                whatsapp.innerHTML = '<i class="bi bi-whatsapp"></i> WhatsApp';
            }
        }
        // ___________________________________________________________________________________________ Authorized Apps
        if (this.target.uid == this.member.uid && this.target.authorized_clients && Object.keys(this.target.authorized_clients).length > 0) {
            const apps_row = _base.create_append(this.root, "div", [
                "row",
                "mt-4"
            ]);
            const apps_col = _base.create_append(apps_row, "div", [
                "col-12"
            ]);
            const apps_card = _base.create_append(apps_col, "div", [
                "card"
            ]);
            const apps_header = _base.create_append(apps_card, "div", [
                "card-header"
            ]);
            const apps_title = _base.create_append(apps_header, "h5", [
                "mb-0"
            ]);
            _base.create_append(apps_title, "i", [
                "bi",
                "bi-shield-check"
            ]);
            apps_title.append(document.createTextNode(" Authorized Applications"));
            const apps_body = _base.create_append(apps_card, "div", [
                "card-body"
            ]);
            _base.create_append(apps_body, "p", [
                "text-muted"
            ]).innerText = "Applications that have access to your account:";
            // Get client details for each authorized client
            this.display_authorized_apps(apps_body);
        }
        // ___________________________________________________________________________________________________ Sanctions
        var sanction_div;
        if (_member.can_sanction(this.member) || this.target.sanctions && this.target.sanctions.length > 0) {
            const sanctions_row = _base.create_append(this.root, "div", [
                "row",
                "mt-4"
            ]);
            const sanctions_col = _base.create_append(sanctions_row, "div", [
                "col-12"
            ]);
            const sanctions_card = _base.create_append(sanctions_col, "div", [
                "card"
            ]);
            const sanctions_header = _base.create_append(sanctions_card, "div", [
                "card-header"
            ]);
            const sanctions_title = _base.create_append(sanctions_header, "h5", [
                "mb-0"
            ]);
            _base.create_append(sanctions_title, "i", [
                "bi",
                "bi-exclamation-triangle"
            ]);
            sanctions_title.append(document.createTextNode(" Sanctions"));
            sanction_div = _base.create_append(sanctions_card, "div", [
                "card-body"
            ]);
        }
        if (this.target.sanctions && this.target.sanctions.length > 0) {
            const sanctions_accordion = _base.create_append(sanction_div, "div", [
                "accordion",
                "w-100",
                "mb-4"
            ], {
                id: "sanctionAccordion"
            });
            for (const [idx, sanction] of Object.entries(this.target.sanctions)){
                const id = `sanction-col-item-${idx}`;
                const head_id = `sanction-col-head-${idx}`;
                const item = _base.create_append(sanctions_accordion, "div", [
                    "accordion-item"
                ]);
                item.dataset.uid = sanction.uid;
                const header = _base.create_append(item, "h2", [
                    "accordion-header"
                ], {
                    id: head_id
                });
                const button = _base.create_append(header, "button", [
                    "accordion-button",
                    "collapsed"
                ], {
                    type: "button",
                    "data-bs-toggle": "collapse",
                    "data-bs-target": `#${id}`,
                    "aria-expanded": "false",
                    "aria-controls": id
                });
                // additional display for RegisteredSanction from previous tournaments
                if (sanction.tournament) {
                    const rsanction = sanction;
                    const timestamp = _utils.date_string(rsanction.tournament);
                    button.innerText = `(${timestamp}: ${rsanction.tournament?.name})`;
                }
                const level_badge = _base.create_append(button, "div", [
                    "badge",
                    "mx-1"
                ]);
                level_badge.innerText = sanction.level;
                switch(sanction.level){
                    case _events.SanctionLevel.CAUTION:
                        level_badge.classList.add("text-bg-secondary");
                        break;
                    case _events.SanctionLevel.WARNING:
                        level_badge.classList.add("text-bg-warning");
                        break;
                    case _events.SanctionLevel.DISQUALIFICATION:
                        level_badge.classList.add("text-bg-danger");
                        break;
                    case _events.SanctionLevel.BAN:
                        level_badge.classList.add("text-bg-danger");
                        break;
                }
                if (sanction.category != _events.SanctionCategory.NONE) {
                    const category_badge = _base.create_append(button, "div", [
                        "badge",
                        "mx-1",
                        "text-bg-secondary"
                    ]);
                    category_badge.innerText = sanction.category;
                }
                const collapse = _base.create_append(item, "div", [
                    "accordion-collapse",
                    "collapse"
                ], {
                    "aria-labelledby": head_id,
                    "data-bs-parent": "#sanctionAccordion"
                });
                collapse.id = id;
                const body = _base.create_append(collapse, "div", [
                    "accordion-body"
                ]);
                body.innerText = sanction.comment;
                const prefix = _base.create_prepend(body, "div", [
                    "border-top",
                    "border-bottom",
                    "border-info",
                    "bg-info",
                    "bg-opacity-10",
                    "d-flex",
                    "p-1",
                    "mb-2"
                ]);
                if (sanction.judge) {
                    const author = _base.create_append(prefix, "div", [
                        "me-2"
                    ]);
                    author.innerText = `Issued by ${sanction.judge.name}`;
                }
                // Remove button only for members who can sanction
                if (_member.can_sanction(this.member)) {
                    const remove_button = _base.create_append(prefix, "div", [
                        "btn",
                        "badge",
                        "btn-danger"
                    ]);
                    remove_button.innerHTML = '<i class="bi bi-trash"></i>';
                    remove_button.addEventListener("click", (ev)=>this.remove_sanction(sanction));
                }
            }
        }
        // ___________________________________________________________________________________________ Add Sanction Form
        if (_member.can_sanction(this.member)) {
            // Add existing sanctions in display()
            const form = _base.create_append(sanction_div, "form", [
                "w-100"
            ]);
            const comment = _base.create_append(form, "textarea", [
                "form-control",
                "mb-2"
            ], {
                type: "text",
                autocomplete: "none",
                rows: 3,
                maxlength: 500,
                name: "comment"
            });
            comment.ariaAutoComplete = "none";
            comment.spellcheck = false;
            comment.placeholder = "Comment";
            const select_div = _base.create_append(form, "div", [
                "d-flex",
                "gap-1"
            ]);
            // ____________________________________________________________________________________________ Level Select
            {
                const level_div = _base.create_append(select_div, "div", [
                    "form-floating"
                ]);
                const level_select = _base.create_append(level_div, "select", [
                    "form-select",
                    "my-2"
                ], {
                    id: "sanctionFormLevel",
                    name: "level"
                });
                level_select.ariaLabel = "Level";
                _base.create_append(level_div, "label", [], {
                    for: "sanctionFormLevel"
                }).innerText = "Level";
                for (const level of Object.values(_events.SanctionLevel))level_select.options.add(_base.create_element("option", [], {
                    value: level,
                    label: level
                }));
                level_select.required = true;
            }
            // _________________________________________________________________________________________ Category Select
            {
                const category_div = _base.create_append(select_div, "div", [
                    "form-floating"
                ]);
                const category_select = _base.create_append(category_div, "select", [
                    "form-select",
                    "my-2"
                ], {
                    id: "sanctionFormCategory",
                    name: "category"
                });
                category_select.ariaLabel = "Category";
                _base.create_append(category_div, "label", [], {
                    for: "sanctionFormCategory"
                }).innerText = "Category";
                category_select.options.add(_base.create_element("option", [], {
                    value: "",
                    label: "N/A"
                }));
                for (const category of Object.values(_events.SanctionCategory))category_select.options.add(_base.create_element("option", [], {
                    value: category,
                    label: category
                }));
                category_select.required = false;
            }
            const buttons_div = _base.create_append(form, "div", [
                "d-flex",
                "my-2"
            ]);
            const submit_button = _base.create_append(buttons_div, "button", [
                "btn",
                "btn-primary",
                "me-2"
            ], {
                type: "submit"
            });
            submit_button.innerText = "Add Sanction";
            form.addEventListener("submit", (ev)=>{
                ev.preventDefault();
                this.add_sanction(new FormData(form));
            });
        }
        // _____________________________________________________________________________________________________ Results
        if (this.target.ratings && Object.keys(this.target.ratings).length > 0) {
            _base.create_append(this.root, "h2", [
                "mt-4"
            ]).innerText = "Events";
            const nav = _base.create_append(this.root, "nav");
            const nav_div = _base.create_append(nav, "div", [
                "nav",
                "nav-tabs"
            ], {
                role: "tablist"
            });
            const ratings = Object.values(this.target.ratings);
            const categories = new Set(ratings.map((r)=>_utils.ranking_category(r.tournament)));
            for (const category of categories){
                const category_str = category.replaceAll(" ", "");
                const nav_tab = _base.create_append(nav_div, "button", [
                    "nav-link"
                ], {
                    id: `navTab${category_str}`,
                    "data-bs-toggle": "tab",
                    "data-bs-target": `#nav${category_str}`,
                    type: "button",
                    role: "tab",
                    "aria-controls": `nav${category_str}`,
                    "aria-selected": "false"
                });
                nav_tab.innerHTML = category + " " + `<span class="badge text-bg-primary align-text-top">${this.target.ranking[category] ?? 0}</span>`;
            }
            const first_tab = nav_div.querySelector("button");
            first_tab.ariaSelected = "true";
            first_tab.classList.add("active");
            const tabs = _base.create_append(this.root, "div", [
                "tab-content"
            ]);
            const cutoff = (0, _luxon.DateTime).now().set({
                hour: 0,
                minute: 0,
                millisecond: 0
            }).minus({
                months: 18
            });
            for (const category of categories){
                const category_str = category.replaceAll(" ", "");
                const tab = _base.create_append(tabs, "div", [
                    "tab-pane",
                    "fade"
                ], {
                    id: `nav${category_str}`,
                    role: "tabpanel",
                    "aria-labelledby": `navTab${category_str}`,
                    tabindex: "0"
                });
                const results_table = _base.create_append(tab, "table", [
                    "my-2",
                    "table",
                    "table-striped",
                    "table-hover"
                ]);
                const head = _base.create_append(results_table, "thead");
                const row = _base.create_append(head, "tr", [
                    "align-middle"
                ]);
                for (const header of [
                    "Tournament",
                    "Date",
                    "Rank",
                    "Result",
                    "RTPs"
                ])_base.create_append(row, "th", [], {
                    scope: "col"
                }).innerText = header;
                const body = _base.create_append(results_table, "tbody");
                const category_ratings = ratings.filter((r)=>_utils.ranking_category(r.tournament) == category);
                category_ratings.sort((a, b)=>_utils.datetime(b.tournament).toMillis() - _utils.datetime(a.tournament).toMillis());
                const top_8 = category_ratings.filter((r)=>_utils.datetime(r.tournament) > cutoff).sort((a, b)=>b.rating_points - a.rating_points).slice(0, 8).map((r)=>r.tournament.uid);
                for (const rating of category_ratings){
                    const row = _base.create_append(body, "tr", [
                        "align-middle"
                    ]);
                    const name_cell = _base.create_append(row, "th", [], {
                        scope: "row"
                    });
                    const link = _base.create_append(name_cell, "a", [], {
                        href: `/tournament/${rating.tournament.uid}/display.html`
                    });
                    var name = _utils.constrain_string(rating.tournament.name, 50);
                    link.innerText = name;
                    const start = _utils.date_string(rating.tournament);
                    _base.create_append(row, "td").innerText = start;
                    _base.create_append(row, "td").innerHTML = _utils.tournament_rank_badge(rating.tournament);
                    _base.create_append(row, "td").innerHTML = _utils.tournament_result_string(rating);
                    if (top_8.includes(rating.tournament.uid)) _base.create_append(row, "td").innerHTML = `<span class="badge text-bg-primary align-text-top">${rating.rating_points}</span>`;
                    else _base.create_append(row, "td").innerHTML = `<span class="badge text-bg-secondary align-text-top">${rating.rating_points}</span>`;
                }
            }
            tabs.querySelector("div").classList.add("show", "active");
            nav_div.querySelectorAll('button').forEach((triggerEl)=>{
                const tabTrigger = new _bootstrap.Tab(triggerEl);
                triggerEl.addEventListener('click', (event)=>{
                    event.preventDefault();
                    tabTrigger.show();
                });
            });
        }
    }
    async display_authorized_apps(container) {
        const client_uids = Object.keys(this.target.authorized_clients);
        if (client_uids.length === 0) return;
        // Fetch client details
        const clients_res = await _base.do_fetch_with_token("/api/vekn/clients", this.token, {});
        const clients = await clients_res.json();
        const clients_map = new Map(clients.map((c)=>[
                c.uid,
                c
            ]));
        for (const client_uid of client_uids){
            const client = clients_map.get(client_uid);
            if (!client) continue;
            const auth_data = this.target.authorized_clients[client_uid];
            const authorized_at = new Date(auth_data.authorized_at);
            const app_div = _base.create_append(container, "div", [
                "d-flex",
                "justify-content-between",
                "align-items-center",
                "border-bottom",
                "py-2"
            ]);
            const app_info = _base.create_append(app_div, "div");
            const app_name = _base.create_append(app_info, "strong");
            app_name.innerText = client.name;
            _base.create_append(app_info, "br");
            const app_date = _base.create_append(app_info, "small", [
                "text-muted"
            ]);
            app_date.innerText = `Authorized on ${authorized_at.toLocaleDateString()} at ${authorized_at.toLocaleTimeString()}`;
            const revoke_form = _base.create_append(app_div, "form", [
                "d-inline"
            ]);
            revoke_form.method = "post";
            revoke_form.action = "/auth/oauth/revoke";
            const client_input = _base.create_append(revoke_form, "input", [], {
                type: "hidden",
                name: "client_uid",
                value: client_uid
            });
            const revoke_button = _base.create_append(revoke_form, "button", [
                "btn",
                "btn-outline-danger",
                "btn-sm"
            ], {
                type: "submit"
            });
            _base.create_append(revoke_button, "i", [
                "bi",
                "bi-x-circle"
            ]);
            revoke_button.append(document.createTextNode(" Revoke Access"));
            revoke_button.addEventListener("click", (ev)=>{
                if (!confirm(`Are you sure you want to revoke access for ${client.name}?`)) ev.preventDefault();
            });
        }
    }
    async load_cities() {
        if (!this.target.country || this.target.country.length < 1) {
            this.cities = new Map();
            return;
        }
        const res = await _base.do_fetch(`/api/vekn/country/${this.target.country}/city`, {});
        this.cities = new Map(Object.entries(await res.json()));
    }
    async reload_target(target) {
        this.target = target;
        await this.load_cities();
        await this.vekn_modal.init(this.token, this.member.uid, this.target.uid);
        this.display();
    }
    async remove_vekn() {
        if (this.member.uid == this.target.uid) // reload required, because we need to change the session's token
        window.location.href = "/vekn/abandon";
        else {
            const res = await _base.do_fetch_with_token(`/api/vekn/members/${this.target.uid}/vekn`, this.token, {
                method: "delete"
            });
            if (res) await this.reload_target(await res.json());
        }
    }
    async new_vekn() {
        const res = await _base.do_fetch_with_token(`/api/vekn/members/${this.target.uid}/sponsor`, this.token, {
            method: "post"
        });
        if (res) await this.reload_target(await res.json());
    }
    async remove_role(role) {
        const res = await _base.do_fetch_with_token(`/api/vekn/members/${this.target.uid}/remove_role`, this.token, {
            method: "post",
            body: JSON.stringify({
                role: role
            })
        });
        if (res) await this.reload_target(await res.json());
    }
    async add_role(role) {
        const res = await _base.do_fetch_with_token(`/api/vekn/members/${this.target.uid}/add_role`, this.token, {
            method: "post",
            body: JSON.stringify({
                role: role
            })
        });
        if (res) await this.reload_target(await res.json());
    }
    async change_info() {
        const info = {
            name: null,
            country: null,
            city: null,
            nickname: null,
            email: null,
            whatsapp: null
        };
        if (this.name.value != this.target.name) info.name = this.name.value;
        if (this.email.value != this.target.email) info.email = this.email.value;
        if (this.whatsapp.value != this.target.whatsapp) info.whatsapp = this.whatsapp.value;
        const selected_country = this.country_select.options[this.country_select.selectedIndex].value;
        if (selected_country != this.target.country) info.country = selected_country;
        if (this.city_select.value != this.target.city) info.city = this.city_select.value;
        // TODO add the nickname field
        const res = await _base.do_fetch_with_token(`/api/vekn/members/${this.target.uid}/info`, this.token, {
            method: "post",
            body: JSON.stringify(info)
        });
        if (res) await this.reload_target(await res.json());
    }
    async unlink_discord() {
        const res = await _base.do_fetch_with_token(`/api/vekn/members/unlink_discord`, this.token, {
            method: "post"
        });
        if (res) await this.reload_target(await res.json());
    }
    async remove_sanction(sanction) {
        const res = await _base.do_fetch_with_token(`/api/vekn/members/${this.target.uid}/sanction/${sanction.uid}`, this.token, {
            method: "delete"
        });
        if (res) await this.reload_target(await res.json());
    }
    async add_sanction(data) {
        const res = await _base.do_fetch_with_token(`/api/vekn/members/${this.target.uid}/sanction`, this.token, {
            method: "post",
            body: JSON.stringify(Object.fromEntries(data.entries()))
        });
        if (res) await this.reload_target(await res.json());
    }
}
async function load() {
    const contentDiv = document.getElementById("contentDiv");
    if (!contentDiv) return;
    const display = new MemberDisplay(contentDiv);
    const token = await _base.fetchToken();
    await display.init(token, new URL(window.location.href));
}
window.addEventListener("load", (ev)=>{
    load();
});

},{"./base":"ikie8","./d":"8rVEj","./member":"6FUFI","./events":"53ndf","./utils":"1fFGC","bootstrap":"h36JB","luxon":"dpK6X"}],"ikie8":[function(require,module,exports,__globalThis) {
// this module defines functions useful for all pages
// note it is only imported in other ts files: it is not meant to be loaded directly
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "create_element", ()=>create_element);
parcelHelpers.export(exports, "create_append", ()=>create_append);
parcelHelpers.export(exports, "create_prepend", ()=>create_prepend);
parcelHelpers.export(exports, "remove_children", ()=>remove_children);
parcelHelpers.export(exports, "remove_but_one_children", ()=>remove_but_one_children);
parcelHelpers.export(exports, "TooltipManager", ()=>TooltipManager);
parcelHelpers.export(exports, "do_fetch", ()=>do_fetch);
parcelHelpers.export(exports, "do_fetch_with_token", ()=>do_fetch_with_token);
parcelHelpers.export(exports, "displayError", ()=>displayError);
parcelHelpers.export(exports, "debounce", ()=>debounce);
parcelHelpers.export(exports, "debounce_async", ()=>debounce_async);
parcelHelpers.export(exports, "fetchToken", ()=>fetchToken);
parcelHelpers.export(exports, "user_uid_from_token", ()=>user_uid_from_token);
parcelHelpers.export(exports, "Modal", ()=>Modal);
parcelHelpers.export(exports, "ConfirmationModal", ()=>ConfirmationModal);
parcelHelpers.export(exports, "Completion", ()=>Completion);
var _bootstrap = require("bootstrap");
var _uuid = require("uuid");
function create_element(tag_name, classes = [], init = {}) {
    const ret = document.createElement(tag_name);
    ret.classList.add(...classes);
    for (const [attribute, value] of Object.entries(init))ret.setAttribute(attribute, value);
    return ret;
}
function create_append(el, tag_name, classes = [], init = {}) {
    const ret = create_element(tag_name, classes, init);
    el.append(ret);
    return ret;
}
function create_prepend(el, tag_name, classes = [], init = {}) {
    const ret = create_element(tag_name, classes, init);
    el.prepend(ret);
    return ret;
}
function remove_children(el) {
    while(el.lastElementChild)el.removeChild(el.lastElementChild);
}
function remove_but_one_children(el) {
    while(el.childElementCount > 1)el.removeChild(el.lastElementChild);
}
class TooltipManager {
    tooltips;
    constructor(){
        this.tooltips = new Map();
    }
    add(el, tip, keep = false) {
        el.dataset.bsToggle = "tooltip";
        el.dataset.bsTitle = tip;
        const tooltip = _bootstrap.Tooltip.getInstance(el);
        if (tooltip) return tooltip;
        const new_tooltip = new _bootstrap.Tooltip(el, {
            trigger: "hover focus",
            container: el.parentElement
        });
        // hide the tooltip on interaction for interactive elements
        if (keep && (el instanceof HTMLButtonElement || el instanceof HTMLAnchorElement || el instanceof HTMLSelectElement)) el.addEventListener("click", ()=>new_tooltip?.hide());
        if (!keep) this.tooltips.set(new_tooltip, el);
        return new_tooltip;
    }
    dispose() {
        for (const tooltip of this.tooltips.keys())tooltip.dispose();
        this.tooltips.clear();
    }
    partial_dispose(el) {
        for (const [tooltip, element] of this.tooltips.entries())if (el.contains(element)) {
            tooltip.dispose();
            this.tooltips.delete(tooltip);
        }
    }
    remove(tooltip) {
        this.tooltips.delete(tooltip);
        tooltip.dispose();
    }
}
async function do_fetch(url, options) {
    // fetch the given url, handle errors and display them in the toaster
    try {
        const response = await fetch(url, options);
        if (!response.ok && response.status != 304) {
            var message = await response.text();
            try {
                message = JSON.parse(message)["detail"];
            } catch (error) {}
            throw new Error(message);
        }
        return response;
    } catch (error) {
        console.log(`Error fetching ${url}`, error.message);
        displayError(error.message);
    }
}
async function do_fetch_with_token(url, token, options) {
    options["headers"] = {
        'Accept': 'application/json',
        'Content-Type': 'application/json',
        'Authorization': `Bearer ${token.access_token}`
    };
    return do_fetch(url, options);
}
function displayError(msg) {
    // display a message in the toaster
    const toast_div = document.getElementById('errorToast');
    const body = toast_div.querySelector("div.toast-body");
    body.innerText = msg;
    _bootstrap.Toast.getOrCreateInstance(toast_div).show();
}
function debounce(func, timeout = 300) {
    let timer = undefined;
    return (...args)=>{
        clearTimeout(timer);
        timer = setTimeout(()=>{
            func.apply(this, args);
        }, timeout);
    };
}
function debounce_async(func, timeout = 300) {
    let timer = undefined;
    return (...args)=>{
        clearTimeout(timer);
        timer = setTimeout(async ()=>{
            await func.apply(this, args);
        }, timeout);
    };
}
async function fetchToken() {
    // fetch the given url, handle errors and display them in the toaster
    try {
        const response = await fetch("/auth/token", {
            method: "get",
            credentials: "same-origin",
            cache: "no-cache"
        });
        if (!response.ok) {
            console.log("Failed to fetch user token", response);
            return;
        }
        return response.json();
    } catch (error) {
        console.log(`Error fetching token`, error.message);
    }
}
function user_uid_from_token(token) {
    return JSON.parse(window.atob(token.access_token.split(".")[1]))["sub"];
}
class Modal {
    modal_div;
    modal;
    modal_title;
    modal_body;
    constructor(el){
        const label_id = (0, _uuid.v4)();
        this.modal_div = create_append(el, "div", [
            "modal",
            "fade"
        ], {
            tabindex: "-1",
            "aria-hidden": "true",
            "aria-labelledby": label_id
        });
        const dialog = create_append(this.modal_div, "div", [
            "modal-dialog"
        ]);
        const content = create_append(dialog, "div", [
            "modal-content"
        ]);
        const header = create_append(content, "div", [
            "modal-header"
        ]);
        this.modal_title = create_append(header, "h1", [
            "modal-title",
            "fs-5"
        ], {
            id: label_id
        });
        create_append(header, "button", [
            "btn-close"
        ], {
            "data-bs-dismiss": "modal",
            "aria-label": "Close"
        });
        this.modal_body = create_append(content, "div", [
            "modal-body",
            "d-flex",
            "flex-column",
            "align-items-center"
        ]);
        this.modal = new _bootstrap.Modal(this.modal_div);
        // Prevent "Blocked aria-hidden" warning by using the inert attribute properly
        this.modal_div.addEventListener("hide.bs.modal", ()=>{
            this.modal_div.setAttribute("inert", "");
        });
        this.modal_div.addEventListener("show.bs.modal", ()=>{
            this.modal_div.removeAttribute("inert");
        });
    }
}
class ConfirmationModal extends Modal {
    message;
    callback;
    constructor(el){
        super(el);
        this.modal_title.innerText = "Are you sure?";
        this.message = create_append(this.modal_body, "div", [
            "d-flex",
            "flex-column",
            "align-items-center"
        ]);
        const row = create_append(this.modal_body, "div", [
            "mt-4",
            "d-flex",
            "flex-row",
            "align-items-center"
        ]);
        const confirm = create_append(row, "button", [
            "btn",
            "btn-danger",
            "me-1",
            "mb-1"
        ], {
            type: "button"
        });
        confirm.innerText = "Confirm";
        confirm.addEventListener("click", (ev)=>this.confirm());
        const cancel = create_append(row, "button", [
            "btn",
            "btn-secondary",
            "me-1",
            "mb-1"
        ], {
            type: "button"
        });
        cancel.innerText = "Cancel";
        cancel.addEventListener("click", (ev)=>this.modal.hide());
    }
    confirm() {
        this.modal.hide();
        this.callback();
    }
    show(message, callback) {
        this.message.innerHTML = message;
        this.callback = callback;
        this.modal.show();
    }
}
class Completion {
    input;
    dropdown_menu;
    dropdown;
    focus;
    debounced_show;
    keydown_handler;
    // optional method for additional automation
    item_selected(item) {}
    constructor(input){
        this.focus = undefined;
        this.input = input;
        input.classList.add("dropdown-toggle");
        input.setAttribute("data-bs-toggle", "dropdown");
        input.parentElement.classList.add("dropdown");
        this.dropdown_menu = create_append(input.parentElement, "ul", [
            "dropdown-menu"
        ]);
        this._empty_input_completion();
        this.debounced_show = debounce_async(async (ev)=>await this._show());
        this.keydown_handler = (ev)=>this._keydown(ev);
        this.input.addEventListener("input", this.debounced_show);
        this.dropdown = _bootstrap.Dropdown.getOrCreateInstance(this.input);
        this.input.parentElement.addEventListener("keydown", this.keydown_handler);
    }
    dispose() {
        this.input.removeEventListener("input", this.debounced_show);
        this.input.parentElement.removeEventListener("keydown", this.keydown_handler);
        this.dropdown.dispose();
    }
    async _show() {
        remove_children(this.dropdown_menu);
        this._reset_focus();
        if (this.input.value.length < 1) {
            this._empty_input_completion();
            this.dropdown.show();
            return;
        }
        if (this.input.value.length < 3) {
            create_append(this.dropdown_menu, "li", [
                "dropdown-item",
                "disabled"
            ], {
                type: "button"
            }).innerText = "Type some more...";
            this.dropdown.show();
            return;
        }
        const items = await this.complete_input(this.input.value);
        if (!items || items.length < 1) {
            create_append(this.dropdown_menu, "li", [
                "dropdown-item",
                "disabled"
            ], {
                type: "button"
            }).innerText = "No result";
            this.dropdown.show();
            return;
        }
        for (const item of items.slice(0, 10)){
            const li = create_append(this.dropdown_menu, "li");
            const button = create_append(li, "button", [
                "dropdown-item"
            ], {
                type: "button",
                "data-item": JSON.stringify(item)
            });
            button.innerText = this.item_label(item);
            button.addEventListener("click", (ev)=>this._select_item(ev));
        }
        this.dropdown.show();
    }
    _empty_input_completion() {
        create_append(this.dropdown_menu, "li", [
            "dropdown-item",
            "disabled"
        ], {
            type: "button"
        }).innerText = "Start typing...";
    }
    reset() {
        this.input.value = "";
        this._reset_focus();
        remove_children(this.dropdown_menu);
        this._empty_input_completion();
    }
    _reset_focus(new_focus) {
        if (new_focus === this.focus) return;
        if (this.focus && this.focus.firstElementChild) this.focus.firstElementChild.classList.remove("active");
        this.focus = new_focus;
        if (this.focus && this.focus.firstElementChild) this.focus.firstElementChild.classList.add("active");
    }
    _select_item(ev) {
        const button = ev.currentTarget;
        const item = JSON.parse(button.dataset.item);
        this.input.value = this.item_label(item);
        this.input.dispatchEvent(new Event("change", {
            bubbles: true
        }));
        this.item_selected(item);
        this._reset_focus();
        this.dropdown.hide();
    }
    _keydown(ev) {
        var next_focus = undefined;
        switch(ev.key){
            case "ArrowDown":
                if (this.focus) next_focus = this.focus.nextElementSibling;
                else next_focus = this.dropdown_menu.firstElementChild;
                if (next_focus === null) next_focus = this.focus;
                break;
            case "ArrowUp":
                if (this.focus) next_focus = this.focus.previousElementSibling;
                else next_focus = this.dropdown_menu.lastElementChild;
                if (next_focus === null) next_focus = this.focus;
                break;
            case "Escape":
                break;
            case "Enter":
                if (this.focus) this.focus.firstElementChild.dispatchEvent(new Event("click"));
                else return;
                break;
            default:
                return;
        }
        ev.stopPropagation();
        ev.preventDefault();
        this._reset_focus(next_focus);
    }
}

},{"bootstrap":"h36JB","uuid":"a2QOC","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"h36JB":[function(require,module,exports,__globalThis) {
/*!
  * Bootstrap v5.3.8 (https://getbootstrap.com/)
  * Copyright 2011-2025 The Bootstrap Authors (https://github.com/twbs/bootstrap/graphs/contributors)
  * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
  */ var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "Alert", ()=>Alert);
parcelHelpers.export(exports, "Button", ()=>Button);
parcelHelpers.export(exports, "Carousel", ()=>Carousel);
parcelHelpers.export(exports, "Collapse", ()=>Collapse);
parcelHelpers.export(exports, "Dropdown", ()=>Dropdown);
parcelHelpers.export(exports, "Modal", ()=>Modal);
parcelHelpers.export(exports, "Offcanvas", ()=>Offcanvas);
parcelHelpers.export(exports, "Popover", ()=>Popover);
parcelHelpers.export(exports, "ScrollSpy", ()=>ScrollSpy);
parcelHelpers.export(exports, "Tab", ()=>Tab);
parcelHelpers.export(exports, "Toast", ()=>Toast);
parcelHelpers.export(exports, "Tooltip", ()=>Tooltip);
var _core = require("@popperjs/core");
/**
 * --------------------------------------------------------------------------
 * Bootstrap dom/data.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const elementMap = new Map();
const Data = {
    set (element, key, instance) {
        if (!elementMap.has(element)) elementMap.set(element, new Map());
        const instanceMap = elementMap.get(element);
        // make it clear we only want one instance per element
        // can be removed later when multiple key/instances are fine to be used
        if (!instanceMap.has(key) && instanceMap.size !== 0) {
            // eslint-disable-next-line no-console
            console.error(`Bootstrap doesn't allow more than one instance per element. Bound instance: ${Array.from(instanceMap.keys())[0]}.`);
            return;
        }
        instanceMap.set(key, instance);
    },
    get (element, key) {
        if (elementMap.has(element)) return elementMap.get(element).get(key) || null;
        return null;
    },
    remove (element, key) {
        if (!elementMap.has(element)) return;
        const instanceMap = elementMap.get(element);
        instanceMap.delete(key);
        // free up element references if there are no instances left for an element
        if (instanceMap.size === 0) elementMap.delete(element);
    }
};
/**
 * --------------------------------------------------------------------------
 * Bootstrap util/index.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ const MAX_UID = 1000000;
const MILLISECONDS_MULTIPLIER = 1000;
const TRANSITION_END = 'transitionend';
/**
 * Properly escape IDs selectors to handle weird IDs
 * @param {string} selector
 * @returns {string}
 */ const parseSelector = (selector)=>{
    if (selector && window.CSS && window.CSS.escape) // document.querySelector needs escaping to handle IDs (html5+) containing for instance /
    selector = selector.replace(/#([^\s"#']+)/g, (match, id)=>`#${CSS.escape(id)}`);
    return selector;
};
// Shout-out Angus Croll (https://goo.gl/pxwQGp)
const toType = (object)=>{
    if (object === null || object === undefined) return `${object}`;
    return Object.prototype.toString.call(object).match(/\s([a-z]+)/i)[1].toLowerCase();
};
/**
 * Public Util API
 */ const getUID = (prefix)=>{
    do prefix += Math.floor(Math.random() * MAX_UID);
    while (document.getElementById(prefix));
    return prefix;
};
const getTransitionDurationFromElement = (element)=>{
    if (!element) return 0;
    // Get transition-duration of the element
    let { transitionDuration, transitionDelay } = window.getComputedStyle(element);
    const floatTransitionDuration = Number.parseFloat(transitionDuration);
    const floatTransitionDelay = Number.parseFloat(transitionDelay);
    // Return 0 if element or transition duration is not found
    if (!floatTransitionDuration && !floatTransitionDelay) return 0;
    // If multiple durations are defined, take the first
    transitionDuration = transitionDuration.split(',')[0];
    transitionDelay = transitionDelay.split(',')[0];
    return (Number.parseFloat(transitionDuration) + Number.parseFloat(transitionDelay)) * MILLISECONDS_MULTIPLIER;
};
const triggerTransitionEnd = (element)=>{
    element.dispatchEvent(new Event(TRANSITION_END));
};
const isElement = (object)=>{
    if (!object || typeof object !== 'object') return false;
    if (typeof object.jquery !== 'undefined') object = object[0];
    return typeof object.nodeType !== 'undefined';
};
const getElement = (object)=>{
    // it's a jQuery object or a node element
    if (isElement(object)) return object.jquery ? object[0] : object;
    if (typeof object === 'string' && object.length > 0) return document.querySelector(parseSelector(object));
    return null;
};
const isVisible = (element)=>{
    if (!isElement(element) || element.getClientRects().length === 0) return false;
    const elementIsVisible = getComputedStyle(element).getPropertyValue('visibility') === 'visible';
    // Handle `details` element as its content may falsie appear visible when it is closed
    const closedDetails = element.closest('details:not([open])');
    if (!closedDetails) return elementIsVisible;
    if (closedDetails !== element) {
        const summary = element.closest('summary');
        if (summary && summary.parentNode !== closedDetails) return false;
        if (summary === null) return false;
    }
    return elementIsVisible;
};
const isDisabled = (element)=>{
    if (!element || element.nodeType !== Node.ELEMENT_NODE) return true;
    if (element.classList.contains('disabled')) return true;
    if (typeof element.disabled !== 'undefined') return element.disabled;
    return element.hasAttribute('disabled') && element.getAttribute('disabled') !== 'false';
};
const findShadowRoot = (element)=>{
    if (!document.documentElement.attachShadow) return null;
    // Can find the shadow root otherwise it'll return the document
    if (typeof element.getRootNode === 'function') {
        const root = element.getRootNode();
        return root instanceof ShadowRoot ? root : null;
    }
    if (element instanceof ShadowRoot) return element;
    // when we don't find a shadow root
    if (!element.parentNode) return null;
    return findShadowRoot(element.parentNode);
};
const noop = ()=>{};
/**
 * Trick to restart an element's animation
 *
 * @param {HTMLElement} element
 * @return void
 *
 * @see https://www.harrytheo.com/blog/2021/02/restart-a-css-animation-with-javascript/#restarting-a-css-animation
 */ const reflow = (element)=>{
    element.offsetHeight; // eslint-disable-line no-unused-expressions
};
const getjQuery = ()=>{
    if (window.jQuery && !document.body.hasAttribute('data-bs-no-jquery')) return window.jQuery;
    return null;
};
const DOMContentLoadedCallbacks = [];
const onDOMContentLoaded = (callback)=>{
    if (document.readyState === 'loading') {
        // add listener on the first call when the document is in loading state
        if (!DOMContentLoadedCallbacks.length) document.addEventListener('DOMContentLoaded', ()=>{
            for (const callback of DOMContentLoadedCallbacks)callback();
        });
        DOMContentLoadedCallbacks.push(callback);
    } else callback();
};
const isRTL = ()=>document.documentElement.dir === 'rtl';
const defineJQueryPlugin = (plugin)=>{
    onDOMContentLoaded(()=>{
        const $ = getjQuery();
        /* istanbul ignore if */ if ($) {
            const name = plugin.NAME;
            const JQUERY_NO_CONFLICT = $.fn[name];
            $.fn[name] = plugin.jQueryInterface;
            $.fn[name].Constructor = plugin;
            $.fn[name].noConflict = ()=>{
                $.fn[name] = JQUERY_NO_CONFLICT;
                return plugin.jQueryInterface;
            };
        }
    });
};
const execute = (possibleCallback, args = [], defaultValue = possibleCallback)=>{
    return typeof possibleCallback === 'function' ? possibleCallback.call(...args) : defaultValue;
};
const executeAfterTransition = (callback, transitionElement, waitForTransition = true)=>{
    if (!waitForTransition) {
        execute(callback);
        return;
    }
    const durationPadding = 5;
    const emulatedDuration = getTransitionDurationFromElement(transitionElement) + durationPadding;
    let called = false;
    const handler = ({ target })=>{
        if (target !== transitionElement) return;
        called = true;
        transitionElement.removeEventListener(TRANSITION_END, handler);
        execute(callback);
    };
    transitionElement.addEventListener(TRANSITION_END, handler);
    setTimeout(()=>{
        if (!called) triggerTransitionEnd(transitionElement);
    }, emulatedDuration);
};
/**
 * Return the previous/next element of a list.
 *
 * @param {array} list    The list of elements
 * @param activeElement   The active element
 * @param shouldGetNext   Choose to get next or previous element
 * @param isCycleAllowed
 * @return {Element|elem} The proper element
 */ const getNextActiveElement = (list, activeElement, shouldGetNext, isCycleAllowed)=>{
    const listLength = list.length;
    let index = list.indexOf(activeElement);
    // if the element does not exist in the list return an element
    // depending on the direction and if cycle is allowed
    if (index === -1) return !shouldGetNext && isCycleAllowed ? list[listLength - 1] : list[0];
    index += shouldGetNext ? 1 : -1;
    if (isCycleAllowed) index = (index + listLength) % listLength;
    return list[Math.max(0, Math.min(index, listLength - 1))];
};
/**
 * --------------------------------------------------------------------------
 * Bootstrap dom/event-handler.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const namespaceRegex = /[^.]*(?=\..*)\.|.*/;
const stripNameRegex = /\..*/;
const stripUidRegex = /::\d+$/;
const eventRegistry = {}; // Events storage
let uidEvent = 1;
const customEvents = {
    mouseenter: 'mouseover',
    mouseleave: 'mouseout'
};
const nativeEvents = new Set([
    'click',
    'dblclick',
    'mouseup',
    'mousedown',
    'contextmenu',
    'mousewheel',
    'DOMMouseScroll',
    'mouseover',
    'mouseout',
    'mousemove',
    'selectstart',
    'selectend',
    'keydown',
    'keypress',
    'keyup',
    'orientationchange',
    'touchstart',
    'touchmove',
    'touchend',
    'touchcancel',
    'pointerdown',
    'pointermove',
    'pointerup',
    'pointerleave',
    'pointercancel',
    'gesturestart',
    'gesturechange',
    'gestureend',
    'focus',
    'blur',
    'change',
    'reset',
    'select',
    'submit',
    'focusin',
    'focusout',
    'load',
    'unload',
    'beforeunload',
    'resize',
    'move',
    'DOMContentLoaded',
    'readystatechange',
    'error',
    'abort',
    'scroll'
]);
/**
 * Private methods
 */ function makeEventUid(element, uid) {
    return uid && `${uid}::${uidEvent++}` || element.uidEvent || uidEvent++;
}
function getElementEvents(element) {
    const uid = makeEventUid(element);
    element.uidEvent = uid;
    eventRegistry[uid] = eventRegistry[uid] || {};
    return eventRegistry[uid];
}
function bootstrapHandler(element, fn) {
    return function handler(event) {
        hydrateObj(event, {
            delegateTarget: element
        });
        if (handler.oneOff) EventHandler.off(element, event.type, fn);
        return fn.apply(element, [
            event
        ]);
    };
}
function bootstrapDelegationHandler(element, selector, fn) {
    return function handler(event) {
        const domElements = element.querySelectorAll(selector);
        for(let { target } = event; target && target !== this; target = target.parentNode)for (const domElement of domElements){
            if (domElement !== target) continue;
            hydrateObj(event, {
                delegateTarget: target
            });
            if (handler.oneOff) EventHandler.off(element, event.type, selector, fn);
            return fn.apply(target, [
                event
            ]);
        }
    };
}
function findHandler(events, callable, delegationSelector = null) {
    return Object.values(events).find((event)=>event.callable === callable && event.delegationSelector === delegationSelector);
}
function normalizeParameters(originalTypeEvent, handler, delegationFunction) {
    const isDelegated = typeof handler === 'string';
    // TODO: tooltip passes `false` instead of selector, so we need to check
    const callable = isDelegated ? delegationFunction : handler || delegationFunction;
    let typeEvent = getTypeEvent(originalTypeEvent);
    if (!nativeEvents.has(typeEvent)) typeEvent = originalTypeEvent;
    return [
        isDelegated,
        callable,
        typeEvent
    ];
}
function addHandler(element, originalTypeEvent, handler, delegationFunction, oneOff) {
    if (typeof originalTypeEvent !== 'string' || !element) return;
    let [isDelegated, callable, typeEvent] = normalizeParameters(originalTypeEvent, handler, delegationFunction);
    // in case of mouseenter or mouseleave wrap the handler within a function that checks for its DOM position
    // this prevents the handler from being dispatched the same way as mouseover or mouseout does
    if (originalTypeEvent in customEvents) {
        const wrapFunction = (fn)=>{
            return function(event) {
                if (!event.relatedTarget || event.relatedTarget !== event.delegateTarget && !event.delegateTarget.contains(event.relatedTarget)) return fn.call(this, event);
            };
        };
        callable = wrapFunction(callable);
    }
    const events = getElementEvents(element);
    const handlers = events[typeEvent] || (events[typeEvent] = {});
    const previousFunction = findHandler(handlers, callable, isDelegated ? handler : null);
    if (previousFunction) {
        previousFunction.oneOff = previousFunction.oneOff && oneOff;
        return;
    }
    const uid = makeEventUid(callable, originalTypeEvent.replace(namespaceRegex, ''));
    const fn = isDelegated ? bootstrapDelegationHandler(element, handler, callable) : bootstrapHandler(element, callable);
    fn.delegationSelector = isDelegated ? handler : null;
    fn.callable = callable;
    fn.oneOff = oneOff;
    fn.uidEvent = uid;
    handlers[uid] = fn;
    element.addEventListener(typeEvent, fn, isDelegated);
}
function removeHandler(element, events, typeEvent, handler, delegationSelector) {
    const fn = findHandler(events[typeEvent], handler, delegationSelector);
    if (!fn) return;
    element.removeEventListener(typeEvent, fn, Boolean(delegationSelector));
    delete events[typeEvent][fn.uidEvent];
}
function removeNamespacedHandlers(element, events, typeEvent, namespace) {
    const storeElementEvent = events[typeEvent] || {};
    for (const [handlerKey, event] of Object.entries(storeElementEvent))if (handlerKey.includes(namespace)) removeHandler(element, events, typeEvent, event.callable, event.delegationSelector);
}
function getTypeEvent(event) {
    // allow to get the native events from namespaced events ('click.bs.button' --> 'click')
    event = event.replace(stripNameRegex, '');
    return customEvents[event] || event;
}
const EventHandler = {
    on (element, event, handler, delegationFunction) {
        addHandler(element, event, handler, delegationFunction, false);
    },
    one (element, event, handler, delegationFunction) {
        addHandler(element, event, handler, delegationFunction, true);
    },
    off (element, originalTypeEvent, handler, delegationFunction) {
        if (typeof originalTypeEvent !== 'string' || !element) return;
        const [isDelegated, callable, typeEvent] = normalizeParameters(originalTypeEvent, handler, delegationFunction);
        const inNamespace = typeEvent !== originalTypeEvent;
        const events = getElementEvents(element);
        const storeElementEvent = events[typeEvent] || {};
        const isNamespace = originalTypeEvent.startsWith('.');
        if (typeof callable !== 'undefined') {
            // Simplest case: handler is passed, remove that listener ONLY.
            if (!Object.keys(storeElementEvent).length) return;
            removeHandler(element, events, typeEvent, callable, isDelegated ? handler : null);
            return;
        }
        if (isNamespace) for (const elementEvent of Object.keys(events))removeNamespacedHandlers(element, events, elementEvent, originalTypeEvent.slice(1));
        for (const [keyHandlers, event] of Object.entries(storeElementEvent)){
            const handlerKey = keyHandlers.replace(stripUidRegex, '');
            if (!inNamespace || originalTypeEvent.includes(handlerKey)) removeHandler(element, events, typeEvent, event.callable, event.delegationSelector);
        }
    },
    trigger (element, event, args) {
        if (typeof event !== 'string' || !element) return null;
        const $ = getjQuery();
        const typeEvent = getTypeEvent(event);
        const inNamespace = event !== typeEvent;
        let jQueryEvent = null;
        let bubbles = true;
        let nativeDispatch = true;
        let defaultPrevented = false;
        if (inNamespace && $) {
            jQueryEvent = $.Event(event, args);
            $(element).trigger(jQueryEvent);
            bubbles = !jQueryEvent.isPropagationStopped();
            nativeDispatch = !jQueryEvent.isImmediatePropagationStopped();
            defaultPrevented = jQueryEvent.isDefaultPrevented();
        }
        const evt = hydrateObj(new Event(event, {
            bubbles,
            cancelable: true
        }), args);
        if (defaultPrevented) evt.preventDefault();
        if (nativeDispatch) element.dispatchEvent(evt);
        if (evt.defaultPrevented && jQueryEvent) jQueryEvent.preventDefault();
        return evt;
    }
};
function hydrateObj(obj, meta = {}) {
    for (const [key, value] of Object.entries(meta))try {
        obj[key] = value;
    } catch (_unused) {
        Object.defineProperty(obj, key, {
            configurable: true,
            get () {
                return value;
            }
        });
    }
    return obj;
}
/**
 * --------------------------------------------------------------------------
 * Bootstrap dom/manipulator.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ function normalizeData(value) {
    if (value === 'true') return true;
    if (value === 'false') return false;
    if (value === Number(value).toString()) return Number(value);
    if (value === '' || value === 'null') return null;
    if (typeof value !== 'string') return value;
    try {
        return JSON.parse(decodeURIComponent(value));
    } catch (_unused) {
        return value;
    }
}
function normalizeDataKey(key) {
    return key.replace(/[A-Z]/g, (chr)=>`-${chr.toLowerCase()}`);
}
const Manipulator = {
    setDataAttribute (element, key, value) {
        element.setAttribute(`data-bs-${normalizeDataKey(key)}`, value);
    },
    removeDataAttribute (element, key) {
        element.removeAttribute(`data-bs-${normalizeDataKey(key)}`);
    },
    getDataAttributes (element) {
        if (!element) return {};
        const attributes = {};
        const bsKeys = Object.keys(element.dataset).filter((key)=>key.startsWith('bs') && !key.startsWith('bsConfig'));
        for (const key of bsKeys){
            let pureKey = key.replace(/^bs/, '');
            pureKey = pureKey.charAt(0).toLowerCase() + pureKey.slice(1);
            attributes[pureKey] = normalizeData(element.dataset[key]);
        }
        return attributes;
    },
    getDataAttribute (element, key) {
        return normalizeData(element.getAttribute(`data-bs-${normalizeDataKey(key)}`));
    }
};
/**
 * --------------------------------------------------------------------------
 * Bootstrap util/config.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Class definition
 */ class Config {
    // Getters
    static get Default() {
        return {};
    }
    static get DefaultType() {
        return {};
    }
    static get NAME() {
        throw new Error('You have to implement the static method "NAME", for each component!');
    }
    _getConfig(config) {
        config = this._mergeConfigObj(config);
        config = this._configAfterMerge(config);
        this._typeCheckConfig(config);
        return config;
    }
    _configAfterMerge(config) {
        return config;
    }
    _mergeConfigObj(config, element) {
        const jsonConfig = isElement(element) ? Manipulator.getDataAttribute(element, 'config') : {}; // try to parse
        return {
            ...this.constructor.Default,
            ...typeof jsonConfig === 'object' ? jsonConfig : {},
            ...isElement(element) ? Manipulator.getDataAttributes(element) : {},
            ...typeof config === 'object' ? config : {}
        };
    }
    _typeCheckConfig(config, configTypes = this.constructor.DefaultType) {
        for (const [property, expectedTypes] of Object.entries(configTypes)){
            const value = config[property];
            const valueType = isElement(value) ? 'element' : toType(value);
            if (!new RegExp(expectedTypes).test(valueType)) throw new TypeError(`${this.constructor.NAME.toUpperCase()}: Option "${property}" provided type "${valueType}" but expected type "${expectedTypes}".`);
        }
    }
}
/**
 * --------------------------------------------------------------------------
 * Bootstrap base-component.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const VERSION = '5.3.8';
/**
 * Class definition
 */ class BaseComponent extends Config {
    constructor(element, config){
        super();
        element = getElement(element);
        if (!element) return;
        this._element = element;
        this._config = this._getConfig(config);
        Data.set(this._element, this.constructor.DATA_KEY, this);
    }
    // Public
    dispose() {
        Data.remove(this._element, this.constructor.DATA_KEY);
        EventHandler.off(this._element, this.constructor.EVENT_KEY);
        for (const propertyName of Object.getOwnPropertyNames(this))this[propertyName] = null;
    }
    // Private
    _queueCallback(callback, element, isAnimated = true) {
        executeAfterTransition(callback, element, isAnimated);
    }
    _getConfig(config) {
        config = this._mergeConfigObj(config, this._element);
        config = this._configAfterMerge(config);
        this._typeCheckConfig(config);
        return config;
    }
    // Static
    static getInstance(element) {
        return Data.get(getElement(element), this.DATA_KEY);
    }
    static getOrCreateInstance(element, config = {}) {
        return this.getInstance(element) || new this(element, typeof config === 'object' ? config : null);
    }
    static get VERSION() {
        return VERSION;
    }
    static get DATA_KEY() {
        return `bs.${this.NAME}`;
    }
    static get EVENT_KEY() {
        return `.${this.DATA_KEY}`;
    }
    static eventName(name) {
        return `${name}${this.EVENT_KEY}`;
    }
}
/**
 * --------------------------------------------------------------------------
 * Bootstrap dom/selector-engine.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ const getSelector = (element)=>{
    let selector = element.getAttribute('data-bs-target');
    if (!selector || selector === '#') {
        let hrefAttribute = element.getAttribute('href');
        // The only valid content that could double as a selector are IDs or classes,
        // so everything starting with `#` or `.`. If a "real" URL is used as the selector,
        // `document.querySelector` will rightfully complain it is invalid.
        // See https://github.com/twbs/bootstrap/issues/32273
        if (!hrefAttribute || !hrefAttribute.includes('#') && !hrefAttribute.startsWith('.')) return null;
        // Just in case some CMS puts out a full URL with the anchor appended
        if (hrefAttribute.includes('#') && !hrefAttribute.startsWith('#')) hrefAttribute = `#${hrefAttribute.split('#')[1]}`;
        selector = hrefAttribute && hrefAttribute !== '#' ? hrefAttribute.trim() : null;
    }
    return selector ? selector.split(',').map((sel)=>parseSelector(sel)).join(',') : null;
};
const SelectorEngine = {
    find (selector, element = document.documentElement) {
        return [].concat(...Element.prototype.querySelectorAll.call(element, selector));
    },
    findOne (selector, element = document.documentElement) {
        return Element.prototype.querySelector.call(element, selector);
    },
    children (element, selector) {
        return [].concat(...element.children).filter((child)=>child.matches(selector));
    },
    parents (element, selector) {
        const parents = [];
        let ancestor = element.parentNode.closest(selector);
        while(ancestor){
            parents.push(ancestor);
            ancestor = ancestor.parentNode.closest(selector);
        }
        return parents;
    },
    prev (element, selector) {
        let previous = element.previousElementSibling;
        while(previous){
            if (previous.matches(selector)) return [
                previous
            ];
            previous = previous.previousElementSibling;
        }
        return [];
    },
    // TODO: this is now unused; remove later along with prev()
    next (element, selector) {
        let next = element.nextElementSibling;
        while(next){
            if (next.matches(selector)) return [
                next
            ];
            next = next.nextElementSibling;
        }
        return [];
    },
    focusableChildren (element) {
        const focusables = [
            'a',
            'button',
            'input',
            'textarea',
            'select',
            'details',
            '[tabindex]',
            '[contenteditable="true"]'
        ].map((selector)=>`${selector}:not([tabindex^="-"])`).join(',');
        return this.find(focusables, element).filter((el)=>!isDisabled(el) && isVisible(el));
    },
    getSelectorFromElement (element) {
        const selector = getSelector(element);
        if (selector) return SelectorEngine.findOne(selector) ? selector : null;
        return null;
    },
    getElementFromSelector (element) {
        const selector = getSelector(element);
        return selector ? SelectorEngine.findOne(selector) : null;
    },
    getMultipleElementsFromSelector (element) {
        const selector = getSelector(element);
        return selector ? SelectorEngine.find(selector) : [];
    }
};
/**
 * --------------------------------------------------------------------------
 * Bootstrap util/component-functions.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ const enableDismissTrigger = (component, method = 'hide')=>{
    const clickEvent = `click.dismiss${component.EVENT_KEY}`;
    const name = component.NAME;
    EventHandler.on(document, clickEvent, `[data-bs-dismiss="${name}"]`, function(event) {
        if ([
            'A',
            'AREA'
        ].includes(this.tagName)) event.preventDefault();
        if (isDisabled(this)) return;
        const target = SelectorEngine.getElementFromSelector(this) || this.closest(`.${name}`);
        const instance = component.getOrCreateInstance(target);
        // Method argument is left, for Alert and only, as it doesn't implement the 'hide' method
        instance[method]();
    });
};
/**
 * --------------------------------------------------------------------------
 * Bootstrap alert.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$f = 'alert';
const DATA_KEY$a = 'bs.alert';
const EVENT_KEY$b = `.${DATA_KEY$a}`;
const EVENT_CLOSE = `close${EVENT_KEY$b}`;
const EVENT_CLOSED = `closed${EVENT_KEY$b}`;
const CLASS_NAME_FADE$5 = 'fade';
const CLASS_NAME_SHOW$8 = 'show';
/**
 * Class definition
 */ class Alert extends BaseComponent {
    // Getters
    static get NAME() {
        return NAME$f;
    }
    // Public
    close() {
        const closeEvent = EventHandler.trigger(this._element, EVENT_CLOSE);
        if (closeEvent.defaultPrevented) return;
        this._element.classList.remove(CLASS_NAME_SHOW$8);
        const isAnimated = this._element.classList.contains(CLASS_NAME_FADE$5);
        this._queueCallback(()=>this._destroyElement(), this._element, isAnimated);
    }
    // Private
    _destroyElement() {
        this._element.remove();
        EventHandler.trigger(this._element, EVENT_CLOSED);
        this.dispose();
    }
    // Static
    static jQueryInterface(config) {
        return this.each(function() {
            const data = Alert.getOrCreateInstance(this);
            if (typeof config !== 'string') return;
            if (data[config] === undefined || config.startsWith('_') || config === 'constructor') throw new TypeError(`No method named "${config}"`);
            data[config](this);
        });
    }
}
/**
 * Data API implementation
 */ enableDismissTrigger(Alert, 'close');
/**
 * jQuery
 */ defineJQueryPlugin(Alert);
/**
 * --------------------------------------------------------------------------
 * Bootstrap button.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$e = 'button';
const DATA_KEY$9 = 'bs.button';
const EVENT_KEY$a = `.${DATA_KEY$9}`;
const DATA_API_KEY$6 = '.data-api';
const CLASS_NAME_ACTIVE$3 = 'active';
const SELECTOR_DATA_TOGGLE$5 = '[data-bs-toggle="button"]';
const EVENT_CLICK_DATA_API$6 = `click${EVENT_KEY$a}${DATA_API_KEY$6}`;
/**
 * Class definition
 */ class Button extends BaseComponent {
    // Getters
    static get NAME() {
        return NAME$e;
    }
    // Public
    toggle() {
        // Toggle class and sync the `aria-pressed` attribute with the return value of the `.toggle()` method
        this._element.setAttribute('aria-pressed', this._element.classList.toggle(CLASS_NAME_ACTIVE$3));
    }
    // Static
    static jQueryInterface(config) {
        return this.each(function() {
            const data = Button.getOrCreateInstance(this);
            if (config === 'toggle') data[config]();
        });
    }
}
/**
 * Data API implementation
 */ EventHandler.on(document, EVENT_CLICK_DATA_API$6, SELECTOR_DATA_TOGGLE$5, (event)=>{
    event.preventDefault();
    const button = event.target.closest(SELECTOR_DATA_TOGGLE$5);
    const data = Button.getOrCreateInstance(button);
    data.toggle();
});
/**
 * jQuery
 */ defineJQueryPlugin(Button);
/**
 * --------------------------------------------------------------------------
 * Bootstrap util/swipe.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$d = 'swipe';
const EVENT_KEY$9 = '.bs.swipe';
const EVENT_TOUCHSTART = `touchstart${EVENT_KEY$9}`;
const EVENT_TOUCHMOVE = `touchmove${EVENT_KEY$9}`;
const EVENT_TOUCHEND = `touchend${EVENT_KEY$9}`;
const EVENT_POINTERDOWN = `pointerdown${EVENT_KEY$9}`;
const EVENT_POINTERUP = `pointerup${EVENT_KEY$9}`;
const POINTER_TYPE_TOUCH = 'touch';
const POINTER_TYPE_PEN = 'pen';
const CLASS_NAME_POINTER_EVENT = 'pointer-event';
const SWIPE_THRESHOLD = 40;
const Default$c = {
    endCallback: null,
    leftCallback: null,
    rightCallback: null
};
const DefaultType$c = {
    endCallback: '(function|null)',
    leftCallback: '(function|null)',
    rightCallback: '(function|null)'
};
/**
 * Class definition
 */ class Swipe extends Config {
    constructor(element, config){
        super();
        this._element = element;
        if (!element || !Swipe.isSupported()) return;
        this._config = this._getConfig(config);
        this._deltaX = 0;
        this._supportPointerEvents = Boolean(window.PointerEvent);
        this._initEvents();
    }
    // Getters
    static get Default() {
        return Default$c;
    }
    static get DefaultType() {
        return DefaultType$c;
    }
    static get NAME() {
        return NAME$d;
    }
    // Public
    dispose() {
        EventHandler.off(this._element, EVENT_KEY$9);
    }
    // Private
    _start(event) {
        if (!this._supportPointerEvents) {
            this._deltaX = event.touches[0].clientX;
            return;
        }
        if (this._eventIsPointerPenTouch(event)) this._deltaX = event.clientX;
    }
    _end(event) {
        if (this._eventIsPointerPenTouch(event)) this._deltaX = event.clientX - this._deltaX;
        this._handleSwipe();
        execute(this._config.endCallback);
    }
    _move(event) {
        this._deltaX = event.touches && event.touches.length > 1 ? 0 : event.touches[0].clientX - this._deltaX;
    }
    _handleSwipe() {
        const absDeltaX = Math.abs(this._deltaX);
        if (absDeltaX <= SWIPE_THRESHOLD) return;
        const direction = absDeltaX / this._deltaX;
        this._deltaX = 0;
        if (!direction) return;
        execute(direction > 0 ? this._config.rightCallback : this._config.leftCallback);
    }
    _initEvents() {
        if (this._supportPointerEvents) {
            EventHandler.on(this._element, EVENT_POINTERDOWN, (event)=>this._start(event));
            EventHandler.on(this._element, EVENT_POINTERUP, (event)=>this._end(event));
            this._element.classList.add(CLASS_NAME_POINTER_EVENT);
        } else {
            EventHandler.on(this._element, EVENT_TOUCHSTART, (event)=>this._start(event));
            EventHandler.on(this._element, EVENT_TOUCHMOVE, (event)=>this._move(event));
            EventHandler.on(this._element, EVENT_TOUCHEND, (event)=>this._end(event));
        }
    }
    _eventIsPointerPenTouch(event) {
        return this._supportPointerEvents && (event.pointerType === POINTER_TYPE_PEN || event.pointerType === POINTER_TYPE_TOUCH);
    }
    // Static
    static isSupported() {
        return 'ontouchstart' in document.documentElement || navigator.maxTouchPoints > 0;
    }
}
/**
 * --------------------------------------------------------------------------
 * Bootstrap carousel.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$c = 'carousel';
const DATA_KEY$8 = 'bs.carousel';
const EVENT_KEY$8 = `.${DATA_KEY$8}`;
const DATA_API_KEY$5 = '.data-api';
const ARROW_LEFT_KEY$1 = 'ArrowLeft';
const ARROW_RIGHT_KEY$1 = 'ArrowRight';
const TOUCHEVENT_COMPAT_WAIT = 500; // Time for mouse compat events to fire after touch
const ORDER_NEXT = 'next';
const ORDER_PREV = 'prev';
const DIRECTION_LEFT = 'left';
const DIRECTION_RIGHT = 'right';
const EVENT_SLIDE = `slide${EVENT_KEY$8}`;
const EVENT_SLID = `slid${EVENT_KEY$8}`;
const EVENT_KEYDOWN$1 = `keydown${EVENT_KEY$8}`;
const EVENT_MOUSEENTER$1 = `mouseenter${EVENT_KEY$8}`;
const EVENT_MOUSELEAVE$1 = `mouseleave${EVENT_KEY$8}`;
const EVENT_DRAG_START = `dragstart${EVENT_KEY$8}`;
const EVENT_LOAD_DATA_API$3 = `load${EVENT_KEY$8}${DATA_API_KEY$5}`;
const EVENT_CLICK_DATA_API$5 = `click${EVENT_KEY$8}${DATA_API_KEY$5}`;
const CLASS_NAME_CAROUSEL = 'carousel';
const CLASS_NAME_ACTIVE$2 = 'active';
const CLASS_NAME_SLIDE = 'slide';
const CLASS_NAME_END = 'carousel-item-end';
const CLASS_NAME_START = 'carousel-item-start';
const CLASS_NAME_NEXT = 'carousel-item-next';
const CLASS_NAME_PREV = 'carousel-item-prev';
const SELECTOR_ACTIVE = '.active';
const SELECTOR_ITEM = '.carousel-item';
const SELECTOR_ACTIVE_ITEM = SELECTOR_ACTIVE + SELECTOR_ITEM;
const SELECTOR_ITEM_IMG = '.carousel-item img';
const SELECTOR_INDICATORS = '.carousel-indicators';
const SELECTOR_DATA_SLIDE = '[data-bs-slide], [data-bs-slide-to]';
const SELECTOR_DATA_RIDE = '[data-bs-ride="carousel"]';
const KEY_TO_DIRECTION = {
    [ARROW_LEFT_KEY$1]: DIRECTION_RIGHT,
    [ARROW_RIGHT_KEY$1]: DIRECTION_LEFT
};
const Default$b = {
    interval: 5000,
    keyboard: true,
    pause: 'hover',
    ride: false,
    touch: true,
    wrap: true
};
const DefaultType$b = {
    interval: '(number|boolean)',
    // TODO:v6 remove boolean support
    keyboard: 'boolean',
    pause: '(string|boolean)',
    ride: '(boolean|string)',
    touch: 'boolean',
    wrap: 'boolean'
};
/**
 * Class definition
 */ class Carousel extends BaseComponent {
    constructor(element, config){
        super(element, config);
        this._interval = null;
        this._activeElement = null;
        this._isSliding = false;
        this.touchTimeout = null;
        this._swipeHelper = null;
        this._indicatorsElement = SelectorEngine.findOne(SELECTOR_INDICATORS, this._element);
        this._addEventListeners();
        if (this._config.ride === CLASS_NAME_CAROUSEL) this.cycle();
    }
    // Getters
    static get Default() {
        return Default$b;
    }
    static get DefaultType() {
        return DefaultType$b;
    }
    static get NAME() {
        return NAME$c;
    }
    // Public
    next() {
        this._slide(ORDER_NEXT);
    }
    nextWhenVisible() {
        // FIXME TODO use `document.visibilityState`
        // Don't call next when the page isn't visible
        // or the carousel or its parent isn't visible
        if (!document.hidden && isVisible(this._element)) this.next();
    }
    prev() {
        this._slide(ORDER_PREV);
    }
    pause() {
        if (this._isSliding) triggerTransitionEnd(this._element);
        this._clearInterval();
    }
    cycle() {
        this._clearInterval();
        this._updateInterval();
        this._interval = setInterval(()=>this.nextWhenVisible(), this._config.interval);
    }
    _maybeEnableCycle() {
        if (!this._config.ride) return;
        if (this._isSliding) {
            EventHandler.one(this._element, EVENT_SLID, ()=>this.cycle());
            return;
        }
        this.cycle();
    }
    to(index) {
        const items = this._getItems();
        if (index > items.length - 1 || index < 0) return;
        if (this._isSliding) {
            EventHandler.one(this._element, EVENT_SLID, ()=>this.to(index));
            return;
        }
        const activeIndex = this._getItemIndex(this._getActive());
        if (activeIndex === index) return;
        const order = index > activeIndex ? ORDER_NEXT : ORDER_PREV;
        this._slide(order, items[index]);
    }
    dispose() {
        if (this._swipeHelper) this._swipeHelper.dispose();
        super.dispose();
    }
    // Private
    _configAfterMerge(config) {
        config.defaultInterval = config.interval;
        return config;
    }
    _addEventListeners() {
        if (this._config.keyboard) EventHandler.on(this._element, EVENT_KEYDOWN$1, (event)=>this._keydown(event));
        if (this._config.pause === 'hover') {
            EventHandler.on(this._element, EVENT_MOUSEENTER$1, ()=>this.pause());
            EventHandler.on(this._element, EVENT_MOUSELEAVE$1, ()=>this._maybeEnableCycle());
        }
        if (this._config.touch && Swipe.isSupported()) this._addTouchEventListeners();
    }
    _addTouchEventListeners() {
        for (const img of SelectorEngine.find(SELECTOR_ITEM_IMG, this._element))EventHandler.on(img, EVENT_DRAG_START, (event)=>event.preventDefault());
        const endCallBack = ()=>{
            if (this._config.pause !== 'hover') return;
            // If it's a touch-enabled device, mouseenter/leave are fired as
            // part of the mouse compatibility events on first tap - the carousel
            // would stop cycling until user tapped out of it;
            // here, we listen for touchend, explicitly pause the carousel
            // (as if it's the second time we tap on it, mouseenter compat event
            // is NOT fired) and after a timeout (to allow for mouse compatibility
            // events to fire) we explicitly restart cycling
            this.pause();
            if (this.touchTimeout) clearTimeout(this.touchTimeout);
            this.touchTimeout = setTimeout(()=>this._maybeEnableCycle(), TOUCHEVENT_COMPAT_WAIT + this._config.interval);
        };
        const swipeConfig = {
            leftCallback: ()=>this._slide(this._directionToOrder(DIRECTION_LEFT)),
            rightCallback: ()=>this._slide(this._directionToOrder(DIRECTION_RIGHT)),
            endCallback: endCallBack
        };
        this._swipeHelper = new Swipe(this._element, swipeConfig);
    }
    _keydown(event) {
        if (/input|textarea/i.test(event.target.tagName)) return;
        const direction = KEY_TO_DIRECTION[event.key];
        if (direction) {
            event.preventDefault();
            this._slide(this._directionToOrder(direction));
        }
    }
    _getItemIndex(element) {
        return this._getItems().indexOf(element);
    }
    _setActiveIndicatorElement(index) {
        if (!this._indicatorsElement) return;
        const activeIndicator = SelectorEngine.findOne(SELECTOR_ACTIVE, this._indicatorsElement);
        activeIndicator.classList.remove(CLASS_NAME_ACTIVE$2);
        activeIndicator.removeAttribute('aria-current');
        const newActiveIndicator = SelectorEngine.findOne(`[data-bs-slide-to="${index}"]`, this._indicatorsElement);
        if (newActiveIndicator) {
            newActiveIndicator.classList.add(CLASS_NAME_ACTIVE$2);
            newActiveIndicator.setAttribute('aria-current', 'true');
        }
    }
    _updateInterval() {
        const element = this._activeElement || this._getActive();
        if (!element) return;
        const elementInterval = Number.parseInt(element.getAttribute('data-bs-interval'), 10);
        this._config.interval = elementInterval || this._config.defaultInterval;
    }
    _slide(order, element = null) {
        if (this._isSliding) return;
        const activeElement = this._getActive();
        const isNext = order === ORDER_NEXT;
        const nextElement = element || getNextActiveElement(this._getItems(), activeElement, isNext, this._config.wrap);
        if (nextElement === activeElement) return;
        const nextElementIndex = this._getItemIndex(nextElement);
        const triggerEvent = (eventName)=>{
            return EventHandler.trigger(this._element, eventName, {
                relatedTarget: nextElement,
                direction: this._orderToDirection(order),
                from: this._getItemIndex(activeElement),
                to: nextElementIndex
            });
        };
        const slideEvent = triggerEvent(EVENT_SLIDE);
        if (slideEvent.defaultPrevented) return;
        if (!activeElement || !nextElement) // Some weirdness is happening, so we bail
        // TODO: change tests that use empty divs to avoid this check
        return;
        const isCycling = Boolean(this._interval);
        this.pause();
        this._isSliding = true;
        this._setActiveIndicatorElement(nextElementIndex);
        this._activeElement = nextElement;
        const directionalClassName = isNext ? CLASS_NAME_START : CLASS_NAME_END;
        const orderClassName = isNext ? CLASS_NAME_NEXT : CLASS_NAME_PREV;
        nextElement.classList.add(orderClassName);
        reflow(nextElement);
        activeElement.classList.add(directionalClassName);
        nextElement.classList.add(directionalClassName);
        const completeCallBack = ()=>{
            nextElement.classList.remove(directionalClassName, orderClassName);
            nextElement.classList.add(CLASS_NAME_ACTIVE$2);
            activeElement.classList.remove(CLASS_NAME_ACTIVE$2, orderClassName, directionalClassName);
            this._isSliding = false;
            triggerEvent(EVENT_SLID);
        };
        this._queueCallback(completeCallBack, activeElement, this._isAnimated());
        if (isCycling) this.cycle();
    }
    _isAnimated() {
        return this._element.classList.contains(CLASS_NAME_SLIDE);
    }
    _getActive() {
        return SelectorEngine.findOne(SELECTOR_ACTIVE_ITEM, this._element);
    }
    _getItems() {
        return SelectorEngine.find(SELECTOR_ITEM, this._element);
    }
    _clearInterval() {
        if (this._interval) {
            clearInterval(this._interval);
            this._interval = null;
        }
    }
    _directionToOrder(direction) {
        if (isRTL()) return direction === DIRECTION_LEFT ? ORDER_PREV : ORDER_NEXT;
        return direction === DIRECTION_LEFT ? ORDER_NEXT : ORDER_PREV;
    }
    _orderToDirection(order) {
        if (isRTL()) return order === ORDER_PREV ? DIRECTION_LEFT : DIRECTION_RIGHT;
        return order === ORDER_PREV ? DIRECTION_RIGHT : DIRECTION_LEFT;
    }
    // Static
    static jQueryInterface(config) {
        return this.each(function() {
            const data = Carousel.getOrCreateInstance(this, config);
            if (typeof config === 'number') {
                data.to(config);
                return;
            }
            if (typeof config === 'string') {
                if (data[config] === undefined || config.startsWith('_') || config === 'constructor') throw new TypeError(`No method named "${config}"`);
                data[config]();
            }
        });
    }
}
/**
 * Data API implementation
 */ EventHandler.on(document, EVENT_CLICK_DATA_API$5, SELECTOR_DATA_SLIDE, function(event) {
    const target = SelectorEngine.getElementFromSelector(this);
    if (!target || !target.classList.contains(CLASS_NAME_CAROUSEL)) return;
    event.preventDefault();
    const carousel = Carousel.getOrCreateInstance(target);
    const slideIndex = this.getAttribute('data-bs-slide-to');
    if (slideIndex) {
        carousel.to(slideIndex);
        carousel._maybeEnableCycle();
        return;
    }
    if (Manipulator.getDataAttribute(this, 'slide') === 'next') {
        carousel.next();
        carousel._maybeEnableCycle();
        return;
    }
    carousel.prev();
    carousel._maybeEnableCycle();
});
EventHandler.on(window, EVENT_LOAD_DATA_API$3, ()=>{
    const carousels = SelectorEngine.find(SELECTOR_DATA_RIDE);
    for (const carousel of carousels)Carousel.getOrCreateInstance(carousel);
});
/**
 * jQuery
 */ defineJQueryPlugin(Carousel);
/**
 * --------------------------------------------------------------------------
 * Bootstrap collapse.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$b = 'collapse';
const DATA_KEY$7 = 'bs.collapse';
const EVENT_KEY$7 = `.${DATA_KEY$7}`;
const DATA_API_KEY$4 = '.data-api';
const EVENT_SHOW$6 = `show${EVENT_KEY$7}`;
const EVENT_SHOWN$6 = `shown${EVENT_KEY$7}`;
const EVENT_HIDE$6 = `hide${EVENT_KEY$7}`;
const EVENT_HIDDEN$6 = `hidden${EVENT_KEY$7}`;
const EVENT_CLICK_DATA_API$4 = `click${EVENT_KEY$7}${DATA_API_KEY$4}`;
const CLASS_NAME_SHOW$7 = 'show';
const CLASS_NAME_COLLAPSE = 'collapse';
const CLASS_NAME_COLLAPSING = 'collapsing';
const CLASS_NAME_COLLAPSED = 'collapsed';
const CLASS_NAME_DEEPER_CHILDREN = `:scope .${CLASS_NAME_COLLAPSE} .${CLASS_NAME_COLLAPSE}`;
const CLASS_NAME_HORIZONTAL = 'collapse-horizontal';
const WIDTH = 'width';
const HEIGHT = 'height';
const SELECTOR_ACTIVES = '.collapse.show, .collapse.collapsing';
const SELECTOR_DATA_TOGGLE$4 = '[data-bs-toggle="collapse"]';
const Default$a = {
    parent: null,
    toggle: true
};
const DefaultType$a = {
    parent: '(null|element)',
    toggle: 'boolean'
};
/**
 * Class definition
 */ class Collapse extends BaseComponent {
    constructor(element, config){
        super(element, config);
        this._isTransitioning = false;
        this._triggerArray = [];
        const toggleList = SelectorEngine.find(SELECTOR_DATA_TOGGLE$4);
        for (const elem of toggleList){
            const selector = SelectorEngine.getSelectorFromElement(elem);
            const filterElement = SelectorEngine.find(selector).filter((foundElement)=>foundElement === this._element);
            if (selector !== null && filterElement.length) this._triggerArray.push(elem);
        }
        this._initializeChildren();
        if (!this._config.parent) this._addAriaAndCollapsedClass(this._triggerArray, this._isShown());
        if (this._config.toggle) this.toggle();
    }
    // Getters
    static get Default() {
        return Default$a;
    }
    static get DefaultType() {
        return DefaultType$a;
    }
    static get NAME() {
        return NAME$b;
    }
    // Public
    toggle() {
        if (this._isShown()) this.hide();
        else this.show();
    }
    show() {
        if (this._isTransitioning || this._isShown()) return;
        let activeChildren = [];
        // find active children
        if (this._config.parent) activeChildren = this._getFirstLevelChildren(SELECTOR_ACTIVES).filter((element)=>element !== this._element).map((element)=>Collapse.getOrCreateInstance(element, {
                toggle: false
            }));
        if (activeChildren.length && activeChildren[0]._isTransitioning) return;
        const startEvent = EventHandler.trigger(this._element, EVENT_SHOW$6);
        if (startEvent.defaultPrevented) return;
        for (const activeInstance of activeChildren)activeInstance.hide();
        const dimension = this._getDimension();
        this._element.classList.remove(CLASS_NAME_COLLAPSE);
        this._element.classList.add(CLASS_NAME_COLLAPSING);
        this._element.style[dimension] = 0;
        this._addAriaAndCollapsedClass(this._triggerArray, true);
        this._isTransitioning = true;
        const complete = ()=>{
            this._isTransitioning = false;
            this._element.classList.remove(CLASS_NAME_COLLAPSING);
            this._element.classList.add(CLASS_NAME_COLLAPSE, CLASS_NAME_SHOW$7);
            this._element.style[dimension] = '';
            EventHandler.trigger(this._element, EVENT_SHOWN$6);
        };
        const capitalizedDimension = dimension[0].toUpperCase() + dimension.slice(1);
        const scrollSize = `scroll${capitalizedDimension}`;
        this._queueCallback(complete, this._element, true);
        this._element.style[dimension] = `${this._element[scrollSize]}px`;
    }
    hide() {
        if (this._isTransitioning || !this._isShown()) return;
        const startEvent = EventHandler.trigger(this._element, EVENT_HIDE$6);
        if (startEvent.defaultPrevented) return;
        const dimension = this._getDimension();
        this._element.style[dimension] = `${this._element.getBoundingClientRect()[dimension]}px`;
        reflow(this._element);
        this._element.classList.add(CLASS_NAME_COLLAPSING);
        this._element.classList.remove(CLASS_NAME_COLLAPSE, CLASS_NAME_SHOW$7);
        for (const trigger of this._triggerArray){
            const element = SelectorEngine.getElementFromSelector(trigger);
            if (element && !this._isShown(element)) this._addAriaAndCollapsedClass([
                trigger
            ], false);
        }
        this._isTransitioning = true;
        const complete = ()=>{
            this._isTransitioning = false;
            this._element.classList.remove(CLASS_NAME_COLLAPSING);
            this._element.classList.add(CLASS_NAME_COLLAPSE);
            EventHandler.trigger(this._element, EVENT_HIDDEN$6);
        };
        this._element.style[dimension] = '';
        this._queueCallback(complete, this._element, true);
    }
    // Private
    _isShown(element = this._element) {
        return element.classList.contains(CLASS_NAME_SHOW$7);
    }
    _configAfterMerge(config) {
        config.toggle = Boolean(config.toggle); // Coerce string values
        config.parent = getElement(config.parent);
        return config;
    }
    _getDimension() {
        return this._element.classList.contains(CLASS_NAME_HORIZONTAL) ? WIDTH : HEIGHT;
    }
    _initializeChildren() {
        if (!this._config.parent) return;
        const children = this._getFirstLevelChildren(SELECTOR_DATA_TOGGLE$4);
        for (const element of children){
            const selected = SelectorEngine.getElementFromSelector(element);
            if (selected) this._addAriaAndCollapsedClass([
                element
            ], this._isShown(selected));
        }
    }
    _getFirstLevelChildren(selector) {
        const children = SelectorEngine.find(CLASS_NAME_DEEPER_CHILDREN, this._config.parent);
        // remove children if greater depth
        return SelectorEngine.find(selector, this._config.parent).filter((element)=>!children.includes(element));
    }
    _addAriaAndCollapsedClass(triggerArray, isOpen) {
        if (!triggerArray.length) return;
        for (const element of triggerArray){
            element.classList.toggle(CLASS_NAME_COLLAPSED, !isOpen);
            element.setAttribute('aria-expanded', isOpen);
        }
    }
    // Static
    static jQueryInterface(config) {
        const _config = {};
        if (typeof config === 'string' && /show|hide/.test(config)) _config.toggle = false;
        return this.each(function() {
            const data = Collapse.getOrCreateInstance(this, _config);
            if (typeof config === 'string') {
                if (typeof data[config] === 'undefined') throw new TypeError(`No method named "${config}"`);
                data[config]();
            }
        });
    }
}
/**
 * Data API implementation
 */ EventHandler.on(document, EVENT_CLICK_DATA_API$4, SELECTOR_DATA_TOGGLE$4, function(event) {
    // preventDefault only for <a> elements (which change the URL) not inside the collapsible element
    if (event.target.tagName === 'A' || event.delegateTarget && event.delegateTarget.tagName === 'A') event.preventDefault();
    for (const element of SelectorEngine.getMultipleElementsFromSelector(this))Collapse.getOrCreateInstance(element, {
        toggle: false
    }).toggle();
});
/**
 * jQuery
 */ defineJQueryPlugin(Collapse);
/**
 * --------------------------------------------------------------------------
 * Bootstrap dropdown.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$a = 'dropdown';
const DATA_KEY$6 = 'bs.dropdown';
const EVENT_KEY$6 = `.${DATA_KEY$6}`;
const DATA_API_KEY$3 = '.data-api';
const ESCAPE_KEY$2 = 'Escape';
const TAB_KEY$1 = 'Tab';
const ARROW_UP_KEY$1 = 'ArrowUp';
const ARROW_DOWN_KEY$1 = 'ArrowDown';
const RIGHT_MOUSE_BUTTON = 2; // MouseEvent.button value for the secondary button, usually the right button
const EVENT_HIDE$5 = `hide${EVENT_KEY$6}`;
const EVENT_HIDDEN$5 = `hidden${EVENT_KEY$6}`;
const EVENT_SHOW$5 = `show${EVENT_KEY$6}`;
const EVENT_SHOWN$5 = `shown${EVENT_KEY$6}`;
const EVENT_CLICK_DATA_API$3 = `click${EVENT_KEY$6}${DATA_API_KEY$3}`;
const EVENT_KEYDOWN_DATA_API = `keydown${EVENT_KEY$6}${DATA_API_KEY$3}`;
const EVENT_KEYUP_DATA_API = `keyup${EVENT_KEY$6}${DATA_API_KEY$3}`;
const CLASS_NAME_SHOW$6 = 'show';
const CLASS_NAME_DROPUP = 'dropup';
const CLASS_NAME_DROPEND = 'dropend';
const CLASS_NAME_DROPSTART = 'dropstart';
const CLASS_NAME_DROPUP_CENTER = 'dropup-center';
const CLASS_NAME_DROPDOWN_CENTER = 'dropdown-center';
const SELECTOR_DATA_TOGGLE$3 = '[data-bs-toggle="dropdown"]:not(.disabled):not(:disabled)';
const SELECTOR_DATA_TOGGLE_SHOWN = `${SELECTOR_DATA_TOGGLE$3}.${CLASS_NAME_SHOW$6}`;
const SELECTOR_MENU = '.dropdown-menu';
const SELECTOR_NAVBAR = '.navbar';
const SELECTOR_NAVBAR_NAV = '.navbar-nav';
const SELECTOR_VISIBLE_ITEMS = '.dropdown-menu .dropdown-item:not(.disabled):not(:disabled)';
const PLACEMENT_TOP = isRTL() ? 'top-end' : 'top-start';
const PLACEMENT_TOPEND = isRTL() ? 'top-start' : 'top-end';
const PLACEMENT_BOTTOM = isRTL() ? 'bottom-end' : 'bottom-start';
const PLACEMENT_BOTTOMEND = isRTL() ? 'bottom-start' : 'bottom-end';
const PLACEMENT_RIGHT = isRTL() ? 'left-start' : 'right-start';
const PLACEMENT_LEFT = isRTL() ? 'right-start' : 'left-start';
const PLACEMENT_TOPCENTER = 'top';
const PLACEMENT_BOTTOMCENTER = 'bottom';
const Default$9 = {
    autoClose: true,
    boundary: 'clippingParents',
    display: 'dynamic',
    offset: [
        0,
        2
    ],
    popperConfig: null,
    reference: 'toggle'
};
const DefaultType$9 = {
    autoClose: '(boolean|string)',
    boundary: '(string|element)',
    display: 'string',
    offset: '(array|string|function)',
    popperConfig: '(null|object|function)',
    reference: '(string|element|object)'
};
/**
 * Class definition
 */ class Dropdown extends BaseComponent {
    constructor(element, config){
        super(element, config);
        this._popper = null;
        this._parent = this._element.parentNode; // dropdown wrapper
        // TODO: v6 revert #37011 & change markup https://getbootstrap.com/docs/5.3/forms/input-group/
        this._menu = SelectorEngine.next(this._element, SELECTOR_MENU)[0] || SelectorEngine.prev(this._element, SELECTOR_MENU)[0] || SelectorEngine.findOne(SELECTOR_MENU, this._parent);
        this._inNavbar = this._detectNavbar();
    }
    // Getters
    static get Default() {
        return Default$9;
    }
    static get DefaultType() {
        return DefaultType$9;
    }
    static get NAME() {
        return NAME$a;
    }
    // Public
    toggle() {
        return this._isShown() ? this.hide() : this.show();
    }
    show() {
        if (isDisabled(this._element) || this._isShown()) return;
        const relatedTarget = {
            relatedTarget: this._element
        };
        const showEvent = EventHandler.trigger(this._element, EVENT_SHOW$5, relatedTarget);
        if (showEvent.defaultPrevented) return;
        this._createPopper();
        // If this is a touch-enabled device we add extra
        // empty mouseover listeners to the body's immediate children;
        // only needed because of broken event delegation on iOS
        // https://www.quirksmode.org/blog/archives/2014/02/mouse_event_bub.html
        if ('ontouchstart' in document.documentElement && !this._parent.closest(SELECTOR_NAVBAR_NAV)) for (const element of [].concat(...document.body.children))EventHandler.on(element, 'mouseover', noop);
        this._element.focus();
        this._element.setAttribute('aria-expanded', true);
        this._menu.classList.add(CLASS_NAME_SHOW$6);
        this._element.classList.add(CLASS_NAME_SHOW$6);
        EventHandler.trigger(this._element, EVENT_SHOWN$5, relatedTarget);
    }
    hide() {
        if (isDisabled(this._element) || !this._isShown()) return;
        const relatedTarget = {
            relatedTarget: this._element
        };
        this._completeHide(relatedTarget);
    }
    dispose() {
        if (this._popper) this._popper.destroy();
        super.dispose();
    }
    update() {
        this._inNavbar = this._detectNavbar();
        if (this._popper) this._popper.update();
    }
    // Private
    _completeHide(relatedTarget) {
        const hideEvent = EventHandler.trigger(this._element, EVENT_HIDE$5, relatedTarget);
        if (hideEvent.defaultPrevented) return;
        // If this is a touch-enabled device we remove the extra
        // empty mouseover listeners we added for iOS support
        if ('ontouchstart' in document.documentElement) for (const element of [].concat(...document.body.children))EventHandler.off(element, 'mouseover', noop);
        if (this._popper) this._popper.destroy();
        this._menu.classList.remove(CLASS_NAME_SHOW$6);
        this._element.classList.remove(CLASS_NAME_SHOW$6);
        this._element.setAttribute('aria-expanded', 'false');
        Manipulator.removeDataAttribute(this._menu, 'popper');
        EventHandler.trigger(this._element, EVENT_HIDDEN$5, relatedTarget);
    }
    _getConfig(config) {
        config = super._getConfig(config);
        if (typeof config.reference === 'object' && !isElement(config.reference) && typeof config.reference.getBoundingClientRect !== 'function') // Popper virtual elements require a getBoundingClientRect method
        throw new TypeError(`${NAME$a.toUpperCase()}: Option "reference" provided type "object" without a required "getBoundingClientRect" method.`);
        return config;
    }
    _createPopper() {
        if (typeof _core === 'undefined') throw new TypeError('Bootstrap\'s dropdowns require Popper (https://popper.js.org/docs/v2/)');
        let referenceElement = this._element;
        if (this._config.reference === 'parent') referenceElement = this._parent;
        else if (isElement(this._config.reference)) referenceElement = getElement(this._config.reference);
        else if (typeof this._config.reference === 'object') referenceElement = this._config.reference;
        const popperConfig = this._getPopperConfig();
        this._popper = _core.createPopper(referenceElement, this._menu, popperConfig);
    }
    _isShown() {
        return this._menu.classList.contains(CLASS_NAME_SHOW$6);
    }
    _getPlacement() {
        const parentDropdown = this._parent;
        if (parentDropdown.classList.contains(CLASS_NAME_DROPEND)) return PLACEMENT_RIGHT;
        if (parentDropdown.classList.contains(CLASS_NAME_DROPSTART)) return PLACEMENT_LEFT;
        if (parentDropdown.classList.contains(CLASS_NAME_DROPUP_CENTER)) return PLACEMENT_TOPCENTER;
        if (parentDropdown.classList.contains(CLASS_NAME_DROPDOWN_CENTER)) return PLACEMENT_BOTTOMCENTER;
        // We need to trim the value because custom properties can also include spaces
        const isEnd = getComputedStyle(this._menu).getPropertyValue('--bs-position').trim() === 'end';
        if (parentDropdown.classList.contains(CLASS_NAME_DROPUP)) return isEnd ? PLACEMENT_TOPEND : PLACEMENT_TOP;
        return isEnd ? PLACEMENT_BOTTOMEND : PLACEMENT_BOTTOM;
    }
    _detectNavbar() {
        return this._element.closest(SELECTOR_NAVBAR) !== null;
    }
    _getOffset() {
        const { offset } = this._config;
        if (typeof offset === 'string') return offset.split(',').map((value)=>Number.parseInt(value, 10));
        if (typeof offset === 'function') return (popperData)=>offset(popperData, this._element);
        return offset;
    }
    _getPopperConfig() {
        const defaultBsPopperConfig = {
            placement: this._getPlacement(),
            modifiers: [
                {
                    name: 'preventOverflow',
                    options: {
                        boundary: this._config.boundary
                    }
                },
                {
                    name: 'offset',
                    options: {
                        offset: this._getOffset()
                    }
                }
            ]
        };
        // Disable Popper if we have a static display or Dropdown is in Navbar
        if (this._inNavbar || this._config.display === 'static') {
            Manipulator.setDataAttribute(this._menu, 'popper', 'static'); // TODO: v6 remove
            defaultBsPopperConfig.modifiers = [
                {
                    name: 'applyStyles',
                    enabled: false
                }
            ];
        }
        return {
            ...defaultBsPopperConfig,
            ...execute(this._config.popperConfig, [
                undefined,
                defaultBsPopperConfig
            ])
        };
    }
    _selectMenuItem({ key, target }) {
        const items = SelectorEngine.find(SELECTOR_VISIBLE_ITEMS, this._menu).filter((element)=>isVisible(element));
        if (!items.length) return;
        // if target isn't included in items (e.g. when expanding the dropdown)
        // allow cycling to get the last item in case key equals ARROW_UP_KEY
        getNextActiveElement(items, target, key === ARROW_DOWN_KEY$1, !items.includes(target)).focus();
    }
    // Static
    static jQueryInterface(config) {
        return this.each(function() {
            const data = Dropdown.getOrCreateInstance(this, config);
            if (typeof config !== 'string') return;
            if (typeof data[config] === 'undefined') throw new TypeError(`No method named "${config}"`);
            data[config]();
        });
    }
    static clearMenus(event) {
        if (event.button === RIGHT_MOUSE_BUTTON || event.type === 'keyup' && event.key !== TAB_KEY$1) return;
        const openToggles = SelectorEngine.find(SELECTOR_DATA_TOGGLE_SHOWN);
        for (const toggle of openToggles){
            const context = Dropdown.getInstance(toggle);
            if (!context || context._config.autoClose === false) continue;
            const composedPath = event.composedPath();
            const isMenuTarget = composedPath.includes(context._menu);
            if (composedPath.includes(context._element) || context._config.autoClose === 'inside' && !isMenuTarget || context._config.autoClose === 'outside' && isMenuTarget) continue;
            // Tab navigation through the dropdown menu or events from contained inputs shouldn't close the menu
            if (context._menu.contains(event.target) && (event.type === 'keyup' && event.key === TAB_KEY$1 || /input|select|option|textarea|form/i.test(event.target.tagName))) continue;
            const relatedTarget = {
                relatedTarget: context._element
            };
            if (event.type === 'click') relatedTarget.clickEvent = event;
            context._completeHide(relatedTarget);
        }
    }
    static dataApiKeydownHandler(event) {
        // If not an UP | DOWN | ESCAPE key => not a dropdown command
        // If input/textarea && if key is other than ESCAPE => not a dropdown command
        const isInput = /input|textarea/i.test(event.target.tagName);
        const isEscapeEvent = event.key === ESCAPE_KEY$2;
        const isUpOrDownEvent = [
            ARROW_UP_KEY$1,
            ARROW_DOWN_KEY$1
        ].includes(event.key);
        if (!isUpOrDownEvent && !isEscapeEvent) return;
        if (isInput && !isEscapeEvent) return;
        event.preventDefault();
        // TODO: v6 revert #37011 & change markup https://getbootstrap.com/docs/5.3/forms/input-group/
        const getToggleButton = this.matches(SELECTOR_DATA_TOGGLE$3) ? this : SelectorEngine.prev(this, SELECTOR_DATA_TOGGLE$3)[0] || SelectorEngine.next(this, SELECTOR_DATA_TOGGLE$3)[0] || SelectorEngine.findOne(SELECTOR_DATA_TOGGLE$3, event.delegateTarget.parentNode);
        const instance = Dropdown.getOrCreateInstance(getToggleButton);
        if (isUpOrDownEvent) {
            event.stopPropagation();
            instance.show();
            instance._selectMenuItem(event);
            return;
        }
        if (instance._isShown()) {
            // else is escape and we check if it is shown
            event.stopPropagation();
            instance.hide();
            getToggleButton.focus();
        }
    }
}
/**
 * Data API implementation
 */ EventHandler.on(document, EVENT_KEYDOWN_DATA_API, SELECTOR_DATA_TOGGLE$3, Dropdown.dataApiKeydownHandler);
EventHandler.on(document, EVENT_KEYDOWN_DATA_API, SELECTOR_MENU, Dropdown.dataApiKeydownHandler);
EventHandler.on(document, EVENT_CLICK_DATA_API$3, Dropdown.clearMenus);
EventHandler.on(document, EVENT_KEYUP_DATA_API, Dropdown.clearMenus);
EventHandler.on(document, EVENT_CLICK_DATA_API$3, SELECTOR_DATA_TOGGLE$3, function(event) {
    event.preventDefault();
    Dropdown.getOrCreateInstance(this).toggle();
});
/**
 * jQuery
 */ defineJQueryPlugin(Dropdown);
/**
 * --------------------------------------------------------------------------
 * Bootstrap util/backdrop.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$9 = 'backdrop';
const CLASS_NAME_FADE$4 = 'fade';
const CLASS_NAME_SHOW$5 = 'show';
const EVENT_MOUSEDOWN = `mousedown.bs.${NAME$9}`;
const Default$8 = {
    className: 'modal-backdrop',
    clickCallback: null,
    isAnimated: false,
    isVisible: true,
    // if false, we use the backdrop helper without adding any element to the dom
    rootElement: 'body' // give the choice to place backdrop under different elements
};
const DefaultType$8 = {
    className: 'string',
    clickCallback: '(function|null)',
    isAnimated: 'boolean',
    isVisible: 'boolean',
    rootElement: '(element|string)'
};
/**
 * Class definition
 */ class Backdrop extends Config {
    constructor(config){
        super();
        this._config = this._getConfig(config);
        this._isAppended = false;
        this._element = null;
    }
    // Getters
    static get Default() {
        return Default$8;
    }
    static get DefaultType() {
        return DefaultType$8;
    }
    static get NAME() {
        return NAME$9;
    }
    // Public
    show(callback) {
        if (!this._config.isVisible) {
            execute(callback);
            return;
        }
        this._append();
        const element = this._getElement();
        if (this._config.isAnimated) reflow(element);
        element.classList.add(CLASS_NAME_SHOW$5);
        this._emulateAnimation(()=>{
            execute(callback);
        });
    }
    hide(callback) {
        if (!this._config.isVisible) {
            execute(callback);
            return;
        }
        this._getElement().classList.remove(CLASS_NAME_SHOW$5);
        this._emulateAnimation(()=>{
            this.dispose();
            execute(callback);
        });
    }
    dispose() {
        if (!this._isAppended) return;
        EventHandler.off(this._element, EVENT_MOUSEDOWN);
        this._element.remove();
        this._isAppended = false;
    }
    // Private
    _getElement() {
        if (!this._element) {
            const backdrop = document.createElement('div');
            backdrop.className = this._config.className;
            if (this._config.isAnimated) backdrop.classList.add(CLASS_NAME_FADE$4);
            this._element = backdrop;
        }
        return this._element;
    }
    _configAfterMerge(config) {
        // use getElement() with the default "body" to get a fresh Element on each instantiation
        config.rootElement = getElement(config.rootElement);
        return config;
    }
    _append() {
        if (this._isAppended) return;
        const element = this._getElement();
        this._config.rootElement.append(element);
        EventHandler.on(element, EVENT_MOUSEDOWN, ()=>{
            execute(this._config.clickCallback);
        });
        this._isAppended = true;
    }
    _emulateAnimation(callback) {
        executeAfterTransition(callback, this._getElement(), this._config.isAnimated);
    }
}
/**
 * --------------------------------------------------------------------------
 * Bootstrap util/focustrap.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$8 = 'focustrap';
const DATA_KEY$5 = 'bs.focustrap';
const EVENT_KEY$5 = `.${DATA_KEY$5}`;
const EVENT_FOCUSIN$2 = `focusin${EVENT_KEY$5}`;
const EVENT_KEYDOWN_TAB = `keydown.tab${EVENT_KEY$5}`;
const TAB_KEY = 'Tab';
const TAB_NAV_FORWARD = 'forward';
const TAB_NAV_BACKWARD = 'backward';
const Default$7 = {
    autofocus: true,
    trapElement: null // The element to trap focus inside of
};
const DefaultType$7 = {
    autofocus: 'boolean',
    trapElement: 'element'
};
/**
 * Class definition
 */ class FocusTrap extends Config {
    constructor(config){
        super();
        this._config = this._getConfig(config);
        this._isActive = false;
        this._lastTabNavDirection = null;
    }
    // Getters
    static get Default() {
        return Default$7;
    }
    static get DefaultType() {
        return DefaultType$7;
    }
    static get NAME() {
        return NAME$8;
    }
    // Public
    activate() {
        if (this._isActive) return;
        if (this._config.autofocus) this._config.trapElement.focus();
        EventHandler.off(document, EVENT_KEY$5); // guard against infinite focus loop
        EventHandler.on(document, EVENT_FOCUSIN$2, (event)=>this._handleFocusin(event));
        EventHandler.on(document, EVENT_KEYDOWN_TAB, (event)=>this._handleKeydown(event));
        this._isActive = true;
    }
    deactivate() {
        if (!this._isActive) return;
        this._isActive = false;
        EventHandler.off(document, EVENT_KEY$5);
    }
    // Private
    _handleFocusin(event) {
        const { trapElement } = this._config;
        if (event.target === document || event.target === trapElement || trapElement.contains(event.target)) return;
        const elements = SelectorEngine.focusableChildren(trapElement);
        if (elements.length === 0) trapElement.focus();
        else if (this._lastTabNavDirection === TAB_NAV_BACKWARD) elements[elements.length - 1].focus();
        else elements[0].focus();
    }
    _handleKeydown(event) {
        if (event.key !== TAB_KEY) return;
        this._lastTabNavDirection = event.shiftKey ? TAB_NAV_BACKWARD : TAB_NAV_FORWARD;
    }
}
/**
 * --------------------------------------------------------------------------
 * Bootstrap util/scrollBar.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const SELECTOR_FIXED_CONTENT = '.fixed-top, .fixed-bottom, .is-fixed, .sticky-top';
const SELECTOR_STICKY_CONTENT = '.sticky-top';
const PROPERTY_PADDING = 'padding-right';
const PROPERTY_MARGIN = 'margin-right';
/**
 * Class definition
 */ class ScrollBarHelper {
    constructor(){
        this._element = document.body;
    }
    // Public
    getWidth() {
        // https://developer.mozilla.org/en-US/docs/Web/API/Window/innerWidth#usage_notes
        const documentWidth = document.documentElement.clientWidth;
        return Math.abs(window.innerWidth - documentWidth);
    }
    hide() {
        const width = this.getWidth();
        this._disableOverFlow();
        // give padding to element to balance the hidden scrollbar width
        this._setElementAttributes(this._element, PROPERTY_PADDING, (calculatedValue)=>calculatedValue + width);
        // trick: We adjust positive paddingRight and negative marginRight to sticky-top elements to keep showing fullwidth
        this._setElementAttributes(SELECTOR_FIXED_CONTENT, PROPERTY_PADDING, (calculatedValue)=>calculatedValue + width);
        this._setElementAttributes(SELECTOR_STICKY_CONTENT, PROPERTY_MARGIN, (calculatedValue)=>calculatedValue - width);
    }
    reset() {
        this._resetElementAttributes(this._element, 'overflow');
        this._resetElementAttributes(this._element, PROPERTY_PADDING);
        this._resetElementAttributes(SELECTOR_FIXED_CONTENT, PROPERTY_PADDING);
        this._resetElementAttributes(SELECTOR_STICKY_CONTENT, PROPERTY_MARGIN);
    }
    isOverflowing() {
        return this.getWidth() > 0;
    }
    // Private
    _disableOverFlow() {
        this._saveInitialAttribute(this._element, 'overflow');
        this._element.style.overflow = 'hidden';
    }
    _setElementAttributes(selector, styleProperty, callback) {
        const scrollbarWidth = this.getWidth();
        const manipulationCallBack = (element)=>{
            if (element !== this._element && window.innerWidth > element.clientWidth + scrollbarWidth) return;
            this._saveInitialAttribute(element, styleProperty);
            const calculatedValue = window.getComputedStyle(element).getPropertyValue(styleProperty);
            element.style.setProperty(styleProperty, `${callback(Number.parseFloat(calculatedValue))}px`);
        };
        this._applyManipulationCallback(selector, manipulationCallBack);
    }
    _saveInitialAttribute(element, styleProperty) {
        const actualValue = element.style.getPropertyValue(styleProperty);
        if (actualValue) Manipulator.setDataAttribute(element, styleProperty, actualValue);
    }
    _resetElementAttributes(selector, styleProperty) {
        const manipulationCallBack = (element)=>{
            const value = Manipulator.getDataAttribute(element, styleProperty);
            // We only want to remove the property if the value is `null`; the value can also be zero
            if (value === null) {
                element.style.removeProperty(styleProperty);
                return;
            }
            Manipulator.removeDataAttribute(element, styleProperty);
            element.style.setProperty(styleProperty, value);
        };
        this._applyManipulationCallback(selector, manipulationCallBack);
    }
    _applyManipulationCallback(selector, callBack) {
        if (isElement(selector)) {
            callBack(selector);
            return;
        }
        for (const sel of SelectorEngine.find(selector, this._element))callBack(sel);
    }
}
/**
 * --------------------------------------------------------------------------
 * Bootstrap modal.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$7 = 'modal';
const DATA_KEY$4 = 'bs.modal';
const EVENT_KEY$4 = `.${DATA_KEY$4}`;
const DATA_API_KEY$2 = '.data-api';
const ESCAPE_KEY$1 = 'Escape';
const EVENT_HIDE$4 = `hide${EVENT_KEY$4}`;
const EVENT_HIDE_PREVENTED$1 = `hidePrevented${EVENT_KEY$4}`;
const EVENT_HIDDEN$4 = `hidden${EVENT_KEY$4}`;
const EVENT_SHOW$4 = `show${EVENT_KEY$4}`;
const EVENT_SHOWN$4 = `shown${EVENT_KEY$4}`;
const EVENT_RESIZE$1 = `resize${EVENT_KEY$4}`;
const EVENT_CLICK_DISMISS = `click.dismiss${EVENT_KEY$4}`;
const EVENT_MOUSEDOWN_DISMISS = `mousedown.dismiss${EVENT_KEY$4}`;
const EVENT_KEYDOWN_DISMISS$1 = `keydown.dismiss${EVENT_KEY$4}`;
const EVENT_CLICK_DATA_API$2 = `click${EVENT_KEY$4}${DATA_API_KEY$2}`;
const CLASS_NAME_OPEN = 'modal-open';
const CLASS_NAME_FADE$3 = 'fade';
const CLASS_NAME_SHOW$4 = 'show';
const CLASS_NAME_STATIC = 'modal-static';
const OPEN_SELECTOR$1 = '.modal.show';
const SELECTOR_DIALOG = '.modal-dialog';
const SELECTOR_MODAL_BODY = '.modal-body';
const SELECTOR_DATA_TOGGLE$2 = '[data-bs-toggle="modal"]';
const Default$6 = {
    backdrop: true,
    focus: true,
    keyboard: true
};
const DefaultType$6 = {
    backdrop: '(boolean|string)',
    focus: 'boolean',
    keyboard: 'boolean'
};
/**
 * Class definition
 */ class Modal extends BaseComponent {
    constructor(element, config){
        super(element, config);
        this._dialog = SelectorEngine.findOne(SELECTOR_DIALOG, this._element);
        this._backdrop = this._initializeBackDrop();
        this._focustrap = this._initializeFocusTrap();
        this._isShown = false;
        this._isTransitioning = false;
        this._scrollBar = new ScrollBarHelper();
        this._addEventListeners();
    }
    // Getters
    static get Default() {
        return Default$6;
    }
    static get DefaultType() {
        return DefaultType$6;
    }
    static get NAME() {
        return NAME$7;
    }
    // Public
    toggle(relatedTarget) {
        return this._isShown ? this.hide() : this.show(relatedTarget);
    }
    show(relatedTarget) {
        if (this._isShown || this._isTransitioning) return;
        const showEvent = EventHandler.trigger(this._element, EVENT_SHOW$4, {
            relatedTarget
        });
        if (showEvent.defaultPrevented) return;
        this._isShown = true;
        this._isTransitioning = true;
        this._scrollBar.hide();
        document.body.classList.add(CLASS_NAME_OPEN);
        this._adjustDialog();
        this._backdrop.show(()=>this._showElement(relatedTarget));
    }
    hide() {
        if (!this._isShown || this._isTransitioning) return;
        const hideEvent = EventHandler.trigger(this._element, EVENT_HIDE$4);
        if (hideEvent.defaultPrevented) return;
        this._isShown = false;
        this._isTransitioning = true;
        this._focustrap.deactivate();
        this._element.classList.remove(CLASS_NAME_SHOW$4);
        this._queueCallback(()=>this._hideModal(), this._element, this._isAnimated());
    }
    dispose() {
        EventHandler.off(window, EVENT_KEY$4);
        EventHandler.off(this._dialog, EVENT_KEY$4);
        this._backdrop.dispose();
        this._focustrap.deactivate();
        super.dispose();
    }
    handleUpdate() {
        this._adjustDialog();
    }
    // Private
    _initializeBackDrop() {
        return new Backdrop({
            isVisible: Boolean(this._config.backdrop),
            // 'static' option will be translated to true, and booleans will keep their value,
            isAnimated: this._isAnimated()
        });
    }
    _initializeFocusTrap() {
        return new FocusTrap({
            trapElement: this._element
        });
    }
    _showElement(relatedTarget) {
        // try to append dynamic modal
        if (!document.body.contains(this._element)) document.body.append(this._element);
        this._element.style.display = 'block';
        this._element.removeAttribute('aria-hidden');
        this._element.setAttribute('aria-modal', true);
        this._element.setAttribute('role', 'dialog');
        this._element.scrollTop = 0;
        const modalBody = SelectorEngine.findOne(SELECTOR_MODAL_BODY, this._dialog);
        if (modalBody) modalBody.scrollTop = 0;
        reflow(this._element);
        this._element.classList.add(CLASS_NAME_SHOW$4);
        const transitionComplete = ()=>{
            if (this._config.focus) this._focustrap.activate();
            this._isTransitioning = false;
            EventHandler.trigger(this._element, EVENT_SHOWN$4, {
                relatedTarget
            });
        };
        this._queueCallback(transitionComplete, this._dialog, this._isAnimated());
    }
    _addEventListeners() {
        EventHandler.on(this._element, EVENT_KEYDOWN_DISMISS$1, (event)=>{
            if (event.key !== ESCAPE_KEY$1) return;
            if (this._config.keyboard) {
                this.hide();
                return;
            }
            this._triggerBackdropTransition();
        });
        EventHandler.on(window, EVENT_RESIZE$1, ()=>{
            if (this._isShown && !this._isTransitioning) this._adjustDialog();
        });
        EventHandler.on(this._element, EVENT_MOUSEDOWN_DISMISS, (event)=>{
            // a bad trick to segregate clicks that may start inside dialog but end outside, and avoid listen to scrollbar clicks
            EventHandler.one(this._element, EVENT_CLICK_DISMISS, (event2)=>{
                if (this._element !== event.target || this._element !== event2.target) return;
                if (this._config.backdrop === 'static') {
                    this._triggerBackdropTransition();
                    return;
                }
                if (this._config.backdrop) this.hide();
            });
        });
    }
    _hideModal() {
        this._element.style.display = 'none';
        this._element.setAttribute('aria-hidden', true);
        this._element.removeAttribute('aria-modal');
        this._element.removeAttribute('role');
        this._isTransitioning = false;
        this._backdrop.hide(()=>{
            document.body.classList.remove(CLASS_NAME_OPEN);
            this._resetAdjustments();
            this._scrollBar.reset();
            EventHandler.trigger(this._element, EVENT_HIDDEN$4);
        });
    }
    _isAnimated() {
        return this._element.classList.contains(CLASS_NAME_FADE$3);
    }
    _triggerBackdropTransition() {
        const hideEvent = EventHandler.trigger(this._element, EVENT_HIDE_PREVENTED$1);
        if (hideEvent.defaultPrevented) return;
        const isModalOverflowing = this._element.scrollHeight > document.documentElement.clientHeight;
        const initialOverflowY = this._element.style.overflowY;
        // return if the following background transition hasn't yet completed
        if (initialOverflowY === 'hidden' || this._element.classList.contains(CLASS_NAME_STATIC)) return;
        if (!isModalOverflowing) this._element.style.overflowY = 'hidden';
        this._element.classList.add(CLASS_NAME_STATIC);
        this._queueCallback(()=>{
            this._element.classList.remove(CLASS_NAME_STATIC);
            this._queueCallback(()=>{
                this._element.style.overflowY = initialOverflowY;
            }, this._dialog);
        }, this._dialog);
        this._element.focus();
    }
    /**
   * The following methods are used to handle overflowing modals
   */ _adjustDialog() {
        const isModalOverflowing = this._element.scrollHeight > document.documentElement.clientHeight;
        const scrollbarWidth = this._scrollBar.getWidth();
        const isBodyOverflowing = scrollbarWidth > 0;
        if (isBodyOverflowing && !isModalOverflowing) {
            const property = isRTL() ? 'paddingLeft' : 'paddingRight';
            this._element.style[property] = `${scrollbarWidth}px`;
        }
        if (!isBodyOverflowing && isModalOverflowing) {
            const property = isRTL() ? 'paddingRight' : 'paddingLeft';
            this._element.style[property] = `${scrollbarWidth}px`;
        }
    }
    _resetAdjustments() {
        this._element.style.paddingLeft = '';
        this._element.style.paddingRight = '';
    }
    // Static
    static jQueryInterface(config, relatedTarget) {
        return this.each(function() {
            const data = Modal.getOrCreateInstance(this, config);
            if (typeof config !== 'string') return;
            if (typeof data[config] === 'undefined') throw new TypeError(`No method named "${config}"`);
            data[config](relatedTarget);
        });
    }
}
/**
 * Data API implementation
 */ EventHandler.on(document, EVENT_CLICK_DATA_API$2, SELECTOR_DATA_TOGGLE$2, function(event) {
    const target = SelectorEngine.getElementFromSelector(this);
    if ([
        'A',
        'AREA'
    ].includes(this.tagName)) event.preventDefault();
    EventHandler.one(target, EVENT_SHOW$4, (showEvent)=>{
        if (showEvent.defaultPrevented) // only register focus restorer if modal will actually get shown
        return;
        EventHandler.one(target, EVENT_HIDDEN$4, ()=>{
            if (isVisible(this)) this.focus();
        });
    });
    // avoid conflict when clicking modal toggler while another one is open
    const alreadyOpen = SelectorEngine.findOne(OPEN_SELECTOR$1);
    if (alreadyOpen) Modal.getInstance(alreadyOpen).hide();
    const data = Modal.getOrCreateInstance(target);
    data.toggle(this);
});
enableDismissTrigger(Modal);
/**
 * jQuery
 */ defineJQueryPlugin(Modal);
/**
 * --------------------------------------------------------------------------
 * Bootstrap offcanvas.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$6 = 'offcanvas';
const DATA_KEY$3 = 'bs.offcanvas';
const EVENT_KEY$3 = `.${DATA_KEY$3}`;
const DATA_API_KEY$1 = '.data-api';
const EVENT_LOAD_DATA_API$2 = `load${EVENT_KEY$3}${DATA_API_KEY$1}`;
const ESCAPE_KEY = 'Escape';
const CLASS_NAME_SHOW$3 = 'show';
const CLASS_NAME_SHOWING$1 = 'showing';
const CLASS_NAME_HIDING = 'hiding';
const CLASS_NAME_BACKDROP = 'offcanvas-backdrop';
const OPEN_SELECTOR = '.offcanvas.show';
const EVENT_SHOW$3 = `show${EVENT_KEY$3}`;
const EVENT_SHOWN$3 = `shown${EVENT_KEY$3}`;
const EVENT_HIDE$3 = `hide${EVENT_KEY$3}`;
const EVENT_HIDE_PREVENTED = `hidePrevented${EVENT_KEY$3}`;
const EVENT_HIDDEN$3 = `hidden${EVENT_KEY$3}`;
const EVENT_RESIZE = `resize${EVENT_KEY$3}`;
const EVENT_CLICK_DATA_API$1 = `click${EVENT_KEY$3}${DATA_API_KEY$1}`;
const EVENT_KEYDOWN_DISMISS = `keydown.dismiss${EVENT_KEY$3}`;
const SELECTOR_DATA_TOGGLE$1 = '[data-bs-toggle="offcanvas"]';
const Default$5 = {
    backdrop: true,
    keyboard: true,
    scroll: false
};
const DefaultType$5 = {
    backdrop: '(boolean|string)',
    keyboard: 'boolean',
    scroll: 'boolean'
};
/**
 * Class definition
 */ class Offcanvas extends BaseComponent {
    constructor(element, config){
        super(element, config);
        this._isShown = false;
        this._backdrop = this._initializeBackDrop();
        this._focustrap = this._initializeFocusTrap();
        this._addEventListeners();
    }
    // Getters
    static get Default() {
        return Default$5;
    }
    static get DefaultType() {
        return DefaultType$5;
    }
    static get NAME() {
        return NAME$6;
    }
    // Public
    toggle(relatedTarget) {
        return this._isShown ? this.hide() : this.show(relatedTarget);
    }
    show(relatedTarget) {
        if (this._isShown) return;
        const showEvent = EventHandler.trigger(this._element, EVENT_SHOW$3, {
            relatedTarget
        });
        if (showEvent.defaultPrevented) return;
        this._isShown = true;
        this._backdrop.show();
        if (!this._config.scroll) new ScrollBarHelper().hide();
        this._element.setAttribute('aria-modal', true);
        this._element.setAttribute('role', 'dialog');
        this._element.classList.add(CLASS_NAME_SHOWING$1);
        const completeCallBack = ()=>{
            if (!this._config.scroll || this._config.backdrop) this._focustrap.activate();
            this._element.classList.add(CLASS_NAME_SHOW$3);
            this._element.classList.remove(CLASS_NAME_SHOWING$1);
            EventHandler.trigger(this._element, EVENT_SHOWN$3, {
                relatedTarget
            });
        };
        this._queueCallback(completeCallBack, this._element, true);
    }
    hide() {
        if (!this._isShown) return;
        const hideEvent = EventHandler.trigger(this._element, EVENT_HIDE$3);
        if (hideEvent.defaultPrevented) return;
        this._focustrap.deactivate();
        this._element.blur();
        this._isShown = false;
        this._element.classList.add(CLASS_NAME_HIDING);
        this._backdrop.hide();
        const completeCallback = ()=>{
            this._element.classList.remove(CLASS_NAME_SHOW$3, CLASS_NAME_HIDING);
            this._element.removeAttribute('aria-modal');
            this._element.removeAttribute('role');
            if (!this._config.scroll) new ScrollBarHelper().reset();
            EventHandler.trigger(this._element, EVENT_HIDDEN$3);
        };
        this._queueCallback(completeCallback, this._element, true);
    }
    dispose() {
        this._backdrop.dispose();
        this._focustrap.deactivate();
        super.dispose();
    }
    // Private
    _initializeBackDrop() {
        const clickCallback = ()=>{
            if (this._config.backdrop === 'static') {
                EventHandler.trigger(this._element, EVENT_HIDE_PREVENTED);
                return;
            }
            this.hide();
        };
        // 'static' option will be translated to true, and booleans will keep their value
        const isVisible = Boolean(this._config.backdrop);
        return new Backdrop({
            className: CLASS_NAME_BACKDROP,
            isVisible,
            isAnimated: true,
            rootElement: this._element.parentNode,
            clickCallback: isVisible ? clickCallback : null
        });
    }
    _initializeFocusTrap() {
        return new FocusTrap({
            trapElement: this._element
        });
    }
    _addEventListeners() {
        EventHandler.on(this._element, EVENT_KEYDOWN_DISMISS, (event)=>{
            if (event.key !== ESCAPE_KEY) return;
            if (this._config.keyboard) {
                this.hide();
                return;
            }
            EventHandler.trigger(this._element, EVENT_HIDE_PREVENTED);
        });
    }
    // Static
    static jQueryInterface(config) {
        return this.each(function() {
            const data = Offcanvas.getOrCreateInstance(this, config);
            if (typeof config !== 'string') return;
            if (data[config] === undefined || config.startsWith('_') || config === 'constructor') throw new TypeError(`No method named "${config}"`);
            data[config](this);
        });
    }
}
/**
 * Data API implementation
 */ EventHandler.on(document, EVENT_CLICK_DATA_API$1, SELECTOR_DATA_TOGGLE$1, function(event) {
    const target = SelectorEngine.getElementFromSelector(this);
    if ([
        'A',
        'AREA'
    ].includes(this.tagName)) event.preventDefault();
    if (isDisabled(this)) return;
    EventHandler.one(target, EVENT_HIDDEN$3, ()=>{
        // focus on trigger when it is closed
        if (isVisible(this)) this.focus();
    });
    // avoid conflict when clicking a toggler of an offcanvas, while another is open
    const alreadyOpen = SelectorEngine.findOne(OPEN_SELECTOR);
    if (alreadyOpen && alreadyOpen !== target) Offcanvas.getInstance(alreadyOpen).hide();
    const data = Offcanvas.getOrCreateInstance(target);
    data.toggle(this);
});
EventHandler.on(window, EVENT_LOAD_DATA_API$2, ()=>{
    for (const selector of SelectorEngine.find(OPEN_SELECTOR))Offcanvas.getOrCreateInstance(selector).show();
});
EventHandler.on(window, EVENT_RESIZE, ()=>{
    for (const element of SelectorEngine.find('[aria-modal][class*=show][class*=offcanvas-]'))if (getComputedStyle(element).position !== 'fixed') Offcanvas.getOrCreateInstance(element).hide();
});
enableDismissTrigger(Offcanvas);
/**
 * jQuery
 */ defineJQueryPlugin(Offcanvas);
/**
 * --------------------------------------------------------------------------
 * Bootstrap util/sanitizer.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ // js-docs-start allow-list
const ARIA_ATTRIBUTE_PATTERN = /^aria-[\w-]*$/i;
const DefaultAllowlist = {
    // Global attributes allowed on any supplied element below.
    '*': [
        'class',
        'dir',
        'id',
        'lang',
        'role',
        ARIA_ATTRIBUTE_PATTERN
    ],
    a: [
        'target',
        'href',
        'title',
        'rel'
    ],
    area: [],
    b: [],
    br: [],
    col: [],
    code: [],
    dd: [],
    div: [],
    dl: [],
    dt: [],
    em: [],
    hr: [],
    h1: [],
    h2: [],
    h3: [],
    h4: [],
    h5: [],
    h6: [],
    i: [],
    img: [
        'src',
        'srcset',
        'alt',
        'title',
        'width',
        'height'
    ],
    li: [],
    ol: [],
    p: [],
    pre: [],
    s: [],
    small: [],
    span: [],
    sub: [],
    sup: [],
    strong: [],
    u: [],
    ul: []
};
// js-docs-end allow-list
const uriAttributes = new Set([
    'background',
    'cite',
    'href',
    'itemtype',
    'longdesc',
    'poster',
    'src',
    'xlink:href'
]);
/**
 * A pattern that recognizes URLs that are safe wrt. XSS in URL navigation
 * contexts.
 *
 * Shout-out to Angular https://github.com/angular/angular/blob/15.2.8/packages/core/src/sanitization/url_sanitizer.ts#L38
 */ const SAFE_URL_PATTERN = /^(?!javascript:)(?:[a-z0-9+.-]+:|[^&:/?#]*(?:[/?#]|$))/i;
const allowedAttribute = (attribute, allowedAttributeList)=>{
    const attributeName = attribute.nodeName.toLowerCase();
    if (allowedAttributeList.includes(attributeName)) {
        if (uriAttributes.has(attributeName)) return Boolean(SAFE_URL_PATTERN.test(attribute.nodeValue));
        return true;
    }
    // Check if a regular expression validates the attribute.
    return allowedAttributeList.filter((attributeRegex)=>attributeRegex instanceof RegExp).some((regex)=>regex.test(attributeName));
};
function sanitizeHtml(unsafeHtml, allowList, sanitizeFunction) {
    if (!unsafeHtml.length) return unsafeHtml;
    if (sanitizeFunction && typeof sanitizeFunction === 'function') return sanitizeFunction(unsafeHtml);
    const domParser = new window.DOMParser();
    const createdDocument = domParser.parseFromString(unsafeHtml, 'text/html');
    const elements = [].concat(...createdDocument.body.querySelectorAll('*'));
    for (const element of elements){
        const elementName = element.nodeName.toLowerCase();
        if (!Object.keys(allowList).includes(elementName)) {
            element.remove();
            continue;
        }
        const attributeList = [].concat(...element.attributes);
        const allowedAttributes = [].concat(allowList['*'] || [], allowList[elementName] || []);
        for (const attribute of attributeList)if (!allowedAttribute(attribute, allowedAttributes)) element.removeAttribute(attribute.nodeName);
    }
    return createdDocument.body.innerHTML;
}
/**
 * --------------------------------------------------------------------------
 * Bootstrap util/template-factory.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$5 = 'TemplateFactory';
const Default$4 = {
    allowList: DefaultAllowlist,
    content: {},
    // { selector : text ,  selector2 : text2 , }
    extraClass: '',
    html: false,
    sanitize: true,
    sanitizeFn: null,
    template: '<div></div>'
};
const DefaultType$4 = {
    allowList: 'object',
    content: 'object',
    extraClass: '(string|function)',
    html: 'boolean',
    sanitize: 'boolean',
    sanitizeFn: '(null|function)',
    template: 'string'
};
const DefaultContentType = {
    entry: '(string|element|function|null)',
    selector: '(string|element)'
};
/**
 * Class definition
 */ class TemplateFactory extends Config {
    constructor(config){
        super();
        this._config = this._getConfig(config);
    }
    // Getters
    static get Default() {
        return Default$4;
    }
    static get DefaultType() {
        return DefaultType$4;
    }
    static get NAME() {
        return NAME$5;
    }
    // Public
    getContent() {
        return Object.values(this._config.content).map((config)=>this._resolvePossibleFunction(config)).filter(Boolean);
    }
    hasContent() {
        return this.getContent().length > 0;
    }
    changeContent(content) {
        this._checkContent(content);
        this._config.content = {
            ...this._config.content,
            ...content
        };
        return this;
    }
    toHtml() {
        const templateWrapper = document.createElement('div');
        templateWrapper.innerHTML = this._maybeSanitize(this._config.template);
        for (const [selector, text] of Object.entries(this._config.content))this._setContent(templateWrapper, text, selector);
        const template = templateWrapper.children[0];
        const extraClass = this._resolvePossibleFunction(this._config.extraClass);
        if (extraClass) template.classList.add(...extraClass.split(' '));
        return template;
    }
    // Private
    _typeCheckConfig(config) {
        super._typeCheckConfig(config);
        this._checkContent(config.content);
    }
    _checkContent(arg) {
        for (const [selector, content] of Object.entries(arg))super._typeCheckConfig({
            selector,
            entry: content
        }, DefaultContentType);
    }
    _setContent(template, content, selector) {
        const templateElement = SelectorEngine.findOne(selector, template);
        if (!templateElement) return;
        content = this._resolvePossibleFunction(content);
        if (!content) {
            templateElement.remove();
            return;
        }
        if (isElement(content)) {
            this._putElementInTemplate(getElement(content), templateElement);
            return;
        }
        if (this._config.html) {
            templateElement.innerHTML = this._maybeSanitize(content);
            return;
        }
        templateElement.textContent = content;
    }
    _maybeSanitize(arg) {
        return this._config.sanitize ? sanitizeHtml(arg, this._config.allowList, this._config.sanitizeFn) : arg;
    }
    _resolvePossibleFunction(arg) {
        return execute(arg, [
            undefined,
            this
        ]);
    }
    _putElementInTemplate(element, templateElement) {
        if (this._config.html) {
            templateElement.innerHTML = '';
            templateElement.append(element);
            return;
        }
        templateElement.textContent = element.textContent;
    }
}
/**
 * --------------------------------------------------------------------------
 * Bootstrap tooltip.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$4 = 'tooltip';
const DISALLOWED_ATTRIBUTES = new Set([
    'sanitize',
    'allowList',
    'sanitizeFn'
]);
const CLASS_NAME_FADE$2 = 'fade';
const CLASS_NAME_MODAL = 'modal';
const CLASS_NAME_SHOW$2 = 'show';
const SELECTOR_TOOLTIP_INNER = '.tooltip-inner';
const SELECTOR_MODAL = `.${CLASS_NAME_MODAL}`;
const EVENT_MODAL_HIDE = 'hide.bs.modal';
const TRIGGER_HOVER = 'hover';
const TRIGGER_FOCUS = 'focus';
const TRIGGER_CLICK = 'click';
const TRIGGER_MANUAL = 'manual';
const EVENT_HIDE$2 = 'hide';
const EVENT_HIDDEN$2 = 'hidden';
const EVENT_SHOW$2 = 'show';
const EVENT_SHOWN$2 = 'shown';
const EVENT_INSERTED = 'inserted';
const EVENT_CLICK$1 = 'click';
const EVENT_FOCUSIN$1 = 'focusin';
const EVENT_FOCUSOUT$1 = 'focusout';
const EVENT_MOUSEENTER = 'mouseenter';
const EVENT_MOUSELEAVE = 'mouseleave';
const AttachmentMap = {
    AUTO: 'auto',
    TOP: 'top',
    RIGHT: isRTL() ? 'left' : 'right',
    BOTTOM: 'bottom',
    LEFT: isRTL() ? 'right' : 'left'
};
const Default$3 = {
    allowList: DefaultAllowlist,
    animation: true,
    boundary: 'clippingParents',
    container: false,
    customClass: '',
    delay: 0,
    fallbackPlacements: [
        'top',
        'right',
        'bottom',
        'left'
    ],
    html: false,
    offset: [
        0,
        6
    ],
    placement: 'top',
    popperConfig: null,
    sanitize: true,
    sanitizeFn: null,
    selector: false,
    template: '<div class="tooltip" role="tooltip"><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div>',
    title: '',
    trigger: 'hover focus'
};
const DefaultType$3 = {
    allowList: 'object',
    animation: 'boolean',
    boundary: '(string|element)',
    container: '(string|element|boolean)',
    customClass: '(string|function)',
    delay: '(number|object)',
    fallbackPlacements: 'array',
    html: 'boolean',
    offset: '(array|string|function)',
    placement: '(string|function)',
    popperConfig: '(null|object|function)',
    sanitize: 'boolean',
    sanitizeFn: '(null|function)',
    selector: '(string|boolean)',
    template: 'string',
    title: '(string|element|function)',
    trigger: 'string'
};
/**
 * Class definition
 */ class Tooltip extends BaseComponent {
    constructor(element, config){
        if (typeof _core === 'undefined') throw new TypeError('Bootstrap\'s tooltips require Popper (https://popper.js.org/docs/v2/)');
        super(element, config);
        // Private
        this._isEnabled = true;
        this._timeout = 0;
        this._isHovered = null;
        this._activeTrigger = {};
        this._popper = null;
        this._templateFactory = null;
        this._newContent = null;
        // Protected
        this.tip = null;
        this._setListeners();
        if (!this._config.selector) this._fixTitle();
    }
    // Getters
    static get Default() {
        return Default$3;
    }
    static get DefaultType() {
        return DefaultType$3;
    }
    static get NAME() {
        return NAME$4;
    }
    // Public
    enable() {
        this._isEnabled = true;
    }
    disable() {
        this._isEnabled = false;
    }
    toggleEnabled() {
        this._isEnabled = !this._isEnabled;
    }
    toggle() {
        if (!this._isEnabled) return;
        if (this._isShown()) {
            this._leave();
            return;
        }
        this._enter();
    }
    dispose() {
        clearTimeout(this._timeout);
        EventHandler.off(this._element.closest(SELECTOR_MODAL), EVENT_MODAL_HIDE, this._hideModalHandler);
        if (this._element.getAttribute('data-bs-original-title')) this._element.setAttribute('title', this._element.getAttribute('data-bs-original-title'));
        this._disposePopper();
        super.dispose();
    }
    show() {
        if (this._element.style.display === 'none') throw new Error('Please use show on visible elements');
        if (!(this._isWithContent() && this._isEnabled)) return;
        const showEvent = EventHandler.trigger(this._element, this.constructor.eventName(EVENT_SHOW$2));
        const shadowRoot = findShadowRoot(this._element);
        const isInTheDom = (shadowRoot || this._element.ownerDocument.documentElement).contains(this._element);
        if (showEvent.defaultPrevented || !isInTheDom) return;
        // TODO: v6 remove this or make it optional
        this._disposePopper();
        const tip = this._getTipElement();
        this._element.setAttribute('aria-describedby', tip.getAttribute('id'));
        const { container } = this._config;
        if (!this._element.ownerDocument.documentElement.contains(this.tip)) {
            container.append(tip);
            EventHandler.trigger(this._element, this.constructor.eventName(EVENT_INSERTED));
        }
        this._popper = this._createPopper(tip);
        tip.classList.add(CLASS_NAME_SHOW$2);
        // If this is a touch-enabled device we add extra
        // empty mouseover listeners to the body's immediate children;
        // only needed because of broken event delegation on iOS
        // https://www.quirksmode.org/blog/archives/2014/02/mouse_event_bub.html
        if ('ontouchstart' in document.documentElement) for (const element of [].concat(...document.body.children))EventHandler.on(element, 'mouseover', noop);
        const complete = ()=>{
            EventHandler.trigger(this._element, this.constructor.eventName(EVENT_SHOWN$2));
            if (this._isHovered === false) this._leave();
            this._isHovered = false;
        };
        this._queueCallback(complete, this.tip, this._isAnimated());
    }
    hide() {
        if (!this._isShown()) return;
        const hideEvent = EventHandler.trigger(this._element, this.constructor.eventName(EVENT_HIDE$2));
        if (hideEvent.defaultPrevented) return;
        const tip = this._getTipElement();
        tip.classList.remove(CLASS_NAME_SHOW$2);
        // If this is a touch-enabled device we remove the extra
        // empty mouseover listeners we added for iOS support
        if ('ontouchstart' in document.documentElement) for (const element of [].concat(...document.body.children))EventHandler.off(element, 'mouseover', noop);
        this._activeTrigger[TRIGGER_CLICK] = false;
        this._activeTrigger[TRIGGER_FOCUS] = false;
        this._activeTrigger[TRIGGER_HOVER] = false;
        this._isHovered = null; // it is a trick to support manual triggering
        const complete = ()=>{
            if (this._isWithActiveTrigger()) return;
            if (!this._isHovered) this._disposePopper();
            this._element.removeAttribute('aria-describedby');
            EventHandler.trigger(this._element, this.constructor.eventName(EVENT_HIDDEN$2));
        };
        this._queueCallback(complete, this.tip, this._isAnimated());
    }
    update() {
        if (this._popper) this._popper.update();
    }
    // Protected
    _isWithContent() {
        return Boolean(this._getTitle());
    }
    _getTipElement() {
        if (!this.tip) this.tip = this._createTipElement(this._newContent || this._getContentForTemplate());
        return this.tip;
    }
    _createTipElement(content) {
        const tip = this._getTemplateFactory(content).toHtml();
        // TODO: remove this check in v6
        if (!tip) return null;
        tip.classList.remove(CLASS_NAME_FADE$2, CLASS_NAME_SHOW$2);
        // TODO: v6 the following can be achieved with CSS only
        tip.classList.add(`bs-${this.constructor.NAME}-auto`);
        const tipId = getUID(this.constructor.NAME).toString();
        tip.setAttribute('id', tipId);
        if (this._isAnimated()) tip.classList.add(CLASS_NAME_FADE$2);
        return tip;
    }
    setContent(content) {
        this._newContent = content;
        if (this._isShown()) {
            this._disposePopper();
            this.show();
        }
    }
    _getTemplateFactory(content) {
        if (this._templateFactory) this._templateFactory.changeContent(content);
        else this._templateFactory = new TemplateFactory({
            ...this._config,
            // the `content` var has to be after `this._config`
            // to override config.content in case of popover
            content,
            extraClass: this._resolvePossibleFunction(this._config.customClass)
        });
        return this._templateFactory;
    }
    _getContentForTemplate() {
        return {
            [SELECTOR_TOOLTIP_INNER]: this._getTitle()
        };
    }
    _getTitle() {
        return this._resolvePossibleFunction(this._config.title) || this._element.getAttribute('data-bs-original-title');
    }
    // Private
    _initializeOnDelegatedTarget(event) {
        return this.constructor.getOrCreateInstance(event.delegateTarget, this._getDelegateConfig());
    }
    _isAnimated() {
        return this._config.animation || this.tip && this.tip.classList.contains(CLASS_NAME_FADE$2);
    }
    _isShown() {
        return this.tip && this.tip.classList.contains(CLASS_NAME_SHOW$2);
    }
    _createPopper(tip) {
        const placement = execute(this._config.placement, [
            this,
            tip,
            this._element
        ]);
        const attachment = AttachmentMap[placement.toUpperCase()];
        return _core.createPopper(this._element, tip, this._getPopperConfig(attachment));
    }
    _getOffset() {
        const { offset } = this._config;
        if (typeof offset === 'string') return offset.split(',').map((value)=>Number.parseInt(value, 10));
        if (typeof offset === 'function') return (popperData)=>offset(popperData, this._element);
        return offset;
    }
    _resolvePossibleFunction(arg) {
        return execute(arg, [
            this._element,
            this._element
        ]);
    }
    _getPopperConfig(attachment) {
        const defaultBsPopperConfig = {
            placement: attachment,
            modifiers: [
                {
                    name: 'flip',
                    options: {
                        fallbackPlacements: this._config.fallbackPlacements
                    }
                },
                {
                    name: 'offset',
                    options: {
                        offset: this._getOffset()
                    }
                },
                {
                    name: 'preventOverflow',
                    options: {
                        boundary: this._config.boundary
                    }
                },
                {
                    name: 'arrow',
                    options: {
                        element: `.${this.constructor.NAME}-arrow`
                    }
                },
                {
                    name: 'preSetPlacement',
                    enabled: true,
                    phase: 'beforeMain',
                    fn: (data)=>{
                        // Pre-set Popper's placement attribute in order to read the arrow sizes properly.
                        // Otherwise, Popper mixes up the width and height dimensions since the initial arrow style is for top placement
                        this._getTipElement().setAttribute('data-popper-placement', data.state.placement);
                    }
                }
            ]
        };
        return {
            ...defaultBsPopperConfig,
            ...execute(this._config.popperConfig, [
                undefined,
                defaultBsPopperConfig
            ])
        };
    }
    _setListeners() {
        const triggers = this._config.trigger.split(' ');
        for (const trigger of triggers){
            if (trigger === 'click') EventHandler.on(this._element, this.constructor.eventName(EVENT_CLICK$1), this._config.selector, (event)=>{
                const context = this._initializeOnDelegatedTarget(event);
                context._activeTrigger[TRIGGER_CLICK] = !(context._isShown() && context._activeTrigger[TRIGGER_CLICK]);
                context.toggle();
            });
            else if (trigger !== TRIGGER_MANUAL) {
                const eventIn = trigger === TRIGGER_HOVER ? this.constructor.eventName(EVENT_MOUSEENTER) : this.constructor.eventName(EVENT_FOCUSIN$1);
                const eventOut = trigger === TRIGGER_HOVER ? this.constructor.eventName(EVENT_MOUSELEAVE) : this.constructor.eventName(EVENT_FOCUSOUT$1);
                EventHandler.on(this._element, eventIn, this._config.selector, (event)=>{
                    const context = this._initializeOnDelegatedTarget(event);
                    context._activeTrigger[event.type === 'focusin' ? TRIGGER_FOCUS : TRIGGER_HOVER] = true;
                    context._enter();
                });
                EventHandler.on(this._element, eventOut, this._config.selector, (event)=>{
                    const context = this._initializeOnDelegatedTarget(event);
                    context._activeTrigger[event.type === 'focusout' ? TRIGGER_FOCUS : TRIGGER_HOVER] = context._element.contains(event.relatedTarget);
                    context._leave();
                });
            }
        }
        this._hideModalHandler = ()=>{
            if (this._element) this.hide();
        };
        EventHandler.on(this._element.closest(SELECTOR_MODAL), EVENT_MODAL_HIDE, this._hideModalHandler);
    }
    _fixTitle() {
        const title = this._element.getAttribute('title');
        if (!title) return;
        if (!this._element.getAttribute('aria-label') && !this._element.textContent.trim()) this._element.setAttribute('aria-label', title);
        this._element.setAttribute('data-bs-original-title', title); // DO NOT USE IT. Is only for backwards compatibility
        this._element.removeAttribute('title');
    }
    _enter() {
        if (this._isShown() || this._isHovered) {
            this._isHovered = true;
            return;
        }
        this._isHovered = true;
        this._setTimeout(()=>{
            if (this._isHovered) this.show();
        }, this._config.delay.show);
    }
    _leave() {
        if (this._isWithActiveTrigger()) return;
        this._isHovered = false;
        this._setTimeout(()=>{
            if (!this._isHovered) this.hide();
        }, this._config.delay.hide);
    }
    _setTimeout(handler, timeout) {
        clearTimeout(this._timeout);
        this._timeout = setTimeout(handler, timeout);
    }
    _isWithActiveTrigger() {
        return Object.values(this._activeTrigger).includes(true);
    }
    _getConfig(config) {
        const dataAttributes = Manipulator.getDataAttributes(this._element);
        for (const dataAttribute of Object.keys(dataAttributes))if (DISALLOWED_ATTRIBUTES.has(dataAttribute)) delete dataAttributes[dataAttribute];
        config = {
            ...dataAttributes,
            ...typeof config === 'object' && config ? config : {}
        };
        config = this._mergeConfigObj(config);
        config = this._configAfterMerge(config);
        this._typeCheckConfig(config);
        return config;
    }
    _configAfterMerge(config) {
        config.container = config.container === false ? document.body : getElement(config.container);
        if (typeof config.delay === 'number') config.delay = {
            show: config.delay,
            hide: config.delay
        };
        if (typeof config.title === 'number') config.title = config.title.toString();
        if (typeof config.content === 'number') config.content = config.content.toString();
        return config;
    }
    _getDelegateConfig() {
        const config = {};
        for (const [key, value] of Object.entries(this._config))if (this.constructor.Default[key] !== value) config[key] = value;
        config.selector = false;
        config.trigger = 'manual';
        // In the future can be replaced with:
        // const keysWithDifferentValues = Object.entries(this._config).filter(entry => this.constructor.Default[entry[0]] !== this._config[entry[0]])
        // `Object.fromEntries(keysWithDifferentValues)`
        return config;
    }
    _disposePopper() {
        if (this._popper) {
            this._popper.destroy();
            this._popper = null;
        }
        if (this.tip) {
            this.tip.remove();
            this.tip = null;
        }
    }
    // Static
    static jQueryInterface(config) {
        return this.each(function() {
            const data = Tooltip.getOrCreateInstance(this, config);
            if (typeof config !== 'string') return;
            if (typeof data[config] === 'undefined') throw new TypeError(`No method named "${config}"`);
            data[config]();
        });
    }
}
/**
 * jQuery
 */ defineJQueryPlugin(Tooltip);
/**
 * --------------------------------------------------------------------------
 * Bootstrap popover.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$3 = 'popover';
const SELECTOR_TITLE = '.popover-header';
const SELECTOR_CONTENT = '.popover-body';
const Default$2 = {
    ...Tooltip.Default,
    content: '',
    offset: [
        0,
        8
    ],
    placement: 'right',
    template: '<div class="popover" role="tooltip"><div class="popover-arrow"></div><h3 class="popover-header"></h3><div class="popover-body"></div></div>',
    trigger: 'click'
};
const DefaultType$2 = {
    ...Tooltip.DefaultType,
    content: '(null|string|element|function)'
};
/**
 * Class definition
 */ class Popover extends Tooltip {
    // Getters
    static get Default() {
        return Default$2;
    }
    static get DefaultType() {
        return DefaultType$2;
    }
    static get NAME() {
        return NAME$3;
    }
    // Overrides
    _isWithContent() {
        return this._getTitle() || this._getContent();
    }
    // Private
    _getContentForTemplate() {
        return {
            [SELECTOR_TITLE]: this._getTitle(),
            [SELECTOR_CONTENT]: this._getContent()
        };
    }
    _getContent() {
        return this._resolvePossibleFunction(this._config.content);
    }
    // Static
    static jQueryInterface(config) {
        return this.each(function() {
            const data = Popover.getOrCreateInstance(this, config);
            if (typeof config !== 'string') return;
            if (typeof data[config] === 'undefined') throw new TypeError(`No method named "${config}"`);
            data[config]();
        });
    }
}
/**
 * jQuery
 */ defineJQueryPlugin(Popover);
/**
 * --------------------------------------------------------------------------
 * Bootstrap scrollspy.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$2 = 'scrollspy';
const DATA_KEY$2 = 'bs.scrollspy';
const EVENT_KEY$2 = `.${DATA_KEY$2}`;
const DATA_API_KEY = '.data-api';
const EVENT_ACTIVATE = `activate${EVENT_KEY$2}`;
const EVENT_CLICK = `click${EVENT_KEY$2}`;
const EVENT_LOAD_DATA_API$1 = `load${EVENT_KEY$2}${DATA_API_KEY}`;
const CLASS_NAME_DROPDOWN_ITEM = 'dropdown-item';
const CLASS_NAME_ACTIVE$1 = 'active';
const SELECTOR_DATA_SPY = '[data-bs-spy="scroll"]';
const SELECTOR_TARGET_LINKS = '[href]';
const SELECTOR_NAV_LIST_GROUP = '.nav, .list-group';
const SELECTOR_NAV_LINKS = '.nav-link';
const SELECTOR_NAV_ITEMS = '.nav-item';
const SELECTOR_LIST_ITEMS = '.list-group-item';
const SELECTOR_LINK_ITEMS = `${SELECTOR_NAV_LINKS}, ${SELECTOR_NAV_ITEMS} > ${SELECTOR_NAV_LINKS}, ${SELECTOR_LIST_ITEMS}`;
const SELECTOR_DROPDOWN = '.dropdown';
const SELECTOR_DROPDOWN_TOGGLE$1 = '.dropdown-toggle';
const Default$1 = {
    offset: null,
    // TODO: v6 @deprecated, keep it for backwards compatibility reasons
    rootMargin: '0px 0px -25%',
    smoothScroll: false,
    target: null,
    threshold: [
        0.1,
        0.5,
        1
    ]
};
const DefaultType$1 = {
    offset: '(number|null)',
    // TODO v6 @deprecated, keep it for backwards compatibility reasons
    rootMargin: 'string',
    smoothScroll: 'boolean',
    target: 'element',
    threshold: 'array'
};
/**
 * Class definition
 */ class ScrollSpy extends BaseComponent {
    constructor(element, config){
        super(element, config);
        // this._element is the observablesContainer and config.target the menu links wrapper
        this._targetLinks = new Map();
        this._observableSections = new Map();
        this._rootElement = getComputedStyle(this._element).overflowY === 'visible' ? null : this._element;
        this._activeTarget = null;
        this._observer = null;
        this._previousScrollData = {
            visibleEntryTop: 0,
            parentScrollTop: 0
        };
        this.refresh(); // initialize
    }
    // Getters
    static get Default() {
        return Default$1;
    }
    static get DefaultType() {
        return DefaultType$1;
    }
    static get NAME() {
        return NAME$2;
    }
    // Public
    refresh() {
        this._initializeTargetsAndObservables();
        this._maybeEnableSmoothScroll();
        if (this._observer) this._observer.disconnect();
        else this._observer = this._getNewObserver();
        for (const section of this._observableSections.values())this._observer.observe(section);
    }
    dispose() {
        this._observer.disconnect();
        super.dispose();
    }
    // Private
    _configAfterMerge(config) {
        // TODO: on v6 target should be given explicitly & remove the {target: 'ss-target'} case
        config.target = getElement(config.target) || document.body;
        // TODO: v6 Only for backwards compatibility reasons. Use rootMargin only
        config.rootMargin = config.offset ? `${config.offset}px 0px -30%` : config.rootMargin;
        if (typeof config.threshold === 'string') config.threshold = config.threshold.split(',').map((value)=>Number.parseFloat(value));
        return config;
    }
    _maybeEnableSmoothScroll() {
        if (!this._config.smoothScroll) return;
        // unregister any previous listeners
        EventHandler.off(this._config.target, EVENT_CLICK);
        EventHandler.on(this._config.target, EVENT_CLICK, SELECTOR_TARGET_LINKS, (event)=>{
            const observableSection = this._observableSections.get(event.target.hash);
            if (observableSection) {
                event.preventDefault();
                const root = this._rootElement || window;
                const height = observableSection.offsetTop - this._element.offsetTop;
                if (root.scrollTo) {
                    root.scrollTo({
                        top: height,
                        behavior: 'smooth'
                    });
                    return;
                }
                // Chrome 60 doesn't support `scrollTo`
                root.scrollTop = height;
            }
        });
    }
    _getNewObserver() {
        const options = {
            root: this._rootElement,
            threshold: this._config.threshold,
            rootMargin: this._config.rootMargin
        };
        return new IntersectionObserver((entries)=>this._observerCallback(entries), options);
    }
    // The logic of selection
    _observerCallback(entries) {
        const targetElement = (entry)=>this._targetLinks.get(`#${entry.target.id}`);
        const activate = (entry)=>{
            this._previousScrollData.visibleEntryTop = entry.target.offsetTop;
            this._process(targetElement(entry));
        };
        const parentScrollTop = (this._rootElement || document.documentElement).scrollTop;
        const userScrollsDown = parentScrollTop >= this._previousScrollData.parentScrollTop;
        this._previousScrollData.parentScrollTop = parentScrollTop;
        for (const entry of entries){
            if (!entry.isIntersecting) {
                this._activeTarget = null;
                this._clearActiveClass(targetElement(entry));
                continue;
            }
            const entryIsLowerThanPrevious = entry.target.offsetTop >= this._previousScrollData.visibleEntryTop;
            // if we are scrolling down, pick the bigger offsetTop
            if (userScrollsDown && entryIsLowerThanPrevious) {
                activate(entry);
                // if parent isn't scrolled, let's keep the first visible item, breaking the iteration
                if (!parentScrollTop) return;
                continue;
            }
            // if we are scrolling up, pick the smallest offsetTop
            if (!userScrollsDown && !entryIsLowerThanPrevious) activate(entry);
        }
    }
    _initializeTargetsAndObservables() {
        this._targetLinks = new Map();
        this._observableSections = new Map();
        const targetLinks = SelectorEngine.find(SELECTOR_TARGET_LINKS, this._config.target);
        for (const anchor of targetLinks){
            // ensure that the anchor has an id and is not disabled
            if (!anchor.hash || isDisabled(anchor)) continue;
            const observableSection = SelectorEngine.findOne(decodeURI(anchor.hash), this._element);
            // ensure that the observableSection exists & is visible
            if (isVisible(observableSection)) {
                this._targetLinks.set(decodeURI(anchor.hash), anchor);
                this._observableSections.set(anchor.hash, observableSection);
            }
        }
    }
    _process(target) {
        if (this._activeTarget === target) return;
        this._clearActiveClass(this._config.target);
        this._activeTarget = target;
        target.classList.add(CLASS_NAME_ACTIVE$1);
        this._activateParents(target);
        EventHandler.trigger(this._element, EVENT_ACTIVATE, {
            relatedTarget: target
        });
    }
    _activateParents(target) {
        // Activate dropdown parents
        if (target.classList.contains(CLASS_NAME_DROPDOWN_ITEM)) {
            SelectorEngine.findOne(SELECTOR_DROPDOWN_TOGGLE$1, target.closest(SELECTOR_DROPDOWN)).classList.add(CLASS_NAME_ACTIVE$1);
            return;
        }
        for (const listGroup of SelectorEngine.parents(target, SELECTOR_NAV_LIST_GROUP))// Set triggered links parents as active
        // With both <ul> and <nav> markup a parent is the previous sibling of any nav ancestor
        for (const item of SelectorEngine.prev(listGroup, SELECTOR_LINK_ITEMS))item.classList.add(CLASS_NAME_ACTIVE$1);
    }
    _clearActiveClass(parent) {
        parent.classList.remove(CLASS_NAME_ACTIVE$1);
        const activeNodes = SelectorEngine.find(`${SELECTOR_TARGET_LINKS}.${CLASS_NAME_ACTIVE$1}`, parent);
        for (const node of activeNodes)node.classList.remove(CLASS_NAME_ACTIVE$1);
    }
    // Static
    static jQueryInterface(config) {
        return this.each(function() {
            const data = ScrollSpy.getOrCreateInstance(this, config);
            if (typeof config !== 'string') return;
            if (data[config] === undefined || config.startsWith('_') || config === 'constructor') throw new TypeError(`No method named "${config}"`);
            data[config]();
        });
    }
}
/**
 * Data API implementation
 */ EventHandler.on(window, EVENT_LOAD_DATA_API$1, ()=>{
    for (const spy of SelectorEngine.find(SELECTOR_DATA_SPY))ScrollSpy.getOrCreateInstance(spy);
});
/**
 * jQuery
 */ defineJQueryPlugin(ScrollSpy);
/**
 * --------------------------------------------------------------------------
 * Bootstrap tab.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME$1 = 'tab';
const DATA_KEY$1 = 'bs.tab';
const EVENT_KEY$1 = `.${DATA_KEY$1}`;
const EVENT_HIDE$1 = `hide${EVENT_KEY$1}`;
const EVENT_HIDDEN$1 = `hidden${EVENT_KEY$1}`;
const EVENT_SHOW$1 = `show${EVENT_KEY$1}`;
const EVENT_SHOWN$1 = `shown${EVENT_KEY$1}`;
const EVENT_CLICK_DATA_API = `click${EVENT_KEY$1}`;
const EVENT_KEYDOWN = `keydown${EVENT_KEY$1}`;
const EVENT_LOAD_DATA_API = `load${EVENT_KEY$1}`;
const ARROW_LEFT_KEY = 'ArrowLeft';
const ARROW_RIGHT_KEY = 'ArrowRight';
const ARROW_UP_KEY = 'ArrowUp';
const ARROW_DOWN_KEY = 'ArrowDown';
const HOME_KEY = 'Home';
const END_KEY = 'End';
const CLASS_NAME_ACTIVE = 'active';
const CLASS_NAME_FADE$1 = 'fade';
const CLASS_NAME_SHOW$1 = 'show';
const CLASS_DROPDOWN = 'dropdown';
const SELECTOR_DROPDOWN_TOGGLE = '.dropdown-toggle';
const SELECTOR_DROPDOWN_MENU = '.dropdown-menu';
const NOT_SELECTOR_DROPDOWN_TOGGLE = `:not(${SELECTOR_DROPDOWN_TOGGLE})`;
const SELECTOR_TAB_PANEL = '.list-group, .nav, [role="tablist"]';
const SELECTOR_OUTER = '.nav-item, .list-group-item';
const SELECTOR_INNER = `.nav-link${NOT_SELECTOR_DROPDOWN_TOGGLE}, .list-group-item${NOT_SELECTOR_DROPDOWN_TOGGLE}, [role="tab"]${NOT_SELECTOR_DROPDOWN_TOGGLE}`;
const SELECTOR_DATA_TOGGLE = '[data-bs-toggle="tab"], [data-bs-toggle="pill"], [data-bs-toggle="list"]'; // TODO: could only be `tab` in v6
const SELECTOR_INNER_ELEM = `${SELECTOR_INNER}, ${SELECTOR_DATA_TOGGLE}`;
const SELECTOR_DATA_TOGGLE_ACTIVE = `.${CLASS_NAME_ACTIVE}[data-bs-toggle="tab"], .${CLASS_NAME_ACTIVE}[data-bs-toggle="pill"], .${CLASS_NAME_ACTIVE}[data-bs-toggle="list"]`;
/**
 * Class definition
 */ class Tab extends BaseComponent {
    constructor(element){
        super(element);
        this._parent = this._element.closest(SELECTOR_TAB_PANEL);
        if (!this._parent) return;
        // Set up initial aria attributes
        this._setInitialAttributes(this._parent, this._getChildren());
        EventHandler.on(this._element, EVENT_KEYDOWN, (event)=>this._keydown(event));
    }
    // Getters
    static get NAME() {
        return NAME$1;
    }
    // Public
    show() {
        // Shows this elem and deactivate the active sibling if exists
        const innerElem = this._element;
        if (this._elemIsActive(innerElem)) return;
        // Search for active tab on same parent to deactivate it
        const active = this._getActiveElem();
        const hideEvent = active ? EventHandler.trigger(active, EVENT_HIDE$1, {
            relatedTarget: innerElem
        }) : null;
        const showEvent = EventHandler.trigger(innerElem, EVENT_SHOW$1, {
            relatedTarget: active
        });
        if (showEvent.defaultPrevented || hideEvent && hideEvent.defaultPrevented) return;
        this._deactivate(active, innerElem);
        this._activate(innerElem, active);
    }
    // Private
    _activate(element, relatedElem) {
        if (!element) return;
        element.classList.add(CLASS_NAME_ACTIVE);
        this._activate(SelectorEngine.getElementFromSelector(element)); // Search and activate/show the proper section
        const complete = ()=>{
            if (element.getAttribute('role') !== 'tab') {
                element.classList.add(CLASS_NAME_SHOW$1);
                return;
            }
            element.removeAttribute('tabindex');
            element.setAttribute('aria-selected', true);
            this._toggleDropDown(element, true);
            EventHandler.trigger(element, EVENT_SHOWN$1, {
                relatedTarget: relatedElem
            });
        };
        this._queueCallback(complete, element, element.classList.contains(CLASS_NAME_FADE$1));
    }
    _deactivate(element, relatedElem) {
        if (!element) return;
        element.classList.remove(CLASS_NAME_ACTIVE);
        element.blur();
        this._deactivate(SelectorEngine.getElementFromSelector(element)); // Search and deactivate the shown section too
        const complete = ()=>{
            if (element.getAttribute('role') !== 'tab') {
                element.classList.remove(CLASS_NAME_SHOW$1);
                return;
            }
            element.setAttribute('aria-selected', false);
            element.setAttribute('tabindex', '-1');
            this._toggleDropDown(element, false);
            EventHandler.trigger(element, EVENT_HIDDEN$1, {
                relatedTarget: relatedElem
            });
        };
        this._queueCallback(complete, element, element.classList.contains(CLASS_NAME_FADE$1));
    }
    _keydown(event) {
        if (![
            ARROW_LEFT_KEY,
            ARROW_RIGHT_KEY,
            ARROW_UP_KEY,
            ARROW_DOWN_KEY,
            HOME_KEY,
            END_KEY
        ].includes(event.key)) return;
        event.stopPropagation(); // stopPropagation/preventDefault both added to support up/down keys without scrolling the page
        event.preventDefault();
        const children = this._getChildren().filter((element)=>!isDisabled(element));
        let nextActiveElement;
        if ([
            HOME_KEY,
            END_KEY
        ].includes(event.key)) nextActiveElement = children[event.key === HOME_KEY ? 0 : children.length - 1];
        else {
            const isNext = [
                ARROW_RIGHT_KEY,
                ARROW_DOWN_KEY
            ].includes(event.key);
            nextActiveElement = getNextActiveElement(children, event.target, isNext, true);
        }
        if (nextActiveElement) {
            nextActiveElement.focus({
                preventScroll: true
            });
            Tab.getOrCreateInstance(nextActiveElement).show();
        }
    }
    _getChildren() {
        // collection of inner elements
        return SelectorEngine.find(SELECTOR_INNER_ELEM, this._parent);
    }
    _getActiveElem() {
        return this._getChildren().find((child)=>this._elemIsActive(child)) || null;
    }
    _setInitialAttributes(parent, children) {
        this._setAttributeIfNotExists(parent, 'role', 'tablist');
        for (const child of children)this._setInitialAttributesOnChild(child);
    }
    _setInitialAttributesOnChild(child) {
        child = this._getInnerElement(child);
        const isActive = this._elemIsActive(child);
        const outerElem = this._getOuterElement(child);
        child.setAttribute('aria-selected', isActive);
        if (outerElem !== child) this._setAttributeIfNotExists(outerElem, 'role', 'presentation');
        if (!isActive) child.setAttribute('tabindex', '-1');
        this._setAttributeIfNotExists(child, 'role', 'tab');
        // set attributes to the related panel too
        this._setInitialAttributesOnTargetPanel(child);
    }
    _setInitialAttributesOnTargetPanel(child) {
        const target = SelectorEngine.getElementFromSelector(child);
        if (!target) return;
        this._setAttributeIfNotExists(target, 'role', 'tabpanel');
        if (child.id) this._setAttributeIfNotExists(target, 'aria-labelledby', `${child.id}`);
    }
    _toggleDropDown(element, open) {
        const outerElem = this._getOuterElement(element);
        if (!outerElem.classList.contains(CLASS_DROPDOWN)) return;
        const toggle = (selector, className)=>{
            const element = SelectorEngine.findOne(selector, outerElem);
            if (element) element.classList.toggle(className, open);
        };
        toggle(SELECTOR_DROPDOWN_TOGGLE, CLASS_NAME_ACTIVE);
        toggle(SELECTOR_DROPDOWN_MENU, CLASS_NAME_SHOW$1);
        outerElem.setAttribute('aria-expanded', open);
    }
    _setAttributeIfNotExists(element, attribute, value) {
        if (!element.hasAttribute(attribute)) element.setAttribute(attribute, value);
    }
    _elemIsActive(elem) {
        return elem.classList.contains(CLASS_NAME_ACTIVE);
    }
    // Try to get the inner element (usually the .nav-link)
    _getInnerElement(elem) {
        return elem.matches(SELECTOR_INNER_ELEM) ? elem : SelectorEngine.findOne(SELECTOR_INNER_ELEM, elem);
    }
    // Try to get the outer element (usually the .nav-item)
    _getOuterElement(elem) {
        return elem.closest(SELECTOR_OUTER) || elem;
    }
    // Static
    static jQueryInterface(config) {
        return this.each(function() {
            const data = Tab.getOrCreateInstance(this);
            if (typeof config !== 'string') return;
            if (data[config] === undefined || config.startsWith('_') || config === 'constructor') throw new TypeError(`No method named "${config}"`);
            data[config]();
        });
    }
}
/**
 * Data API implementation
 */ EventHandler.on(document, EVENT_CLICK_DATA_API, SELECTOR_DATA_TOGGLE, function(event) {
    if ([
        'A',
        'AREA'
    ].includes(this.tagName)) event.preventDefault();
    if (isDisabled(this)) return;
    Tab.getOrCreateInstance(this).show();
});
/**
 * Initialize on focus
 */ EventHandler.on(window, EVENT_LOAD_DATA_API, ()=>{
    for (const element of SelectorEngine.find(SELECTOR_DATA_TOGGLE_ACTIVE))Tab.getOrCreateInstance(element);
});
/**
 * jQuery
 */ defineJQueryPlugin(Tab);
/**
 * --------------------------------------------------------------------------
 * Bootstrap toast.js
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 * --------------------------------------------------------------------------
 */ /**
 * Constants
 */ const NAME = 'toast';
const DATA_KEY = 'bs.toast';
const EVENT_KEY = `.${DATA_KEY}`;
const EVENT_MOUSEOVER = `mouseover${EVENT_KEY}`;
const EVENT_MOUSEOUT = `mouseout${EVENT_KEY}`;
const EVENT_FOCUSIN = `focusin${EVENT_KEY}`;
const EVENT_FOCUSOUT = `focusout${EVENT_KEY}`;
const EVENT_HIDE = `hide${EVENT_KEY}`;
const EVENT_HIDDEN = `hidden${EVENT_KEY}`;
const EVENT_SHOW = `show${EVENT_KEY}`;
const EVENT_SHOWN = `shown${EVENT_KEY}`;
const CLASS_NAME_FADE = 'fade';
const CLASS_NAME_HIDE = 'hide'; // @deprecated - kept here only for backwards compatibility
const CLASS_NAME_SHOW = 'show';
const CLASS_NAME_SHOWING = 'showing';
const DefaultType = {
    animation: 'boolean',
    autohide: 'boolean',
    delay: 'number'
};
const Default = {
    animation: true,
    autohide: true,
    delay: 5000
};
/**
 * Class definition
 */ class Toast extends BaseComponent {
    constructor(element, config){
        super(element, config);
        this._timeout = null;
        this._hasMouseInteraction = false;
        this._hasKeyboardInteraction = false;
        this._setListeners();
    }
    // Getters
    static get Default() {
        return Default;
    }
    static get DefaultType() {
        return DefaultType;
    }
    static get NAME() {
        return NAME;
    }
    // Public
    show() {
        const showEvent = EventHandler.trigger(this._element, EVENT_SHOW);
        if (showEvent.defaultPrevented) return;
        this._clearTimeout();
        if (this._config.animation) this._element.classList.add(CLASS_NAME_FADE);
        const complete = ()=>{
            this._element.classList.remove(CLASS_NAME_SHOWING);
            EventHandler.trigger(this._element, EVENT_SHOWN);
            this._maybeScheduleHide();
        };
        this._element.classList.remove(CLASS_NAME_HIDE); // @deprecated
        reflow(this._element);
        this._element.classList.add(CLASS_NAME_SHOW, CLASS_NAME_SHOWING);
        this._queueCallback(complete, this._element, this._config.animation);
    }
    hide() {
        if (!this.isShown()) return;
        const hideEvent = EventHandler.trigger(this._element, EVENT_HIDE);
        if (hideEvent.defaultPrevented) return;
        const complete = ()=>{
            this._element.classList.add(CLASS_NAME_HIDE); // @deprecated
            this._element.classList.remove(CLASS_NAME_SHOWING, CLASS_NAME_SHOW);
            EventHandler.trigger(this._element, EVENT_HIDDEN);
        };
        this._element.classList.add(CLASS_NAME_SHOWING);
        this._queueCallback(complete, this._element, this._config.animation);
    }
    dispose() {
        this._clearTimeout();
        if (this.isShown()) this._element.classList.remove(CLASS_NAME_SHOW);
        super.dispose();
    }
    isShown() {
        return this._element.classList.contains(CLASS_NAME_SHOW);
    }
    // Private
    _maybeScheduleHide() {
        if (!this._config.autohide) return;
        if (this._hasMouseInteraction || this._hasKeyboardInteraction) return;
        this._timeout = setTimeout(()=>{
            this.hide();
        }, this._config.delay);
    }
    _onInteraction(event, isInteracting) {
        switch(event.type){
            case 'mouseover':
            case 'mouseout':
                this._hasMouseInteraction = isInteracting;
                break;
            case 'focusin':
            case 'focusout':
                this._hasKeyboardInteraction = isInteracting;
                break;
        }
        if (isInteracting) {
            this._clearTimeout();
            return;
        }
        const nextElement = event.relatedTarget;
        if (this._element === nextElement || this._element.contains(nextElement)) return;
        this._maybeScheduleHide();
    }
    _setListeners() {
        EventHandler.on(this._element, EVENT_MOUSEOVER, (event)=>this._onInteraction(event, true));
        EventHandler.on(this._element, EVENT_MOUSEOUT, (event)=>this._onInteraction(event, false));
        EventHandler.on(this._element, EVENT_FOCUSIN, (event)=>this._onInteraction(event, true));
        EventHandler.on(this._element, EVENT_FOCUSOUT, (event)=>this._onInteraction(event, false));
    }
    _clearTimeout() {
        clearTimeout(this._timeout);
        this._timeout = null;
    }
    // Static
    static jQueryInterface(config) {
        return this.each(function() {
            const data = Toast.getOrCreateInstance(this, config);
            if (typeof config === 'string') {
                if (typeof data[config] === 'undefined') throw new TypeError(`No method named "${config}"`);
                data[config](this);
            }
        });
    }
}
/**
 * Data API implementation
 */ enableDismissTrigger(Toast);
/**
 * jQuery
 */ defineJQueryPlugin(Toast);

},{"@popperjs/core":"7unqC","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"7unqC":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "popperGenerator", ()=>(0, _createPopperJs.popperGenerator)) // eslint-disable-next-line import/no-unused-modules
;
parcelHelpers.export(exports, "detectOverflow", ()=>(0, _createPopperJs.detectOverflow));
parcelHelpers.export(exports, "createPopperBase", ()=>(0, _createPopperJs.createPopper));
parcelHelpers.export(exports, "createPopper", ()=>(0, _popperJs.createPopper)) // eslint-disable-next-line import/no-unused-modules
;
parcelHelpers.export(exports, "createPopperLite", ()=>(0, _popperLiteJs.createPopper));
var _enumsJs = require("./enums.js");
parcelHelpers.exportAll(_enumsJs, exports);
var _indexJs = require("./modifiers/index.js"); // eslint-disable-next-line import/no-unused-modules
parcelHelpers.exportAll(_indexJs, exports);
var _createPopperJs = require("./createPopper.js");
var _popperJs = require("./popper.js");
var _popperLiteJs = require("./popper-lite.js");

},{"./enums.js":"lCAq5","./modifiers/index.js":"cap3W","./createPopper.js":"cHuNp","./popper.js":"1PuRF","./popper-lite.js":"gKW1N","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"lCAq5":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "top", ()=>top);
parcelHelpers.export(exports, "bottom", ()=>bottom);
parcelHelpers.export(exports, "right", ()=>right);
parcelHelpers.export(exports, "left", ()=>left);
parcelHelpers.export(exports, "auto", ()=>auto);
parcelHelpers.export(exports, "basePlacements", ()=>basePlacements);
parcelHelpers.export(exports, "start", ()=>start);
parcelHelpers.export(exports, "end", ()=>end);
parcelHelpers.export(exports, "clippingParents", ()=>clippingParents);
parcelHelpers.export(exports, "viewport", ()=>viewport);
parcelHelpers.export(exports, "popper", ()=>popper);
parcelHelpers.export(exports, "reference", ()=>reference);
parcelHelpers.export(exports, "variationPlacements", ()=>variationPlacements);
parcelHelpers.export(exports, "placements", ()=>placements);
parcelHelpers.export(exports, "beforeRead", ()=>beforeRead);
parcelHelpers.export(exports, "read", ()=>read);
parcelHelpers.export(exports, "afterRead", ()=>afterRead);
parcelHelpers.export(exports, "beforeMain", ()=>beforeMain);
parcelHelpers.export(exports, "main", ()=>main);
parcelHelpers.export(exports, "afterMain", ()=>afterMain);
parcelHelpers.export(exports, "beforeWrite", ()=>beforeWrite);
parcelHelpers.export(exports, "write", ()=>write);
parcelHelpers.export(exports, "afterWrite", ()=>afterWrite);
parcelHelpers.export(exports, "modifierPhases", ()=>modifierPhases);
var top = 'top';
var bottom = 'bottom';
var right = 'right';
var left = 'left';
var auto = 'auto';
var basePlacements = [
    top,
    bottom,
    right,
    left
];
var start = 'start';
var end = 'end';
var clippingParents = 'clippingParents';
var viewport = 'viewport';
var popper = 'popper';
var reference = 'reference';
var variationPlacements = /*#__PURE__*/ basePlacements.reduce(function(acc, placement) {
    return acc.concat([
        placement + "-" + start,
        placement + "-" + end
    ]);
}, []);
var placements = /*#__PURE__*/ [].concat(basePlacements, [
    auto
]).reduce(function(acc, placement) {
    return acc.concat([
        placement,
        placement + "-" + start,
        placement + "-" + end
    ]);
}, []); // modifiers that need to read the DOM
var beforeRead = 'beforeRead';
var read = 'read';
var afterRead = 'afterRead'; // pure-logic modifiers
var beforeMain = 'beforeMain';
var main = 'main';
var afterMain = 'afterMain'; // modifier with the purpose to write to the DOM (or write into a framework state)
var beforeWrite = 'beforeWrite';
var write = 'write';
var afterWrite = 'afterWrite';
var modifierPhases = [
    beforeRead,
    read,
    afterRead,
    beforeMain,
    main,
    afterMain,
    beforeWrite,
    write,
    afterWrite
];

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"gkKU3":[function(require,module,exports,__globalThis) {
exports.interopDefault = function(a) {
    return a && a.__esModule ? a : {
        default: a
    };
};
exports.defineInteropFlag = function(a) {
    Object.defineProperty(a, '__esModule', {
        value: true
    });
};
exports.exportAll = function(source, dest) {
    Object.keys(source).forEach(function(key) {
        if (key === 'default' || key === '__esModule' || Object.prototype.hasOwnProperty.call(dest, key)) return;
        Object.defineProperty(dest, key, {
            enumerable: true,
            get: function() {
                return source[key];
            }
        });
    });
    return dest;
};
exports.export = function(dest, destName, get) {
    Object.defineProperty(dest, destName, {
        enumerable: true,
        get: get
    });
};

},{}],"cap3W":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "applyStyles", ()=>(0, _applyStylesJsDefault.default));
parcelHelpers.export(exports, "arrow", ()=>(0, _arrowJsDefault.default));
parcelHelpers.export(exports, "computeStyles", ()=>(0, _computeStylesJsDefault.default));
parcelHelpers.export(exports, "eventListeners", ()=>(0, _eventListenersJsDefault.default));
parcelHelpers.export(exports, "flip", ()=>(0, _flipJsDefault.default));
parcelHelpers.export(exports, "hide", ()=>(0, _hideJsDefault.default));
parcelHelpers.export(exports, "offset", ()=>(0, _offsetJsDefault.default));
parcelHelpers.export(exports, "popperOffsets", ()=>(0, _popperOffsetsJsDefault.default));
parcelHelpers.export(exports, "preventOverflow", ()=>(0, _preventOverflowJsDefault.default));
var _applyStylesJs = require("./applyStyles.js");
var _applyStylesJsDefault = parcelHelpers.interopDefault(_applyStylesJs);
var _arrowJs = require("./arrow.js");
var _arrowJsDefault = parcelHelpers.interopDefault(_arrowJs);
var _computeStylesJs = require("./computeStyles.js");
var _computeStylesJsDefault = parcelHelpers.interopDefault(_computeStylesJs);
var _eventListenersJs = require("./eventListeners.js");
var _eventListenersJsDefault = parcelHelpers.interopDefault(_eventListenersJs);
var _flipJs = require("./flip.js");
var _flipJsDefault = parcelHelpers.interopDefault(_flipJs);
var _hideJs = require("./hide.js");
var _hideJsDefault = parcelHelpers.interopDefault(_hideJs);
var _offsetJs = require("./offset.js");
var _offsetJsDefault = parcelHelpers.interopDefault(_offsetJs);
var _popperOffsetsJs = require("./popperOffsets.js");
var _popperOffsetsJsDefault = parcelHelpers.interopDefault(_popperOffsetsJs);
var _preventOverflowJs = require("./preventOverflow.js");
var _preventOverflowJsDefault = parcelHelpers.interopDefault(_preventOverflowJs);

},{"./applyStyles.js":"4iMn4","./arrow.js":"31HFW","./computeStyles.js":"gDlm2","./eventListeners.js":"hBKsL","./flip.js":"fv5wq","./hide.js":"2g4OF","./offset.js":"3GKVY","./popperOffsets.js":"6I679","./preventOverflow.js":"1AMhb","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"4iMn4":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
var _getNodeNameJs = require("../dom-utils/getNodeName.js");
var _getNodeNameJsDefault = parcelHelpers.interopDefault(_getNodeNameJs);
var _instanceOfJs = require("../dom-utils/instanceOf.js"); // This modifier takes the styles prepared by the `computeStyles` modifier
// and applies them to the HTMLElements such as popper and arrow
function applyStyles(_ref) {
    var state = _ref.state;
    Object.keys(state.elements).forEach(function(name) {
        var style = state.styles[name] || {};
        var attributes = state.attributes[name] || {};
        var element = state.elements[name]; // arrow is optional + virtual elements
        if (!(0, _instanceOfJs.isHTMLElement)(element) || !(0, _getNodeNameJsDefault.default)(element)) return;
         // Flow doesn't support to extend this property, but it's the most
        // effective way to apply styles to an HTMLElement
        // $FlowFixMe[cannot-write]
        Object.assign(element.style, style);
        Object.keys(attributes).forEach(function(name) {
            var value = attributes[name];
            if (value === false) element.removeAttribute(name);
            else element.setAttribute(name, value === true ? '' : value);
        });
    });
}
function effect(_ref2) {
    var state = _ref2.state;
    var initialStyles = {
        popper: {
            position: state.options.strategy,
            left: '0',
            top: '0',
            margin: '0'
        },
        arrow: {
            position: 'absolute'
        },
        reference: {}
    };
    Object.assign(state.elements.popper.style, initialStyles.popper);
    state.styles = initialStyles;
    if (state.elements.arrow) Object.assign(state.elements.arrow.style, initialStyles.arrow);
    return function() {
        Object.keys(state.elements).forEach(function(name) {
            var element = state.elements[name];
            var attributes = state.attributes[name] || {};
            var styleProperties = Object.keys(state.styles.hasOwnProperty(name) ? state.styles[name] : initialStyles[name]); // Set all values to an empty string to unset them
            var style = styleProperties.reduce(function(style, property) {
                style[property] = '';
                return style;
            }, {}); // arrow is optional + virtual elements
            if (!(0, _instanceOfJs.isHTMLElement)(element) || !(0, _getNodeNameJsDefault.default)(element)) return;
            Object.assign(element.style, style);
            Object.keys(attributes).forEach(function(attribute) {
                element.removeAttribute(attribute);
            });
        });
    };
} // eslint-disable-next-line import/no-unused-modules
exports.default = {
    name: 'applyStyles',
    enabled: true,
    phase: 'write',
    fn: applyStyles,
    effect: effect,
    requires: [
        'computeStyles'
    ]
};

},{"../dom-utils/getNodeName.js":"a2Qom","../dom-utils/instanceOf.js":"gYFUC","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"a2Qom":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getNodeName);
function getNodeName(element) {
    return element ? (element.nodeName || '').toLowerCase() : null;
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"gYFUC":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "isElement", ()=>isElement);
parcelHelpers.export(exports, "isHTMLElement", ()=>isHTMLElement);
parcelHelpers.export(exports, "isShadowRoot", ()=>isShadowRoot);
var _getWindowJs = require("./getWindow.js");
var _getWindowJsDefault = parcelHelpers.interopDefault(_getWindowJs);
function isElement(node) {
    var OwnElement = (0, _getWindowJsDefault.default)(node).Element;
    return node instanceof OwnElement || node instanceof Element;
}
function isHTMLElement(node) {
    var OwnElement = (0, _getWindowJsDefault.default)(node).HTMLElement;
    return node instanceof OwnElement || node instanceof HTMLElement;
}
function isShadowRoot(node) {
    // IE 11 has no ShadowRoot
    if (typeof ShadowRoot === 'undefined') return false;
    var OwnElement = (0, _getWindowJsDefault.default)(node).ShadowRoot;
    return node instanceof OwnElement || node instanceof ShadowRoot;
}

},{"./getWindow.js":"2SkOo","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"2SkOo":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getWindow);
function getWindow(node) {
    if (node == null) return window;
    if (node.toString() !== '[object Window]') {
        var ownerDocument = node.ownerDocument;
        return ownerDocument ? ownerDocument.defaultView || window : window;
    }
    return node;
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"31HFW":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
var _getBasePlacementJs = require("../utils/getBasePlacement.js");
var _getBasePlacementJsDefault = parcelHelpers.interopDefault(_getBasePlacementJs);
var _getLayoutRectJs = require("../dom-utils/getLayoutRect.js");
var _getLayoutRectJsDefault = parcelHelpers.interopDefault(_getLayoutRectJs);
var _containsJs = require("../dom-utils/contains.js");
var _containsJsDefault = parcelHelpers.interopDefault(_containsJs);
var _getOffsetParentJs = require("../dom-utils/getOffsetParent.js");
var _getOffsetParentJsDefault = parcelHelpers.interopDefault(_getOffsetParentJs);
var _getMainAxisFromPlacementJs = require("../utils/getMainAxisFromPlacement.js");
var _getMainAxisFromPlacementJsDefault = parcelHelpers.interopDefault(_getMainAxisFromPlacementJs);
var _withinJs = require("../utils/within.js");
var _mergePaddingObjectJs = require("../utils/mergePaddingObject.js");
var _mergePaddingObjectJsDefault = parcelHelpers.interopDefault(_mergePaddingObjectJs);
var _expandToHashMapJs = require("../utils/expandToHashMap.js");
var _expandToHashMapJsDefault = parcelHelpers.interopDefault(_expandToHashMapJs);
var _enumsJs = require("../enums.js"); // eslint-disable-next-line import/no-unused-modules
var toPaddingObject = function toPaddingObject(padding, state) {
    padding = typeof padding === 'function' ? padding(Object.assign({}, state.rects, {
        placement: state.placement
    })) : padding;
    return (0, _mergePaddingObjectJsDefault.default)(typeof padding !== 'number' ? padding : (0, _expandToHashMapJsDefault.default)(padding, (0, _enumsJs.basePlacements)));
};
function arrow(_ref) {
    var _state$modifiersData$;
    var state = _ref.state, name = _ref.name, options = _ref.options;
    var arrowElement = state.elements.arrow;
    var popperOffsets = state.modifiersData.popperOffsets;
    var basePlacement = (0, _getBasePlacementJsDefault.default)(state.placement);
    var axis = (0, _getMainAxisFromPlacementJsDefault.default)(basePlacement);
    var isVertical = [
        (0, _enumsJs.left),
        (0, _enumsJs.right)
    ].indexOf(basePlacement) >= 0;
    var len = isVertical ? 'height' : 'width';
    if (!arrowElement || !popperOffsets) return;
    var paddingObject = toPaddingObject(options.padding, state);
    var arrowRect = (0, _getLayoutRectJsDefault.default)(arrowElement);
    var minProp = axis === 'y' ? (0, _enumsJs.top) : (0, _enumsJs.left);
    var maxProp = axis === 'y' ? (0, _enumsJs.bottom) : (0, _enumsJs.right);
    var endDiff = state.rects.reference[len] + state.rects.reference[axis] - popperOffsets[axis] - state.rects.popper[len];
    var startDiff = popperOffsets[axis] - state.rects.reference[axis];
    var arrowOffsetParent = (0, _getOffsetParentJsDefault.default)(arrowElement);
    var clientSize = arrowOffsetParent ? axis === 'y' ? arrowOffsetParent.clientHeight || 0 : arrowOffsetParent.clientWidth || 0 : 0;
    var centerToReference = endDiff / 2 - startDiff / 2; // Make sure the arrow doesn't overflow the popper if the center point is
    // outside of the popper bounds
    var min = paddingObject[minProp];
    var max = clientSize - arrowRect[len] - paddingObject[maxProp];
    var center = clientSize / 2 - arrowRect[len] / 2 + centerToReference;
    var offset = (0, _withinJs.within)(min, center, max); // Prevents breaking syntax highlighting...
    var axisProp = axis;
    state.modifiersData[name] = (_state$modifiersData$ = {}, _state$modifiersData$[axisProp] = offset, _state$modifiersData$.centerOffset = offset - center, _state$modifiersData$);
}
function effect(_ref2) {
    var state = _ref2.state, options = _ref2.options;
    var _options$element = options.element, arrowElement = _options$element === void 0 ? '[data-popper-arrow]' : _options$element;
    if (arrowElement == null) return;
     // CSS selector
    if (typeof arrowElement === 'string') {
        arrowElement = state.elements.popper.querySelector(arrowElement);
        if (!arrowElement) return;
    }
    if (!(0, _containsJsDefault.default)(state.elements.popper, arrowElement)) return;
    state.elements.arrow = arrowElement;
} // eslint-disable-next-line import/no-unused-modules
exports.default = {
    name: 'arrow',
    enabled: true,
    phase: 'main',
    fn: arrow,
    effect: effect,
    requires: [
        'popperOffsets'
    ],
    requiresIfExists: [
        'preventOverflow'
    ]
};

},{"../utils/getBasePlacement.js":"59Wp3","../dom-utils/getLayoutRect.js":"jvjuf","../dom-utils/contains.js":"4QxRR","../dom-utils/getOffsetParent.js":"laoYw","../utils/getMainAxisFromPlacement.js":"1Xlom","../utils/within.js":"3glSz","../utils/mergePaddingObject.js":"lEIf9","../utils/expandToHashMap.js":"iQlH5","../enums.js":"lCAq5","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"59Wp3":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getBasePlacement);
var _enumsJs = require("../enums.js");
function getBasePlacement(placement) {
    return placement.split('-')[0];
}

},{"../enums.js":"lCAq5","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"jvjuf":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getLayoutRect);
var _getBoundingClientRectJs = require("./getBoundingClientRect.js"); // Returns the layout rect of an element relative to its offsetParent. Layout
var _getBoundingClientRectJsDefault = parcelHelpers.interopDefault(_getBoundingClientRectJs);
function getLayoutRect(element) {
    var clientRect = (0, _getBoundingClientRectJsDefault.default)(element); // Use the clientRect sizes if it's not been transformed.
    // Fixes https://github.com/popperjs/popper-core/issues/1223
    var width = element.offsetWidth;
    var height = element.offsetHeight;
    if (Math.abs(clientRect.width - width) <= 1) width = clientRect.width;
    if (Math.abs(clientRect.height - height) <= 1) height = clientRect.height;
    return {
        x: element.offsetLeft,
        y: element.offsetTop,
        width: width,
        height: height
    };
}

},{"./getBoundingClientRect.js":"9CFSQ","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"9CFSQ":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getBoundingClientRect);
var _instanceOfJs = require("./instanceOf.js");
var _mathJs = require("../utils/math.js");
var _getWindowJs = require("./getWindow.js");
var _getWindowJsDefault = parcelHelpers.interopDefault(_getWindowJs);
var _isLayoutViewportJs = require("./isLayoutViewport.js");
var _isLayoutViewportJsDefault = parcelHelpers.interopDefault(_isLayoutViewportJs);
function getBoundingClientRect(element, includeScale, isFixedStrategy) {
    if (includeScale === void 0) includeScale = false;
    if (isFixedStrategy === void 0) isFixedStrategy = false;
    var clientRect = element.getBoundingClientRect();
    var scaleX = 1;
    var scaleY = 1;
    if (includeScale && (0, _instanceOfJs.isHTMLElement)(element)) {
        scaleX = element.offsetWidth > 0 ? (0, _mathJs.round)(clientRect.width) / element.offsetWidth || 1 : 1;
        scaleY = element.offsetHeight > 0 ? (0, _mathJs.round)(clientRect.height) / element.offsetHeight || 1 : 1;
    }
    var _ref = (0, _instanceOfJs.isElement)(element) ? (0, _getWindowJsDefault.default)(element) : window, visualViewport = _ref.visualViewport;
    var addVisualOffsets = !(0, _isLayoutViewportJsDefault.default)() && isFixedStrategy;
    var x = (clientRect.left + (addVisualOffsets && visualViewport ? visualViewport.offsetLeft : 0)) / scaleX;
    var y = (clientRect.top + (addVisualOffsets && visualViewport ? visualViewport.offsetTop : 0)) / scaleY;
    var width = clientRect.width / scaleX;
    var height = clientRect.height / scaleY;
    return {
        width: width,
        height: height,
        top: y,
        right: x + width,
        bottom: y + height,
        left: x,
        x: x,
        y: y
    };
}

},{"./instanceOf.js":"gYFUC","../utils/math.js":"gQqVe","./getWindow.js":"2SkOo","./isLayoutViewport.js":"3ipHv","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"gQqVe":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "max", ()=>max);
parcelHelpers.export(exports, "min", ()=>min);
parcelHelpers.export(exports, "round", ()=>round);
var max = Math.max;
var min = Math.min;
var round = Math.round;

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"3ipHv":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>isLayoutViewport);
var _userAgentJs = require("../utils/userAgent.js");
var _userAgentJsDefault = parcelHelpers.interopDefault(_userAgentJs);
function isLayoutViewport() {
    return !/^((?!chrome|android).)*safari/i.test((0, _userAgentJsDefault.default)());
}

},{"../utils/userAgent.js":"1hEx0","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"1hEx0":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getUAString);
function getUAString() {
    var uaData = navigator.userAgentData;
    if (uaData != null && uaData.brands && Array.isArray(uaData.brands)) return uaData.brands.map(function(item) {
        return item.brand + "/" + item.version;
    }).join(' ');
    return navigator.userAgent;
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"4QxRR":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>contains);
var _instanceOfJs = require("./instanceOf.js");
function contains(parent, child) {
    var rootNode = child.getRootNode && child.getRootNode(); // First, attempt with faster native method
    if (parent.contains(child)) return true;
    else if (rootNode && (0, _instanceOfJs.isShadowRoot)(rootNode)) {
        var next = child;
        do {
            if (next && parent.isSameNode(next)) return true;
             // $FlowFixMe[prop-missing]: need a better way to handle this...
            next = next.parentNode || next.host;
        }while (next);
    } // Give up, the result is false
    return false;
}

},{"./instanceOf.js":"gYFUC","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"laoYw":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getOffsetParent);
var _getWindowJs = require("./getWindow.js");
var _getWindowJsDefault = parcelHelpers.interopDefault(_getWindowJs);
var _getNodeNameJs = require("./getNodeName.js");
var _getNodeNameJsDefault = parcelHelpers.interopDefault(_getNodeNameJs);
var _getComputedStyleJs = require("./getComputedStyle.js");
var _getComputedStyleJsDefault = parcelHelpers.interopDefault(_getComputedStyleJs);
var _instanceOfJs = require("./instanceOf.js");
var _isTableElementJs = require("./isTableElement.js");
var _isTableElementJsDefault = parcelHelpers.interopDefault(_isTableElementJs);
var _getParentNodeJs = require("./getParentNode.js");
var _getParentNodeJsDefault = parcelHelpers.interopDefault(_getParentNodeJs);
var _userAgentJs = require("../utils/userAgent.js");
var _userAgentJsDefault = parcelHelpers.interopDefault(_userAgentJs);
function getTrueOffsetParent(element) {
    if (!(0, _instanceOfJs.isHTMLElement)(element) || // https://github.com/popperjs/popper-core/issues/837
    (0, _getComputedStyleJsDefault.default)(element).position === 'fixed') return null;
    return element.offsetParent;
} // `.offsetParent` reports `null` for fixed elements, while absolute elements
// return the containing block
function getContainingBlock(element) {
    var isFirefox = /firefox/i.test((0, _userAgentJsDefault.default)());
    var isIE = /Trident/i.test((0, _userAgentJsDefault.default)());
    if (isIE && (0, _instanceOfJs.isHTMLElement)(element)) {
        // In IE 9, 10 and 11 fixed elements containing block is always established by the viewport
        var elementCss = (0, _getComputedStyleJsDefault.default)(element);
        if (elementCss.position === 'fixed') return null;
    }
    var currentNode = (0, _getParentNodeJsDefault.default)(element);
    if ((0, _instanceOfJs.isShadowRoot)(currentNode)) currentNode = currentNode.host;
    while((0, _instanceOfJs.isHTMLElement)(currentNode) && [
        'html',
        'body'
    ].indexOf((0, _getNodeNameJsDefault.default)(currentNode)) < 0){
        var css = (0, _getComputedStyleJsDefault.default)(currentNode); // This is non-exhaustive but covers the most common CSS properties that
        // create a containing block.
        // https://developer.mozilla.org/en-US/docs/Web/CSS/Containing_block#identifying_the_containing_block
        if (css.transform !== 'none' || css.perspective !== 'none' || css.contain === 'paint' || [
            'transform',
            'perspective'
        ].indexOf(css.willChange) !== -1 || isFirefox && css.willChange === 'filter' || isFirefox && css.filter && css.filter !== 'none') return currentNode;
        else currentNode = currentNode.parentNode;
    }
    return null;
} // Gets the closest ancestor positioned element. Handles some edge cases,
function getOffsetParent(element) {
    var window = (0, _getWindowJsDefault.default)(element);
    var offsetParent = getTrueOffsetParent(element);
    while(offsetParent && (0, _isTableElementJsDefault.default)(offsetParent) && (0, _getComputedStyleJsDefault.default)(offsetParent).position === 'static')offsetParent = getTrueOffsetParent(offsetParent);
    if (offsetParent && ((0, _getNodeNameJsDefault.default)(offsetParent) === 'html' || (0, _getNodeNameJsDefault.default)(offsetParent) === 'body' && (0, _getComputedStyleJsDefault.default)(offsetParent).position === 'static')) return window;
    return offsetParent || getContainingBlock(element) || window;
}

},{"./getWindow.js":"2SkOo","./getNodeName.js":"a2Qom","./getComputedStyle.js":"3mZjB","./instanceOf.js":"gYFUC","./isTableElement.js":"2qBb7","./getParentNode.js":"bIHpd","../utils/userAgent.js":"1hEx0","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"3mZjB":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getComputedStyle);
var _getWindowJs = require("./getWindow.js");
var _getWindowJsDefault = parcelHelpers.interopDefault(_getWindowJs);
function getComputedStyle(element) {
    return (0, _getWindowJsDefault.default)(element).getComputedStyle(element);
}

},{"./getWindow.js":"2SkOo","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"2qBb7":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>isTableElement);
var _getNodeNameJs = require("./getNodeName.js");
var _getNodeNameJsDefault = parcelHelpers.interopDefault(_getNodeNameJs);
function isTableElement(element) {
    return [
        'table',
        'td',
        'th'
    ].indexOf((0, _getNodeNameJsDefault.default)(element)) >= 0;
}

},{"./getNodeName.js":"a2Qom","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"bIHpd":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getParentNode);
var _getNodeNameJs = require("./getNodeName.js");
var _getNodeNameJsDefault = parcelHelpers.interopDefault(_getNodeNameJs);
var _getDocumentElementJs = require("./getDocumentElement.js");
var _getDocumentElementJsDefault = parcelHelpers.interopDefault(_getDocumentElementJs);
var _instanceOfJs = require("./instanceOf.js");
function getParentNode(element) {
    if ((0, _getNodeNameJsDefault.default)(element) === 'html') return element;
    return(// $FlowFixMe[incompatible-return]
    // $FlowFixMe[prop-missing]
    element.assignedSlot || // step into the shadow DOM of the parent of a slotted node
    element.parentNode || ((0, _instanceOfJs.isShadowRoot)(element) ? element.host : null) || // ShadowRoot detected
    // $FlowFixMe[incompatible-call]: HTMLElement is a Node
    (0, _getDocumentElementJsDefault.default)(element) // fallback
    );
}

},{"./getNodeName.js":"a2Qom","./getDocumentElement.js":"eJ9Y1","./instanceOf.js":"gYFUC","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"eJ9Y1":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getDocumentElement);
var _instanceOfJs = require("./instanceOf.js");
function getDocumentElement(element) {
    // $FlowFixMe[incompatible-return]: assume body is always available
    return (((0, _instanceOfJs.isElement)(element) ? element.ownerDocument : element.document) || window.document).documentElement;
}

},{"./instanceOf.js":"gYFUC","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"1Xlom":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getMainAxisFromPlacement);
function getMainAxisFromPlacement(placement) {
    return [
        'top',
        'bottom'
    ].indexOf(placement) >= 0 ? 'x' : 'y';
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"3glSz":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "within", ()=>within);
parcelHelpers.export(exports, "withinMaxClamp", ()=>withinMaxClamp);
var _mathJs = require("./math.js");
function within(min, value, max) {
    return (0, _mathJs.max)(min, (0, _mathJs.min)(value, max));
}
function withinMaxClamp(min, value, max) {
    var v = within(min, value, max);
    return v > max ? max : v;
}

},{"./math.js":"gQqVe","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"lEIf9":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>mergePaddingObject);
var _getFreshSideObjectJs = require("./getFreshSideObject.js");
var _getFreshSideObjectJsDefault = parcelHelpers.interopDefault(_getFreshSideObjectJs);
function mergePaddingObject(paddingObject) {
    return Object.assign({}, (0, _getFreshSideObjectJsDefault.default)(), paddingObject);
}

},{"./getFreshSideObject.js":"g4xOt","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"g4xOt":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getFreshSideObject);
function getFreshSideObject() {
    return {
        top: 0,
        right: 0,
        bottom: 0,
        left: 0
    };
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"iQlH5":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>expandToHashMap);
function expandToHashMap(value, keys) {
    return keys.reduce(function(hashMap, key) {
        hashMap[key] = value;
        return hashMap;
    }, {});
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"gDlm2":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "mapToStyles", ()=>mapToStyles);
var _enumsJs = require("../enums.js");
var _getOffsetParentJs = require("../dom-utils/getOffsetParent.js");
var _getOffsetParentJsDefault = parcelHelpers.interopDefault(_getOffsetParentJs);
var _getWindowJs = require("../dom-utils/getWindow.js");
var _getWindowJsDefault = parcelHelpers.interopDefault(_getWindowJs);
var _getDocumentElementJs = require("../dom-utils/getDocumentElement.js");
var _getDocumentElementJsDefault = parcelHelpers.interopDefault(_getDocumentElementJs);
var _getComputedStyleJs = require("../dom-utils/getComputedStyle.js");
var _getComputedStyleJsDefault = parcelHelpers.interopDefault(_getComputedStyleJs);
var _getBasePlacementJs = require("../utils/getBasePlacement.js");
var _getBasePlacementJsDefault = parcelHelpers.interopDefault(_getBasePlacementJs);
var _getVariationJs = require("../utils/getVariation.js");
var _getVariationJsDefault = parcelHelpers.interopDefault(_getVariationJs);
var _mathJs = require("../utils/math.js"); // eslint-disable-next-line import/no-unused-modules
var unsetSides = {
    top: 'auto',
    right: 'auto',
    bottom: 'auto',
    left: 'auto'
}; // Round the offsets to the nearest suitable subpixel based on the DPR.
// Zooming can change the DPR, but it seems to report a value that will
// cleanly divide the values into the appropriate subpixels.
function roundOffsetsByDPR(_ref, win) {
    var x = _ref.x, y = _ref.y;
    var dpr = win.devicePixelRatio || 1;
    return {
        x: (0, _mathJs.round)(x * dpr) / dpr || 0,
        y: (0, _mathJs.round)(y * dpr) / dpr || 0
    };
}
function mapToStyles(_ref2) {
    var _Object$assign2;
    var popper = _ref2.popper, popperRect = _ref2.popperRect, placement = _ref2.placement, variation = _ref2.variation, offsets = _ref2.offsets, position = _ref2.position, gpuAcceleration = _ref2.gpuAcceleration, adaptive = _ref2.adaptive, roundOffsets = _ref2.roundOffsets, isFixed = _ref2.isFixed;
    var _offsets$x = offsets.x, x = _offsets$x === void 0 ? 0 : _offsets$x, _offsets$y = offsets.y, y = _offsets$y === void 0 ? 0 : _offsets$y;
    var _ref3 = typeof roundOffsets === 'function' ? roundOffsets({
        x: x,
        y: y
    }) : {
        x: x,
        y: y
    };
    x = _ref3.x;
    y = _ref3.y;
    var hasX = offsets.hasOwnProperty('x');
    var hasY = offsets.hasOwnProperty('y');
    var sideX = (0, _enumsJs.left);
    var sideY = (0, _enumsJs.top);
    var win = window;
    if (adaptive) {
        var offsetParent = (0, _getOffsetParentJsDefault.default)(popper);
        var heightProp = 'clientHeight';
        var widthProp = 'clientWidth';
        if (offsetParent === (0, _getWindowJsDefault.default)(popper)) {
            offsetParent = (0, _getDocumentElementJsDefault.default)(popper);
            if ((0, _getComputedStyleJsDefault.default)(offsetParent).position !== 'static' && position === 'absolute') {
                heightProp = 'scrollHeight';
                widthProp = 'scrollWidth';
            }
        } // $FlowFixMe[incompatible-cast]: force type refinement, we compare offsetParent with window above, but Flow doesn't detect it
        offsetParent;
        if (placement === (0, _enumsJs.top) || (placement === (0, _enumsJs.left) || placement === (0, _enumsJs.right)) && variation === (0, _enumsJs.end)) {
            sideY = (0, _enumsJs.bottom);
            var offsetY = isFixed && offsetParent === win && win.visualViewport ? win.visualViewport.height : offsetParent[heightProp];
            y -= offsetY - popperRect.height;
            y *= gpuAcceleration ? 1 : -1;
        }
        if (placement === (0, _enumsJs.left) || (placement === (0, _enumsJs.top) || placement === (0, _enumsJs.bottom)) && variation === (0, _enumsJs.end)) {
            sideX = (0, _enumsJs.right);
            var offsetX = isFixed && offsetParent === win && win.visualViewport ? win.visualViewport.width : offsetParent[widthProp];
            x -= offsetX - popperRect.width;
            x *= gpuAcceleration ? 1 : -1;
        }
    }
    var commonStyles = Object.assign({
        position: position
    }, adaptive && unsetSides);
    var _ref4 = roundOffsets === true ? roundOffsetsByDPR({
        x: x,
        y: y
    }, (0, _getWindowJsDefault.default)(popper)) : {
        x: x,
        y: y
    };
    x = _ref4.x;
    y = _ref4.y;
    if (gpuAcceleration) {
        var _Object$assign;
        return Object.assign({}, commonStyles, (_Object$assign = {}, _Object$assign[sideY] = hasY ? '0' : '', _Object$assign[sideX] = hasX ? '0' : '', _Object$assign.transform = (win.devicePixelRatio || 1) <= 1 ? "translate(" + x + "px, " + y + "px)" : "translate3d(" + x + "px, " + y + "px, 0)", _Object$assign));
    }
    return Object.assign({}, commonStyles, (_Object$assign2 = {}, _Object$assign2[sideY] = hasY ? y + "px" : '', _Object$assign2[sideX] = hasX ? x + "px" : '', _Object$assign2.transform = '', _Object$assign2));
}
function computeStyles(_ref5) {
    var state = _ref5.state, options = _ref5.options;
    var _options$gpuAccelerat = options.gpuAcceleration, gpuAcceleration = _options$gpuAccelerat === void 0 ? true : _options$gpuAccelerat, _options$adaptive = options.adaptive, adaptive = _options$adaptive === void 0 ? true : _options$adaptive, _options$roundOffsets = options.roundOffsets, roundOffsets = _options$roundOffsets === void 0 ? true : _options$roundOffsets;
    var commonStyles = {
        placement: (0, _getBasePlacementJsDefault.default)(state.placement),
        variation: (0, _getVariationJsDefault.default)(state.placement),
        popper: state.elements.popper,
        popperRect: state.rects.popper,
        gpuAcceleration: gpuAcceleration,
        isFixed: state.options.strategy === 'fixed'
    };
    if (state.modifiersData.popperOffsets != null) state.styles.popper = Object.assign({}, state.styles.popper, mapToStyles(Object.assign({}, commonStyles, {
        offsets: state.modifiersData.popperOffsets,
        position: state.options.strategy,
        adaptive: adaptive,
        roundOffsets: roundOffsets
    })));
    if (state.modifiersData.arrow != null) state.styles.arrow = Object.assign({}, state.styles.arrow, mapToStyles(Object.assign({}, commonStyles, {
        offsets: state.modifiersData.arrow,
        position: 'absolute',
        adaptive: false,
        roundOffsets: roundOffsets
    })));
    state.attributes.popper = Object.assign({}, state.attributes.popper, {
        'data-popper-placement': state.placement
    });
} // eslint-disable-next-line import/no-unused-modules
exports.default = {
    name: 'computeStyles',
    enabled: true,
    phase: 'beforeWrite',
    fn: computeStyles,
    data: {}
};

},{"../enums.js":"lCAq5","../dom-utils/getOffsetParent.js":"laoYw","../dom-utils/getWindow.js":"2SkOo","../dom-utils/getDocumentElement.js":"eJ9Y1","../dom-utils/getComputedStyle.js":"3mZjB","../utils/getBasePlacement.js":"59Wp3","../utils/getVariation.js":"hIo7Y","../utils/math.js":"gQqVe","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"hIo7Y":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getVariation);
function getVariation(placement) {
    return placement.split('-')[1];
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"hBKsL":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
var _getWindowJs = require("../dom-utils/getWindow.js"); // eslint-disable-next-line import/no-unused-modules
var _getWindowJsDefault = parcelHelpers.interopDefault(_getWindowJs);
var passive = {
    passive: true
};
function effect(_ref) {
    var state = _ref.state, instance = _ref.instance, options = _ref.options;
    var _options$scroll = options.scroll, scroll = _options$scroll === void 0 ? true : _options$scroll, _options$resize = options.resize, resize = _options$resize === void 0 ? true : _options$resize;
    var window = (0, _getWindowJsDefault.default)(state.elements.popper);
    var scrollParents = [].concat(state.scrollParents.reference, state.scrollParents.popper);
    if (scroll) scrollParents.forEach(function(scrollParent) {
        scrollParent.addEventListener('scroll', instance.update, passive);
    });
    if (resize) window.addEventListener('resize', instance.update, passive);
    return function() {
        if (scroll) scrollParents.forEach(function(scrollParent) {
            scrollParent.removeEventListener('scroll', instance.update, passive);
        });
        if (resize) window.removeEventListener('resize', instance.update, passive);
    };
} // eslint-disable-next-line import/no-unused-modules
exports.default = {
    name: 'eventListeners',
    enabled: true,
    phase: 'write',
    fn: function fn() {},
    effect: effect,
    data: {}
};

},{"../dom-utils/getWindow.js":"2SkOo","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"fv5wq":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
var _getOppositePlacementJs = require("../utils/getOppositePlacement.js");
var _getOppositePlacementJsDefault = parcelHelpers.interopDefault(_getOppositePlacementJs);
var _getBasePlacementJs = require("../utils/getBasePlacement.js");
var _getBasePlacementJsDefault = parcelHelpers.interopDefault(_getBasePlacementJs);
var _getOppositeVariationPlacementJs = require("../utils/getOppositeVariationPlacement.js");
var _getOppositeVariationPlacementJsDefault = parcelHelpers.interopDefault(_getOppositeVariationPlacementJs);
var _detectOverflowJs = require("../utils/detectOverflow.js");
var _detectOverflowJsDefault = parcelHelpers.interopDefault(_detectOverflowJs);
var _computeAutoPlacementJs = require("../utils/computeAutoPlacement.js");
var _computeAutoPlacementJsDefault = parcelHelpers.interopDefault(_computeAutoPlacementJs);
var _enumsJs = require("../enums.js");
var _getVariationJs = require("../utils/getVariation.js"); // eslint-disable-next-line import/no-unused-modules
var _getVariationJsDefault = parcelHelpers.interopDefault(_getVariationJs);
function getExpandedFallbackPlacements(placement) {
    if ((0, _getBasePlacementJsDefault.default)(placement) === (0, _enumsJs.auto)) return [];
    var oppositePlacement = (0, _getOppositePlacementJsDefault.default)(placement);
    return [
        (0, _getOppositeVariationPlacementJsDefault.default)(placement),
        oppositePlacement,
        (0, _getOppositeVariationPlacementJsDefault.default)(oppositePlacement)
    ];
}
function flip(_ref) {
    var state = _ref.state, options = _ref.options, name = _ref.name;
    if (state.modifiersData[name]._skip) return;
    var _options$mainAxis = options.mainAxis, checkMainAxis = _options$mainAxis === void 0 ? true : _options$mainAxis, _options$altAxis = options.altAxis, checkAltAxis = _options$altAxis === void 0 ? true : _options$altAxis, specifiedFallbackPlacements = options.fallbackPlacements, padding = options.padding, boundary = options.boundary, rootBoundary = options.rootBoundary, altBoundary = options.altBoundary, _options$flipVariatio = options.flipVariations, flipVariations = _options$flipVariatio === void 0 ? true : _options$flipVariatio, allowedAutoPlacements = options.allowedAutoPlacements;
    var preferredPlacement = state.options.placement;
    var basePlacement = (0, _getBasePlacementJsDefault.default)(preferredPlacement);
    var isBasePlacement = basePlacement === preferredPlacement;
    var fallbackPlacements = specifiedFallbackPlacements || (isBasePlacement || !flipVariations ? [
        (0, _getOppositePlacementJsDefault.default)(preferredPlacement)
    ] : getExpandedFallbackPlacements(preferredPlacement));
    var placements = [
        preferredPlacement
    ].concat(fallbackPlacements).reduce(function(acc, placement) {
        return acc.concat((0, _getBasePlacementJsDefault.default)(placement) === (0, _enumsJs.auto) ? (0, _computeAutoPlacementJsDefault.default)(state, {
            placement: placement,
            boundary: boundary,
            rootBoundary: rootBoundary,
            padding: padding,
            flipVariations: flipVariations,
            allowedAutoPlacements: allowedAutoPlacements
        }) : placement);
    }, []);
    var referenceRect = state.rects.reference;
    var popperRect = state.rects.popper;
    var checksMap = new Map();
    var makeFallbackChecks = true;
    var firstFittingPlacement = placements[0];
    for(var i = 0; i < placements.length; i++){
        var placement = placements[i];
        var _basePlacement = (0, _getBasePlacementJsDefault.default)(placement);
        var isStartVariation = (0, _getVariationJsDefault.default)(placement) === (0, _enumsJs.start);
        var isVertical = [
            (0, _enumsJs.top),
            (0, _enumsJs.bottom)
        ].indexOf(_basePlacement) >= 0;
        var len = isVertical ? 'width' : 'height';
        var overflow = (0, _detectOverflowJsDefault.default)(state, {
            placement: placement,
            boundary: boundary,
            rootBoundary: rootBoundary,
            altBoundary: altBoundary,
            padding: padding
        });
        var mainVariationSide = isVertical ? isStartVariation ? (0, _enumsJs.right) : (0, _enumsJs.left) : isStartVariation ? (0, _enumsJs.bottom) : (0, _enumsJs.top);
        if (referenceRect[len] > popperRect[len]) mainVariationSide = (0, _getOppositePlacementJsDefault.default)(mainVariationSide);
        var altVariationSide = (0, _getOppositePlacementJsDefault.default)(mainVariationSide);
        var checks = [];
        if (checkMainAxis) checks.push(overflow[_basePlacement] <= 0);
        if (checkAltAxis) checks.push(overflow[mainVariationSide] <= 0, overflow[altVariationSide] <= 0);
        if (checks.every(function(check) {
            return check;
        })) {
            firstFittingPlacement = placement;
            makeFallbackChecks = false;
            break;
        }
        checksMap.set(placement, checks);
    }
    if (makeFallbackChecks) {
        // `2` may be desired in some cases – research later
        var numberOfChecks = flipVariations ? 3 : 1;
        var _loop = function _loop(_i) {
            var fittingPlacement = placements.find(function(placement) {
                var checks = checksMap.get(placement);
                if (checks) return checks.slice(0, _i).every(function(check) {
                    return check;
                });
            });
            if (fittingPlacement) {
                firstFittingPlacement = fittingPlacement;
                return "break";
            }
        };
        for(var _i = numberOfChecks; _i > 0; _i--){
            var _ret = _loop(_i);
            if (_ret === "break") break;
        }
    }
    if (state.placement !== firstFittingPlacement) {
        state.modifiersData[name]._skip = true;
        state.placement = firstFittingPlacement;
        state.reset = true;
    }
} // eslint-disable-next-line import/no-unused-modules
exports.default = {
    name: 'flip',
    enabled: true,
    phase: 'main',
    fn: flip,
    requiresIfExists: [
        'offset'
    ],
    data: {
        _skip: false
    }
};

},{"../utils/getOppositePlacement.js":"a8CY0","../utils/getBasePlacement.js":"59Wp3","../utils/getOppositeVariationPlacement.js":"bKTLC","../utils/detectOverflow.js":"ltCuw","../utils/computeAutoPlacement.js":"gytMj","../enums.js":"lCAq5","../utils/getVariation.js":"hIo7Y","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"a8CY0":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getOppositePlacement);
var hash = {
    left: 'right',
    right: 'left',
    bottom: 'top',
    top: 'bottom'
};
function getOppositePlacement(placement) {
    return placement.replace(/left|right|bottom|top/g, function(matched) {
        return hash[matched];
    });
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"bKTLC":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getOppositeVariationPlacement);
var hash = {
    start: 'end',
    end: 'start'
};
function getOppositeVariationPlacement(placement) {
    return placement.replace(/start|end/g, function(matched) {
        return hash[matched];
    });
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"ltCuw":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>detectOverflow);
var _getClippingRectJs = require("../dom-utils/getClippingRect.js");
var _getClippingRectJsDefault = parcelHelpers.interopDefault(_getClippingRectJs);
var _getDocumentElementJs = require("../dom-utils/getDocumentElement.js");
var _getDocumentElementJsDefault = parcelHelpers.interopDefault(_getDocumentElementJs);
var _getBoundingClientRectJs = require("../dom-utils/getBoundingClientRect.js");
var _getBoundingClientRectJsDefault = parcelHelpers.interopDefault(_getBoundingClientRectJs);
var _computeOffsetsJs = require("./computeOffsets.js");
var _computeOffsetsJsDefault = parcelHelpers.interopDefault(_computeOffsetsJs);
var _rectToClientRectJs = require("./rectToClientRect.js");
var _rectToClientRectJsDefault = parcelHelpers.interopDefault(_rectToClientRectJs);
var _enumsJs = require("../enums.js");
var _instanceOfJs = require("../dom-utils/instanceOf.js");
var _mergePaddingObjectJs = require("./mergePaddingObject.js");
var _mergePaddingObjectJsDefault = parcelHelpers.interopDefault(_mergePaddingObjectJs);
var _expandToHashMapJs = require("./expandToHashMap.js"); // eslint-disable-next-line import/no-unused-modules
var _expandToHashMapJsDefault = parcelHelpers.interopDefault(_expandToHashMapJs);
function detectOverflow(state, options) {
    if (options === void 0) options = {};
    var _options = options, _options$placement = _options.placement, placement = _options$placement === void 0 ? state.placement : _options$placement, _options$strategy = _options.strategy, strategy = _options$strategy === void 0 ? state.strategy : _options$strategy, _options$boundary = _options.boundary, boundary = _options$boundary === void 0 ? (0, _enumsJs.clippingParents) : _options$boundary, _options$rootBoundary = _options.rootBoundary, rootBoundary = _options$rootBoundary === void 0 ? (0, _enumsJs.viewport) : _options$rootBoundary, _options$elementConte = _options.elementContext, elementContext = _options$elementConte === void 0 ? (0, _enumsJs.popper) : _options$elementConte, _options$altBoundary = _options.altBoundary, altBoundary = _options$altBoundary === void 0 ? false : _options$altBoundary, _options$padding = _options.padding, padding = _options$padding === void 0 ? 0 : _options$padding;
    var paddingObject = (0, _mergePaddingObjectJsDefault.default)(typeof padding !== 'number' ? padding : (0, _expandToHashMapJsDefault.default)(padding, (0, _enumsJs.basePlacements)));
    var altContext = elementContext === (0, _enumsJs.popper) ? (0, _enumsJs.reference) : (0, _enumsJs.popper);
    var popperRect = state.rects.popper;
    var element = state.elements[altBoundary ? altContext : elementContext];
    var clippingClientRect = (0, _getClippingRectJsDefault.default)((0, _instanceOfJs.isElement)(element) ? element : element.contextElement || (0, _getDocumentElementJsDefault.default)(state.elements.popper), boundary, rootBoundary, strategy);
    var referenceClientRect = (0, _getBoundingClientRectJsDefault.default)(state.elements.reference);
    var popperOffsets = (0, _computeOffsetsJsDefault.default)({
        reference: referenceClientRect,
        element: popperRect,
        strategy: 'absolute',
        placement: placement
    });
    var popperClientRect = (0, _rectToClientRectJsDefault.default)(Object.assign({}, popperRect, popperOffsets));
    var elementClientRect = elementContext === (0, _enumsJs.popper) ? popperClientRect : referenceClientRect; // positive = overflowing the clipping rect
    // 0 or negative = within the clipping rect
    var overflowOffsets = {
        top: clippingClientRect.top - elementClientRect.top + paddingObject.top,
        bottom: elementClientRect.bottom - clippingClientRect.bottom + paddingObject.bottom,
        left: clippingClientRect.left - elementClientRect.left + paddingObject.left,
        right: elementClientRect.right - clippingClientRect.right + paddingObject.right
    };
    var offsetData = state.modifiersData.offset; // Offsets can be applied only to the popper element
    if (elementContext === (0, _enumsJs.popper) && offsetData) {
        var offset = offsetData[placement];
        Object.keys(overflowOffsets).forEach(function(key) {
            var multiply = [
                (0, _enumsJs.right),
                (0, _enumsJs.bottom)
            ].indexOf(key) >= 0 ? 1 : -1;
            var axis = [
                (0, _enumsJs.top),
                (0, _enumsJs.bottom)
            ].indexOf(key) >= 0 ? 'y' : 'x';
            overflowOffsets[key] += offset[axis] * multiply;
        });
    }
    return overflowOffsets;
}

},{"../dom-utils/getClippingRect.js":"eeg2s","../dom-utils/getDocumentElement.js":"eJ9Y1","../dom-utils/getBoundingClientRect.js":"9CFSQ","./computeOffsets.js":"7jtXk","./rectToClientRect.js":"cQ3tg","../enums.js":"lCAq5","../dom-utils/instanceOf.js":"gYFUC","./mergePaddingObject.js":"lEIf9","./expandToHashMap.js":"iQlH5","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"eeg2s":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getClippingRect);
var _enumsJs = require("../enums.js");
var _getViewportRectJs = require("./getViewportRect.js");
var _getViewportRectJsDefault = parcelHelpers.interopDefault(_getViewportRectJs);
var _getDocumentRectJs = require("./getDocumentRect.js");
var _getDocumentRectJsDefault = parcelHelpers.interopDefault(_getDocumentRectJs);
var _listScrollParentsJs = require("./listScrollParents.js");
var _listScrollParentsJsDefault = parcelHelpers.interopDefault(_listScrollParentsJs);
var _getOffsetParentJs = require("./getOffsetParent.js");
var _getOffsetParentJsDefault = parcelHelpers.interopDefault(_getOffsetParentJs);
var _getDocumentElementJs = require("./getDocumentElement.js");
var _getDocumentElementJsDefault = parcelHelpers.interopDefault(_getDocumentElementJs);
var _getComputedStyleJs = require("./getComputedStyle.js");
var _getComputedStyleJsDefault = parcelHelpers.interopDefault(_getComputedStyleJs);
var _instanceOfJs = require("./instanceOf.js");
var _getBoundingClientRectJs = require("./getBoundingClientRect.js");
var _getBoundingClientRectJsDefault = parcelHelpers.interopDefault(_getBoundingClientRectJs);
var _getParentNodeJs = require("./getParentNode.js");
var _getParentNodeJsDefault = parcelHelpers.interopDefault(_getParentNodeJs);
var _containsJs = require("./contains.js");
var _containsJsDefault = parcelHelpers.interopDefault(_containsJs);
var _getNodeNameJs = require("./getNodeName.js");
var _getNodeNameJsDefault = parcelHelpers.interopDefault(_getNodeNameJs);
var _rectToClientRectJs = require("../utils/rectToClientRect.js");
var _rectToClientRectJsDefault = parcelHelpers.interopDefault(_rectToClientRectJs);
var _mathJs = require("../utils/math.js");
function getInnerBoundingClientRect(element, strategy) {
    var rect = (0, _getBoundingClientRectJsDefault.default)(element, false, strategy === 'fixed');
    rect.top = rect.top + element.clientTop;
    rect.left = rect.left + element.clientLeft;
    rect.bottom = rect.top + element.clientHeight;
    rect.right = rect.left + element.clientWidth;
    rect.width = element.clientWidth;
    rect.height = element.clientHeight;
    rect.x = rect.left;
    rect.y = rect.top;
    return rect;
}
function getClientRectFromMixedType(element, clippingParent, strategy) {
    return clippingParent === (0, _enumsJs.viewport) ? (0, _rectToClientRectJsDefault.default)((0, _getViewportRectJsDefault.default)(element, strategy)) : (0, _instanceOfJs.isElement)(clippingParent) ? getInnerBoundingClientRect(clippingParent, strategy) : (0, _rectToClientRectJsDefault.default)((0, _getDocumentRectJsDefault.default)((0, _getDocumentElementJsDefault.default)(element)));
} // A "clipping parent" is an overflowable container with the characteristic of
// clipping (or hiding) overflowing elements with a position different from
// `initial`
function getClippingParents(element) {
    var clippingParents = (0, _listScrollParentsJsDefault.default)((0, _getParentNodeJsDefault.default)(element));
    var canEscapeClipping = [
        'absolute',
        'fixed'
    ].indexOf((0, _getComputedStyleJsDefault.default)(element).position) >= 0;
    var clipperElement = canEscapeClipping && (0, _instanceOfJs.isHTMLElement)(element) ? (0, _getOffsetParentJsDefault.default)(element) : element;
    if (!(0, _instanceOfJs.isElement)(clipperElement)) return [];
     // $FlowFixMe[incompatible-return]: https://github.com/facebook/flow/issues/1414
    return clippingParents.filter(function(clippingParent) {
        return (0, _instanceOfJs.isElement)(clippingParent) && (0, _containsJsDefault.default)(clippingParent, clipperElement) && (0, _getNodeNameJsDefault.default)(clippingParent) !== 'body';
    });
} // Gets the maximum area that the element is visible in due to any number of
function getClippingRect(element, boundary, rootBoundary, strategy) {
    var mainClippingParents = boundary === 'clippingParents' ? getClippingParents(element) : [].concat(boundary);
    var clippingParents = [].concat(mainClippingParents, [
        rootBoundary
    ]);
    var firstClippingParent = clippingParents[0];
    var clippingRect = clippingParents.reduce(function(accRect, clippingParent) {
        var rect = getClientRectFromMixedType(element, clippingParent, strategy);
        accRect.top = (0, _mathJs.max)(rect.top, accRect.top);
        accRect.right = (0, _mathJs.min)(rect.right, accRect.right);
        accRect.bottom = (0, _mathJs.min)(rect.bottom, accRect.bottom);
        accRect.left = (0, _mathJs.max)(rect.left, accRect.left);
        return accRect;
    }, getClientRectFromMixedType(element, firstClippingParent, strategy));
    clippingRect.width = clippingRect.right - clippingRect.left;
    clippingRect.height = clippingRect.bottom - clippingRect.top;
    clippingRect.x = clippingRect.left;
    clippingRect.y = clippingRect.top;
    return clippingRect;
}

},{"../enums.js":"lCAq5","./getViewportRect.js":"cnH2G","./getDocumentRect.js":"d94SC","./listScrollParents.js":"2di3T","./getOffsetParent.js":"laoYw","./getDocumentElement.js":"eJ9Y1","./getComputedStyle.js":"3mZjB","./instanceOf.js":"gYFUC","./getBoundingClientRect.js":"9CFSQ","./getParentNode.js":"bIHpd","./contains.js":"4QxRR","./getNodeName.js":"a2Qom","../utils/rectToClientRect.js":"cQ3tg","../utils/math.js":"gQqVe","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"cnH2G":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getViewportRect);
var _getWindowJs = require("./getWindow.js");
var _getWindowJsDefault = parcelHelpers.interopDefault(_getWindowJs);
var _getDocumentElementJs = require("./getDocumentElement.js");
var _getDocumentElementJsDefault = parcelHelpers.interopDefault(_getDocumentElementJs);
var _getWindowScrollBarXJs = require("./getWindowScrollBarX.js");
var _getWindowScrollBarXJsDefault = parcelHelpers.interopDefault(_getWindowScrollBarXJs);
var _isLayoutViewportJs = require("./isLayoutViewport.js");
var _isLayoutViewportJsDefault = parcelHelpers.interopDefault(_isLayoutViewportJs);
function getViewportRect(element, strategy) {
    var win = (0, _getWindowJsDefault.default)(element);
    var html = (0, _getDocumentElementJsDefault.default)(element);
    var visualViewport = win.visualViewport;
    var width = html.clientWidth;
    var height = html.clientHeight;
    var x = 0;
    var y = 0;
    if (visualViewport) {
        width = visualViewport.width;
        height = visualViewport.height;
        var layoutViewport = (0, _isLayoutViewportJsDefault.default)();
        if (layoutViewport || !layoutViewport && strategy === 'fixed') {
            x = visualViewport.offsetLeft;
            y = visualViewport.offsetTop;
        }
    }
    return {
        width: width,
        height: height,
        x: x + (0, _getWindowScrollBarXJsDefault.default)(element),
        y: y
    };
}

},{"./getWindow.js":"2SkOo","./getDocumentElement.js":"eJ9Y1","./getWindowScrollBarX.js":"sz4Ld","./isLayoutViewport.js":"3ipHv","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"sz4Ld":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getWindowScrollBarX);
var _getBoundingClientRectJs = require("./getBoundingClientRect.js");
var _getBoundingClientRectJsDefault = parcelHelpers.interopDefault(_getBoundingClientRectJs);
var _getDocumentElementJs = require("./getDocumentElement.js");
var _getDocumentElementJsDefault = parcelHelpers.interopDefault(_getDocumentElementJs);
var _getWindowScrollJs = require("./getWindowScroll.js");
var _getWindowScrollJsDefault = parcelHelpers.interopDefault(_getWindowScrollJs);
function getWindowScrollBarX(element) {
    // If <html> has a CSS width greater than the viewport, then this will be
    // incorrect for RTL.
    // Popper 1 is broken in this case and never had a bug report so let's assume
    // it's not an issue. I don't think anyone ever specifies width on <html>
    // anyway.
    // Browsers where the left scrollbar doesn't cause an issue report `0` for
    // this (e.g. Edge 2019, IE11, Safari)
    return (0, _getBoundingClientRectJsDefault.default)((0, _getDocumentElementJsDefault.default)(element)).left + (0, _getWindowScrollJsDefault.default)(element).scrollLeft;
}

},{"./getBoundingClientRect.js":"9CFSQ","./getDocumentElement.js":"eJ9Y1","./getWindowScroll.js":"1XUtN","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"1XUtN":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getWindowScroll);
var _getWindowJs = require("./getWindow.js");
var _getWindowJsDefault = parcelHelpers.interopDefault(_getWindowJs);
function getWindowScroll(node) {
    var win = (0, _getWindowJsDefault.default)(node);
    var scrollLeft = win.pageXOffset;
    var scrollTop = win.pageYOffset;
    return {
        scrollLeft: scrollLeft,
        scrollTop: scrollTop
    };
}

},{"./getWindow.js":"2SkOo","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"d94SC":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getDocumentRect);
var _getDocumentElementJs = require("./getDocumentElement.js");
var _getDocumentElementJsDefault = parcelHelpers.interopDefault(_getDocumentElementJs);
var _getComputedStyleJs = require("./getComputedStyle.js");
var _getComputedStyleJsDefault = parcelHelpers.interopDefault(_getComputedStyleJs);
var _getWindowScrollBarXJs = require("./getWindowScrollBarX.js");
var _getWindowScrollBarXJsDefault = parcelHelpers.interopDefault(_getWindowScrollBarXJs);
var _getWindowScrollJs = require("./getWindowScroll.js");
var _getWindowScrollJsDefault = parcelHelpers.interopDefault(_getWindowScrollJs);
var _mathJs = require("../utils/math.js"); // Gets the entire size of the scrollable document area, even extending outside
function getDocumentRect(element) {
    var _element$ownerDocumen;
    var html = (0, _getDocumentElementJsDefault.default)(element);
    var winScroll = (0, _getWindowScrollJsDefault.default)(element);
    var body = (_element$ownerDocumen = element.ownerDocument) == null ? void 0 : _element$ownerDocumen.body;
    var width = (0, _mathJs.max)(html.scrollWidth, html.clientWidth, body ? body.scrollWidth : 0, body ? body.clientWidth : 0);
    var height = (0, _mathJs.max)(html.scrollHeight, html.clientHeight, body ? body.scrollHeight : 0, body ? body.clientHeight : 0);
    var x = -winScroll.scrollLeft + (0, _getWindowScrollBarXJsDefault.default)(element);
    var y = -winScroll.scrollTop;
    if ((0, _getComputedStyleJsDefault.default)(body || html).direction === 'rtl') x += (0, _mathJs.max)(html.clientWidth, body ? body.clientWidth : 0) - width;
    return {
        width: width,
        height: height,
        x: x,
        y: y
    };
}

},{"./getDocumentElement.js":"eJ9Y1","./getComputedStyle.js":"3mZjB","./getWindowScrollBarX.js":"sz4Ld","./getWindowScroll.js":"1XUtN","../utils/math.js":"gQqVe","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"2di3T":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>listScrollParents);
var _getScrollParentJs = require("./getScrollParent.js");
var _getScrollParentJsDefault = parcelHelpers.interopDefault(_getScrollParentJs);
var _getParentNodeJs = require("./getParentNode.js");
var _getParentNodeJsDefault = parcelHelpers.interopDefault(_getParentNodeJs);
var _getWindowJs = require("./getWindow.js");
var _getWindowJsDefault = parcelHelpers.interopDefault(_getWindowJs);
var _isScrollParentJs = require("./isScrollParent.js");
var _isScrollParentJsDefault = parcelHelpers.interopDefault(_isScrollParentJs);
function listScrollParents(element, list) {
    var _element$ownerDocumen;
    if (list === void 0) list = [];
    var scrollParent = (0, _getScrollParentJsDefault.default)(element);
    var isBody = scrollParent === ((_element$ownerDocumen = element.ownerDocument) == null ? void 0 : _element$ownerDocumen.body);
    var win = (0, _getWindowJsDefault.default)(scrollParent);
    var target = isBody ? [
        win
    ].concat(win.visualViewport || [], (0, _isScrollParentJsDefault.default)(scrollParent) ? scrollParent : []) : scrollParent;
    var updatedList = list.concat(target);
    return isBody ? updatedList : updatedList.concat(listScrollParents((0, _getParentNodeJsDefault.default)(target)));
}

},{"./getScrollParent.js":"jy4ZS","./getParentNode.js":"bIHpd","./getWindow.js":"2SkOo","./isScrollParent.js":"9rLGO","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"jy4ZS":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getScrollParent);
var _getParentNodeJs = require("./getParentNode.js");
var _getParentNodeJsDefault = parcelHelpers.interopDefault(_getParentNodeJs);
var _isScrollParentJs = require("./isScrollParent.js");
var _isScrollParentJsDefault = parcelHelpers.interopDefault(_isScrollParentJs);
var _getNodeNameJs = require("./getNodeName.js");
var _getNodeNameJsDefault = parcelHelpers.interopDefault(_getNodeNameJs);
var _instanceOfJs = require("./instanceOf.js");
function getScrollParent(node) {
    if ([
        'html',
        'body',
        '#document'
    ].indexOf((0, _getNodeNameJsDefault.default)(node)) >= 0) // $FlowFixMe[incompatible-return]: assume body is always available
    return node.ownerDocument.body;
    if ((0, _instanceOfJs.isHTMLElement)(node) && (0, _isScrollParentJsDefault.default)(node)) return node;
    return getScrollParent((0, _getParentNodeJsDefault.default)(node));
}

},{"./getParentNode.js":"bIHpd","./isScrollParent.js":"9rLGO","./getNodeName.js":"a2Qom","./instanceOf.js":"gYFUC","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"9rLGO":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>isScrollParent);
var _getComputedStyleJs = require("./getComputedStyle.js");
var _getComputedStyleJsDefault = parcelHelpers.interopDefault(_getComputedStyleJs);
function isScrollParent(element) {
    // Firefox wants us to check `-x` and `-y` variations as well
    var _getComputedStyle = (0, _getComputedStyleJsDefault.default)(element), overflow = _getComputedStyle.overflow, overflowX = _getComputedStyle.overflowX, overflowY = _getComputedStyle.overflowY;
    return /auto|scroll|overlay|hidden/.test(overflow + overflowY + overflowX);
}

},{"./getComputedStyle.js":"3mZjB","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"cQ3tg":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>rectToClientRect);
function rectToClientRect(rect) {
    return Object.assign({}, rect, {
        left: rect.x,
        top: rect.y,
        right: rect.x + rect.width,
        bottom: rect.y + rect.height
    });
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"7jtXk":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>computeOffsets);
var _getBasePlacementJs = require("./getBasePlacement.js");
var _getBasePlacementJsDefault = parcelHelpers.interopDefault(_getBasePlacementJs);
var _getVariationJs = require("./getVariation.js");
var _getVariationJsDefault = parcelHelpers.interopDefault(_getVariationJs);
var _getMainAxisFromPlacementJs = require("./getMainAxisFromPlacement.js");
var _getMainAxisFromPlacementJsDefault = parcelHelpers.interopDefault(_getMainAxisFromPlacementJs);
var _enumsJs = require("../enums.js");
function computeOffsets(_ref) {
    var reference = _ref.reference, element = _ref.element, placement = _ref.placement;
    var basePlacement = placement ? (0, _getBasePlacementJsDefault.default)(placement) : null;
    var variation = placement ? (0, _getVariationJsDefault.default)(placement) : null;
    var commonX = reference.x + reference.width / 2 - element.width / 2;
    var commonY = reference.y + reference.height / 2 - element.height / 2;
    var offsets;
    switch(basePlacement){
        case 0, _enumsJs.top:
            offsets = {
                x: commonX,
                y: reference.y - element.height
            };
            break;
        case 0, _enumsJs.bottom:
            offsets = {
                x: commonX,
                y: reference.y + reference.height
            };
            break;
        case 0, _enumsJs.right:
            offsets = {
                x: reference.x + reference.width,
                y: commonY
            };
            break;
        case 0, _enumsJs.left:
            offsets = {
                x: reference.x - element.width,
                y: commonY
            };
            break;
        default:
            offsets = {
                x: reference.x,
                y: reference.y
            };
    }
    var mainAxis = basePlacement ? (0, _getMainAxisFromPlacementJsDefault.default)(basePlacement) : null;
    if (mainAxis != null) {
        var len = mainAxis === 'y' ? 'height' : 'width';
        switch(variation){
            case 0, _enumsJs.start:
                offsets[mainAxis] = offsets[mainAxis] - (reference[len] / 2 - element[len] / 2);
                break;
            case 0, _enumsJs.end:
                offsets[mainAxis] = offsets[mainAxis] + (reference[len] / 2 - element[len] / 2);
                break;
            default:
        }
    }
    return offsets;
}

},{"./getBasePlacement.js":"59Wp3","./getVariation.js":"hIo7Y","./getMainAxisFromPlacement.js":"1Xlom","../enums.js":"lCAq5","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"gytMj":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>computeAutoPlacement);
var _getVariationJs = require("./getVariation.js");
var _getVariationJsDefault = parcelHelpers.interopDefault(_getVariationJs);
var _enumsJs = require("../enums.js");
var _detectOverflowJs = require("./detectOverflow.js");
var _detectOverflowJsDefault = parcelHelpers.interopDefault(_detectOverflowJs);
var _getBasePlacementJs = require("./getBasePlacement.js");
var _getBasePlacementJsDefault = parcelHelpers.interopDefault(_getBasePlacementJs);
function computeAutoPlacement(state, options) {
    if (options === void 0) options = {};
    var _options = options, placement = _options.placement, boundary = _options.boundary, rootBoundary = _options.rootBoundary, padding = _options.padding, flipVariations = _options.flipVariations, _options$allowedAutoP = _options.allowedAutoPlacements, allowedAutoPlacements = _options$allowedAutoP === void 0 ? (0, _enumsJs.placements) : _options$allowedAutoP;
    var variation = (0, _getVariationJsDefault.default)(placement);
    var placements = variation ? flipVariations ? (0, _enumsJs.variationPlacements) : (0, _enumsJs.variationPlacements).filter(function(placement) {
        return (0, _getVariationJsDefault.default)(placement) === variation;
    }) : (0, _enumsJs.basePlacements);
    var allowedPlacements = placements.filter(function(placement) {
        return allowedAutoPlacements.indexOf(placement) >= 0;
    });
    if (allowedPlacements.length === 0) allowedPlacements = placements;
     // $FlowFixMe[incompatible-type]: Flow seems to have problems with two array unions...
    var overflows = allowedPlacements.reduce(function(acc, placement) {
        acc[placement] = (0, _detectOverflowJsDefault.default)(state, {
            placement: placement,
            boundary: boundary,
            rootBoundary: rootBoundary,
            padding: padding
        })[(0, _getBasePlacementJsDefault.default)(placement)];
        return acc;
    }, {});
    return Object.keys(overflows).sort(function(a, b) {
        return overflows[a] - overflows[b];
    });
}

},{"./getVariation.js":"hIo7Y","../enums.js":"lCAq5","./detectOverflow.js":"ltCuw","./getBasePlacement.js":"59Wp3","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"2g4OF":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
var _enumsJs = require("../enums.js");
var _detectOverflowJs = require("../utils/detectOverflow.js");
var _detectOverflowJsDefault = parcelHelpers.interopDefault(_detectOverflowJs);
function getSideOffsets(overflow, rect, preventedOffsets) {
    if (preventedOffsets === void 0) preventedOffsets = {
        x: 0,
        y: 0
    };
    return {
        top: overflow.top - rect.height - preventedOffsets.y,
        right: overflow.right - rect.width + preventedOffsets.x,
        bottom: overflow.bottom - rect.height + preventedOffsets.y,
        left: overflow.left - rect.width - preventedOffsets.x
    };
}
function isAnySideFullyClipped(overflow) {
    return [
        (0, _enumsJs.top),
        (0, _enumsJs.right),
        (0, _enumsJs.bottom),
        (0, _enumsJs.left)
    ].some(function(side) {
        return overflow[side] >= 0;
    });
}
function hide(_ref) {
    var state = _ref.state, name = _ref.name;
    var referenceRect = state.rects.reference;
    var popperRect = state.rects.popper;
    var preventedOffsets = state.modifiersData.preventOverflow;
    var referenceOverflow = (0, _detectOverflowJsDefault.default)(state, {
        elementContext: 'reference'
    });
    var popperAltOverflow = (0, _detectOverflowJsDefault.default)(state, {
        altBoundary: true
    });
    var referenceClippingOffsets = getSideOffsets(referenceOverflow, referenceRect);
    var popperEscapeOffsets = getSideOffsets(popperAltOverflow, popperRect, preventedOffsets);
    var isReferenceHidden = isAnySideFullyClipped(referenceClippingOffsets);
    var hasPopperEscaped = isAnySideFullyClipped(popperEscapeOffsets);
    state.modifiersData[name] = {
        referenceClippingOffsets: referenceClippingOffsets,
        popperEscapeOffsets: popperEscapeOffsets,
        isReferenceHidden: isReferenceHidden,
        hasPopperEscaped: hasPopperEscaped
    };
    state.attributes.popper = Object.assign({}, state.attributes.popper, {
        'data-popper-reference-hidden': isReferenceHidden,
        'data-popper-escaped': hasPopperEscaped
    });
} // eslint-disable-next-line import/no-unused-modules
exports.default = {
    name: 'hide',
    enabled: true,
    phase: 'main',
    requiresIfExists: [
        'preventOverflow'
    ],
    fn: hide
};

},{"../enums.js":"lCAq5","../utils/detectOverflow.js":"ltCuw","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"3GKVY":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "distanceAndSkiddingToXY", ()=>distanceAndSkiddingToXY);
var _getBasePlacementJs = require("../utils/getBasePlacement.js");
var _getBasePlacementJsDefault = parcelHelpers.interopDefault(_getBasePlacementJs);
var _enumsJs = require("../enums.js"); // eslint-disable-next-line import/no-unused-modules
function distanceAndSkiddingToXY(placement, rects, offset) {
    var basePlacement = (0, _getBasePlacementJsDefault.default)(placement);
    var invertDistance = [
        (0, _enumsJs.left),
        (0, _enumsJs.top)
    ].indexOf(basePlacement) >= 0 ? -1 : 1;
    var _ref = typeof offset === 'function' ? offset(Object.assign({}, rects, {
        placement: placement
    })) : offset, skidding = _ref[0], distance = _ref[1];
    skidding = skidding || 0;
    distance = (distance || 0) * invertDistance;
    return [
        (0, _enumsJs.left),
        (0, _enumsJs.right)
    ].indexOf(basePlacement) >= 0 ? {
        x: distance,
        y: skidding
    } : {
        x: skidding,
        y: distance
    };
}
function offset(_ref2) {
    var state = _ref2.state, options = _ref2.options, name = _ref2.name;
    var _options$offset = options.offset, offset = _options$offset === void 0 ? [
        0,
        0
    ] : _options$offset;
    var data = (0, _enumsJs.placements).reduce(function(acc, placement) {
        acc[placement] = distanceAndSkiddingToXY(placement, state.rects, offset);
        return acc;
    }, {});
    var _data$state$placement = data[state.placement], x = _data$state$placement.x, y = _data$state$placement.y;
    if (state.modifiersData.popperOffsets != null) {
        state.modifiersData.popperOffsets.x += x;
        state.modifiersData.popperOffsets.y += y;
    }
    state.modifiersData[name] = data;
} // eslint-disable-next-line import/no-unused-modules
exports.default = {
    name: 'offset',
    enabled: true,
    phase: 'main',
    requires: [
        'popperOffsets'
    ],
    fn: offset
};

},{"../utils/getBasePlacement.js":"59Wp3","../enums.js":"lCAq5","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"6I679":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
var _computeOffsetsJs = require("../utils/computeOffsets.js");
var _computeOffsetsJsDefault = parcelHelpers.interopDefault(_computeOffsetsJs);
function popperOffsets(_ref) {
    var state = _ref.state, name = _ref.name;
    // Offsets are the actual position the popper needs to have to be
    // properly positioned near its reference element
    // This is the most basic placement, and will be adjusted by
    // the modifiers in the next step
    state.modifiersData[name] = (0, _computeOffsetsJsDefault.default)({
        reference: state.rects.reference,
        element: state.rects.popper,
        strategy: 'absolute',
        placement: state.placement
    });
} // eslint-disable-next-line import/no-unused-modules
exports.default = {
    name: 'popperOffsets',
    enabled: true,
    phase: 'read',
    fn: popperOffsets,
    data: {}
};

},{"../utils/computeOffsets.js":"7jtXk","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"1AMhb":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
var _enumsJs = require("../enums.js");
var _getBasePlacementJs = require("../utils/getBasePlacement.js");
var _getBasePlacementJsDefault = parcelHelpers.interopDefault(_getBasePlacementJs);
var _getMainAxisFromPlacementJs = require("../utils/getMainAxisFromPlacement.js");
var _getMainAxisFromPlacementJsDefault = parcelHelpers.interopDefault(_getMainAxisFromPlacementJs);
var _getAltAxisJs = require("../utils/getAltAxis.js");
var _getAltAxisJsDefault = parcelHelpers.interopDefault(_getAltAxisJs);
var _withinJs = require("../utils/within.js");
var _getLayoutRectJs = require("../dom-utils/getLayoutRect.js");
var _getLayoutRectJsDefault = parcelHelpers.interopDefault(_getLayoutRectJs);
var _getOffsetParentJs = require("../dom-utils/getOffsetParent.js");
var _getOffsetParentJsDefault = parcelHelpers.interopDefault(_getOffsetParentJs);
var _detectOverflowJs = require("../utils/detectOverflow.js");
var _detectOverflowJsDefault = parcelHelpers.interopDefault(_detectOverflowJs);
var _getVariationJs = require("../utils/getVariation.js");
var _getVariationJsDefault = parcelHelpers.interopDefault(_getVariationJs);
var _getFreshSideObjectJs = require("../utils/getFreshSideObject.js");
var _getFreshSideObjectJsDefault = parcelHelpers.interopDefault(_getFreshSideObjectJs);
var _mathJs = require("../utils/math.js");
function preventOverflow(_ref) {
    var state = _ref.state, options = _ref.options, name = _ref.name;
    var _options$mainAxis = options.mainAxis, checkMainAxis = _options$mainAxis === void 0 ? true : _options$mainAxis, _options$altAxis = options.altAxis, checkAltAxis = _options$altAxis === void 0 ? false : _options$altAxis, boundary = options.boundary, rootBoundary = options.rootBoundary, altBoundary = options.altBoundary, padding = options.padding, _options$tether = options.tether, tether = _options$tether === void 0 ? true : _options$tether, _options$tetherOffset = options.tetherOffset, tetherOffset = _options$tetherOffset === void 0 ? 0 : _options$tetherOffset;
    var overflow = (0, _detectOverflowJsDefault.default)(state, {
        boundary: boundary,
        rootBoundary: rootBoundary,
        padding: padding,
        altBoundary: altBoundary
    });
    var basePlacement = (0, _getBasePlacementJsDefault.default)(state.placement);
    var variation = (0, _getVariationJsDefault.default)(state.placement);
    var isBasePlacement = !variation;
    var mainAxis = (0, _getMainAxisFromPlacementJsDefault.default)(basePlacement);
    var altAxis = (0, _getAltAxisJsDefault.default)(mainAxis);
    var popperOffsets = state.modifiersData.popperOffsets;
    var referenceRect = state.rects.reference;
    var popperRect = state.rects.popper;
    var tetherOffsetValue = typeof tetherOffset === 'function' ? tetherOffset(Object.assign({}, state.rects, {
        placement: state.placement
    })) : tetherOffset;
    var normalizedTetherOffsetValue = typeof tetherOffsetValue === 'number' ? {
        mainAxis: tetherOffsetValue,
        altAxis: tetherOffsetValue
    } : Object.assign({
        mainAxis: 0,
        altAxis: 0
    }, tetherOffsetValue);
    var offsetModifierState = state.modifiersData.offset ? state.modifiersData.offset[state.placement] : null;
    var data = {
        x: 0,
        y: 0
    };
    if (!popperOffsets) return;
    if (checkMainAxis) {
        var _offsetModifierState$;
        var mainSide = mainAxis === 'y' ? (0, _enumsJs.top) : (0, _enumsJs.left);
        var altSide = mainAxis === 'y' ? (0, _enumsJs.bottom) : (0, _enumsJs.right);
        var len = mainAxis === 'y' ? 'height' : 'width';
        var offset = popperOffsets[mainAxis];
        var min = offset + overflow[mainSide];
        var max = offset - overflow[altSide];
        var additive = tether ? -popperRect[len] / 2 : 0;
        var minLen = variation === (0, _enumsJs.start) ? referenceRect[len] : popperRect[len];
        var maxLen = variation === (0, _enumsJs.start) ? -popperRect[len] : -referenceRect[len]; // We need to include the arrow in the calculation so the arrow doesn't go
        // outside the reference bounds
        var arrowElement = state.elements.arrow;
        var arrowRect = tether && arrowElement ? (0, _getLayoutRectJsDefault.default)(arrowElement) : {
            width: 0,
            height: 0
        };
        var arrowPaddingObject = state.modifiersData['arrow#persistent'] ? state.modifiersData['arrow#persistent'].padding : (0, _getFreshSideObjectJsDefault.default)();
        var arrowPaddingMin = arrowPaddingObject[mainSide];
        var arrowPaddingMax = arrowPaddingObject[altSide]; // If the reference length is smaller than the arrow length, we don't want
        // to include its full size in the calculation. If the reference is small
        // and near the edge of a boundary, the popper can overflow even if the
        // reference is not overflowing as well (e.g. virtual elements with no
        // width or height)
        var arrowLen = (0, _withinJs.within)(0, referenceRect[len], arrowRect[len]);
        var minOffset = isBasePlacement ? referenceRect[len] / 2 - additive - arrowLen - arrowPaddingMin - normalizedTetherOffsetValue.mainAxis : minLen - arrowLen - arrowPaddingMin - normalizedTetherOffsetValue.mainAxis;
        var maxOffset = isBasePlacement ? -referenceRect[len] / 2 + additive + arrowLen + arrowPaddingMax + normalizedTetherOffsetValue.mainAxis : maxLen + arrowLen + arrowPaddingMax + normalizedTetherOffsetValue.mainAxis;
        var arrowOffsetParent = state.elements.arrow && (0, _getOffsetParentJsDefault.default)(state.elements.arrow);
        var clientOffset = arrowOffsetParent ? mainAxis === 'y' ? arrowOffsetParent.clientTop || 0 : arrowOffsetParent.clientLeft || 0 : 0;
        var offsetModifierValue = (_offsetModifierState$ = offsetModifierState == null ? void 0 : offsetModifierState[mainAxis]) != null ? _offsetModifierState$ : 0;
        var tetherMin = offset + minOffset - offsetModifierValue - clientOffset;
        var tetherMax = offset + maxOffset - offsetModifierValue;
        var preventedOffset = (0, _withinJs.within)(tether ? (0, _mathJs.min)(min, tetherMin) : min, offset, tether ? (0, _mathJs.max)(max, tetherMax) : max);
        popperOffsets[mainAxis] = preventedOffset;
        data[mainAxis] = preventedOffset - offset;
    }
    if (checkAltAxis) {
        var _offsetModifierState$2;
        var _mainSide = mainAxis === 'x' ? (0, _enumsJs.top) : (0, _enumsJs.left);
        var _altSide = mainAxis === 'x' ? (0, _enumsJs.bottom) : (0, _enumsJs.right);
        var _offset = popperOffsets[altAxis];
        var _len = altAxis === 'y' ? 'height' : 'width';
        var _min = _offset + overflow[_mainSide];
        var _max = _offset - overflow[_altSide];
        var isOriginSide = [
            (0, _enumsJs.top),
            (0, _enumsJs.left)
        ].indexOf(basePlacement) !== -1;
        var _offsetModifierValue = (_offsetModifierState$2 = offsetModifierState == null ? void 0 : offsetModifierState[altAxis]) != null ? _offsetModifierState$2 : 0;
        var _tetherMin = isOriginSide ? _min : _offset - referenceRect[_len] - popperRect[_len] - _offsetModifierValue + normalizedTetherOffsetValue.altAxis;
        var _tetherMax = isOriginSide ? _offset + referenceRect[_len] + popperRect[_len] - _offsetModifierValue - normalizedTetherOffsetValue.altAxis : _max;
        var _preventedOffset = tether && isOriginSide ? (0, _withinJs.withinMaxClamp)(_tetherMin, _offset, _tetherMax) : (0, _withinJs.within)(tether ? _tetherMin : _min, _offset, tether ? _tetherMax : _max);
        popperOffsets[altAxis] = _preventedOffset;
        data[altAxis] = _preventedOffset - _offset;
    }
    state.modifiersData[name] = data;
} // eslint-disable-next-line import/no-unused-modules
exports.default = {
    name: 'preventOverflow',
    enabled: true,
    phase: 'main',
    fn: preventOverflow,
    requiresIfExists: [
        'offset'
    ]
};

},{"../enums.js":"lCAq5","../utils/getBasePlacement.js":"59Wp3","../utils/getMainAxisFromPlacement.js":"1Xlom","../utils/getAltAxis.js":"59FWE","../utils/within.js":"3glSz","../dom-utils/getLayoutRect.js":"jvjuf","../dom-utils/getOffsetParent.js":"laoYw","../utils/detectOverflow.js":"ltCuw","../utils/getVariation.js":"hIo7Y","../utils/getFreshSideObject.js":"g4xOt","../utils/math.js":"gQqVe","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"59FWE":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getAltAxis);
function getAltAxis(axis) {
    return axis === 'x' ? 'y' : 'x';
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"cHuNp":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "popperGenerator", ()=>popperGenerator);
parcelHelpers.export(exports, "createPopper", ()=>createPopper);
parcelHelpers.export(exports, "detectOverflow", ()=>(0, _detectOverflowJsDefault.default));
var _getCompositeRectJs = require("./dom-utils/getCompositeRect.js");
var _getCompositeRectJsDefault = parcelHelpers.interopDefault(_getCompositeRectJs);
var _getLayoutRectJs = require("./dom-utils/getLayoutRect.js");
var _getLayoutRectJsDefault = parcelHelpers.interopDefault(_getLayoutRectJs);
var _listScrollParentsJs = require("./dom-utils/listScrollParents.js");
var _listScrollParentsJsDefault = parcelHelpers.interopDefault(_listScrollParentsJs);
var _getOffsetParentJs = require("./dom-utils/getOffsetParent.js");
var _getOffsetParentJsDefault = parcelHelpers.interopDefault(_getOffsetParentJs);
var _orderModifiersJs = require("./utils/orderModifiers.js");
var _orderModifiersJsDefault = parcelHelpers.interopDefault(_orderModifiersJs);
var _debounceJs = require("./utils/debounce.js");
var _debounceJsDefault = parcelHelpers.interopDefault(_debounceJs);
var _mergeByNameJs = require("./utils/mergeByName.js");
var _mergeByNameJsDefault = parcelHelpers.interopDefault(_mergeByNameJs);
var _detectOverflowJs = require("./utils/detectOverflow.js");
var _detectOverflowJsDefault = parcelHelpers.interopDefault(_detectOverflowJs);
var _instanceOfJs = require("./dom-utils/instanceOf.js");
var DEFAULT_OPTIONS = {
    placement: 'bottom',
    modifiers: [],
    strategy: 'absolute'
};
function areValidElements() {
    for(var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++)args[_key] = arguments[_key];
    return !args.some(function(element) {
        return !(element && typeof element.getBoundingClientRect === 'function');
    });
}
function popperGenerator(generatorOptions) {
    if (generatorOptions === void 0) generatorOptions = {};
    var _generatorOptions = generatorOptions, _generatorOptions$def = _generatorOptions.defaultModifiers, defaultModifiers = _generatorOptions$def === void 0 ? [] : _generatorOptions$def, _generatorOptions$def2 = _generatorOptions.defaultOptions, defaultOptions = _generatorOptions$def2 === void 0 ? DEFAULT_OPTIONS : _generatorOptions$def2;
    return function createPopper(reference, popper, options) {
        if (options === void 0) options = defaultOptions;
        var state = {
            placement: 'bottom',
            orderedModifiers: [],
            options: Object.assign({}, DEFAULT_OPTIONS, defaultOptions),
            modifiersData: {},
            elements: {
                reference: reference,
                popper: popper
            },
            attributes: {},
            styles: {}
        };
        var effectCleanupFns = [];
        var isDestroyed = false;
        var instance = {
            state: state,
            setOptions: function setOptions(setOptionsAction) {
                var options = typeof setOptionsAction === 'function' ? setOptionsAction(state.options) : setOptionsAction;
                cleanupModifierEffects();
                state.options = Object.assign({}, defaultOptions, state.options, options);
                state.scrollParents = {
                    reference: (0, _instanceOfJs.isElement)(reference) ? (0, _listScrollParentsJsDefault.default)(reference) : reference.contextElement ? (0, _listScrollParentsJsDefault.default)(reference.contextElement) : [],
                    popper: (0, _listScrollParentsJsDefault.default)(popper)
                }; // Orders the modifiers based on their dependencies and `phase`
                // properties
                var orderedModifiers = (0, _orderModifiersJsDefault.default)((0, _mergeByNameJsDefault.default)([].concat(defaultModifiers, state.options.modifiers))); // Strip out disabled modifiers
                state.orderedModifiers = orderedModifiers.filter(function(m) {
                    return m.enabled;
                });
                runModifierEffects();
                return instance.update();
            },
            // Sync update – it will always be executed, even if not necessary. This
            // is useful for low frequency updates where sync behavior simplifies the
            // logic.
            // For high frequency updates (e.g. `resize` and `scroll` events), always
            // prefer the async Popper#update method
            forceUpdate: function forceUpdate() {
                if (isDestroyed) return;
                var _state$elements = state.elements, reference = _state$elements.reference, popper = _state$elements.popper; // Don't proceed if `reference` or `popper` are not valid elements
                // anymore
                if (!areValidElements(reference, popper)) return;
                 // Store the reference and popper rects to be read by modifiers
                state.rects = {
                    reference: (0, _getCompositeRectJsDefault.default)(reference, (0, _getOffsetParentJsDefault.default)(popper), state.options.strategy === 'fixed'),
                    popper: (0, _getLayoutRectJsDefault.default)(popper)
                }; // Modifiers have the ability to reset the current update cycle. The
                // most common use case for this is the `flip` modifier changing the
                // placement, which then needs to re-run all the modifiers, because the
                // logic was previously ran for the previous placement and is therefore
                // stale/incorrect
                state.reset = false;
                state.placement = state.options.placement; // On each update cycle, the `modifiersData` property for each modifier
                // is filled with the initial data specified by the modifier. This means
                // it doesn't persist and is fresh on each update.
                // To ensure persistent data, use `${name}#persistent`
                state.orderedModifiers.forEach(function(modifier) {
                    return state.modifiersData[modifier.name] = Object.assign({}, modifier.data);
                });
                for(var index = 0; index < state.orderedModifiers.length; index++){
                    if (state.reset === true) {
                        state.reset = false;
                        index = -1;
                        continue;
                    }
                    var _state$orderedModifie = state.orderedModifiers[index], fn = _state$orderedModifie.fn, _state$orderedModifie2 = _state$orderedModifie.options, _options = _state$orderedModifie2 === void 0 ? {} : _state$orderedModifie2, name = _state$orderedModifie.name;
                    if (typeof fn === 'function') state = fn({
                        state: state,
                        options: _options,
                        name: name,
                        instance: instance
                    }) || state;
                }
            },
            // Async and optimistically optimized update – it will not be executed if
            // not necessary (debounced to run at most once-per-tick)
            update: (0, _debounceJsDefault.default)(function() {
                return new Promise(function(resolve) {
                    instance.forceUpdate();
                    resolve(state);
                });
            }),
            destroy: function destroy() {
                cleanupModifierEffects();
                isDestroyed = true;
            }
        };
        if (!areValidElements(reference, popper)) return instance;
        instance.setOptions(options).then(function(state) {
            if (!isDestroyed && options.onFirstUpdate) options.onFirstUpdate(state);
        }); // Modifiers have the ability to execute arbitrary code before the first
        // update cycle runs. They will be executed in the same order as the update
        // cycle. This is useful when a modifier adds some persistent data that
        // other modifiers need to use, but the modifier is run after the dependent
        // one.
        function runModifierEffects() {
            state.orderedModifiers.forEach(function(_ref) {
                var name = _ref.name, _ref$options = _ref.options, options = _ref$options === void 0 ? {} : _ref$options, effect = _ref.effect;
                if (typeof effect === 'function') {
                    var cleanupFn = effect({
                        state: state,
                        name: name,
                        instance: instance,
                        options: options
                    });
                    var noopFn = function noopFn() {};
                    effectCleanupFns.push(cleanupFn || noopFn);
                }
            });
        }
        function cleanupModifierEffects() {
            effectCleanupFns.forEach(function(fn) {
                return fn();
            });
            effectCleanupFns = [];
        }
        return instance;
    };
}
var createPopper = /*#__PURE__*/ popperGenerator(); // eslint-disable-next-line import/no-unused-modules

},{"./dom-utils/getCompositeRect.js":"ijPls","./dom-utils/getLayoutRect.js":"jvjuf","./dom-utils/listScrollParents.js":"2di3T","./dom-utils/getOffsetParent.js":"laoYw","./utils/orderModifiers.js":"N0VO0","./utils/debounce.js":"g6Chr","./utils/mergeByName.js":"2zTVN","./utils/detectOverflow.js":"ltCuw","./dom-utils/instanceOf.js":"gYFUC","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"ijPls":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getCompositeRect);
var _getBoundingClientRectJs = require("./getBoundingClientRect.js");
var _getBoundingClientRectJsDefault = parcelHelpers.interopDefault(_getBoundingClientRectJs);
var _getNodeScrollJs = require("./getNodeScroll.js");
var _getNodeScrollJsDefault = parcelHelpers.interopDefault(_getNodeScrollJs);
var _getNodeNameJs = require("./getNodeName.js");
var _getNodeNameJsDefault = parcelHelpers.interopDefault(_getNodeNameJs);
var _instanceOfJs = require("./instanceOf.js");
var _getWindowScrollBarXJs = require("./getWindowScrollBarX.js");
var _getWindowScrollBarXJsDefault = parcelHelpers.interopDefault(_getWindowScrollBarXJs);
var _getDocumentElementJs = require("./getDocumentElement.js");
var _getDocumentElementJsDefault = parcelHelpers.interopDefault(_getDocumentElementJs);
var _isScrollParentJs = require("./isScrollParent.js");
var _isScrollParentJsDefault = parcelHelpers.interopDefault(_isScrollParentJs);
var _mathJs = require("../utils/math.js");
function isElementScaled(element) {
    var rect = element.getBoundingClientRect();
    var scaleX = (0, _mathJs.round)(rect.width) / element.offsetWidth || 1;
    var scaleY = (0, _mathJs.round)(rect.height) / element.offsetHeight || 1;
    return scaleX !== 1 || scaleY !== 1;
} // Returns the composite rect of an element relative to its offsetParent.
function getCompositeRect(elementOrVirtualElement, offsetParent, isFixed) {
    if (isFixed === void 0) isFixed = false;
    var isOffsetParentAnElement = (0, _instanceOfJs.isHTMLElement)(offsetParent);
    var offsetParentIsScaled = (0, _instanceOfJs.isHTMLElement)(offsetParent) && isElementScaled(offsetParent);
    var documentElement = (0, _getDocumentElementJsDefault.default)(offsetParent);
    var rect = (0, _getBoundingClientRectJsDefault.default)(elementOrVirtualElement, offsetParentIsScaled, isFixed);
    var scroll = {
        scrollLeft: 0,
        scrollTop: 0
    };
    var offsets = {
        x: 0,
        y: 0
    };
    if (isOffsetParentAnElement || !isOffsetParentAnElement && !isFixed) {
        if ((0, _getNodeNameJsDefault.default)(offsetParent) !== 'body' || // https://github.com/popperjs/popper-core/issues/1078
        (0, _isScrollParentJsDefault.default)(documentElement)) scroll = (0, _getNodeScrollJsDefault.default)(offsetParent);
        if ((0, _instanceOfJs.isHTMLElement)(offsetParent)) {
            offsets = (0, _getBoundingClientRectJsDefault.default)(offsetParent, true);
            offsets.x += offsetParent.clientLeft;
            offsets.y += offsetParent.clientTop;
        } else if (documentElement) offsets.x = (0, _getWindowScrollBarXJsDefault.default)(documentElement);
    }
    return {
        x: rect.left + scroll.scrollLeft - offsets.x,
        y: rect.top + scroll.scrollTop - offsets.y,
        width: rect.width,
        height: rect.height
    };
}

},{"./getBoundingClientRect.js":"9CFSQ","./getNodeScroll.js":"bBjCr","./getNodeName.js":"a2Qom","./instanceOf.js":"gYFUC","./getWindowScrollBarX.js":"sz4Ld","./getDocumentElement.js":"eJ9Y1","./isScrollParent.js":"9rLGO","../utils/math.js":"gQqVe","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"bBjCr":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getNodeScroll);
var _getWindowScrollJs = require("./getWindowScroll.js");
var _getWindowScrollJsDefault = parcelHelpers.interopDefault(_getWindowScrollJs);
var _getWindowJs = require("./getWindow.js");
var _getWindowJsDefault = parcelHelpers.interopDefault(_getWindowJs);
var _instanceOfJs = require("./instanceOf.js");
var _getHTMLElementScrollJs = require("./getHTMLElementScroll.js");
var _getHTMLElementScrollJsDefault = parcelHelpers.interopDefault(_getHTMLElementScrollJs);
function getNodeScroll(node) {
    if (node === (0, _getWindowJsDefault.default)(node) || !(0, _instanceOfJs.isHTMLElement)(node)) return (0, _getWindowScrollJsDefault.default)(node);
    else return (0, _getHTMLElementScrollJsDefault.default)(node);
}

},{"./getWindowScroll.js":"1XUtN","./getWindow.js":"2SkOo","./instanceOf.js":"gYFUC","./getHTMLElementScroll.js":"6pwY2","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"6pwY2":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>getHTMLElementScroll);
function getHTMLElementScroll(element) {
    return {
        scrollLeft: element.scrollLeft,
        scrollTop: element.scrollTop
    };
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"N0VO0":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>orderModifiers);
var _enumsJs = require("../enums.js"); // source: https://stackoverflow.com/questions/49875255
function order(modifiers) {
    var map = new Map();
    var visited = new Set();
    var result = [];
    modifiers.forEach(function(modifier) {
        map.set(modifier.name, modifier);
    }); // On visiting object, check for its dependencies and visit them recursively
    function sort(modifier) {
        visited.add(modifier.name);
        var requires = [].concat(modifier.requires || [], modifier.requiresIfExists || []);
        requires.forEach(function(dep) {
            if (!visited.has(dep)) {
                var depModifier = map.get(dep);
                if (depModifier) sort(depModifier);
            }
        });
        result.push(modifier);
    }
    modifiers.forEach(function(modifier) {
        if (!visited.has(modifier.name)) // check for visited object
        sort(modifier);
    });
    return result;
}
function orderModifiers(modifiers) {
    // order based on dependencies
    var orderedModifiers = order(modifiers); // order based on phase
    return (0, _enumsJs.modifierPhases).reduce(function(acc, phase) {
        return acc.concat(orderedModifiers.filter(function(modifier) {
            return modifier.phase === phase;
        }));
    }, []);
}

},{"../enums.js":"lCAq5","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"g6Chr":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>debounce);
function debounce(fn) {
    var pending;
    return function() {
        if (!pending) pending = new Promise(function(resolve) {
            Promise.resolve().then(function() {
                pending = undefined;
                resolve(fn());
            });
        });
        return pending;
    };
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"2zTVN":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>mergeByName);
function mergeByName(modifiers) {
    var merged = modifiers.reduce(function(merged, current) {
        var existing = merged[current.name];
        merged[current.name] = existing ? Object.assign({}, existing, current, {
            options: Object.assign({}, existing.options, current.options),
            data: Object.assign({}, existing.data, current.data)
        }) : current;
        return merged;
    }, {}); // IE11 does not support Object.values
    return Object.keys(merged).map(function(key) {
        return merged[key];
    });
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"1PuRF":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "createPopperLite", ()=>(0, _popperLiteJs.createPopper)) // eslint-disable-next-line import/no-unused-modules
;
parcelHelpers.export(exports, "createPopper", ()=>createPopper) // eslint-disable-next-line import/no-unused-modules
;
parcelHelpers.export(exports, "popperGenerator", ()=>(0, _createPopperJs.popperGenerator));
parcelHelpers.export(exports, "defaultModifiers", ()=>defaultModifiers);
parcelHelpers.export(exports, "detectOverflow", ()=>(0, _createPopperJs.detectOverflow));
var _createPopperJs = require("./createPopper.js");
var _eventListenersJs = require("./modifiers/eventListeners.js");
var _eventListenersJsDefault = parcelHelpers.interopDefault(_eventListenersJs);
var _popperOffsetsJs = require("./modifiers/popperOffsets.js");
var _popperOffsetsJsDefault = parcelHelpers.interopDefault(_popperOffsetsJs);
var _computeStylesJs = require("./modifiers/computeStyles.js");
var _computeStylesJsDefault = parcelHelpers.interopDefault(_computeStylesJs);
var _applyStylesJs = require("./modifiers/applyStyles.js");
var _applyStylesJsDefault = parcelHelpers.interopDefault(_applyStylesJs);
var _offsetJs = require("./modifiers/offset.js");
var _offsetJsDefault = parcelHelpers.interopDefault(_offsetJs);
var _flipJs = require("./modifiers/flip.js");
var _flipJsDefault = parcelHelpers.interopDefault(_flipJs);
var _preventOverflowJs = require("./modifiers/preventOverflow.js");
var _preventOverflowJsDefault = parcelHelpers.interopDefault(_preventOverflowJs);
var _arrowJs = require("./modifiers/arrow.js");
var _arrowJsDefault = parcelHelpers.interopDefault(_arrowJs);
var _hideJs = require("./modifiers/hide.js");
var _hideJsDefault = parcelHelpers.interopDefault(_hideJs);
var _popperLiteJs = require("./popper-lite.js");
var _indexJs = require("./modifiers/index.js");
parcelHelpers.exportAll(_indexJs, exports);
var defaultModifiers = [
    (0, _eventListenersJsDefault.default),
    (0, _popperOffsetsJsDefault.default),
    (0, _computeStylesJsDefault.default),
    (0, _applyStylesJsDefault.default),
    (0, _offsetJsDefault.default),
    (0, _flipJsDefault.default),
    (0, _preventOverflowJsDefault.default),
    (0, _arrowJsDefault.default),
    (0, _hideJsDefault.default)
];
var createPopper = /*#__PURE__*/ (0, _createPopperJs.popperGenerator)({
    defaultModifiers: defaultModifiers
}); // eslint-disable-next-line import/no-unused-modules

},{"./createPopper.js":"cHuNp","./modifiers/eventListeners.js":"hBKsL","./modifiers/popperOffsets.js":"6I679","./modifiers/computeStyles.js":"gDlm2","./modifiers/applyStyles.js":"4iMn4","./modifiers/offset.js":"3GKVY","./modifiers/flip.js":"fv5wq","./modifiers/preventOverflow.js":"1AMhb","./modifiers/arrow.js":"31HFW","./modifiers/hide.js":"2g4OF","./popper-lite.js":false,"./modifiers/index.js":false,"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"gKW1N":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "createPopper", ()=>createPopper);
parcelHelpers.export(exports, "popperGenerator", ()=>(0, _createPopperJs.popperGenerator));
parcelHelpers.export(exports, "defaultModifiers", ()=>defaultModifiers);
parcelHelpers.export(exports, "detectOverflow", ()=>(0, _createPopperJs.detectOverflow));
var _createPopperJs = require("./createPopper.js");
var _eventListenersJs = require("./modifiers/eventListeners.js");
var _eventListenersJsDefault = parcelHelpers.interopDefault(_eventListenersJs);
var _popperOffsetsJs = require("./modifiers/popperOffsets.js");
var _popperOffsetsJsDefault = parcelHelpers.interopDefault(_popperOffsetsJs);
var _computeStylesJs = require("./modifiers/computeStyles.js");
var _computeStylesJsDefault = parcelHelpers.interopDefault(_computeStylesJs);
var _applyStylesJs = require("./modifiers/applyStyles.js");
var _applyStylesJsDefault = parcelHelpers.interopDefault(_applyStylesJs);
var defaultModifiers = [
    (0, _eventListenersJsDefault.default),
    (0, _popperOffsetsJsDefault.default),
    (0, _computeStylesJsDefault.default),
    (0, _applyStylesJsDefault.default)
];
var createPopper = /*#__PURE__*/ (0, _createPopperJs.popperGenerator)({
    defaultModifiers: defaultModifiers
}); // eslint-disable-next-line import/no-unused-modules

},{"./createPopper.js":"cHuNp","./modifiers/eventListeners.js":"hBKsL","./modifiers/popperOffsets.js":"6I679","./modifiers/computeStyles.js":"gDlm2","./modifiers/applyStyles.js":"4iMn4","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"a2QOC":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "MAX", ()=>(0, _maxJsDefault.default));
parcelHelpers.export(exports, "NIL", ()=>(0, _nilJsDefault.default));
parcelHelpers.export(exports, "parse", ()=>(0, _parseJsDefault.default));
parcelHelpers.export(exports, "stringify", ()=>(0, _stringifyJsDefault.default));
parcelHelpers.export(exports, "v1", ()=>(0, _v1JsDefault.default));
parcelHelpers.export(exports, "v1ToV6", ()=>(0, _v1ToV6JsDefault.default));
parcelHelpers.export(exports, "v3", ()=>(0, _v3JsDefault.default));
parcelHelpers.export(exports, "v4", ()=>(0, _v4JsDefault.default));
parcelHelpers.export(exports, "v5", ()=>(0, _v5JsDefault.default));
parcelHelpers.export(exports, "v6", ()=>(0, _v6JsDefault.default));
parcelHelpers.export(exports, "v6ToV1", ()=>(0, _v6ToV1JsDefault.default));
parcelHelpers.export(exports, "v7", ()=>(0, _v7JsDefault.default));
parcelHelpers.export(exports, "validate", ()=>(0, _validateJsDefault.default));
parcelHelpers.export(exports, "version", ()=>(0, _versionJsDefault.default));
var _maxJs = require("./max.js");
var _maxJsDefault = parcelHelpers.interopDefault(_maxJs);
var _nilJs = require("./nil.js");
var _nilJsDefault = parcelHelpers.interopDefault(_nilJs);
var _parseJs = require("./parse.js");
var _parseJsDefault = parcelHelpers.interopDefault(_parseJs);
var _stringifyJs = require("./stringify.js");
var _stringifyJsDefault = parcelHelpers.interopDefault(_stringifyJs);
var _v1Js = require("./v1.js");
var _v1JsDefault = parcelHelpers.interopDefault(_v1Js);
var _v1ToV6Js = require("./v1ToV6.js");
var _v1ToV6JsDefault = parcelHelpers.interopDefault(_v1ToV6Js);
var _v3Js = require("./v3.js");
var _v3JsDefault = parcelHelpers.interopDefault(_v3Js);
var _v4Js = require("./v4.js");
var _v4JsDefault = parcelHelpers.interopDefault(_v4Js);
var _v5Js = require("./v5.js");
var _v5JsDefault = parcelHelpers.interopDefault(_v5Js);
var _v6Js = require("./v6.js");
var _v6JsDefault = parcelHelpers.interopDefault(_v6Js);
var _v6ToV1Js = require("./v6ToV1.js");
var _v6ToV1JsDefault = parcelHelpers.interopDefault(_v6ToV1Js);
var _v7Js = require("./v7.js");
var _v7JsDefault = parcelHelpers.interopDefault(_v7Js);
var _validateJs = require("./validate.js");
var _validateJsDefault = parcelHelpers.interopDefault(_validateJs);
var _versionJs = require("./version.js");
var _versionJsDefault = parcelHelpers.interopDefault(_versionJs);

},{"./max.js":false,"./nil.js":false,"./parse.js":false,"./stringify.js":false,"./v1.js":false,"./v1ToV6.js":false,"./v3.js":false,"./v4.js":"3LtLY","./v5.js":false,"./v6.js":false,"./v6ToV1.js":false,"./v7.js":false,"./validate.js":false,"./version.js":false,"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"krriJ":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "unsafeStringify", ()=>unsafeStringify);
var _validateJs = require("./validate.js");
var _validateJsDefault = parcelHelpers.interopDefault(_validateJs);
const byteToHex = [];
for(let i = 0; i < 256; ++i)byteToHex.push((i + 0x100).toString(16).slice(1));
function unsafeStringify(arr, offset = 0) {
    return (byteToHex[arr[offset + 0]] + byteToHex[arr[offset + 1]] + byteToHex[arr[offset + 2]] + byteToHex[arr[offset + 3]] + '-' + byteToHex[arr[offset + 4]] + byteToHex[arr[offset + 5]] + '-' + byteToHex[arr[offset + 6]] + byteToHex[arr[offset + 7]] + '-' + byteToHex[arr[offset + 8]] + byteToHex[arr[offset + 9]] + '-' + byteToHex[arr[offset + 10]] + byteToHex[arr[offset + 11]] + byteToHex[arr[offset + 12]] + byteToHex[arr[offset + 13]] + byteToHex[arr[offset + 14]] + byteToHex[arr[offset + 15]]).toLowerCase();
}
function stringify(arr, offset = 0) {
    const uuid = unsafeStringify(arr, offset);
    if (!(0, _validateJsDefault.default)(uuid)) throw TypeError('Stringified UUID is invalid');
    return uuid;
}
exports.default = stringify;

},{"./validate.js":"iKCxU","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"iKCxU":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
var _regexJs = require("./regex.js");
var _regexJsDefault = parcelHelpers.interopDefault(_regexJs);
function validate(uuid) {
    return typeof uuid === 'string' && (0, _regexJsDefault.default).test(uuid);
}
exports.default = validate;

},{"./regex.js":"idjzo","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"idjzo":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
exports.default = /^(?:[0-9a-f]{8}-[0-9a-f]{4}-[1-8][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}|00000000-0000-0000-0000-000000000000|ffffffff-ffff-ffff-ffff-ffffffffffff)$/i;

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"3LtLY":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
var _nativeJs = require("./native.js");
var _nativeJsDefault = parcelHelpers.interopDefault(_nativeJs);
var _rngJs = require("./rng.js");
var _rngJsDefault = parcelHelpers.interopDefault(_rngJs);
var _stringifyJs = require("./stringify.js");
function _v4(options, buf, offset) {
    options = options || {};
    const rnds = options.random ?? options.rng?.() ?? (0, _rngJsDefault.default)();
    if (rnds.length < 16) throw new Error('Random bytes length must be >= 16');
    rnds[6] = rnds[6] & 0x0f | 0x40;
    rnds[8] = rnds[8] & 0x3f | 0x80;
    if (buf) {
        offset = offset || 0;
        if (offset < 0 || offset + 16 > buf.length) throw new RangeError(`UUID byte range ${offset}:${offset + 15} is out of buffer bounds`);
        for(let i = 0; i < 16; ++i)buf[offset + i] = rnds[i];
        return buf;
    }
    return (0, _stringifyJs.unsafeStringify)(rnds);
}
function v4(options, buf, offset) {
    if ((0, _nativeJsDefault.default).randomUUID && !buf && !options) return (0, _nativeJsDefault.default).randomUUID();
    return _v4(options, buf, offset);
}
exports.default = v4;

},{"./native.js":"3iTXz","./rng.js":"7mHk4","./stringify.js":"krriJ","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"3iTXz":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
const randomUUID = typeof crypto !== 'undefined' && crypto.randomUUID && crypto.randomUUID.bind(crypto);
exports.default = {
    randomUUID
};

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"7mHk4":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "default", ()=>rng);
let getRandomValues;
const rnds8 = new Uint8Array(16);
function rng() {
    if (!getRandomValues) {
        if (typeof crypto === 'undefined' || !crypto.getRandomValues) throw new Error('crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported');
        getRandomValues = crypto.getRandomValues.bind(crypto);
    }
    return getRandomValues(rnds8);
}

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"8rVEj":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "TournamentFormat", ()=>TournamentFormat);
parcelHelpers.export(exports, "TournamentRank", ()=>TournamentRank);
parcelHelpers.export(exports, "TournamentState", ()=>TournamentState);
parcelHelpers.export(exports, "StandingsMode", ()=>StandingsMode);
parcelHelpers.export(exports, "DeckListsMode", ()=>DeckListsMode);
parcelHelpers.export(exports, "PlayerState", ()=>PlayerState);
parcelHelpers.export(exports, "TableState", ()=>TableState);
parcelHelpers.export(exports, "Barrier", ()=>Barrier);
parcelHelpers.export(exports, "RankingCategoy", ()=>RankingCategoy);
parcelHelpers.export(exports, "LeagueRanking", ()=>LeagueRanking);
parcelHelpers.export(exports, "LeagueKind", ()=>LeagueKind);
parcelHelpers.export(exports, "MemberRole", ()=>MemberRole);
parcelHelpers.export(exports, "MemberFilter", ()=>MemberFilter);
parcelHelpers.export(exports, "AlertLevel", ()=>AlertLevel);
var TournamentFormat = /*#__PURE__*/ function(TournamentFormat) {
    TournamentFormat["Standard"] = "Standard";
    TournamentFormat["V5"] = "V5";
    TournamentFormat["Limited"] = "Limited";
    TournamentFormat["Draft"] = "Draft";
    return TournamentFormat;
}({});
var TournamentRank = /*#__PURE__*/ function(TournamentRank) {
    TournamentRank["BASIC"] = "";
    TournamentRank["NC"] = "National Championship";
    TournamentRank["CC"] = "Continental Championship";
    TournamentRank["GP"] = "Grand Prix";
    return TournamentRank;
}({});
var TournamentState = /*#__PURE__*/ function(TournamentState) {
    TournamentState["PLANNED"] = "Planned";
    TournamentState["REGISTRATION"] = "Registration";
    TournamentState["WAITING"] = "Waiting";
    TournamentState["PLAYING"] = "Playing";
    TournamentState["FINALS"] = "Finals";
    TournamentState["FINISHED"] = "Finished";
    return TournamentState;
}({});
var StandingsMode = /*#__PURE__*/ function(StandingsMode) {
    StandingsMode["PRIVATE"] = "Private";
    StandingsMode["CUTOFF"] = "Cutoff";
    StandingsMode["TOP_10"] = "Top 10";
    StandingsMode["PUBLIC"] = "Public";
    return StandingsMode;
}({});
var DeckListsMode = /*#__PURE__*/ function(DeckListsMode) {
    DeckListsMode["WINNER"] = "Winner";
    DeckListsMode["FINALISTS"] = "Finalists";
    DeckListsMode["ALL"] = "All";
    return DeckListsMode;
}({});
var PlayerState = /*#__PURE__*/ function(PlayerState) {
    PlayerState["REGISTERED"] = "Registered";
    PlayerState["CHECKED_IN"] = "Checked-in";
    PlayerState["PLAYING"] = "Playing";
    PlayerState["FINISHED"] = "Finished";
    return PlayerState;
}({});
var TableState = /*#__PURE__*/ function(TableState) {
    TableState["FINISHED"] = "Finished";
    TableState["IN_PROGRESS"] = "In Progress";
    TableState["INVALID"] = "Invalid";
    return TableState;
}({});
var Barrier = /*#__PURE__*/ function(Barrier) {
    Barrier["MISSING_DECK"] = "Missing Deck";
    Barrier["BANNED"] = "Banned";
    Barrier["DISQUALIFIED"] = "Disqualified";
    Barrier["MAX_ROUNDS"] = "Max Rounds";
    return Barrier;
}({});
var RankingCategoy = /*#__PURE__*/ function(RankingCategoy) {
    RankingCategoy["CONSTRUCTED_ONLINE"] = "Constructed Online";
    RankingCategoy["CONSTRUCTED_ONSITE"] = "Constructed Onsite";
    RankingCategoy["LIMITED_ONLINE"] = "Limited Online";
    RankingCategoy["LIMITED_ONSITE"] = "Limited Onsite";
    return RankingCategoy;
}({});
var LeagueRanking = /*#__PURE__*/ function(LeagueRanking) {
    LeagueRanking["RTP"] = "RTP";
    LeagueRanking["GP"] = "GP";
    LeagueRanking["Score"] = "Score";
    return LeagueRanking;
}({});
var LeagueKind = /*#__PURE__*/ function(LeagueKind) {
    LeagueKind["LEAGUE"] = "League";
    LeagueKind["META"] = "Meta-League";
    return LeagueKind;
}({});
var MemberRole = /*#__PURE__*/ function(MemberRole) {
    MemberRole["ADMIN"] = "Admin";
    MemberRole["PRINCE"] = "Prince";
    MemberRole["RULEMONGER"] = "Rulemonger";
    MemberRole["JUDGE"] = "Judge";
    MemberRole["JUDGEKIN"] = "Judgekin";
    MemberRole["NC"] = "NC";
    MemberRole["PTC"] = "PTC";
    MemberRole["PLAYTESTER"] = "Playtester";
    MemberRole["ETHICS"] = "Ethics";
    return MemberRole;
}({});
var MemberFilter = /*#__PURE__*/ function(MemberFilter) {
    MemberFilter["MY_RECRUITS"] = "My Recruits";
    MemberFilter["NO_SPONSOR"] = "No Sponsor";
    MemberFilter["NO_VEKN"] = "No VEKN";
    return MemberFilter;
}({});
var AlertLevel = /*#__PURE__*/ function(AlertLevel) {
    AlertLevel["INFO"] = "Info";
    AlertLevel["SUCCESS"] = "Success";
    AlertLevel["WARNING"] = "Warning";
    AlertLevel["DANGER"] = "Danger";
    return AlertLevel;
}({});

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"6FUFI":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "MembersDB", ()=>MembersDB);
parcelHelpers.export(exports, "get_user", ()=>get_user);
parcelHelpers.export(exports, "to_public_person", ()=>to_public_person);
parcelHelpers.export(exports, "PersonNameCompletion", ()=>PersonNameCompletion);
parcelHelpers.export(exports, "PersonLookup", ()=>PersonLookup);
parcelHelpers.export(exports, "can_change_role", ()=>can_change_role);
parcelHelpers.export(exports, "can_organize", ()=>can_organize);
parcelHelpers.export(exports, "can_admin_tournament", ()=>can_admin_tournament);
parcelHelpers.export(exports, "can_admin_league", ()=>can_admin_league);
parcelHelpers.export(exports, "can_change_info", ()=>can_change_info);
parcelHelpers.export(exports, "can_sanction", ()=>can_sanction);
parcelHelpers.export(exports, "can_change_vekn", ()=>can_change_vekn);
parcelHelpers.export(exports, "can_playtest", ()=>can_playtest);
parcelHelpers.export(exports, "can_contact", ()=>can_contact);
parcelHelpers.export(exports, "AddMemberModal", ()=>AddMemberModal);
parcelHelpers.export(exports, "ExistingVeknModal", ()=>ExistingVeknModal);
var _d = require("./d");
var _base = require("./base");
var _idb = require("idb");
var _uuid = require("uuid");
var _unidecode = require("unidecode");
var _unidecodeDefault = parcelHelpers.interopDefault(_unidecode);
// Increment this number if/when the person model changes
const VERSION = 1;
function normalize_string(s) {
    var res = (0, _unidecodeDefault.default)(s).toLowerCase();
    // remove non-letters non-numbers
    res.replace(/[^\p{L}\p{N}\s]/gu, "");
    // remove spurious spaces
    res.replace(/\s{2,}/g, " ");
    return res;
}
class MembersDB {
    token;
    db;
    trie;
    root;
    constructor(token, el){
        this.token = token;
        this.root = el;
    }
    spinner_overlay() {
        const overlay = _base.create_append(this.root, "div", [
            "w-100",
            "h-100",
            "d-flex",
            "align-items-center",
            "justify-content-center"
        ]);
        _base.create_append(overlay, "div", [
            "spinner-border"
        ], {
            role: "status"
        });
        _base.create_append(overlay, "div", [], {}).innerText = "Loading members...";
        return overlay;
    }
    async init() {
        this.trie = new Map();
        this.db = await _idb.openDB("VEKN", VERSION, {
            upgrade (db, oldVersion, newVersion, transaction, event) {
                const membersStore = db.createObjectStore("members", {
                    keyPath: "uid"
                });
                membersStore.createIndex("vekn", "vekn", {
                    unique: false
                });
                console.log("re-created members db");
            },
            blocked (currentVersion, blockedVersion, event) {
                window.location.reload();
            },
            blocking (currentVersion, blockedVersion, event) {
                window.location.reload();
            },
            terminated () {
                window.location.reload();
            }
        });
        await this.refresh();
        await this.build_trie();
    }
    async reload() {
        sessionStorage.removeItem("members_refresh");
        this.trie = new Map();
        await this.refresh();
        await this.build_trie();
    }
    async refresh() {
        console.log("refreshing db");
        const options = {
            headers: {
                'Accept': 'application/json, application/x-ndjson',
                'Authorization': `Bearer ${this.token.access_token}`
            }
        };
        const last_timestamp = sessionStorage.getItem("members_refresh");
        if (last_timestamp) options.headers["If-None-Match"] = last_timestamp;
        const res = await _base.do_fetch("/api/vekn/members", options);
        if (!res) return;
        if (res.headers.get("X-Data-Scope") == "public") {
            // reset db systematically
            this.db.clear("members");
            sessionStorage.removeItem("members_refresh");
            // put the partial list
            const update = await res.json();
            const tr = this.db.transaction("members", "readwrite");
            for (const member of update)tr.store.put(member);
            await tr.done;
        } else if (res.headers.get("content-type") == "application/x-ndjson") {
            // wait for the whole stream: we can refine later if needed
            // but we cannot wait on the stream during the IndexDB transaction anyway
            const old_keys = new Set(await this.db.getAllKeys("members"));
            const reader = res.body.getReader();
            const decoder = new TextDecoder();
            const new_keys = new Set();
            var buffer = "";
            const spinner = this.spinner_overlay();
            while(true){
                const { value, done } = await reader.read();
                if (done) break;
                buffer += decoder.decode(value, {
                    stream: true
                });
                const parts = buffer.split("\n");
                // last entry may be partial
                buffer = parts.pop();
                const tr = this.db.transaction("members", "readwrite");
                for (const line of parts){
                    if (line.trim()) try {
                        const person = JSON.parse(line);
                        tr.store.put(person);
                        new_keys.add(person.uid);
                    } catch (e) {
                        console.error("Invalid JSON:", line, e);
                    }
                }
                await tr.done;
            }
            // process tail
            if (buffer.trim()) {
                const tr = this.db.transaction("members", "readwrite");
                try {
                    const person = JSON.parse(buffer);
                    tr.store.put(person);
                    new_keys.add(person.uid);
                } catch (e) {
                    console.error("Invalid JSON at end:", buffer, e);
                }
                await tr.done;
            }
            // remove persons that were not in stream
            const tr = this.db.transaction("members", "readwrite");
            for (const key of old_keys.difference(new_keys))tr.store.delete(key);
            await tr.done;
            // record timestamp
            sessionStorage.setItem("members_refresh", res.headers.get("ETag"));
            spinner.remove();
        } else if (res.headers.get("content-type") == "application/json") {
            const update = await res.json();
            const tr = this.db.transaction("members", "readwrite");
            for (const person of update.update)tr.store.put(person);
            for (const uid of update.delete)tr.store.delete(uid);
            await tr.done;
            // record timestamp
            sessionStorage.setItem("members_refresh", res.headers.get("ETag"));
        }
    }
    _get_trie_parts(name) {
        return normalize_string(name).split(" ");
    }
    trie_add(person) {
        for (const part of this._get_trie_parts(person.name))for(var i = 1; i < part.length + 1; i++){
            const piece = part.slice(0, i);
            if (!this.trie.has(piece)) this.trie.set(piece, new Map());
            this.trie.get(piece).set(person.uid, {
                name: person.name,
                uid: person.uid,
                vekn: person.vekn,
                country: person.country,
                country_flag: person.country_flag
            });
        }
    }
    trie_remove(person) {
        for (const part of this._get_trie_parts(person.name))for(var i = 1; i < part.length + 1; i++){
            const piece = part.slice(0, i);
            const match = this.trie.get(piece);
            if (!match) continue;
            match.delete(person.uid);
        }
    }
    async build_trie() {
        for (const person of (await this.db.getAll("members")))this.trie_add(person);
    }
    async get_by_uid(uid) {
        return await this.db.get("members", uid);
    }
    async get_by_vekn(vekn) {
        return await this.db.getFromIndex("members", "vekn", vekn);
    }
    complete_name(s) {
        var members_list = undefined;
        for (const part of this._get_trie_parts(s)){
            const lookup = this.trie.get(part);
            if (lookup) {
                if (members_list) members_list = members_list.filter((m)=>lookup.has(m.uid));
                else members_list = [
                    ...lookup.values()
                ].sort((a, b)=>a.name.localeCompare(b.name));
            }
        }
        return members_list ? members_list : [];
    }
    async add_online(member) {
        const res = await _base.do_fetch_with_token("/api/vekn/members", this.token, {
            method: "post",
            body: JSON.stringify(member)
        });
        if (res) {
            const ret = await res.json();
            await this.db.put("members", ret);
            return ret;
        }
    }
    async getAll() {
        return await this.db.getAll("members");
    }
}
async function get_user(token) {
    const uid = _base.user_uid_from_token(token);
    const res = await _base.do_fetch_with_token(`/api/vekn/members/${uid}`, token, {});
    if (res) return await res.json();
}
function to_public_person(person) {
    return {
        uid: person.uid,
        name: person.name,
        vekn: person.vekn,
        country: person.country,
        country_flag: person.country_flag,
        city: person.city
    };
}
class PersonNameCompletion extends _base.Completion {
    membersDB;
    input_vekn_id;
    button;
    callback;
    constructor(membersDB, input, callback, button){
        super(input);
        this.membersDB = membersDB;
        this.callback = callback;
        this.button = button;
    }
    async complete_input(value) {
        return this.membersDB.complete_name(value);
    }
    item_label(item) {
        if (item.country) return `${item.name} (${item.country_flag} ${item.country})`;
        return item.name;
    }
    item_selected(item) {
        this.callback(item);
    }
}
class PersonLookup {
    form;
    input_vekn_id;
    input_name;
    name_completion;
    button;
    membersDB;
    person;
    constructor(members_db, root, label, inline = false){
        this.membersDB = members_db;
        const form_uid = (0, _uuid.v4)();
        // create an empty form on top of the body, so it can be used inside a "real" form
        this.form = _base.create_prepend(document.body, "form", [], {
            id: form_uid
        });
        const top_div = _base.create_append(root, "div", [
            "d-sm-flex"
        ]);
        if (inline) top_div.classList.add("flex-row", "align-items-center");
        else top_div.classList.add("flex-column");
        const vekn_div = _base.create_append(top_div, "div", [
            "me-2",
            "mb-2"
        ]);
        this.input_vekn_id = _base.create_append(vekn_div, "input", [
            "form-control"
        ], {
            type: "text",
            placeholder: "VEKN ID number",
            autocomplete: "off",
            form: form_uid,
            name: "new-vekn-id"
        });
        this.input_vekn_id.ariaAutoComplete = "none";
        this.input_vekn_id.spellcheck = false;
        const dropdown_div = _base.create_append(top_div, "div", [
            "me-2",
            "mb-2"
        ]);
        this.input_name = _base.create_append(dropdown_div, "input", [
            "form-control"
        ], {
            type: "text",
            placeholder: "Name",
            autocomplete: "off",
            form: form_uid,
            name: "new-name"
        });
        this.input_name.ariaAutoComplete = "none";
        this.input_name.spellcheck = false;
        const button_div = _base.create_append(top_div, "div", [
            "me-2",
            "mb-2"
        ]);
        this.button = _base.create_append(button_div, "button", [
            "btn",
            "btn-primary"
        ], {
            type: "submit",
            form: form_uid
        });
        this.button.innerText = label;
        this.button.disabled = true;
        this.name_completion = new PersonNameCompletion(this.membersDB, this.input_name, (p)=>this.select_member_by_name(p), this.button);
        this.input_vekn_id.addEventListener("input", (ev)=>this.select_member_by_vekn());
    }
    reset() {
        this.person = undefined;
        this.input_vekn_id.value = "";
        this.name_completion.reset();
        this.button.disabled = true;
    }
    async select_member_by_vekn() {
        this.person = to_public_person(await this.membersDB.get_by_vekn(this.input_vekn_id.value));
        if (this.person) {
            this.input_name.value = this.person.name;
            this.button.disabled = false;
            this.button.focus();
        } else {
            this.input_name.value = "";
            this.button.disabled = true;
        }
    }
    select_member_by_name(person) {
        this.person = to_public_person(person);
        this.input_vekn_id.value = this.person.vekn;
        this.button.disabled = false;
        this.button.focus();
    }
}
function can_change_role(member, target, role) {
    if (member.roles.includes(_d.MemberRole.ADMIN)) return true;
    switch(role){
        case _d.MemberRole.PRINCE:
            if (member.roles.includes(_d.MemberRole.NC) && member.country == target.country) return true;
            return false;
        case _d.MemberRole.PLAYTESTER:
            if (member.roles.includes(_d.MemberRole.PTC)) return true;
            return false;
        default:
            return false;
    }
}
function can_organize(member) {
    if (member.roles.includes(_d.MemberRole.ADMIN)) return true;
    if (member.roles.includes(_d.MemberRole.NC)) return true;
    if (member.roles.includes(_d.MemberRole.PRINCE)) return true;
    return false;
}
function can_admin_tournament(member, tournament) {
    if (member.roles.includes(_d.MemberRole.ADMIN)) return true;
    if (member.roles.includes(_d.MemberRole.NC) && member.country == tournament.country) return true;
    if (tournament.judges.find((j)=>j.uid == member.uid)) return true;
    return false;
}
function can_admin_league(member, league) {
    if (member.roles.includes(_d.MemberRole.ADMIN)) return true;
    if (member.roles.includes(_d.MemberRole.NC) && member.country == league.country) return true;
    if (league.organizers.find((j)=>j.uid == member.uid)) return true;
    return false;
}
function can_change_info(member, target) {
    if (member.uid == target.uid) return true;
    const member_roles = new Set(member.roles);
    if (member_roles.has(_d.MemberRole.ADMIN)) return true;
    const target_roles = new Set(target.roles);
    if (target_roles.has(_d.MemberRole.ADMIN)) return false;
    if (target_roles.has(_d.MemberRole.NC)) return false;
    if (target_roles.has(_d.MemberRole.PRINCE) || target_roles.has(_d.MemberRole.PTC) || target_roles.has(_d.MemberRole.ETHICS)) {
        if (member.roles.includes(_d.MemberRole.NC) && member.country == target.country) return true;
        return false;
    }
    if (member_roles.has(_d.MemberRole.NC) || member_roles.has(_d.MemberRole.PTC) || member_roles.has(_d.MemberRole.ETHICS)) return true;
    if (member_roles.has(_d.MemberRole.PRINCE) && member.country == target.country) return true;
    return false;
}
function can_sanction(member) {
    if (member.roles.includes(_d.MemberRole.ADMIN)) return true;
    if (member.roles.includes(_d.MemberRole.RULEMONGER)) return true;
    if (member.roles.includes(_d.MemberRole.JUDGE)) return true;
    if (member.roles.includes(_d.MemberRole.ETHICS)) return true;
    return false;
}
function can_change_vekn(member, target) {
    if (member.uid == target.uid) return true;
    if (member.roles.includes(_d.MemberRole.ADMIN)) return true;
    if (member.roles.includes(_d.MemberRole.NC) && member.country == target.country) return true;
    return false;
}
function can_playtest(member) {
    if (member && member.roles && (member.roles.includes(_d.MemberRole.ADMIN) || member.roles.includes(_d.MemberRole.PTC) || member.roles.includes(_d.MemberRole.PLAYTESTER))) return true;
    return false;
}
function can_contact(member, target) {
    if (!(member && member.roles && target)) return false;
    if (member.uid == target.uid || member.roles.includes(_d.MemberRole.ADMIN)) return true;
    if (target.roles.includes(_d.MemberRole.NC)) return true;
    if (member.country == target.country && target.roles.includes(_d.MemberRole.PRINCE)) return true;
    if (member.country == target.country && (member.roles.includes(_d.MemberRole.PRINCE) || member.roles.includes(_d.MemberRole.NC))) return true;
    if (member.roles.includes(_d.MemberRole.NC) && target.roles.includes(_d.MemberRole.ADMIN)) return true;
    return false;
}
class AddMemberModal extends _base.Modal {
    token;
    members_map;
    countries;
    form;
    name;
    country;
    city;
    email;
    submit_button;
    callback;
    assign_vekn;
    constructor(el, members_map, callback){
        super(el);
        this.members_map = members_map;
        this.callback = callback;
        this.modal_title.innerText = "Add Member";
        this.form = _base.create_append(this.modal_body, "form");
        const alert = _base.create_append(this.form, "div", [
            "alert",
            "alert-warning"
        ], {
            role: "alert"
        });
        alert.innerText = "Do not register people from an online contact: ask them to create an account and send you a link to their profile to assign them a VEKN ID";
        this.name = _base.create_append(this.form, "input", [
            "form-control",
            "my-2"
        ], {
            type: "text",
            autocomplete: "new-name",
            name: "new-name"
        });
        this.name.ariaAutoComplete = "none";
        this.name.spellcheck = false;
        this.name.placeholder = "Name";
        this.country = _base.create_append(this.form, "select", [
            "form-select",
            "my-2"
        ], {
            name: "country",
            autocomplete: "none"
        });
        this.city = _base.create_append(this.form, "select", [
            "form-select",
            "my-2"
        ], {
            name: "city"
        });
        this.email = _base.create_append(this.form, "input", [
            "form-control",
            "my-2"
        ], {
            type: "text",
            autocomplete: "new-email",
            name: "new-email"
        });
        this.email.placeholder = "E-mail";
        this.email.ariaAutoComplete = "none";
        this.email.spellcheck = false;
        this.submit_button = _base.create_append(this.form, "button", [
            "btn",
            "btn-primary",
            "my-2"
        ], {
            type: "submit"
        });
        this.submit_button.innerText = "Submit";
        this.country.ariaLabel = "Country";
        this.country.options.add(_base.create_element("option", [], {
            value: "",
            label: "Country"
        }));
        this.country.required = true;
        this.city.options.add(_base.create_element("option", [], {
            value: "",
            label: "City"
        }));
        this.city.required = false;
        this.country.addEventListener("change", (ev)=>this.change_country());
        this.form.addEventListener("submit", (ev)=>this.submit(ev));
        this.modal_div.addEventListener("shown.bs.modal", ()=>{
            this.name.focus();
        });
    }
    async init(token, countries) {
        if (token) this.token = token;
        else this.token = await _base.fetchToken();
        if (countries) this.countries = countries;
        else {
            const res = await _base.do_fetch("/api/vekn/country", {});
            this.countries = await res.json();
        }
        for (const country of this.countries){
            const option = document.createElement("option");
            option.value = country.country;
            option.label = country.country;
            this.country.options.add(option);
        }
    }
    show() {
        this.name.value = "";
        this.email.value = "";
        this.country.selectedIndex = 0;
        this.city.selectedIndex = 0;
        this.city.disabled = true;
        this.modal.show();
    }
    async change_country() {
        while(this.city.options.length > 1)this.city.options.remove(1);
        if (this.country.selectedIndex < 1) this.city.disabled = true;
        else {
            // TODO deactivate this or something for offline mode
            const res = await _base.do_fetch(`/api/vekn/country/${this.country.value}/city`, {});
            const cities = await res.json();
            for (const city of cities){
                const option = document.createElement("option");
                option.value = city.unique_name;
                option.label = city.unique_name;
                this.city.options.add(option);
            }
            this.city.disabled = false;
        }
    }
    async submit(ev) {
        ev.preventDefault();
        const member = {
            uid: (0, _uuid.v4)(),
            name: this.name.value,
            vekn: "",
            country: this.country.value,
            city: this.city.value,
            email: this.email.value
        };
        var person = await this.members_map.add_online(member);
        if (person) this.callback(person);
        this.modal.hide();
    }
}
class ExistingVeknModal extends _base.Modal {
    token;
    user_uid;
    target_uid;
    form;
    vekn_input;
    submit_button;
    callback;
    constructor(el, callback){
        super(el);
        this.callback = callback;
        this.form = _base.create_append(this.modal_body, "form");
        this.vekn_input = _base.create_append(this.form, "input", [
            "form-control",
            "mb-2"
        ], {
            type: "text",
            name: "new-vekn",
            placeholder: "VEKN# ID",
            autocomplete: "new-vekn"
        });
        this.vekn_input.spellcheck = false;
        this.vekn_input.ariaAutoComplete = "none";
        this.submit_button = _base.create_append(this.form, "button", [
            "btn",
            "btn-primary",
            "me-2",
            "mb-2"
        ], {
            type: "submit"
        });
        this.form.addEventListener("submit", (ev)=>this.submit(ev).then());
        this.modal_div.addEventListener("shown.bs.modal", ()=>{
            this.vekn_input.focus();
        });
    }
    async init(token, user_uid, target_uid) {
        if (token) this.token = token;
        else this.token = await _base.fetchToken();
        if (user_uid) this.user_uid = user_uid;
        else this.user_uid = _base.user_uid_from_token(token);
        if (target_uid) this.target_uid = target_uid;
        else this.target_uid = this.user_uid;
        if (this.target_uid == this.user_uid) {
            this.modal_title.innerText = "Claim VEKN ID";
            this.submit_button.innerText = "Claim";
        } else {
            this.modal_title.innerText = "Assign existing VEKN ID";
            this.submit_button.innerText = "Assign";
        }
    }
    async submit(ev) {
        ev.preventDefault();
        if (this.target_uid == this.user_uid) {
            // reload required, because we need to change the session's token
            const url = new URL("/vekn/claim", window.location.origin);
            url.searchParams.set("vekn", this.vekn_input.value);
            window.location.href = url.href;
        } else {
            const options = {
                method: "post",
                body: JSON.stringify({
                    vekn: this.vekn_input.value
                })
            };
            const res = await _base.do_fetch_with_token(`/api/vekn/members/${this.target_uid}/vekn`, this.token, options);
            this.callback(await res.json());
        }
        this.modal.hide();
    }
    show() {
        this.vekn_input.value = "";
        this.modal.show();
    }
}

},{"./d":"8rVEj","./base":"ikie8","idb":"kozAz","uuid":"a2QOC","unidecode":"gjsS5","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"kozAz":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "deleteDB", ()=>deleteDB);
parcelHelpers.export(exports, "openDB", ()=>openDB);
parcelHelpers.export(exports, "unwrap", ()=>unwrap);
parcelHelpers.export(exports, "wrap", ()=>wrap);
const instanceOfAny = (object, constructors)=>constructors.some((c)=>object instanceof c);
let idbProxyableTypes;
let cursorAdvanceMethods;
// This is a function to prevent it throwing up in node environments.
function getIdbProxyableTypes() {
    return idbProxyableTypes || (idbProxyableTypes = [
        IDBDatabase,
        IDBObjectStore,
        IDBIndex,
        IDBCursor,
        IDBTransaction
    ]);
}
// This is a function to prevent it throwing up in node environments.
function getCursorAdvanceMethods() {
    return cursorAdvanceMethods || (cursorAdvanceMethods = [
        IDBCursor.prototype.advance,
        IDBCursor.prototype.continue,
        IDBCursor.prototype.continuePrimaryKey
    ]);
}
const transactionDoneMap = new WeakMap();
const transformCache = new WeakMap();
const reverseTransformCache = new WeakMap();
function promisifyRequest(request) {
    const promise = new Promise((resolve, reject)=>{
        const unlisten = ()=>{
            request.removeEventListener('success', success);
            request.removeEventListener('error', error);
        };
        const success = ()=>{
            resolve(wrap(request.result));
            unlisten();
        };
        const error = ()=>{
            reject(request.error);
            unlisten();
        };
        request.addEventListener('success', success);
        request.addEventListener('error', error);
    });
    // This mapping exists in reverseTransformCache but doesn't exist in transformCache. This
    // is because we create many promises from a single IDBRequest.
    reverseTransformCache.set(promise, request);
    return promise;
}
function cacheDonePromiseForTransaction(tx) {
    // Early bail if we've already created a done promise for this transaction.
    if (transactionDoneMap.has(tx)) return;
    const done = new Promise((resolve, reject)=>{
        const unlisten = ()=>{
            tx.removeEventListener('complete', complete);
            tx.removeEventListener('error', error);
            tx.removeEventListener('abort', error);
        };
        const complete = ()=>{
            resolve();
            unlisten();
        };
        const error = ()=>{
            reject(tx.error || new DOMException('AbortError', 'AbortError'));
            unlisten();
        };
        tx.addEventListener('complete', complete);
        tx.addEventListener('error', error);
        tx.addEventListener('abort', error);
    });
    // Cache it for later retrieval.
    transactionDoneMap.set(tx, done);
}
let idbProxyTraps = {
    get (target, prop, receiver) {
        if (target instanceof IDBTransaction) {
            // Special handling for transaction.done.
            if (prop === 'done') return transactionDoneMap.get(target);
            // Make tx.store return the only store in the transaction, or undefined if there are many.
            if (prop === 'store') return receiver.objectStoreNames[1] ? undefined : receiver.objectStore(receiver.objectStoreNames[0]);
        }
        // Else transform whatever we get back.
        return wrap(target[prop]);
    },
    set (target, prop, value) {
        target[prop] = value;
        return true;
    },
    has (target, prop) {
        if (target instanceof IDBTransaction && (prop === 'done' || prop === 'store')) return true;
        return prop in target;
    }
};
function replaceTraps(callback) {
    idbProxyTraps = callback(idbProxyTraps);
}
function wrapFunction(func) {
    // Due to expected object equality (which is enforced by the caching in `wrap`), we
    // only create one new func per func.
    // Cursor methods are special, as the behaviour is a little more different to standard IDB. In
    // IDB, you advance the cursor and wait for a new 'success' on the IDBRequest that gave you the
    // cursor. It's kinda like a promise that can resolve with many values. That doesn't make sense
    // with real promises, so each advance methods returns a new promise for the cursor object, or
    // undefined if the end of the cursor has been reached.
    if (getCursorAdvanceMethods().includes(func)) return function(...args) {
        // Calling the original function with the proxy as 'this' causes ILLEGAL INVOCATION, so we use
        // the original object.
        func.apply(unwrap(this), args);
        return wrap(this.request);
    };
    return function(...args) {
        // Calling the original function with the proxy as 'this' causes ILLEGAL INVOCATION, so we use
        // the original object.
        return wrap(func.apply(unwrap(this), args));
    };
}
function transformCachableValue(value) {
    if (typeof value === 'function') return wrapFunction(value);
    // This doesn't return, it just creates a 'done' promise for the transaction,
    // which is later returned for transaction.done (see idbObjectHandler).
    if (value instanceof IDBTransaction) cacheDonePromiseForTransaction(value);
    if (instanceOfAny(value, getIdbProxyableTypes())) return new Proxy(value, idbProxyTraps);
    // Return the same value back if we're not going to transform it.
    return value;
}
function wrap(value) {
    // We sometimes generate multiple promises from a single IDBRequest (eg when cursoring), because
    // IDB is weird and a single IDBRequest can yield many responses, so these can't be cached.
    if (value instanceof IDBRequest) return promisifyRequest(value);
    // If we've already transformed this value before, reuse the transformed value.
    // This is faster, but it also provides object equality.
    if (transformCache.has(value)) return transformCache.get(value);
    const newValue = transformCachableValue(value);
    // Not all types are transformed.
    // These may be primitive types, so they can't be WeakMap keys.
    if (newValue !== value) {
        transformCache.set(value, newValue);
        reverseTransformCache.set(newValue, value);
    }
    return newValue;
}
const unwrap = (value)=>reverseTransformCache.get(value);
/**
 * Open a database.
 *
 * @param name Name of the database.
 * @param version Schema version.
 * @param callbacks Additional callbacks.
 */ function openDB(name, version, { blocked, upgrade, blocking, terminated } = {}) {
    const request = indexedDB.open(name, version);
    const openPromise = wrap(request);
    if (upgrade) request.addEventListener('upgradeneeded', (event)=>{
        upgrade(wrap(request.result), event.oldVersion, event.newVersion, wrap(request.transaction), event);
    });
    if (blocked) request.addEventListener('blocked', (event)=>blocked(// Casting due to https://github.com/microsoft/TypeScript-DOM-lib-generator/pull/1405
        event.oldVersion, event.newVersion, event));
    openPromise.then((db)=>{
        if (terminated) db.addEventListener('close', ()=>terminated());
        if (blocking) db.addEventListener('versionchange', (event)=>blocking(event.oldVersion, event.newVersion, event));
    }).catch(()=>{});
    return openPromise;
}
/**
 * Delete a database.
 *
 * @param name Name of the database.
 */ function deleteDB(name, { blocked } = {}) {
    const request = indexedDB.deleteDatabase(name);
    if (blocked) request.addEventListener('blocked', (event)=>blocked(// Casting due to https://github.com/microsoft/TypeScript-DOM-lib-generator/pull/1405
        event.oldVersion, event));
    return wrap(request).then(()=>undefined);
}
const readMethods = [
    'get',
    'getKey',
    'getAll',
    'getAllKeys',
    'count'
];
const writeMethods = [
    'put',
    'add',
    'delete',
    'clear'
];
const cachedMethods = new Map();
function getMethod(target, prop) {
    if (!(target instanceof IDBDatabase && !(prop in target) && typeof prop === 'string')) return;
    if (cachedMethods.get(prop)) return cachedMethods.get(prop);
    const targetFuncName = prop.replace(/FromIndex$/, '');
    const useIndex = prop !== targetFuncName;
    const isWrite = writeMethods.includes(targetFuncName);
    if (// Bail if the target doesn't exist on the target. Eg, getAll isn't in Edge.
    !(targetFuncName in (useIndex ? IDBIndex : IDBObjectStore).prototype) || !(isWrite || readMethods.includes(targetFuncName))) return;
    const method = async function(storeName, ...args) {
        // isWrite ? 'readwrite' : undefined gzipps better, but fails in Edge :(
        const tx = this.transaction(storeName, isWrite ? 'readwrite' : 'readonly');
        let target = tx.store;
        if (useIndex) target = target.index(args.shift());
        // Must reject if op rejects.
        // If it's a write operation, must reject if tx.done rejects.
        // Must reject with op rejection first.
        // Must resolve with op value.
        // Must handle both promises (no unhandled rejections)
        return (await Promise.all([
            target[targetFuncName](...args),
            isWrite && tx.done
        ]))[0];
    };
    cachedMethods.set(prop, method);
    return method;
}
replaceTraps((oldTraps)=>({
        ...oldTraps,
        get: (target, prop, receiver)=>getMethod(target, prop) || oldTraps.get(target, prop, receiver),
        has: (target, prop)=>!!getMethod(target, prop) || oldTraps.has(target, prop)
    }));
const advanceMethodProps = [
    'continue',
    'continuePrimaryKey',
    'advance'
];
const methodMap = {};
const advanceResults = new WeakMap();
const ittrProxiedCursorToOriginalProxy = new WeakMap();
const cursorIteratorTraps = {
    get (target, prop) {
        if (!advanceMethodProps.includes(prop)) return target[prop];
        let cachedFunc = methodMap[prop];
        if (!cachedFunc) cachedFunc = methodMap[prop] = function(...args) {
            advanceResults.set(this, ittrProxiedCursorToOriginalProxy.get(this)[prop](...args));
        };
        return cachedFunc;
    }
};
async function* iterate(...args) {
    // tslint:disable-next-line:no-this-assignment
    let cursor = this;
    if (!(cursor instanceof IDBCursor)) cursor = await cursor.openCursor(...args);
    if (!cursor) return;
    cursor;
    const proxiedCursor = new Proxy(cursor, cursorIteratorTraps);
    ittrProxiedCursorToOriginalProxy.set(proxiedCursor, cursor);
    // Map this double-proxy back to the original, so other cursor methods work.
    reverseTransformCache.set(proxiedCursor, unwrap(cursor));
    while(cursor){
        yield proxiedCursor;
        // If one of the advancing methods was not called, call continue().
        cursor = await (advanceResults.get(proxiedCursor) || cursor.continue());
        advanceResults.delete(proxiedCursor);
    }
}
function isIteratorProp(target, prop) {
    return prop === Symbol.asyncIterator && instanceOfAny(target, [
        IDBIndex,
        IDBObjectStore,
        IDBCursor
    ]) || prop === 'iterate' && instanceOfAny(target, [
        IDBIndex,
        IDBObjectStore
    ]);
}
replaceTraps((oldTraps)=>({
        ...oldTraps,
        get (target, prop, receiver) {
            if (isIteratorProp(target, prop)) return iterate;
            return oldTraps.get(target, prop, receiver);
        },
        has (target, prop) {
            return isIteratorProp(target, prop) || oldTraps.has(target, prop);
        }
    }));

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"gjsS5":[function(require,module,exports,__globalThis) {
/**
 * Unidecode takes UTF-8 data and tries to represent it in US-ASCII characters (i.e., the universally displayable characters between 0x00 and 0x7F).
 * The representation is almost always an attempt at transliteration -- i.e., conveying, in Roman letters, the pronunciation expressed by the text in
 * some other writing system.
 *
 * The tables used (in data) are converted from the tables provided in the perl library Text::Unidecode (http://search.cpan.org/dist/Text-Unidecode/lib/Text/Unidecode.pm)
 * and are distributed under the perl license
 *
 * @author Francois-Guillaume Ribreau
 *
 * Based on the port of unidecode for php
 */ 'use strict';
var tr = {};
var utf8_rx = /(?![\x00-\x7F]|[\xC0-\xDF][\x80-\xBF]|[\xE0-\xEF][\x80-\xBF]{2}|[\xF0-\xF7][\x80-\xBF]{3})./g;
module.exports = function(str, sub) {
    return str.replace(utf8_rx, function(match) {
        return unidecode_internal_replace(match, sub);
    });
};
function unidecode_internal_replace(match, sub) {
    // Default sub to empty string
    if (sub === null || sub === undefined) sub = '';
    var utf16 = utf8_to_utf16(match);
    if (utf16 > 0xFFFF) return sub;
    else {
        var h = utf16 >> 8;
        var l = utf16 & 0xFF;
        // (18) 18 > h < 1e (30)
        if (h > 24 && h < 30) return sub;
        //(d7) 215 > h < 249 (f9) no supported
        if (h > 215 && h < 249) return sub;
        if (!tr[h]) switch(dec2hex(h)){
            case '00':
                tr[h] = require("eb19aef5a8a736ad");
                break;
            case '01':
                tr[h] = require("fca5c7a0130ca931");
                break;
            case '02':
                tr[h] = require("d0dfdd59a5019a41");
                break;
            case '03':
                tr[h] = require("cf071b86c9c0bcc8");
                break;
            case '04':
                tr[h] = require("6257feb24379420d");
                break;
            case '05':
                tr[h] = require("6fa532d147e96a51");
                break;
            case '06':
                tr[h] = require("a0116ae4da2e71d4");
                break;
            case '07':
                tr[h] = require("7834355d394fa533");
                break;
            case '09':
                tr[h] = require("61d7fdc2220a484d");
                break;
            case '0a':
                tr[h] = require("7a19a273e644d2d7");
                break;
            case '0b':
                tr[h] = require("2052ea7f0074e9f");
                break;
            case '0c':
                tr[h] = require("ec4279f4a5bdb665");
                break;
            case '0d':
                tr[h] = require("33f5c48e902a38ab");
                break;
            case '0e':
                tr[h] = require("ed76868b63c58d0a");
                break;
            case '0f':
                tr[h] = require("1372361a7b296dea");
                break;
            case '10':
                tr[h] = require("873b723cd3b17951");
                break;
            case '11':
                tr[h] = require("78820dec21994a62");
                break;
            case '12':
                tr[h] = require("a19b818f90a58897");
                break;
            case '13':
                tr[h] = require("67358897f5a2a464");
                break;
            case '14':
                tr[h] = require("c2bb0ee9c9ecaf30");
                break;
            case '15':
                tr[h] = require("7f24cd2850ddef16");
                break;
            case '16':
                tr[h] = require("9357c929e31c0491");
                break;
            case '17':
                tr[h] = require("8aeeba8d4584b3cc");
                break;
            case '18':
                tr[h] = require("69643e2a9f12e581");
                break;
            case '19':
                tr[h] = require("ba5ab1ffefa8b19f");
                break;
            case '1a':
                tr[h] = require("298fc947d1b40541");
                break;
            case '1b':
                tr[h] = require("43f72b04dffab819");
                break;
            case '1c':
                tr[h] = require("5994f398e556c487");
                break;
            case '1d':
                tr[h] = require("7c6bd5f65544e832");
                break;
            case '1e':
                tr[h] = require("54a4dd3fc4f4a078");
                break;
            case '1f':
                tr[h] = require("bc568dda2c913630");
                break;
            case '20':
                tr[h] = require("cb762a6418086914");
                break;
            case '21':
                tr[h] = require("7164c06c9aba8675");
                break;
            case '22':
                tr[h] = require("aff7d8b4778869ee");
                break;
            case '23':
                tr[h] = require("f8f54fbc761400a6");
                break;
            case '24':
                tr[h] = require("ce9fbeaeabe34d3b");
                break;
            case '25':
                tr[h] = require("8064bceb1dd3fc58");
                break;
            case '26':
                tr[h] = require("d5c054164fa9bcb6");
                break;
            case '27':
                tr[h] = require("cafc119be91d33a0");
                break;
            case '28':
                tr[h] = require("7b1188ad1a50383f");
                break;
            case '2e':
                tr[h] = require("340e61c0cb10df34");
                break;
            case '2f':
                tr[h] = require("cdf60e86187f7ca1");
                break;
            case '30':
                tr[h] = require("229dda70cb9cdf22");
                break;
            case '31':
                tr[h] = require("2d6ed4d7e0e6e648");
                break;
            case '32':
                tr[h] = require("776c81bcf59a4aab");
                break;
            case '33':
                tr[h] = require("287c4f9551ab6b2c");
                break;
            case '4d':
                tr[h] = require("26f1544747528679");
                break;
            case '4e':
                tr[h] = require("2db3ed89a0cad04d");
                break;
            case '4f':
                tr[h] = require("6dee1a0986cc798d");
                break;
            case '50':
                tr[h] = require("cf7f9d08cf15dea8");
                break;
            case '51':
                tr[h] = require("c97c931958c760d4");
                break;
            case '52':
                tr[h] = require("c9af6c4be0657d56");
                break;
            case '53':
                tr[h] = require("c652c629a9ddcbc2");
                break;
            case '54':
                tr[h] = require("e05d0f92aabd94e2");
                break;
            case '55':
                tr[h] = require("9f604ebac8b57af");
                break;
            case '56':
                tr[h] = require("f6fda2cfc9dd99cb");
                break;
            case '57':
                tr[h] = require("a6d26dd45ed6c4c9");
                break;
            case '58':
                tr[h] = require("3add2610bcbfc84c");
                break;
            case '59':
                tr[h] = require("9986964e55ede182");
                break;
            case '5a':
                tr[h] = require("123b67ee78e6349d");
                break;
            case '5b':
                tr[h] = require("44d13fd381b581d2");
                break;
            case '5c':
                tr[h] = require("665278c48e98cc7e");
                break;
            case '5d':
                tr[h] = require("81c4d7261618fee2");
                break;
            case '5e':
                tr[h] = require("b6be6e9d7945e23b");
                break;
            case '5f':
                tr[h] = require("d17fc06b4ba41427");
                break;
            case '60':
                tr[h] = require("c0c4485dc1e7226");
                break;
            case '61':
                tr[h] = require("a00803dbe7c5779f");
                break;
            case '62':
                tr[h] = require("e6071366a31d2bc1");
                break;
            case '63':
                tr[h] = require("545b8135ce0504c3");
                break;
            case '64':
                tr[h] = require("4d936b874b7af474");
                break;
            case '65':
                tr[h] = require("fb38d48fe202e3ee");
                break;
            case '66':
                tr[h] = require("d84f3675b59714f8");
                break;
            case '67':
                tr[h] = require("2e259d18592fbf5");
                break;
            case '68':
                tr[h] = require("8dcbfd371a060de1");
                break;
            case '69':
                tr[h] = require("572b549fde22abc0");
                break;
            case '6a':
                tr[h] = require("e764d71a1b0adc16");
                break;
            case '6b':
                tr[h] = require("11aaabd159437ba5");
                break;
            case '6c':
                tr[h] = require("18d30abe29d6a58f");
                break;
            case '6d':
                tr[h] = require("1d3256317b4f8a7c");
                break;
            case '6e':
                tr[h] = require("1cedab75d0807011");
                break;
            case '6f':
                tr[h] = require("5010d67cc205f4bc");
                break;
            case '70':
                tr[h] = require("22c9304676b99d4c");
                break;
            case '71':
                tr[h] = require("2d740677be6a4e8");
                break;
            case '72':
                tr[h] = require("3b76d3d4358453be");
                break;
            case '73':
                tr[h] = require("b47ab2159b064304");
                break;
            case '74':
                tr[h] = require("ca882612380e498f");
                break;
            case '75':
                tr[h] = require("c346c1f8845c5c5c");
                break;
            case '76':
                tr[h] = require("76ffe048117225d7");
                break;
            case '77':
                tr[h] = require("3acb36c4504fcdfd");
                break;
            case '78':
                tr[h] = require("bc47e464fcdb9bdf");
                break;
            case '79':
                tr[h] = require("75a48e2fb144e1ea");
                break;
            case '7a':
                tr[h] = require("ef89a7bbe3235a27");
                break;
            case '7b':
                tr[h] = require("53236afbbaad1773");
                break;
            case '7c':
                tr[h] = require("9e3bdc1db41f3681");
                break;
            case '7d':
                tr[h] = require("32b86b6ec7544fa4");
                break;
            case '7e':
                tr[h] = require("c2449af40f0a2f9");
                break;
            case '7f':
                tr[h] = require("9e4a1acbf23d8190");
                break;
            case '80':
                tr[h] = require("684164f8c63e9d1d");
                break;
            case '81':
                tr[h] = require("5ec16ff196229ad2");
                break;
            case '82':
                tr[h] = require("2d1bee6ac08a1693");
                break;
            case '83':
                tr[h] = require("cccf730cc5a925f0");
                break;
            case '84':
                tr[h] = require("f07c1565d73be0ea");
                break;
            case '85':
                tr[h] = require("c737cd096827fca1");
                break;
            case '86':
                tr[h] = require("622d146517dbf5e7");
                break;
            case '87':
                tr[h] = require("aeb6a36cbef32bb4");
                break;
            case '88':
                tr[h] = require("ee772ae1a8249a47");
                break;
            case '89':
                tr[h] = require("72e57051eeb8e800");
                break;
            case '8a':
                tr[h] = require("c324ef3d6c37215f");
                break;
            case '8b':
                tr[h] = require("aa3160b962c5beeb");
                break;
            case '8c':
                tr[h] = require("15937cbd513e8313");
                break;
            case '8d':
                tr[h] = require("683cea4c6432eb7");
                break;
            case '8e':
                tr[h] = require("cd085697276396c");
                break;
            case '8f':
                tr[h] = require("7914bb34f4d2d32c");
                break;
            case '90':
                tr[h] = require("c1b5f2e62e607d8b");
                break;
            case '91':
                tr[h] = require("390439b85863411d");
                break;
            case '92':
                tr[h] = require("d942f81965f26f9f");
                break;
            case '93':
                tr[h] = require("b4dc3d06d3a67b54");
                break;
            case '94':
                tr[h] = require("e4c9d8f15e0debaa");
                break;
            case '95':
                tr[h] = require("e6872e84681e9cab");
                break;
            case '96':
                tr[h] = require("706fce8e47981c6f");
                break;
            case '97':
                tr[h] = require("a2cf8380b4db88c9");
                break;
            case '98':
                tr[h] = require("9047b18fe0772c7");
                break;
            case '99':
                tr[h] = require("99952f3cb52a0bd4");
                break;
            case '9a':
                tr[h] = require("5564c83403c458f1");
                break;
            case '9b':
                tr[h] = require("7690157990b1473f");
                break;
            case '9c':
                tr[h] = require("59bee7f15ba52041");
                break;
            case '9d':
                tr[h] = require("1e9500ef15d91518");
                break;
            case '9e':
                tr[h] = require("80023a214cddfa2c");
                break;
            case '9f':
                tr[h] = require("d430b8c933617872");
                break;
            case 'a0':
                tr[h] = require("6fb10abd2e6289cf");
                break;
            case 'a1':
                tr[h] = require("c65c9e9d10f2f3ef");
                break;
            case 'a2':
                tr[h] = require("579e3f6345d81373");
                break;
            case 'a3':
                tr[h] = require("fa2ee8b6cb917098");
                break;
            case 'a4':
                tr[h] = require("7db797ae8ee57355");
                break;
            case 'ac':
                tr[h] = require("a209e3ea7d1fa982");
                break;
            case 'ad':
                tr[h] = require("f6ecb576c47c13cb");
                break;
            case 'ae':
                tr[h] = require("3631eb159bad61d7");
                break;
            case 'af':
                tr[h] = require("6e4178687c0ba978");
                break;
            case 'b0':
                tr[h] = require("43d31b7fea860ca2");
                break;
            case 'b1':
                tr[h] = require("f3d6fa42aabb2e73");
                break;
            case 'b2':
                tr[h] = require("c80b9d921bd94c77");
                break;
            case 'b3':
                tr[h] = require("2754af58fbf77690");
                break;
            case 'b4':
                tr[h] = require("97a90d11e0f01fab");
                break;
            case 'b5':
                tr[h] = require("1767099032b7a859");
                break;
            case 'b6':
                tr[h] = require("fee79dd24f20ee4c");
                break;
            case 'b7':
                tr[h] = require("b14430cf93add81e");
                break;
            case 'b8':
                tr[h] = require("d4ddd42a97680918");
                break;
            case 'b9':
                tr[h] = require("e2f7a0e0a60ec36");
                break;
            case 'ba':
                tr[h] = require("70ab160475ea141e");
                break;
            case 'bb':
                tr[h] = require("f11890e4db6cf404");
                break;
            case 'bc':
                tr[h] = require("9609a217fef1dabc");
                break;
            case 'bd':
                tr[h] = require("24a2db40469cc749");
                break;
            case 'be':
                tr[h] = require("7571399a0f5a21f6");
                break;
            case 'bf':
                tr[h] = require("4badab89d590dc6e");
                break;
            case 'c0':
                tr[h] = require("ca6d834bf79fe390");
                break;
            case 'c1':
                tr[h] = require("aa1487494234e378");
                break;
            case 'c2':
                tr[h] = require("5928070e65c16f98");
                break;
            case 'c3':
                tr[h] = require("cc7d42fe2d7c9a1b");
                break;
            case 'c4':
                tr[h] = require("dd0944ac9a2ae30b");
                break;
            case 'c5':
                tr[h] = require("73322a122ebe968b");
                break;
            case 'c6':
                tr[h] = require("b5759aa9d747de5b");
                break;
            case 'c7':
                tr[h] = require("40308247ef3b3ba3");
                break;
            case 'c8':
                tr[h] = require("54ae97515077b43e");
                break;
            case 'c9':
                tr[h] = require("9652cf66cfe8adf2");
                break;
            case 'ca':
                tr[h] = require("1b4ac65d1d4e0e88");
                break;
            case 'cb':
                tr[h] = require("cd6cc63ef3fa5663");
                break;
            case 'cc':
                tr[h] = require("f7a84b74aa3ca5ec");
                break;
            case 'cd':
                tr[h] = require("62167d4654df0290");
                break;
            case 'ce':
                tr[h] = require("56a06d845914e571");
                break;
            case 'cf':
                tr[h] = require("8616e1f381bad0e7");
                break;
            case 'd0':
                tr[h] = require("4de4c22fec3f4f2b");
                break;
            case 'd1':
                tr[h] = require("f98b03b69d9e8431");
                break;
            case 'd2':
                tr[h] = require("42f4af399229c5ee");
                break;
            case 'd3':
                tr[h] = require("4d8eae2128abf76f");
                break;
            case 'd4':
                tr[h] = require("99e036b2d4da330");
                break;
            case 'd5':
                tr[h] = require("ce4a3168a4ac6e68");
                break;
            case 'd6':
                tr[h] = require("617f2218e7d43b94");
                break;
            case 'd7':
                tr[h] = require("466a9e4e9af03823");
                break;
            case 'f9':
                tr[h] = require("8c6cd327fd8dc7bb");
                break;
            case 'fa':
                tr[h] = require("4801e111812cde33");
                break;
            case 'fb':
                tr[h] = require("811a9fea4ee883d7");
                break;
            case 'fc':
                tr[h] = require("8483367b9f9933b3");
                break;
            case 'fd':
                tr[h] = require("a0e9e2ad86e79702");
                break;
            case 'fe':
                tr[h] = require("c79f623235308a50");
                break;
            case 'ff':
                tr[h] = require("73a041395a6ac773");
                break;
            default:
                // console.error("Unidecode file not found for h=", h);
                return sub;
        }
        if (tr[h][l]) return tr[h][l];
        else return sub;
    }
}
function dec2hex(i) {
    return (i + 0x100).toString(16).substr(-2);
}
function utf8_to_utf16(raw) {
    var b1, b2, b3, b4, x, y, z;
    while(Array.isArray(raw))raw = raw[0];
    switch(raw.length){
        case 1:
            return ord(raw);
        // http://en.wikipedia.org/wiki/UTF-8
        case 2:
            b1 = ord(raw.substr(0, 1));
            b2 = ord(raw.substr(1, 1));
            x = (b1 & 0x03) << 6 | b2 & 0x3F;
            y = (b1 & 0x1C) >> 2;
            return y << 8 | x;
        case 3:
            b1 = ord(raw.substr(0, 1));
            b2 = ord(raw.substr(1, 1));
            b3 = ord(raw.substr(2, 1));
            x = (b2 & 0x03) << 6 | b3 & 0x3F;
            y = (b1 & 0x0F) << 4 | (b2 & 0x3C) >> 2;
            return y << 8 | x;
        default:
            b1 = ord(raw.substr(0, 1));
            b2 = ord(raw.substr(1, 1));
            b3 = ord(raw.substr(2, 1));
            b4 = ord(raw.substr(3, 1));
            x = (b3 & 0x03) << 6 | b4 & 0x3F;
            y = (b2 & 0x0F) << 4 | (b3 & 0x3C) >> 2;
            z = (b1 & 0x07) << 5 | (b2 & 0x30) >> 4;
            return z << 16 | y << 8 | x;
    }
}
/* From php.js */ function ord(string) {
    // Returns the codepoint value of a character
    //
    // version: 1109.2015
    // discuss at: http://phpjs.org/functions/ord
    // +   original by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
    // +   bugfixed by: Onno Marsman
    // +   improved by: Brett Zamir (http://brett-zamir.me)
    // +   input by: incidence
    // *     example 1: ord('K');
    // *     returns 1: 75
    // *     example 2: ord('\uD800\uDC00'); // surrogate pair to create a single Unicode character
    // *     returns 2: 65536
    var str = string + '', code = str.charCodeAt(0);
    if (0xD800 <= code && code <= 0xDBFF) {
        var hi = code;
        if (str.length === 1) return code; // This is just a high surrogate with no following low surrogate, so we return its value;
        var low = str.charCodeAt(1);
        return (hi - 0xD800) * 0x400 + (low - 0xDC00) + 0x10000;
    }
    if (0xDC00 <= code && code <= 0xDFFF) return code; // This is just a low surrogate with no preceding high surrogate, so we return its value;
    return code;
}

},{"eb19aef5a8a736ad":"U3ukf","fca5c7a0130ca931":"hLNB0","d0dfdd59a5019a41":"6CGXw","cf071b86c9c0bcc8":"6QVR3","6257feb24379420d":"3yDz3","6fa532d147e96a51":"ifIRm","a0116ae4da2e71d4":"UsyR3","7834355d394fa533":"fO1EW","61d7fdc2220a484d":"cbsRY","7a19a273e644d2d7":"ltun8","2052ea7f0074e9f":"fL7Eq","ec4279f4a5bdb665":"ib8Mm","33f5c48e902a38ab":"3PzMV","ed76868b63c58d0a":"kYAjG","1372361a7b296dea":"eIZuB","873b723cd3b17951":"eqZAu","78820dec21994a62":"al7LD","a19b818f90a58897":"iyrYA","67358897f5a2a464":"muaNW","c2bb0ee9c9ecaf30":"dhQhJ","7f24cd2850ddef16":"9AZds","9357c929e31c0491":"kZ4ek","8aeeba8d4584b3cc":"br86K","69643e2a9f12e581":"4lKBn","ba5ab1ffefa8b19f":"5KFf3","298fc947d1b40541":"e4UUF","43f72b04dffab819":"8n3HL","5994f398e556c487":"eWBsg","7c6bd5f65544e832":"3YGvw","54a4dd3fc4f4a078":"cJlqR","bc568dda2c913630":"ij3jv","cb762a6418086914":"lCtrr","7164c06c9aba8675":"bDpzj","aff7d8b4778869ee":"f6pnH","f8f54fbc761400a6":"htFfJ","ce9fbeaeabe34d3b":"fdOTX","8064bceb1dd3fc58":"6ojvI","d5c054164fa9bcb6":"lCqGN","cafc119be91d33a0":"ixVsK","7b1188ad1a50383f":"eVRC8","340e61c0cb10df34":"awspy","cdf60e86187f7ca1":"7DXKE","229dda70cb9cdf22":"bE0Ph","2d6ed4d7e0e6e648":"01Iq8","776c81bcf59a4aab":"hj9XP","287c4f9551ab6b2c":"cQy6T","26f1544747528679":"hbylO","2db3ed89a0cad04d":"afUkn","6dee1a0986cc798d":"6hXSX","cf7f9d08cf15dea8":"iMCqY","c97c931958c760d4":"6FVQM","c9af6c4be0657d56":"1ViFw","c652c629a9ddcbc2":"4n55g","e05d0f92aabd94e2":"6tTi7","9f604ebac8b57af":"2rZIo","f6fda2cfc9dd99cb":"7jLq7","a6d26dd45ed6c4c9":"91Fbs","3add2610bcbfc84c":"hS9jd","9986964e55ede182":"jsWtu","123b67ee78e6349d":"e0Yzt","44d13fd381b581d2":"fCEl5","665278c48e98cc7e":"xkWup","81c4d7261618fee2":"ioIwY","b6be6e9d7945e23b":"hM2C3","d17fc06b4ba41427":"7bKkm","c0c4485dc1e7226":"60aC0","a00803dbe7c5779f":"lJVZb","e6071366a31d2bc1":"iyfaK","545b8135ce0504c3":"7SBaZ","4d936b874b7af474":"aPQEX","fb38d48fe202e3ee":"5K9I5","d84f3675b59714f8":"Rwls2","2e259d18592fbf5":"bezhW","8dcbfd371a060de1":"h3CUS","572b549fde22abc0":"ancCc","e764d71a1b0adc16":"baARH","11aaabd159437ba5":"5qSe9","18d30abe29d6a58f":"1h0Na","1d3256317b4f8a7c":"jK2LT","1cedab75d0807011":"jwwwq","5010d67cc205f4bc":"bKFl0","22c9304676b99d4c":"lf5mY","2d740677be6a4e8":"1kC3b","3b76d3d4358453be":"kXeHy","b47ab2159b064304":"8gHCc","ca882612380e498f":"6PUNT","c346c1f8845c5c5c":"8nNhZ","76ffe048117225d7":"6h7yr","3acb36c4504fcdfd":"c9gcj","bc47e464fcdb9bdf":"icPWK","75a48e2fb144e1ea":"94Kxb","ef89a7bbe3235a27":"3Tffl","53236afbbaad1773":"30zwm","9e3bdc1db41f3681":"9ScTc","32b86b6ec7544fa4":"oHKRD","c2449af40f0a2f9":"CfAp4","9e4a1acbf23d8190":"1dOun","684164f8c63e9d1d":"6VpqN","5ec16ff196229ad2":"8zZFx","2d1bee6ac08a1693":"6qmC9","cccf730cc5a925f0":"bDdix","f07c1565d73be0ea":"4cVP2","c737cd096827fca1":"k9RTY","622d146517dbf5e7":"kQ118","aeb6a36cbef32bb4":"hpvyz","ee772ae1a8249a47":"hwBdK","72e57051eeb8e800":"6ABk8","c324ef3d6c37215f":"aFGdV","aa3160b962c5beeb":"31OMH","15937cbd513e8313":"fqfUC","683cea4c6432eb7":"5xlbc","cd085697276396c":"evrv7","7914bb34f4d2d32c":"hpdQl","c1b5f2e62e607d8b":"YZ7y6","390439b85863411d":"fMu3g","d942f81965f26f9f":"lWyjj","b4dc3d06d3a67b54":"gNXHz","e4c9d8f15e0debaa":"he6RC","e6872e84681e9cab":"ldtmX","706fce8e47981c6f":"dBfqF","a2cf8380b4db88c9":"fSQ4W","9047b18fe0772c7":"2quN2","99952f3cb52a0bd4":"7bzlO","5564c83403c458f1":"aLPv2","7690157990b1473f":"kDhaC","59bee7f15ba52041":"l7Oxx","1e9500ef15d91518":"2Gf1t","80023a214cddfa2c":"ivYZQ","d430b8c933617872":"kW7Dj","6fb10abd2e6289cf":"lqoxc","c65c9e9d10f2f3ef":"4Fc4G","579e3f6345d81373":"auYF9","fa2ee8b6cb917098":"7NtEF","7db797ae8ee57355":"cRM5y","a209e3ea7d1fa982":"fz5Db","f6ecb576c47c13cb":"fZy3P","3631eb159bad61d7":"bgAFb","6e4178687c0ba978":"50dyF","43d31b7fea860ca2":"2HADJ","f3d6fa42aabb2e73":"4y3Id","c80b9d921bd94c77":"yiPge","2754af58fbf77690":"iFAdB","97a90d11e0f01fab":"c3Tpj","1767099032b7a859":"7Etd8","fee79dd24f20ee4c":"8dUzb","b14430cf93add81e":"3i1Ke","d4ddd42a97680918":"8d7nq","e2f7a0e0a60ec36":"iugBR","70ab160475ea141e":"a0grS","f11890e4db6cf404":"eGbnx","9609a217fef1dabc":"3pzbL","24a2db40469cc749":"9n03R","7571399a0f5a21f6":"f1grB","4badab89d590dc6e":"fdd2h","ca6d834bf79fe390":"js4IM","aa1487494234e378":"dun76","5928070e65c16f98":"7kVjE","cc7d42fe2d7c9a1b":"bLHI7","dd0944ac9a2ae30b":"9aE1x","73322a122ebe968b":"7pzXW","b5759aa9d747de5b":"b95vI","40308247ef3b3ba3":"LJSEa","54ae97515077b43e":"XytEM","9652cf66cfe8adf2":"4FKys","1b4ac65d1d4e0e88":"giIp0","cd6cc63ef3fa5663":"gN4OR","f7a84b74aa3ca5ec":"6cDvC","62167d4654df0290":"9fuxi","56a06d845914e571":"ctqoC","8616e1f381bad0e7":"aNYIL","4de4c22fec3f4f2b":"ewKNn","f98b03b69d9e8431":"gUVJK","42f4af399229c5ee":"kYr5R","4d8eae2128abf76f":"9nQiO","99e036b2d4da330":"aCyhY","ce4a3168a4ac6e68":"7iF1m","617f2218e7d43b94":"kzuEK","466a9e4e9af03823":"3QEib","8c6cd327fd8dc7bb":"7bjJ6","4801e111812cde33":"29Yyq","811a9fea4ee883d7":"g0cOw","8483367b9f9933b3":"5jNy7","a0e9e2ad86e79702":"akxgZ","c79f623235308a50":"emLzZ","73a041395a6ac773":"gXDZe"}],"U3ukf":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2015-10-15 07:49:48 MDT sburke@cpan.org"
module.exports = [
    //  BLOCK U+0000
    "\\x00",
    "\\x01",
    "\\x02",
    "\\x03",
    "\\x04",
    "\\x05",
    "\\x06",
    "\\x07",
    "\\x08",
    "\\x09",
    "\\x0a",
    "\\x0b",
    "\\x0c",
    "\\x0d",
    "\\x0e",
    "\\x0f",
    // ^00      ^01       ^02       ^03       ^04       ^05       ^06       ^07       ^08       ^09       ^0a       ^0b       ^0c       ^0d       ^0e       ^0f       
    "\\x10",
    "\\x11",
    "\\x12",
    "\\x13",
    "\\x14",
    "\\x15",
    "\\x16",
    "\\x17",
    "\\x18",
    "\\x19",
    "\\x1a",
    "\\x1b",
    "\\x1c",
    "\\x1d",
    "\\x1e",
    "\\x1f",
    // ^10      ^11       ^12       ^13       ^14       ^15       ^16       ^17       ^18       ^19       ^1a       ^1b       ^1c       ^1d       ^1e       ^1f       
    ' ',
    "!",
    "\"",
    "#",
    "\\$",
    "%",
    "&",
    "'",
    "(",
    ")",
    "*",
    "+",
    ",",
    "-",
    ".",
    "/",
    // ^20  ^21    ^22    ^23    ^24     ^25    ^26    ^27    ^28    ^29    ^2a    ^2b    ^2c ^2d  ^2e    ^2f    ^30    
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    ":",
    ";",
    "<",
    "=",
    ">",
    "?",
    // ^30  ^31  ^32  ^33  ^34  ^35  ^36  ^37  ^38  ^39  ^3a    ^3b    ^3c    ^3d    ^3e    ^3f    
    "\\@",
    'A',
    'B',
    'C',
    'D',
    'E',
    'F',
    'G',
    'H',
    'I',
    'J',
    'K',
    'L',
    'M',
    'N',
    'O',
    // ^40    ^41  ^42  ^43  ^44  ^45  ^46  ^47  ^48  ^49  ^4a  ^4b  ^4c  ^4d  ^4e  ^4f  
    'P',
    'Q',
    'R',
    'S',
    'T',
    'U',
    'V',
    'W',
    'X',
    'Y',
    'Z',
    "[",
    "\\\\",
    "]",
    "^",
    "_",
    // ^50  ^51  ^52  ^53  ^54  ^55  ^56  ^57  ^58  ^59  ^5a  ^5b    ^5c     ^5d    ^5e    ^5f    
    "`",
    'a',
    'b',
    'c',
    'd',
    'e',
    'f',
    'g',
    'h',
    'i',
    'j',
    'k',
    'l',
    'm',
    'n',
    'o',
    // ^60   ^61  ^62  ^63  ^64  ^65  ^66  ^67  ^68  ^69  ^6a  ^6b  ^6c  ^6d  ^6e  ^6f  
    'p',
    'q',
    'r',
    's',
    't',
    'u',
    'v',
    'w',
    'x',
    'y',
    'z',
    "\\{",
    "|",
    "\\}",
    "~",
    "\\x7f",
    // ^70  ^71  ^72  ^73  ^74  ^75  ^76  ^77  ^78  ^79  ^7a  ^7b     ^7c    ^7d     ^7e    ^7f       
    // ======================================================================
    //  Strictly speaking, these are the Unicode values:
    //  "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "",
    //  ^80 ^81 ^82 ^83 ^84 ^85 ^86 ^87 ^88 ^89 ^8a ^8b ^8c ^8d ^8e ^8f  
    //  "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "",
    //  ^90 ^91 ^92 ^93 ^94 ^95 ^96 ^97 ^98 ^99 ^9a ^9b ^9c ^9d ^9e ^9f  
    // 
    //  But I've decided to tolerate Win-1252 input:
    "EUR",
    '',
    ",",
    "f",
    ",,",
    "...",
    "+",
    "++",
    "^",
    "%0",
    "S",
    "<",
    "OE",
    '',
    "Z",
    '',
    '',
    "'",
    "'",
    "\"",
    "\"",
    "*",
    "-",
    "--",
    "~",
    "tm",
    "s",
    ">",
    "oe",
    '',
    "z",
    "Y",
    //  See: https://en.wikipedia.org/wiki/Latin-1_Supplement_%28Unicode_block%29
    // ======================================================================
    //  And now, back to Latin-1 = Unicode values...
    ' ',
    "!",
    "C/",
    'PS',
    "\\$?",
    "Y=",
    "|",
    'SS',
    "\"",
    "(c)",
    'a',
    "<<",
    "!",
    "",
    "(r)",
    "-",
    // ^a0  ^a1    ^a2     ^a3   ^a4      ^a5     ^a6    ^a7   ^a8    ^a9      ^aa  ^ab     ^ac   ^ad  ^ae      ^af    
    'deg',
    "+-",
    '2',
    '3',
    "'",
    'u',
    'P',
    "*",
    ",",
    '1',
    'o',
    ">>",
    "1/4",
    "1/2",
    "3/4",
    "?",
    // ^b0   ^b1     ^b2  ^b3  ^b4    ^b5  ^b6  ^b7    ^b8 ^b9  ^ba  ^bb  ^bc     ^bd      ^be      ^bf      ^c0    
    'A',
    'A',
    'A',
    'A',
    'A',
    'A',
    'AE',
    'C',
    'E',
    'E',
    'E',
    'E',
    'I',
    'I',
    'I',
    'I',
    // ^c0  ^c1  ^c2  ^c3  ^c4  ^c5  ^c6   ^c7  ^c8  ^c9  ^ca  ^cb  ^cc  ^cd  ^ce  ^cf  
    'D',
    'N',
    'O',
    'O',
    'O',
    'O',
    'O',
    'x',
    'O',
    'U',
    'U',
    'U',
    'U',
    'Y',
    'Th',
    'ss',
    // ^d0  ^d1  ^d2  ^d3  ^d4  ^d5  ^d6  ^d7  ^d8  ^d9  ^da  ^db  ^dc  ^dd  ^de   ^df   
    'a',
    'a',
    'a',
    'a',
    'a',
    'a',
    'ae',
    'c',
    'e',
    'e',
    'e',
    'e',
    'i',
    'i',
    'i',
    'i',
    // ^e0  ^e1  ^e2  ^e3  ^e4  ^e5  ^e6   ^e7  ^e8  ^e9  ^ea  ^eb  ^ec  ^ed  ^ee  ^ef  
    'd',
    'n',
    'o',
    'o',
    'o',
    'o',
    'o',
    "/",
    'o',
    'u',
    'u',
    'u',
    'u',
    'y',
    'th',
    'y'
];

},{}],"hLNB0":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2014-07-09 03:12:21 MDT sburke@cpan.org"
module.exports = [
    'A',
    'a',
    'A',
    'a',
    'A',
    'a',
    'C',
    'c',
    'C',
    'c',
    'C',
    'c',
    'C',
    'c',
    'D',
    'd',
    'D',
    'd',
    'E',
    'e',
    'E',
    'e',
    'E',
    'e',
    'E',
    'e',
    'E',
    'e',
    'G',
    'g',
    'G',
    'g',
    'G',
    'g',
    'G',
    'g',
    'H',
    'h',
    'H',
    'h',
    'I',
    'i',
    'I',
    'i',
    'I',
    'i',
    'I',
    'i',
    'I',
    'i',
    'IJ',
    'ij',
    'J',
    'j',
    'K',
    'k',
    'k',
    'L',
    'l',
    'L',
    'l',
    'L',
    'l',
    'L',
    'l',
    'L',
    'l',
    'N',
    'n',
    'N',
    'n',
    'N',
    'n',
    "'n",
    'ng',
    'NG',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'OE',
    'oe',
    'R',
    'r',
    'R',
    'r',
    'R',
    'r',
    'S',
    's',
    'S',
    's',
    'S',
    's',
    'S',
    's',
    'T',
    't',
    'T',
    't',
    'T',
    't',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'W',
    'w',
    'Y',
    'y',
    'Y',
    'Z',
    'z',
    'Z',
    'z',
    'Z',
    'z',
    's',
    'b',
    'B',
    'B',
    'b',
    '6',
    '6',
    'O',
    'C',
    'c',
    'D',
    'D',
    'D',
    'd',
    'd',
    '3',
    "\\@",
    'E',
    'F',
    'f',
    'G',
    'G',
    'hv',
    'I',
    'I',
    'K',
    'k',
    'l',
    'l',
    'W',
    'N',
    'n',
    'O',
    'O',
    'o',
    'OI',
    'oi',
    'P',
    'p',
    'YR',
    '2',
    '2',
    'SH',
    'sh',
    't',
    'T',
    't',
    'T',
    'U',
    'u',
    'Y',
    'V',
    'Y',
    'y',
    'Z',
    'z',
    'ZH',
    'ZH',
    'zh',
    'zh',
    '2',
    '5',
    '5',
    'ts',
    'w',
    "|",
    "||",
    "|=",
    "!",
    'DZ',
    'Dz',
    'dz',
    'LJ',
    'Lj',
    'lj',
    'NJ',
    'Nj',
    'nj',
    'A',
    'a',
    'I',
    'i',
    'O',
    'o',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    "\\@",
    'A',
    'a',
    'A',
    'a',
    'AE',
    'ae',
    'G',
    'g',
    'G',
    'g',
    'K',
    'k',
    'O',
    'o',
    'O',
    'o',
    'ZH',
    'zh',
    'j',
    'DZ',
    'Dz',
    'dz',
    'G',
    'g',
    'HV',
    'W',
    'N',
    'n',
    'A',
    'a',
    'AE',
    'ae',
    'O',
    'o'
];

},{}],"6CGXw":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:13:16 MDT"
module.exports = [
    'A',
    'a',
    'A',
    'a',
    'E',
    'e',
    'E',
    'e',
    'I',
    'i',
    'I',
    'i',
    'O',
    'o',
    'O',
    'o',
    'R',
    'r',
    'R',
    'r',
    'U',
    'u',
    'U',
    'u',
    'S',
    's',
    'T',
    't',
    'Y',
    'y',
    'H',
    'h',
    'N',
    'd',
    'OU',
    'ou',
    'Z',
    'z',
    'A',
    'a',
    'E',
    'e',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'Y',
    'y',
    'l',
    'n',
    't',
    'j',
    'db',
    'qp',
    'A',
    'C',
    'c',
    'L',
    'T',
    's',
    'z',
    '[?]',
    '[?]',
    'B',
    'U',
    '^',
    'E',
    'e',
    'J',
    'j',
    'q',
    'q',
    'R',
    'r',
    'Y',
    'y',
    'a',
    'a',
    'a',
    'b',
    'o',
    'c',
    'd',
    'd',
    'e',
    "\\@",
    "\\@",
    'e',
    'e',
    'e',
    'e',
    'j',
    'g',
    'g',
    'g',
    'g',
    'u',
    'Y',
    'h',
    'h',
    'i',
    'i',
    'I',
    'l',
    'l',
    'l',
    'lZ',
    'W',
    'W',
    'm',
    'n',
    'n',
    'n',
    'o',
    'OE',
    'O',
    'F',
    'r',
    'r',
    'r',
    'r',
    'r',
    'r',
    'r',
    'R',
    'R',
    's',
    'S',
    'j',
    'S',
    'S',
    't',
    't',
    'u',
    'U',
    'v',
    "^",
    'w',
    'y',
    'Y',
    'z',
    'z',
    'Z',
    'Z',
    "?",
    "?",
    "?",
    'C',
    "\\@",
    'B',
    'E',
    'G',
    'H',
    'j',
    'k',
    'L',
    'q',
    "?",
    "?",
    'dz',
    'dZ',
    'dz',
    'ts',
    'tS',
    'tC',
    'fN',
    'ls',
    'lz',
    'WW',
    "]]",
    'h',
    'h',
    'h',
    'h',
    'j',
    'r',
    'r',
    'r',
    'r',
    'w',
    'y',
    "'",
    "\"",
    "`",
    "'",
    "`",
    "`",
    "'",
    "?",
    "?",
    "<",
    ">",
    "^",
    'V',
    "^",
    'V',
    "'",
    "-",
    "/",
    "\\\\",
    ",",
    "_",
    "\\\\",
    "/",
    ":",
    ".",
    "`",
    "'",
    "^",
    'V',
    "+",
    "-",
    'V',
    ".",
    "\\@",
    ",",
    "~",
    "\"",
    'R',
    'X',
    'G',
    'l',
    's',
    'x',
    "?",
    //  U+2e5 ...
    //  ˥   ˦    ˧    ˨     ˩   ˪    ˫
    "5",
    "4",
    "3",
    "2",
    "1",
    "/",
    "\\",
    'V',
    "=",
    "\"",
    'V',
    //  ...and also 16 UPA modifiers:
    //  ˰ ˱ ˲ ˳ ˴ ˵ ˶ ˷ ˸ ˹ ˺ ˻ ˼ ˽ ˾ ˿
    "^",
    "<",
    ">",
    "o",
    "`",
    "``",
    "//",
    "~",
    ":",
    "[-",
    "-]",
    "[_",
    "_]",
    "_",
    "_",
    "<"
];

},{}],"6QVR3":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:21:04 MDT"
module.exports = [
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    // '[?]', '[?]', '[?]', '[?]', '[?]', '[?]', '[?]', '[?]', '[?]', '[?]', '[?]', '[?]', '[?]',
    'a',
    'e',
    'i',
    'o',
    'u',
    'c',
    'd',
    'h',
    'm',
    'r',
    't',
    'v',
    'x',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "'",
    ",",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    '[?]',
    '[?]',
    '[?]',
    "?",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    'A',
    ";",
    'E',
    'E',
    'I',
    '[?]',
    'O',
    '[?]',
    'U',
    'O',
    'I',
    'A',
    'B',
    'G',
    'D',
    'E',
    'Z',
    'E',
    'Th',
    'I',
    'K',
    'L',
    'M',
    'N',
    'Ks',
    'O',
    'P',
    'R',
    '[?]',
    'S',
    'T',
    'U',
    'Ph',
    'Kh',
    'Ps',
    'O',
    'I',
    'U',
    'a',
    'e',
    'e',
    'i',
    'u',
    'a',
    'b',
    'g',
    'd',
    'e',
    'z',
    'e',
    'th',
    'i',
    'k',
    'l',
    'm',
    'n',
    'x',
    'o',
    'p',
    'r',
    's',
    's',
    't',
    'u',
    'ph',
    'kh',
    'ps',
    'o',
    'i',
    'u',
    'o',
    'u',
    'o',
    '[?]',
    'b',
    'th',
    'U',
    'U',
    'U',
    'ph',
    'p',
    "&",
    '[?]',
    '[?]',
    'St',
    'st',
    'W',
    'w',
    'Q',
    'q',
    'Sp',
    'sp',
    'Sh',
    'sh',
    'F',
    'f',
    'Kh',
    'kh',
    'H',
    'h',
    'G',
    'g',
    'CH',
    'ch',
    'Ti',
    'ti',
    // 03F0:
    //  ϰ ϱ ϲ ϳ  
    'k',
    'r',
    'c',
    'j',
    //  ϴ ϵ ϶ Ϸ 
    'TH',
    'e',
    'e',
    'Sh',
    //  ϸ Ϲ Ϻ ϻ
    'sh',
    's',
    '[?]',
    '[?]',
    //  ϼ Ͻ Ͼ Ͽ
    'r/',
    'S',
    'S.',
    'S.'
];

},{}],"3yDz3":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:24:41 MDT"
module.exports = [
    'Ie',
    'Io',
    'Dj',
    'Gj',
    'E',
    'Dz',
    'I',
    'Yi',
    'J',
    'Lj',
    'Nj',
    'Tsh',
    'Kj',
    'I',
    'U',
    'Dzh',
    'A',
    'B',
    'V',
    'G',
    'D',
    'E',
    'Zh',
    'Z',
    'I',
    'I',
    'K',
    'L',
    'M',
    'N',
    'O',
    'P',
    'R',
    'S',
    'T',
    'U',
    'F',
    'Kh',
    'Ts',
    'Ch',
    'Sh',
    'Shch',
    "",
    'Y',
    "'",
    'E',
    'Iu',
    'Ia',
    'a',
    'b',
    'v',
    'g',
    'd',
    'e',
    'zh',
    'z',
    'i',
    'i',
    'k',
    'l',
    'm',
    'n',
    'o',
    'p',
    'r',
    's',
    't',
    'u',
    'f',
    'kh',
    'ts',
    'ch',
    'sh',
    'shch',
    "",
    'y',
    "'",
    'e',
    'iu',
    'ia',
    'ie',
    'io',
    'dj',
    'gj',
    'ie',
    'dz',
    'i',
    'yi',
    'j',
    'lj',
    'nj',
    'tsh',
    'kj',
    'i',
    'u',
    'dzh',
    'O',
    'o',
    'E',
    'e',
    'Ie',
    'ie',
    'E',
    'e',
    'Ie',
    'ie',
    'O',
    'o',
    'Io',
    'io',
    'Ks',
    'ks',
    'Ps',
    'ps',
    'F',
    'f',
    'Y',
    'y',
    'Y',
    'y',
    'u',
    'u',
    'O',
    'o',
    'O',
    'o',
    'Ot',
    'ot',
    'Q',
    'q',
    "*1000*",
    "",
    "",
    "",
    "",
    '[?]',
    "*100.000*",
    "*1.000.000*",
    '[?]',
    '[?]',
    "\"",
    "\"",
    "R'",
    "r'",
    "G'",
    "g'",
    "G'",
    "g'",
    "G'",
    "g'",
    "Zh'",
    "zh'",
    "Z'",
    "z'",
    "K'",
    "k'",
    "K'",
    "k'",
    "K'",
    "k'",
    "K'",
    "k'",
    "N'",
    "n'",
    'Ng',
    'ng',
    "P'",
    "p'",
    'Kh',
    'kh',
    "S'",
    "s'",
    "T'",
    "t'",
    'U',
    'u',
    "U'",
    "u'",
    "Kh'",
    "kh'",
    'Tts',
    'tts',
    "Ch'",
    "ch'",
    "Ch'",
    "ch'",
    'H',
    'h',
    'Ch',
    'ch',
    "Ch'",
    "ch'",
    "`",
    'Zh',
    'zh',
    "K'",
    "k'",
    '[?]',
    '[?]',
    "N'",
    "n'",
    '[?]',
    '[?]',
    'Ch',
    'ch',
    '[?]',
    '[?]',
    '[?]',
    'a',
    'a',
    'A',
    'a',
    'Ae',
    'ae',
    'Ie',
    'ie',
    "\\@",
    "\\@",
    "\\@",
    "\\@",
    'Zh',
    'zh',
    'Z',
    'z',
    'Dz',
    'dz',
    'I',
    'i',
    'I',
    'i',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'E',
    'e',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'Ch',
    'ch',
    '[?]',
    '[?]',
    'Y',
    'y',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"ifIRm":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:23:07 MDT"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'A',
    'B',
    'G',
    'D',
    'E',
    'Z',
    'E',
    'E',
    "T`",
    'Zh',
    'I',
    'L',
    'Kh',
    'Ts',
    'K',
    'H',
    'Dz',
    'Gh',
    'Ch',
    'M',
    'Y',
    'N',
    'Sh',
    'O',
    "Ch`",
    'P',
    'J',
    'Rh',
    'S',
    'V',
    'T',
    'R',
    "Ts`",
    'W',
    "P`",
    "K`",
    'O',
    'F',
    '[?]',
    '[?]',
    "<",
    "'",
    "/",
    "!",
    ",",
    "?",
    ".",
    '[?]',
    'a',
    'b',
    'g',
    'd',
    'e',
    'z',
    'e',
    'e',
    "t`",
    'zh',
    'i',
    'l',
    'kh',
    'ts',
    'k',
    'h',
    'dz',
    'gh',
    'ch',
    'm',
    'y',
    'n',
    'sh',
    'o',
    "ch`",
    'p',
    'j',
    'rh',
    's',
    'v',
    't',
    'r',
    "ts`",
    'w',
    "p`",
    "k`",
    'o',
    'f',
    'ew',
    '[?]',
    ".",
    "-",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "\\@",
    'e',
    'a',
    'o',
    'i',
    'e',
    'e',
    'a',
    'a',
    'o',
    '[?]',
    'u',
    "'",
    "",
    "",
    "",
    //  u+05c0:
    "|",
    "",
    "",
    ":",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    'b',
    'g',
    'd',
    'h',
    'v',
    'z',
    'kh',
    't',
    'y',
    'k',
    'k',
    'l',
    'm',
    'm',
    'n',
    'n',
    's',
    "`",
    'p',
    'p',
    'ts',
    'ts',
    'q',
    'r',
    'sh',
    't',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'V',
    'oy',
    'i',
    "'",
    "\"",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"UsyR3":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:26:30 MDT"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    ",",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    ";",
    '[?]',
    '[?]',
    '[?]',
    "?",
    '[?]',
    "",
    'a',
    "'",
    "w'",
    "",
    "y'",
    "",
    'b',
    "\\@",
    't',
    'th',
    'j',
    'H',
    'kh',
    'd',
    'dh',
    'r',
    'z',
    's',
    'sh',
    'S',
    'D',
    'T',
    'Z',
    "`",
    'G',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    'f',
    'q',
    'k',
    'l',
    'm',
    'n',
    'h',
    'w',
    "~",
    'y',
    'an',
    'un',
    'in',
    'a',
    'u',
    'i',
    'W',
    "",
    "",
    "'",
    "'",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    "%",
    ".",
    ",",
    "*",
    '[?]',
    '[?]',
    "",
    "'",
    "'",
    "'",
    "",
    "'",
    "'w",
    "'u",
    "'y",
    'tt',
    'tth',
    'b',
    't',
    'T',
    'p',
    'th',
    'bh',
    "'h",
    'H',
    'ny',
    'dy',
    'H',
    'ch',
    'cch',
    'dd',
    'D',
    'D',
    'Dt',
    'dh',
    'ddh',
    'd',
    'D',
    'D',
    'rr',
    'R',
    'R',
    'R',
    'R',
    'R',
    'R',
    'j',
    'R',
    'S',
    'S',
    'S',
    'S',
    'S',
    'T',
    'GH',
    'F',
    'F',
    'F',
    'v',
    'f',
    'ph',
    'Q',
    'Q',
    'kh',
    'k',
    'K',
    'K',
    'ng',
    'K',
    'g',
    'G',
    'N',
    'G',
    'G',
    'G',
    'L',
    'L',
    'L',
    'L',
    'N',
    'N',
    'N',
    'N',
    'N',
    'h',
    'Ch',
    'hy',
    'h',
    'H',
    "\\@",
    'W',
    'oe',
    'oe',
    'u',
    'yu',
    'yu',
    'W',
    'v',
    'y',
    'Y',
    'Y',
    'W',
    "",
    "",
    'y',
    "y'",
    ".",
    'ae',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "\\@",
    "#",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "^",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    'Sh',
    'D',
    'Gh',
    "&",
    "+m",
    "h"
];

},{}],"fO1EW":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:27:18 MDT"
module.exports = [
    "//",
    "/",
    ",",
    "!",
    "!",
    "-",
    ",",
    ",",
    ";",
    "?",
    "~",
    "\\{",
    "\\}",
    "*",
    '[?]',
    "",
    "'",
    "",
    'b',
    'g',
    'g',
    'd',
    'd',
    'h',
    'w',
    'z',
    'H',
    't',
    't',
    'y',
    'yh',
    'k',
    'l',
    'm',
    'n',
    's',
    's',
    "`",
    'p',
    'p',
    'S',
    'q',
    'r',
    'sh',
    't',
    '[?]',
    '[?]',
    '[?]',
    'a',
    'a',
    'a',
    'A',
    'A',
    'A',
    'e',
    'e',
    'e',
    'E',
    'i',
    'i',
    'u',
    'u',
    'u',
    'o',
    "",
    "`",
    "'",
    "",
    "",
    'X',
    'Q',
    "\\@",
    "\\@",
    "|",
    "+",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'h',
    'sh',
    'n',
    'r',
    'b',
    'L',
    'k',
    "'",
    'v',
    'm',
    'f',
    'dh',
    'th',
    'l',
    'g',
    'ny',
    's',
    'd',
    'z',
    't',
    'y',
    'p',
    'j',
    'ch',
    'tt',
    'hh',
    'kh',
    'th',
    'z',
    'sh',
    's',
    'd',
    't',
    'z',
    "`",
    'gh',
    'q',
    'w',
    'a',
    'aa',
    'i',
    'ee',
    'u',
    'oo',
    'e',
    'ey',
    'o',
    'oa',
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"cbsRY":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:29:33 MDT"
module.exports = [
    '[?]',
    'N',
    'N',
    'H',
    '[?]',
    'a',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'L',
    'eN',
    'e',
    'e',
    'ai',
    'oN',
    'o',
    'o',
    'au',
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'c',
    'ch',
    'j',
    'jh',
    'ny',
    'tt',
    'tth',
    'dd',
    'ddh',
    'nn',
    't',
    'th',
    'd',
    'dh',
    'n',
    'nnn',
    'p',
    'ph',
    'b',
    'bh',
    'm',
    'y',
    'r',
    'rr',
    'l',
    'l',
    'lll',
    'v',
    'sh',
    'ss',
    's',
    'h',
    '[?]',
    '[?]',
    "'",
    "'",
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'RR',
    'eN',
    'e',
    'e',
    'ai',
    'oN',
    'o',
    'o',
    'au',
    "",
    '[?]',
    '[?]',
    'AUM',
    "'",
    "'",
    "`",
    "'",
    '[?]',
    '[?]',
    '[?]',
    'q',
    'khh',
    'ghh',
    'z',
    'dddh',
    'rh',
    'f',
    'yy',
    'RR',
    'LL',
    'L',
    'LL',
    " / ",
    " // ",
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    ".",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'N',
    'N',
    'H',
    '[?]',
    'a',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'RR',
    '[?]',
    '[?]',
    'e',
    'ai',
    '[?]',
    '[?]',
    'o',
    'au',
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'c',
    'ch',
    'j',
    'jh',
    'ny',
    'tt',
    'tth',
    'dd',
    'ddh',
    'nn',
    't',
    'th',
    'd',
    'dh',
    'n',
    '[?]',
    'p',
    'ph',
    'b',
    'bh',
    'm',
    'y',
    'r',
    '[?]',
    'l',
    '[?]',
    '[?]',
    '[?]',
    'sh',
    'ss',
    's',
    'h',
    '[?]',
    '[?]',
    "'",
    '[?]',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'RR',
    '[?]',
    '[?]',
    'e',
    'ai',
    '[?]',
    '[?]',
    'o',
    'au',
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "+",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'rr',
    'rh',
    '[?]',
    'yy',
    'RR',
    'LL',
    'L',
    'LL',
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    "r'",
    "r`",
    'Rs',
    'Rs',
    "1/",
    "2/",
    "3/",
    "4/",
    " 1 - 1/",
    "/16",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"ltun8":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:34:57 MDT"
module.exports = [
    '[?]',
    '[?]',
    'N',
    '[?]',
    '[?]',
    'a',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'ee',
    'ai',
    '[?]',
    '[?]',
    'oo',
    'au',
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'c',
    'ch',
    'j',
    'jh',
    'ny',
    'tt',
    'tth',
    'dd',
    'ddh',
    'nn',
    't',
    'th',
    'd',
    'dh',
    'n',
    '[?]',
    'p',
    'ph',
    'b',
    'bb',
    'm',
    'y',
    'r',
    '[?]',
    'l',
    'll',
    '[?]',
    'v',
    'sh',
    '[?]',
    's',
    'h',
    '[?]',
    '[?]',
    "'",
    '[?]',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'ee',
    'ai',
    '[?]',
    '[?]',
    'oo',
    'au',
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'khh',
    'ghh',
    'z',
    'rr',
    '[?]',
    'f',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    'N',
    'H',
    "",
    "",
    "G.E.O.",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'N',
    'N',
    'H',
    '[?]',
    'a',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    '[?]',
    'eN',
    '[?]',
    'e',
    'ai',
    'oN',
    '[?]',
    'o',
    'au',
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'c',
    'ch',
    'j',
    'jh',
    'ny',
    'tt',
    'tth',
    'dd',
    'ddh',
    'nn',
    't',
    'th',
    'd',
    'dh',
    'n',
    '[?]',
    'p',
    'ph',
    'b',
    'bh',
    'm',
    'ya',
    'r',
    '[?]',
    'l',
    'll',
    '[?]',
    'v',
    'sh',
    'ss',
    's',
    'h',
    '[?]',
    '[?]',
    "'",
    "'",
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'RR',
    'eN',
    '[?]',
    'e',
    'ai',
    'oN',
    '[?]',
    'o',
    'au',
    "",
    '[?]',
    '[?]',
    'AUM',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'RR',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    '.',
    'R',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'zh',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"fL7Eq":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:38:25 MDT"
module.exports = [
    '[?]',
    'N',
    'N',
    'H',
    '[?]',
    'a',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'L',
    '[?]',
    '[?]',
    'e',
    'ai',
    '[?]',
    '[?]',
    'o',
    'au',
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'c',
    'ch',
    'j',
    'jh',
    'ny',
    'tt',
    'tth',
    'dd',
    'ddh',
    'nn',
    't',
    'th',
    'd',
    'dh',
    'n',
    '[?]',
    'p',
    'ph',
    'b',
    'bh',
    'm',
    'y',
    'r',
    '[?]',
    'l',
    'll',
    '[?]',
    "",
    'sh',
    'ss',
    's',
    'h',
    '[?]',
    '[?]',
    "'",
    "'",
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    '[?]',
    '[?]',
    '[?]',
    'e',
    'ai',
    '[?]',
    '[?]',
    'o',
    'au',
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "+",
    "+",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'rr',
    'rh',
    '[?]',
    'yy',
    'RR',
    'LL',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'N',
    'H',
    '[?]',
    'a',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    '[?]',
    '[?]',
    '[?]',
    'e',
    'ee',
    'ai',
    '[?]',
    'o',
    'oo',
    'au',
    'k',
    '[?]',
    '[?]',
    '[?]',
    'ng',
    'c',
    '[?]',
    'j',
    '[?]',
    'ny',
    'tt',
    '[?]',
    '[?]',
    '[?]',
    'nn',
    't',
    '[?]',
    '[?]',
    '[?]',
    'n',
    'nnn',
    'p',
    '[?]',
    '[?]',
    '[?]',
    'm',
    'y',
    'r',
    'rr',
    'l',
    'll',
    'lll',
    'v',
    '[?]',
    'ss',
    's',
    'h',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    '[?]',
    '[?]',
    '[?]',
    'e',
    'ee',
    'ai',
    '[?]',
    'o',
    'oo',
    'au',
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "+",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    "+10+",
    "+100+",
    "+1000+",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"ib8Mm":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:39:01 MDT"
module.exports = [
    '[?]',
    'N',
    'N',
    'H',
    '[?]',
    'a',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'L',
    '[?]',
    'e',
    'ee',
    'ai',
    '[?]',
    'o',
    'oo',
    'au',
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'c',
    'ch',
    'j',
    'jh',
    'ny',
    'tt',
    'tth',
    'dd',
    'ddh',
    'nn',
    't',
    'th',
    'd',
    'dh',
    'n',
    '[?]',
    'p',
    'ph',
    'b',
    'bh',
    'm',
    'y',
    'r',
    'rr',
    'l',
    'll',
    '[?]',
    'v',
    'sh',
    'ss',
    's',
    'h',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'RR',
    '[?]',
    'e',
    'ee',
    'ai',
    '[?]',
    'o',
    'oo',
    'au',
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "+",
    "+",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'RR',
    'LL',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'N',
    'H',
    '[?]',
    'a',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'L',
    '[?]',
    'e',
    'ee',
    'ai',
    '[?]',
    'o',
    'oo',
    'au',
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'c',
    'ch',
    'j',
    'jh',
    'ny',
    'tt',
    'tth',
    'dd',
    'ddh',
    'nn',
    't',
    'th',
    'd',
    'dh',
    'n',
    '[?]',
    'p',
    'ph',
    'b',
    'bh',
    'm',
    'y',
    'r',
    'rr',
    'l',
    'll',
    '[?]',
    'v',
    'sh',
    'ss',
    's',
    'h',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'RR',
    '[?]',
    'e',
    'ee',
    'ai',
    '[?]',
    'o',
    'oo',
    'au',
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "+",
    "+",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'lll',
    '[?]',
    'RR',
    'LL',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"3PzMV":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:40:04 MDT"
module.exports = [
    '[?]',
    '[?]',
    'N',
    'H',
    '[?]',
    'a',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'L',
    '[?]',
    'e',
    'ee',
    'ai',
    '[?]',
    'o',
    'oo',
    'au',
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'c',
    'ch',
    'j',
    'jh',
    'ny',
    'tt',
    'tth',
    'dd',
    'ddh',
    'nn',
    't',
    'th',
    'd',
    'dh',
    'n',
    '[?]',
    'p',
    'ph',
    'b',
    'bh',
    'm',
    'y',
    'r',
    'rr',
    'l',
    'll',
    'lll',
    'v',
    'sh',
    'ss',
    's',
    'h',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    '[?]',
    '[?]',
    'e',
    'ee',
    'ai',
    "",
    'o',
    'oo',
    'au',
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "+",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'RR',
    'LL',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'N',
    'H',
    '[?]',
    'a',
    'aa',
    'ae',
    'aae',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'RR',
    'L',
    'LL',
    'e',
    'ee',
    'ai',
    'o',
    'oo',
    'au',
    '[?]',
    '[?]',
    '[?]',
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'nng',
    'c',
    'ch',
    'j',
    'jh',
    'ny',
    'jny',
    'nyj',
    'tt',
    'tth',
    'dd',
    'ddh',
    'nn',
    'nndd',
    't',
    'th',
    'd',
    'dh',
    'n',
    '[?]',
    'nd',
    'p',
    'ph',
    'b',
    'bh',
    'm',
    'mb',
    'y',
    'r',
    '[?]',
    'l',
    '[?]',
    '[?]',
    'v',
    'sh',
    'ss',
    's',
    'h',
    'll',
    'f',
    '[?]',
    '[?]',
    '[?]',
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'aa',
    'ae',
    'aae',
    'i',
    'ii',
    'u',
    '[?]',
    'uu',
    '[?]',
    'R',
    'e',
    'ee',
    'ai',
    'o',
    'oo',
    'au',
    'L',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'RR',
    'LL',
    " . ",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"kYAjG":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:40:50 MDT"
module.exports = [
    '[?]',
    'k',
    'kh',
    'kh',
    'kh',
    'kh',
    'kh',
    'ng',
    'cch',
    'ch',
    'ch',
    'ch',
    'ch',
    'y',
    'd',
    't',
    'th',
    'th',
    'th',
    'n',
    'd',
    't',
    'th',
    'th',
    'th',
    'n',
    'b',
    'p',
    'ph',
    'f',
    'ph',
    'f',
    'ph',
    'm',
    'y',
    'r',
    'R',
    'l',
    'L',
    'w',
    's',
    's',
    's',
    'h',
    'l',
    "`",
    'h',
    "~",
    'a',
    'a',
    'aa',
    'am',
    'i',
    'ii',
    'ue',
    'uue',
    'u',
    'uu',
    "'",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "Bh.",
    'e',
    'ae',
    'o',
    'ai',
    'ai',
    'ao',
    "+",
    "",
    "",
    "",
    "",
    "",
    "",
    'M',
    "",
    " * ",
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    " // ",
    " /// ",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'k',
    'kh',
    '[?]',
    'kh',
    '[?]',
    '[?]',
    'ng',
    'ch',
    '[?]',
    's',
    '[?]',
    '[?]',
    'ny',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'd',
    'h',
    'th',
    'th',
    '[?]',
    'n',
    'b',
    'p',
    'ph',
    'f',
    'ph',
    'f',
    '[?]',
    'm',
    'y',
    'r',
    '[?]',
    'l',
    '[?]',
    'w',
    '[?]',
    '[?]',
    's',
    'h',
    '[?]',
    "`",
    "",
    "~",
    'a',
    "",
    'aa',
    'am',
    'i',
    'ii',
    'y',
    'yy',
    'u',
    'uu',
    '[?]',
    'o',
    'l',
    'ny',
    '[?]',
    '[?]',
    'e',
    'ei',
    'o',
    'ay',
    'ai',
    '[?]',
    "+",
    '[?]',
    "",
    "",
    "",
    "",
    "",
    'M',
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    '[?]',
    '[?]',
    'hn',
    'hm',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"eIZuB":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:41:36 MDT"
module.exports = [
    'AUM',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    " // ",
    " * ",
    "",
    "-",
    " / ",
    " / ",
    " // ",
    " -/ ",
    " +/ ",
    " X/ ",
    " /XX/ ",
    " /X/ ",
    ", ",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    ".5",
    "1.5",
    "2.5",
    "3.5",
    "4.5",
    "5.5",
    "6.5",
    "7.5",
    "8.5",
    "-.5",
    "+",
    "*",
    "^",
    "_",
    "",
    "~",
    '[?]',
    "]",
    "[[",
    "]]",
    "",
    "",
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'c',
    'ch',
    'j',
    '[?]',
    'ny',
    'tt',
    'tth',
    'dd',
    'ddh',
    'nn',
    't',
    'th',
    'd',
    'dh',
    'n',
    'p',
    'ph',
    'b',
    'bh',
    'm',
    'ts',
    'tsh',
    'dz',
    'dzh',
    'w',
    'zh',
    'z',
    "'",
    'y',
    'r',
    'l',
    'sh',
    'ssh',
    's',
    'h',
    'a',
    'kss',
    'r',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'R',
    'RR',
    'L',
    'LL',
    'e',
    'ee',
    'o',
    'oo',
    'M',
    'H',
    'i',
    'ii',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'c',
    'ch',
    'j',
    '[?]',
    'ny',
    'tt',
    'tth',
    'dd',
    'ddh',
    'nn',
    't',
    'th',
    'd',
    'dh',
    'n',
    'p',
    'ph',
    'b',
    'bh',
    'm',
    'ts',
    'tsh',
    'dz',
    'dzh',
    'w',
    'zh',
    'z',
    "'",
    'y',
    'r',
    'l',
    'sh',
    'ss',
    's',
    'h',
    'a',
    'kss',
    'w',
    'y',
    'r',
    '[?]',
    'X',
    " :X: ",
    " /O/ ",
    " /o/ ",
    " \\\\o\\\\ ",
    " (O) ",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"eqZAu":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:42:32 MDT"
module.exports = [
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'c',
    'ch',
    'j',
    'jh',
    'ny',
    'nny',
    'tt',
    'tth',
    'dd',
    'ddh',
    'nn',
    'tt',
    'th',
    'd',
    'dh',
    'n',
    'p',
    'ph',
    'b',
    'bh',
    'm',
    'y',
    'r',
    'l',
    'w',
    's',
    'h',
    'll',
    'a',
    '[?]',
    'i',
    'ii',
    'u',
    'uu',
    'e',
    '[?]',
    'o',
    'au',
    '[?]',
    'aa',
    'i',
    'ii',
    'u',
    'uu',
    'e',
    'ai',
    '[?]',
    '[?]',
    '[?]',
    'N',
    "'",
    ":",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    " / ",
    " // ",
    "n*",
    "r*",
    "l*",
    "e*",
    'sh',
    'ss',
    'R',
    'RR',
    'L',
    'LL',
    'R',
    'RR',
    'L',
    'LL',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'A',
    'B',
    'G',
    'D',
    'E',
    'V',
    'Z',
    "T`",
    'I',
    'K',
    'L',
    'M',
    'N',
    'O',
    'P',
    'Zh',
    'R',
    'S',
    'T',
    'U',
    "P`",
    "K`",
    "G'",
    'Q',
    'Sh',
    "Ch`",
    "C`",
    "Z'",
    'C',
    'Ch',
    'X',
    'J',
    'H',
    'E',
    'Y',
    'W',
    'Xh',
    'OE',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'a',
    'b',
    'g',
    'd',
    'e',
    'v',
    'z',
    "t`",
    'i',
    'k',
    'l',
    'm',
    'n',
    'o',
    'p',
    'zh',
    'r',
    's',
    't',
    'u',
    "p`",
    "k`",
    "g'",
    'q',
    'sh',
    "ch`",
    "c`",
    "z'",
    'c',
    'ch',
    'x',
    'j',
    'h',
    'e',
    'y',
    'w',
    'xh',
    'oe',
    'f',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    " // ",
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"al7LD":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:46:54 MDT"
module.exports = [
    'g',
    'gg',
    'n',
    'd',
    'dd',
    'r',
    'm',
    'b',
    'bb',
    's',
    'ss',
    "",
    'j',
    'jj',
    'c',
    'k',
    't',
    'p',
    'h',
    'ng',
    'nn',
    'nd',
    'nb',
    'dg',
    'rn',
    'rr',
    'rh',
    'rN',
    'mb',
    'mN',
    'bg',
    'bn',
    "",
    'bs',
    'bsg',
    'bst',
    'bsb',
    'bss',
    'bsj',
    'bj',
    'bc',
    'bt',
    'bp',
    'bN',
    'bbN',
    'sg',
    'sn',
    'sd',
    'sr',
    'sm',
    'sb',
    'sbg',
    'sss',
    's',
    'sj',
    'sc',
    'sk',
    'st',
    'sp',
    'sh',
    "",
    "",
    "",
    "",
    'Z',
    'g',
    'd',
    'm',
    'b',
    's',
    'Z',
    "",
    'j',
    'c',
    't',
    'p',
    'N',
    'j',
    "",
    "",
    "",
    "",
    'ck',
    'ch',
    "",
    "",
    'pb',
    'pN',
    'hh',
    'Q',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    'a',
    'ae',
    'ya',
    'yae',
    'eo',
    'e',
    'yeo',
    'ye',
    'o',
    'wa',
    'wae',
    'oe',
    'yo',
    'u',
    'weo',
    'we',
    'wi',
    'yu',
    'eu',
    'yi',
    'i',
    "a-o",
    "a-u",
    "ya-o",
    "ya-yo",
    "eo-o",
    "eo-u",
    "eo-eu",
    "yeo-o",
    "yeo-u",
    "o-eo",
    "o-e",
    "o-ye",
    "o-o",
    "o-u",
    "yo-ya",
    "yo-yae",
    "yo-yeo",
    "yo-o",
    "yo-i",
    "u-a",
    "u-ae",
    "u-eo-eu",
    "u-ye",
    "u-u",
    "yu-a",
    "yu-eo",
    "yu-e",
    "yu-yeo",
    "yu-ye",
    "yu-u",
    "yu-i",
    "eu-u",
    "eu-eu",
    "yi-u",
    "i-a",
    "i-ya",
    "i-o",
    "i-u",
    "i-eu",
    "i-U",
    'U',
    "U-eo",
    "U-u",
    "U-i",
    'UU',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'g',
    'gg',
    'gs',
    'n',
    'nj',
    'nh',
    'd',
    'l',
    'lg',
    'lm',
    'lb',
    'ls',
    'lt',
    'lp',
    'lh',
    'm',
    'b',
    'bs',
    's',
    'ss',
    'ng',
    'j',
    'c',
    'k',
    't',
    'p',
    'h',
    'gl',
    'gsg',
    'ng',
    'nd',
    'ns',
    'nZ',
    'nt',
    'dg',
    'tl',
    'lgs',
    'ln',
    'ld',
    'lth',
    'll',
    'lmg',
    'lms',
    'lbs',
    'lbh',
    'rNp',
    'lss',
    'lZ',
    'lk',
    'lQ',
    'mg',
    'ml',
    'mb',
    'ms',
    'mss',
    'mZ',
    'mc',
    'mh',
    'mN',
    'bl',
    'bp',
    'ph',
    'pN',
    'sg',
    'sd',
    'sl',
    'sb',
    'Z',
    'g',
    'ss',
    "",
    'kh',
    'N',
    'Ns',
    'NZ',
    'pb',
    'pN',
    'hn',
    'hl',
    'hm',
    'hb',
    'Q',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"iyrYA":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:22 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'ha',
    'hu',
    'hi',
    'haa',
    'hee',
    'he',
    'ho',
    '[?]',
    'la',
    'lu',
    'li',
    'laa',
    'lee',
    'le',
    'lo',
    'lwa',
    'hha',
    'hhu',
    'hhi',
    'hhaa',
    'hhee',
    'hhe',
    'hho',
    'hhwa',
    'ma',
    'mu',
    'mi',
    'maa',
    'mee',
    'me',
    'mo',
    'mwa',
    'sza',
    'szu',
    'szi',
    'szaa',
    'szee',
    'sze',
    'szo',
    'szwa',
    'ra',
    'ru',
    'ri',
    'raa',
    'ree',
    're',
    'ro',
    'rwa',
    'sa',
    'su',
    'si',
    'saa',
    'see',
    'se',
    'so',
    'swa',
    'sha',
    'shu',
    'shi',
    'shaa',
    'shee',
    'she',
    'sho',
    'shwa',
    'qa',
    'qu',
    'qi',
    'qaa',
    'qee',
    'qe',
    'qo',
    '[?]',
    'qwa',
    '[?]',
    'qwi',
    'qwaa',
    'qwee',
    'qwe',
    '[?]',
    '[?]',
    'qha',
    'qhu',
    'qhi',
    'qhaa',
    'qhee',
    'qhe',
    'qho',
    '[?]',
    'qhwa',
    '[?]',
    'qhwi',
    'qhwaa',
    'qhwee',
    'qhwe',
    '[?]',
    '[?]',
    'ba',
    'bu',
    'bi',
    'baa',
    'bee',
    'be',
    'bo',
    'bwa',
    'va',
    'vu',
    'vi',
    'vaa',
    'vee',
    've',
    'vo',
    'vwa',
    'ta',
    'tu',
    'ti',
    'taa',
    'tee',
    'te',
    'to',
    'twa',
    'ca',
    'cu',
    'ci',
    'caa',
    'cee',
    'ce',
    'co',
    'cwa',
    'xa',
    'xu',
    'xi',
    'xaa',
    'xee',
    'xe',
    'xo',
    '[?]',
    'xwa',
    '[?]',
    'xwi',
    'xwaa',
    'xwee',
    'xwe',
    '[?]',
    '[?]',
    'na',
    'nu',
    'ni',
    'naa',
    'nee',
    'ne',
    'no',
    'nwa',
    'nya',
    'nyu',
    'nyi',
    'nyaa',
    'nyee',
    'nye',
    'nyo',
    'nywa',
    "'a",
    "'u",
    '[?]',
    "'aa",
    "'ee",
    "'e",
    "'o",
    "'wa",
    'ka',
    'ku',
    'ki',
    'kaa',
    'kee',
    'ke',
    'ko',
    '[?]',
    'kwa',
    '[?]',
    'kwi',
    'kwaa',
    'kwee',
    'kwe',
    '[?]',
    '[?]',
    'kxa',
    'kxu',
    'kxi',
    'kxaa',
    'kxee',
    'kxe',
    'kxo',
    '[?]',
    'kxwa',
    '[?]',
    'kxwi',
    'kxwaa',
    'kxwee',
    'kxwe',
    '[?]',
    '[?]',
    'wa',
    'wu',
    'wi',
    'waa',
    'wee',
    'we',
    'wo',
    '[?]',
    "`a",
    "`u",
    "`i",
    "`aa",
    "`ee",
    "`e",
    "`o",
    '[?]',
    'za',
    'zu',
    'zi',
    'zaa',
    'zee',
    'ze',
    'zo',
    'zwa',
    'zha',
    'zhu',
    'zhi',
    'zhaa',
    'zhee',
    'zhe',
    'zho',
    'zhwa',
    'ya',
    'yu',
    'yi',
    'yaa',
    'yee',
    'ye',
    'yo',
    '[?]',
    'da',
    'du',
    'di',
    'daa',
    'dee',
    'de',
    'do',
    'dwa',
    'dda',
    'ddu',
    'ddi',
    'ddaa',
    'ddee',
    'dde',
    'ddo',
    'ddwa'
];

},{}],"muaNW":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:52:21 MDT"
module.exports = [
    'ja',
    'ju',
    'ji',
    'jaa',
    'jee',
    'je',
    'jo',
    'jwa',
    'ga',
    'gu',
    'gi',
    'gaa',
    'gee',
    'ge',
    'go',
    '[?]',
    'gwa',
    '[?]',
    'gwi',
    'gwaa',
    'gwee',
    'gwe',
    '[?]',
    '[?]',
    'gga',
    'ggu',
    'ggi',
    'ggaa',
    'ggee',
    'gge',
    'ggo',
    '[?]',
    'tha',
    'thu',
    'thi',
    'thaa',
    'thee',
    'the',
    'tho',
    'thwa',
    'cha',
    'chu',
    'chi',
    'chaa',
    'chee',
    'che',
    'cho',
    'chwa',
    'pha',
    'phu',
    'phi',
    'phaa',
    'phee',
    'phe',
    'pho',
    'phwa',
    'tsa',
    'tsu',
    'tsi',
    'tsaa',
    'tsee',
    'tse',
    'tso',
    'tswa',
    'tza',
    'tzu',
    'tzi',
    'tzaa',
    'tzee',
    'tze',
    'tzo',
    '[?]',
    'fa',
    'fu',
    'fi',
    'faa',
    'fee',
    'fe',
    'fo',
    'fwa',
    'pa',
    'pu',
    'pi',
    'paa',
    'pee',
    'pe',
    'po',
    'pwa',
    'rya',
    'mya',
    'fya',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    ' ',
    ".",
    ",",
    ";",
    ":",
    ":: ",
    "?",
    "//",
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    "10+",
    "20+",
    "30+",
    "40+",
    "50+",
    "60+",
    "70+",
    "80+",
    "90+",
    "100+",
    "10,000+",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'a',
    'e',
    'i',
    'o',
    'u',
    'v',
    'ga',
    'ka',
    'ge',
    'gi',
    'go',
    'gu',
    'gv',
    'ha',
    'he',
    'hi',
    'ho',
    'hu',
    'hv',
    'la',
    'le',
    'li',
    'lo',
    'lu',
    'lv',
    'ma',
    'me',
    'mi',
    'mo',
    'mu',
    'na',
    'hna',
    'nah',
    'ne',
    'ni',
    'no',
    'nu',
    'nv',
    'qua',
    'que',
    'qui',
    'quo',
    'quu',
    'quv',
    'sa',
    's',
    'se',
    'si',
    'so',
    'su',
    'sv',
    'da',
    'ta',
    'de',
    'te',
    'di',
    'ti',
    'do',
    'du',
    'dv',
    'dla',
    'tla',
    'tle',
    'tli',
    'tlo',
    'tlu',
    'tlv',
    'tsa',
    'tse',
    'tsi',
    'tso',
    'tsu',
    'tsv',
    'wa',
    'we',
    'wi',
    'wo',
    'wu',
    'wv',
    'ya',
    'ye',
    'yi',
    'yo',
    'yu',
    'yv',
    'MV',
    '[?]',
    '[?]',
    'ye',
    'yi',
    'yo',
    'yu',
    'yv',
    'mv',
    '[?]',
    '[?]'
];

},{}],"dhQhJ":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:22 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    '[?]',
    'e',
    'aai',
    'i',
    'ii',
    'o',
    'oo',
    'oo',
    'ee',
    'i',
    'a',
    'aa',
    'we',
    'we',
    'wi',
    'wi',
    'wii',
    'wii',
    'wo',
    'wo',
    'woo',
    'woo',
    'woo',
    'wa',
    'wa',
    'waa',
    'waa',
    'waa',
    'ai',
    'w',
    "'",
    't',
    'k',
    'sh',
    's',
    'n',
    'w',
    'n',
    "[?]",
    'w',
    'c',
    "?",
    'l',
    'en',
    'in',
    'on',
    'an',
    'pe',
    'paai',
    'pi',
    'pii',
    'po',
    'poo',
    'poo',
    'hee',
    'hi',
    'pa',
    'paa',
    'pwe',
    'pwe',
    'pwi',
    'pwi',
    'pwii',
    'pwii',
    'pwo',
    'pwo',
    'pwoo',
    'pwoo',
    'pwa',
    'pwa',
    'pwaa',
    'pwaa',
    'pwaa',
    'p',
    'p',
    'h',
    'te',
    'taai',
    'ti',
    'tii',
    'to',
    'too',
    'too',
    'dee',
    'di',
    'ta',
    'taa',
    'twe',
    'twe',
    'twi',
    'twi',
    'twii',
    'twii',
    'two',
    'two',
    'twoo',
    'twoo',
    'twa',
    'twa',
    'twaa',
    'twaa',
    'twaa',
    't',
    'tte',
    'tti',
    'tto',
    'tta',
    'ke',
    'kaai',
    'ki',
    'kii',
    'ko',
    'koo',
    'koo',
    'ka',
    'kaa',
    'kwe',
    'kwe',
    'kwi',
    'kwi',
    'kwii',
    'kwii',
    'kwo',
    'kwo',
    'kwoo',
    'kwoo',
    'kwa',
    'kwa',
    'kwaa',
    'kwaa',
    'kwaa',
    'k',
    'kw',
    'keh',
    'kih',
    'koh',
    'kah',
    'ce',
    'caai',
    'ci',
    'cii',
    'co',
    'coo',
    'coo',
    'ca',
    'caa',
    'cwe',
    'cwe',
    'cwi',
    'cwi',
    'cwii',
    'cwii',
    'cwo',
    'cwo',
    'cwoo',
    'cwoo',
    'cwa',
    'cwa',
    'cwaa',
    'cwaa',
    'cwaa',
    'c',
    'th',
    'me',
    'maai',
    'mi',
    'mii',
    'mo',
    'moo',
    'moo',
    'ma',
    'maa',
    'mwe',
    'mwe',
    'mwi',
    'mwi',
    'mwii',
    'mwii',
    'mwo',
    'mwo',
    'mwoo',
    'mwoo',
    'mwa',
    'mwa',
    'mwaa',
    'mwaa',
    'mwaa',
    'm',
    'm',
    'mh',
    'm',
    'm',
    'ne',
    'naai',
    'ni',
    'nii',
    'no',
    'noo',
    'noo',
    'na',
    'naa',
    'nwe',
    'nwe',
    'nwa',
    'nwa',
    'nwaa',
    'nwaa',
    'nwaa',
    'n',
    'ng',
    'nh',
    'le',
    'laai',
    'li',
    'lii',
    'lo',
    'loo',
    'loo',
    'la',
    'laa',
    'lwe',
    'lwe',
    'lwi',
    'lwi',
    'lwii',
    'lwii',
    'lwo',
    'lwo',
    'lwoo',
    'lwoo',
    'lwa',
    'lwa',
    'lwaa',
    'lwaa',
    'l',
    'l',
    'l',
    'se',
    'saai',
    'si',
    'sii',
    'so',
    'soo',
    'soo',
    'sa',
    'saa',
    'swe',
    'swe',
    'swi',
    'swi',
    'swii',
    'swii',
    'swo',
    'swo',
    'swoo',
    'swoo'
];

},{}],"9AZds":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:22 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'swa',
    'swa',
    'swaa',
    'swaa',
    'swaa',
    's',
    's',
    'sw',
    's',
    'sk',
    'skw',
    'sW',
    'spwa',
    'stwa',
    'skwa',
    'scwa',
    'she',
    'shi',
    'shii',
    'sho',
    'shoo',
    'sha',
    'shaa',
    'shwe',
    'shwe',
    'shwi',
    'shwi',
    'shwii',
    'shwii',
    'shwo',
    'shwo',
    'shwoo',
    'shwoo',
    'shwa',
    'shwa',
    'shwaa',
    'shwaa',
    'sh',
    'ye',
    'yaai',
    'yi',
    'yii',
    'yo',
    'yoo',
    'yoo',
    'ya',
    'yaa',
    'ywe',
    'ywe',
    'ywi',
    'ywi',
    'ywii',
    'ywii',
    'ywo',
    'ywo',
    'ywoo',
    'ywoo',
    'ywa',
    'ywa',
    'ywaa',
    'ywaa',
    'ywaa',
    'y',
    'y',
    'y',
    'yi',
    're',
    're',
    'le',
    'raai',
    'ri',
    'rii',
    'ro',
    'roo',
    'lo',
    'ra',
    'raa',
    'la',
    'rwaa',
    'rwaa',
    'r',
    'r',
    'r',
    'fe',
    'faai',
    'fi',
    'fii',
    'fo',
    'foo',
    'fa',
    'faa',
    'fwaa',
    'fwaa',
    'f',
    'the',
    'the',
    'thi',
    'thi',
    'thii',
    'thii',
    'tho',
    'thoo',
    'tha',
    'thaa',
    'thwaa',
    'thwaa',
    'th',
    'tthe',
    'tthi',
    'ttho',
    'ttha',
    'tth',
    'tye',
    'tyi',
    'tyo',
    'tya',
    'he',
    'hi',
    'hii',
    'ho',
    'hoo',
    'ha',
    'haa',
    'h',
    'h',
    'hk',
    'qaai',
    'qi',
    'qii',
    'qo',
    'qoo',
    'qa',
    'qaa',
    'q',
    'tlhe',
    'tlhi',
    'tlho',
    'tlha',
    're',
    'ri',
    'ro',
    'ra',
    'ngaai',
    'ngi',
    'ngii',
    'ngo',
    'ngoo',
    'nga',
    'ngaa',
    'ng',
    'nng',
    'she',
    'shi',
    'sho',
    'sha',
    'the',
    'thi',
    'tho',
    'tha',
    'th',
    'lhi',
    'lhii',
    'lho',
    'lhoo',
    'lha',
    'lhaa',
    'lh',
    'the',
    'thi',
    'thii',
    'tho',
    'thoo',
    'tha',
    'thaa',
    'th',
    'b',
    'e',
    'i',
    'o',
    'a',
    'we',
    'wi',
    'wo',
    'wa',
    'ne',
    'ni',
    'no',
    'na',
    'ke',
    'ki',
    'ko',
    'ka',
    'he',
    'hi',
    'ho',
    'ha',
    'ghu',
    'gho',
    'ghe',
    'ghee',
    'ghi',
    'gha',
    'ru',
    'ro',
    're',
    'ree',
    'ri',
    'ra',
    'wu',
    'wo',
    'we',
    'wee',
    'wi',
    'wa',
    'hwu',
    'hwo',
    'hwe',
    'hwee',
    'hwi',
    'hwa',
    'thu',
    'tho',
    'the',
    'thee',
    'thi',
    'tha',
    'ttu',
    'tto',
    'tte',
    'ttee',
    'tti',
    'tta',
    'pu',
    'po',
    'pe',
    'pee',
    'pi',
    'pa',
    'p',
    'gu',
    'go',
    'ge',
    'gee',
    'gi',
    'ga',
    'khu',
    'kho',
    'khe',
    'khee',
    'khi',
    'kha',
    'kku',
    'kko',
    'kke',
    'kkee',
    'kki'
];

},{}],"kZ4ek":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:54:35 MDT"
module.exports = [
    'kka',
    'kk',
    'nu',
    'no',
    'ne',
    'nee',
    'ni',
    'na',
    'mu',
    'mo',
    'me',
    'mee',
    'mi',
    'ma',
    'yu',
    'yo',
    'ye',
    'yee',
    'yi',
    'ya',
    'ju',
    'ju',
    'jo',
    'je',
    'jee',
    'ji',
    'ji',
    'ja',
    'jju',
    'jjo',
    'jje',
    'jjee',
    'jji',
    'jja',
    'lu',
    'lo',
    'le',
    'lee',
    'li',
    'la',
    'dlu',
    'dlo',
    'dle',
    'dlee',
    'dli',
    'dla',
    'lhu',
    'lho',
    'lhe',
    'lhee',
    'lhi',
    'lha',
    'tlhu',
    'tlho',
    'tlhe',
    'tlhee',
    'tlhi',
    'tlha',
    'tlu',
    'tlo',
    'tle',
    'tlee',
    'tli',
    'tla',
    'zu',
    'zo',
    'ze',
    'zee',
    'zi',
    'za',
    'z',
    'z',
    'dzu',
    'dzo',
    'dze',
    'dzee',
    'dzi',
    'dza',
    'su',
    'so',
    'se',
    'see',
    'si',
    'sa',
    'shu',
    'sho',
    'she',
    'shee',
    'shi',
    'sha',
    'sh',
    'tsu',
    'tso',
    'tse',
    'tsee',
    'tsi',
    'tsa',
    'chu',
    'cho',
    'che',
    'chee',
    'chi',
    'cha',
    'ttsu',
    'ttso',
    'ttse',
    'ttsee',
    'ttsi',
    'ttsa',
    'X',
    ".",
    'qai',
    'ngai',
    'nngi',
    'nngii',
    'nngo',
    'nngoo',
    'nnga',
    'nngaa',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    ' ',
    'b',
    'l',
    'f',
    's',
    'n',
    'h',
    'd',
    't',
    'c',
    'q',
    'm',
    'g',
    'ng',
    'z',
    'r',
    'a',
    'o',
    'u',
    'e',
    'i',
    'ch',
    'th',
    'ph',
    'p',
    'x',
    'p',
    "<",
    ">",
    '[?]',
    '[?]',
    '[?]',
    'f',
    'v',
    'u',
    'yr',
    'y',
    'w',
    'th',
    'th',
    'a',
    'o',
    'ac',
    'ae',
    'o',
    'o',
    'o',
    'oe',
    'on',
    'r',
    'k',
    'c',
    'k',
    'g',
    'ng',
    'g',
    'g',
    'w',
    'h',
    'h',
    'h',
    'h',
    'n',
    'n',
    'n',
    'i',
    'e',
    'j',
    'g',
    'ae',
    'a',
    'eo',
    'p',
    'z',
    's',
    's',
    's',
    'c',
    'z',
    't',
    't',
    'd',
    'b',
    'b',
    'p',
    'p',
    'e',
    'm',
    'm',
    'm',
    'l',
    'l',
    'ng',
    'ng',
    'd',
    'o',
    'ear',
    'ior',
    'qu',
    'qu',
    'qu',
    's',
    'yr',
    'yr',
    'yr',
    'q',
    'x',
    ".",
    ":",
    "+",
    '17',
    '18',
    '19',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"br86K":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:55:25 MDT"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'k',
    'kh',
    'g',
    'gh',
    'ng',
    'c',
    'ch',
    'j',
    'jh',
    'ny',
    't',
    'tth',
    'd',
    'ddh',
    'nn',
    't',
    'th',
    'd',
    'dh',
    'n',
    'p',
    'ph',
    'b',
    'bh',
    'm',
    'y',
    'r',
    'l',
    'v',
    'sh',
    'ss',
    's',
    'h',
    'l',
    'q',
    'a',
    'aa',
    'i',
    'ii',
    'u',
    'uk',
    'uu',
    'uuv',
    'ry',
    'ryy',
    'ly',
    'lyy',
    'e',
    'ai',
    'oo',
    'oo',
    'au',
    'a',
    'aa',
    'aa',
    'i',
    'ii',
    'y',
    'yy',
    'u',
    'uu',
    'ua',
    'oe',
    'ya',
    'ie',
    'e',
    'ae',
    'ai',
    'oo',
    'au',
    'M',
    'H',
    "a`",
    "",
    "",
    "",
    'r',
    "",
    "!",
    "",
    "",
    "",
    "",
    "",
    ".",
    " // ",
    ":",
    "+",
    "++",
    " * ",
    " /// ",
    'KR',
    "'",
    '[?]',
    '[?]',
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"4lKBn":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:55:53 MDT"
module.exports = [
    " \\@ ",
    " ... ",
    ", ",
    ". ",
    ": ",
    " // ",
    "",
    "-",
    ", ",
    ". ",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'a',
    'e',
    'i',
    'o',
    'u',
    'O',
    'U',
    'ee',
    'n',
    'ng',
    'b',
    'p',
    'q',
    'g',
    'm',
    'l',
    's',
    'sh',
    't',
    'd',
    'ch',
    'j',
    'y',
    'r',
    'w',
    'f',
    'k',
    'kha',
    'ts',
    'z',
    'h',
    'zr',
    'lh',
    'zh',
    'ch',
    "-",
    'e',
    'i',
    'o',
    'u',
    'O',
    'U',
    'ng',
    'b',
    'p',
    'q',
    'g',
    'm',
    't',
    'd',
    'ch',
    'j',
    'ts',
    'y',
    'w',
    'k',
    'g',
    'h',
    'jy',
    'ny',
    'dz',
    'e',
    'i',
    'iy',
    'U',
    'u',
    'ng',
    'k',
    'g',
    'h',
    'p',
    'sh',
    't',
    'd',
    'j',
    'f',
    'g',
    'h',
    'ts',
    'z',
    'r',
    'ch',
    'zh',
    'i',
    'k',
    'r',
    'f',
    'zh',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'H',
    'X',
    'W',
    'M',
    ' 3 ',
    ' 333 ',
    'a',
    'i',
    'k',
    'ng',
    'c',
    'tt',
    'tth',
    'dd',
    'nn',
    't',
    'd',
    'p',
    'ph',
    'ss',
    'zh',
    'z',
    'a',
    't',
    'zh',
    'gh',
    'ng',
    'c',
    'jh',
    'tta',
    'ddh',
    't',
    'dh',
    'ss',
    'cy',
    'zh',
    'z',
    'u',
    'y',
    'bh',
    "'",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"5KFf3":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2014-07-09 04:45:32 MDT sburke@cpan.org"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"e4UUF":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2014-07-09 04:45:01 MDT sburke@cpan.org"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"8n3HL":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2014-07-09 04:45:07 MDT sburke@cpan.org"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"eWBsg":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2014-07-09 04:44:34 MDT sburke@cpan.org"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"3YGvw":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2014-07-09 04:44:20 MDT sburke@cpan.org"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"cJlqR":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:36:46 MDT"
module.exports = [
    'A',
    'a',
    'B',
    'b',
    'B',
    'b',
    'B',
    'b',
    'C',
    'c',
    'D',
    'd',
    'D',
    'd',
    'D',
    'd',
    'D',
    'd',
    'D',
    'd',
    'E',
    'e',
    'E',
    'e',
    'E',
    'e',
    'E',
    'e',
    'E',
    'e',
    'F',
    'f',
    'G',
    'g',
    'H',
    'h',
    'H',
    'h',
    'H',
    'h',
    'H',
    'h',
    'H',
    'h',
    'I',
    'i',
    'I',
    'i',
    'K',
    'k',
    'K',
    'k',
    'K',
    'k',
    'L',
    'l',
    'L',
    'l',
    'L',
    'l',
    'L',
    'l',
    'M',
    'm',
    'M',
    'm',
    'M',
    'm',
    'N',
    'n',
    'N',
    'n',
    'N',
    'n',
    'N',
    'n',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'P',
    'p',
    'P',
    'p',
    'R',
    'r',
    'R',
    'r',
    'R',
    'r',
    'R',
    'r',
    'S',
    's',
    'S',
    's',
    'S',
    's',
    'S',
    's',
    'S',
    's',
    'T',
    't',
    'T',
    't',
    'T',
    't',
    'T',
    't',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'V',
    'v',
    'V',
    'v',
    'W',
    'w',
    'W',
    'w',
    'W',
    'w',
    'W',
    'w',
    'W',
    'w',
    'X',
    'x',
    'X',
    'x',
    'Y',
    'y',
    'Z',
    'z',
    'Z',
    'z',
    'Z',
    'z',
    'h',
    't',
    'w',
    'y',
    'a',
    's',
    's',
    's',
    'Ss',
    'd',
    'A',
    'a',
    'A',
    'a',
    'A',
    'a',
    'A',
    'a',
    'A',
    'a',
    'A',
    'a',
    'A',
    'a',
    'A',
    'a',
    'A',
    'a',
    'A',
    'a',
    'A',
    'a',
    'A',
    'a',
    'E',
    'e',
    'E',
    'e',
    'E',
    'e',
    'E',
    'e',
    'E',
    'e',
    'E',
    'e',
    'E',
    'e',
    'E',
    'e',
    'I',
    'i',
    'I',
    'i',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'O',
    'o',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    'U',
    'u',
    //  0x1EF_:
    'U',
    // 	: 01AF 0323
    'u',
    // 	: 01B0 0323
    // @		Latin general extensions
    'Y',
    // 	: 0059 0300
    'y',
    // 	* Welsh
    // 	: 0079 0300
    'Y',
    // 	: 0059 0323
    'y',
    // 	: 0079 0323
    'Y',
    // 	: 0059 0309
    'y',
    // 	: 0079 0309
    'Y',
    // 	: 0059 0303
    'y',
    // 	: 0079 0303
    // @		Medievalist additions
    "LL",
    "ll",
    "V",
    "v",
    "Y",
    "y"
];

},{}],"ij3jv":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:57:09 MDT"
module.exports = [
    'a',
    'a',
    'a',
    'a',
    'a',
    'a',
    'a',
    'a',
    'A',
    'A',
    'A',
    'A',
    'A',
    'A',
    'A',
    'A',
    'e',
    'e',
    'e',
    'e',
    'e',
    'e',
    '[?]',
    '[?]',
    'E',
    'E',
    'E',
    'E',
    'E',
    'E',
    '[?]',
    '[?]',
    'e',
    'e',
    'e',
    'e',
    'e',
    'e',
    'e',
    'e',
    'E',
    'E',
    'E',
    'E',
    'E',
    'E',
    'E',
    'E',
    'i',
    'i',
    'i',
    'i',
    'i',
    'i',
    'i',
    'i',
    'I',
    'I',
    'I',
    'I',
    'I',
    'I',
    'I',
    'I',
    'o',
    'o',
    'o',
    'o',
    'o',
    'o',
    '[?]',
    '[?]',
    'O',
    'O',
    'O',
    'O',
    'O',
    'O',
    '[?]',
    '[?]',
    'u',
    'u',
    'u',
    'u',
    'u',
    'u',
    'u',
    'u',
    '[?]',
    'U',
    '[?]',
    'U',
    '[?]',
    'U',
    '[?]',
    'U',
    'o',
    'o',
    'o',
    'o',
    'o',
    'o',
    'o',
    'o',
    'O',
    'O',
    'O',
    'O',
    'O',
    'O',
    'O',
    'O',
    'a',
    'a',
    'e',
    'e',
    'e',
    'e',
    'i',
    'i',
    'o',
    'o',
    'u',
    'u',
    'o',
    'o',
    '[?]',
    '[?]',
    'a',
    'a',
    'a',
    'a',
    'a',
    'a',
    'a',
    'a',
    'A',
    'A',
    'A',
    'A',
    'A',
    'A',
    'A',
    'A',
    'e',
    'e',
    'e',
    'e',
    'e',
    'e',
    'e',
    'e',
    'E',
    'E',
    'E',
    'E',
    'E',
    'E',
    'E',
    'E',
    'o',
    'o',
    'o',
    'o',
    'o',
    'o',
    'o',
    'o',
    'O',
    'O',
    'O',
    'O',
    'O',
    'O',
    'O',
    'O',
    'a',
    'a',
    'a',
    'a',
    'a',
    '[?]',
    'a',
    'a',
    'A',
    'A',
    'A',
    'A',
    'A',
    "'",
    'i',
    "'",
    "~",
    "\"~",
    'e',
    'e',
    'e',
    '[?]',
    'e',
    'e',
    'E',
    'E',
    'E',
    'E',
    'E',
    "'`",
    "''",
    "'~",
    'i',
    'i',
    'i',
    'i',
    '[?]',
    '[?]',
    'i',
    'i',
    'I',
    'I',
    'I',
    'I',
    '[?]',
    "`'",
    "`'",
    "`~",
    'u',
    'u',
    'u',
    'u',
    'R',
    'R',
    'u',
    'u',
    'U',
    'U',
    'U',
    'U',
    'R',
    "\"`",
    "\"'",
    "`",
    '[?]',
    '[?]',
    'o',
    'o',
    'o',
    '[?]',
    'o',
    'o',
    'O',
    'O',
    'O',
    'O',
    'O',
    "'",
    "`",
    '[?]'
];

},{}],"lCtrr":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:57:55 MDT"
module.exports = [
    ' ',
    ' ',
    ' ',
    ' ',
    ' ',
    ' ',
    ' ',
    ' ',
    ' ',
    ' ',
    ' ',
    ' ',
    "",
    "",
    "",
    "",
    "-",
    "-",
    "-",
    "-",
    "--",
    "--",
    "||",
    "_",
    "'",
    "'",
    ",",
    "'",
    "\"",
    "\"",
    ",,",
    "\"",
    "+",
    "++",
    "*",
    "*>",
    ".",
    "..",
    "...",
    ".",
    "\\n",
    "\\n\\n",
    "",
    "",
    "",
    "",
    "",
    ' ',
    "%0",
    "%00",
    "'",
    "''",
    "'''",
    "`",
    "``",
    "```",
    "^",
    "<",
    ">",
    "*",
    "!!",
    "!?",
    "-",
    "_",
    "-",
    "^",
    "***",
    "--",
    "/",
    "-[",
    "]-",
    '[?]',
    "?!",
    "!?",
    '7',
    'PP',
    "(]",
    "[)",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    '0',
    "",
    "",
    "",
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    "+",
    "-",
    "=",
    "(",
    ")",
    'n',
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    "+",
    "-",
    "=",
    "(",
    ")",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'ECU',
    'CL',
    'Cr',
    'FF',
    'L',
    'mil',
    'N',
    'Pts',
    'Rs',
    'W',
    'NS',
    'D',
    'EUR',
    'K',
    'T',
    'Dr',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"bDpzj":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 06:58:45 MDT"
module.exports = [
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "tm",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    " 1/3 ",
    " 2/3 ",
    " 1/5 ",
    " 2/5 ",
    " 3/5 ",
    " 4/5 ",
    " 1/6 ",
    " 5/6 ",
    " 1/8 ",
    " 3/8 ",
    " 5/8 ",
    " 7/8 ",
    " 1/",
    'I',
    'II',
    'III',
    'IV',
    'V',
    'VI',
    'VII',
    'VIII',
    'IX',
    'X',
    'XI',
    'XII',
    'L',
    'C',
    'D',
    'M',
    'i',
    'ii',
    'iii',
    'iv',
    'v',
    'vi',
    'vii',
    'viii',
    'ix',
    'x',
    'xi',
    'xii',
    'l',
    'c',
    'd',
    'm',
    "(D",
    "D)",
    "((|))",
    ")",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "-",
    "|",
    "-",
    "|",
    "-",
    "|",
    "\\\\",
    "/",
    "\\\\",
    "/",
    "-",
    "-",
    "~",
    "~",
    "-",
    "|",
    "-",
    "|",
    "-",
    "-",
    "-",
    "|",
    "-",
    "|",
    "|",
    "-",
    "-",
    "-",
    "-",
    "-",
    "-",
    "|",
    "|",
    "|",
    "|",
    "|",
    "|",
    "|",
    "^",
    'V',
    "\\\\",
    "=",
    'V',
    "^",
    "-",
    "-",
    "|",
    "|",
    "-",
    "-",
    "|",
    "|",
    "=",
    "|",
    "=",
    "=",
    "|",
    "=",
    "|",
    "=",
    "=",
    "=",
    "=",
    "=",
    "=",
    "|",
    "=",
    "|",
    "=",
    "|",
    "\\\\",
    "/",
    "\\\\",
    "/",
    "=",
    "=",
    "~",
    "~",
    "|",
    "|",
    "-",
    "|",
    "-",
    "|",
    "-",
    "-",
    "-",
    "|",
    "-",
    "|",
    "|",
    "|",
    "|",
    "|",
    "|",
    "|",
    "-",
    "\\\\",
    "\\\\",
    "|",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"f6pnH":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:00:32 MDT"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"htFfJ":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:00:48 MDT"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"fdOTX":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:01:27 MDT"
module.exports = [
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"6ojvI":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:04:30 MDT"
module.exports = [
    "-",
    "-",
    "|",
    "|",
    "-",
    "-",
    "|",
    "|",
    "-",
    "-",
    "|",
    "|",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "-",
    "-",
    "|",
    "|",
    "-",
    "|",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "+",
    "/",
    "\\\\",
    'X',
    "-",
    "|",
    "-",
    "|",
    "-",
    "|",
    "-",
    "|",
    "-",
    "|",
    "-",
    "|",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "-",
    "|",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "#",
    "^",
    "^",
    "^",
    "^",
    ">",
    ">",
    ">",
    ">",
    ">",
    ">",
    'V',
    'V',
    'V',
    'V',
    "<",
    "<",
    "<",
    "<",
    "<",
    "<",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "*",
    "#",
    "#",
    "#",
    "#",
    "#",
    "^",
    "^",
    "^",
    'O',
    "#",
    "#",
    "#",
    "#",
    "O",
    "O",
    "O",
    "O",
    '/',
    '\\',
    '\\',
    '#',
    '#',
    '#',
    '#',
    '/'
];

},{}],"lCqGN":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:04:55 MDT"
module.exports = [
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"ixVsK":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:05:14 MDT"
module.exports = [
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"eVRC8":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:23 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    ' ',
    'a',
    '1',
    'b',
    "'",
    'k',
    '2',
    'l',
    "\\@",
    'c',
    'i',
    'f',
    "/",
    'm',
    's',
    'p',
    "\"",
    'e',
    '3',
    'h',
    '9',
    'o',
    '6',
    'r',
    "^",
    'd',
    'j',
    'g',
    ">",
    'n',
    't',
    'q',
    ",",
    "*",
    '5',
    "<",
    "-",
    'u',
    '8',
    'v',
    ".",
    "%",
    "[",
    "\\$",
    "+",
    'x',
    "!",
    "&",
    ";",
    ":",
    '4',
    "\\\\",
    '0',
    'z',
    '7',
    "(",
    "_",
    "?",
    'w',
    "]",
    "#",
    'y',
    ")",
    "=",
    "[d7]",
    "[d17]",
    "[d27]",
    "[d127]",
    "[d37]",
    "[d137]",
    "[d237]",
    "[d1237]",
    "[d47]",
    "[d147]",
    "[d247]",
    "[d1247]",
    "[d347]",
    "[d1347]",
    "[d2347]",
    "[d12347]",
    "[d57]",
    "[d157]",
    "[d257]",
    "[d1257]",
    "[d357]",
    "[d1357]",
    "[d2357]",
    "[d12357]",
    "[d457]",
    "[d1457]",
    "[d2457]",
    "[d12457]",
    "[d3457]",
    "[d13457]",
    "[d23457]",
    "[d123457]",
    "[d67]",
    "[d167]",
    "[d267]",
    "[d1267]",
    "[d367]",
    "[d1367]",
    "[d2367]",
    "[d12367]",
    "[d467]",
    "[d1467]",
    "[d2467]",
    "[d12467]",
    "[d3467]",
    "[d13467]",
    "[d23467]",
    "[d123467]",
    "[d567]",
    "[d1567]",
    "[d2567]",
    "[d12567]",
    "[d3567]",
    "[d13567]",
    "[d23567]",
    "[d123567]",
    "[d4567]",
    "[d14567]",
    "[d24567]",
    "[d124567]",
    "[d34567]",
    "[d134567]",
    "[d234567]",
    "[d1234567]",
    "[d8]",
    "[d18]",
    "[d28]",
    "[d128]",
    "[d38]",
    "[d138]",
    "[d238]",
    "[d1238]",
    "[d48]",
    "[d148]",
    "[d248]",
    "[d1248]",
    "[d348]",
    "[d1348]",
    "[d2348]",
    "[d12348]",
    "[d58]",
    "[d158]",
    "[d258]",
    "[d1258]",
    "[d358]",
    "[d1358]",
    "[d2358]",
    "[d12358]",
    "[d458]",
    "[d1458]",
    "[d2458]",
    "[d12458]",
    "[d3458]",
    "[d13458]",
    "[d23458]",
    "[d123458]",
    "[d68]",
    "[d168]",
    "[d268]",
    "[d1268]",
    "[d368]",
    "[d1368]",
    "[d2368]",
    "[d12368]",
    "[d468]",
    "[d1468]",
    "[d2468]",
    "[d12468]",
    "[d3468]",
    "[d13468]",
    "[d23468]",
    "[d123468]",
    "[d568]",
    "[d1568]",
    "[d2568]",
    "[d12568]",
    "[d3568]",
    "[d13568]",
    "[d23568]",
    "[d123568]",
    "[d4568]",
    "[d14568]",
    "[d24568]",
    "[d124568]",
    "[d34568]",
    "[d134568]",
    "[d234568]",
    "[d1234568]",
    "[d78]",
    "[d178]",
    "[d278]",
    "[d1278]",
    "[d378]",
    "[d1378]",
    "[d2378]",
    "[d12378]",
    "[d478]",
    "[d1478]",
    "[d2478]",
    "[d12478]",
    "[d3478]",
    "[d13478]",
    "[d23478]",
    "[d123478]",
    "[d578]",
    "[d1578]",
    "[d2578]",
    "[d12578]",
    "[d3578]",
    "[d13578]",
    "[d23578]",
    "[d123578]",
    "[d4578]",
    "[d14578]",
    "[d24578]",
    "[d124578]",
    "[d34578]",
    "[d134578]",
    "[d234578]",
    "[d1234578]",
    "[d678]",
    "[d1678]",
    "[d2678]",
    "[d12678]",
    "[d3678]",
    "[d13678]",
    "[d23678]",
    "[d123678]",
    "[d4678]",
    "[d14678]",
    "[d24678]",
    "[d124678]",
    "[d34678]",
    "[d134678]",
    "[d234678]",
    "[d1234678]",
    "[d5678]",
    "[d15678]",
    "[d25678]",
    "[d125678]",
    "[d35678]",
    "[d135678]",
    "[d235678]",
    "[d1235678]",
    "[d45678]",
    "[d145678]",
    "[d245678]",
    "[d1245678]",
    "[d345678]",
    "[d1345678]",
    "[d2345678]",
    "[d12345678]"
];

},{}],"awspy":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:06:16 MDT"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    '[?]',
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"7DXKE":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:06:31 MDT"
module.exports = [
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"bE0Ph":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:08:09 MDT"
module.exports = [
    ' ',
    ", ",
    ". ",
    "\"",
    "[JIS]",
    "\"",
    "/",
    '0',
    "<",
    "> ",
    "<<",
    ">> ",
    "[",
    "] ",
    "\\{",
    "\\} ",
    "[(",
    ")] ",
    "\\@",
    'X ',
    "[",
    "] ",
    "[[",
    "]] ",
    "((",
    ")) ",
    "[[",
    "]] ",
    "~ ",
    "``",
    "''",
    ",,",
    "\\@",
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    "",
    "",
    "",
    "",
    "",
    "",
    "~",
    "+",
    "+",
    "+",
    "+",
    "",
    "\\@",
    " // ",
    "+10+",
    "+20+",
    "+30+",
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    '[?]',
    'a',
    'a',
    'i',
    'i',
    'u',
    'u',
    'e',
    'e',
    'o',
    'o',
    'ka',
    'ga',
    'ki',
    'gi',
    'ku',
    'gu',
    'ke',
    'ge',
    'ko',
    'go',
    'sa',
    'za',
    'si',
    'zi',
    'su',
    'zu',
    'se',
    'ze',
    'so',
    'zo',
    'ta',
    'da',
    'ti',
    'di',
    'tu',
    'tu',
    'du',
    'te',
    'de',
    'to',
    'do',
    'na',
    'ni',
    'nu',
    'ne',
    'no',
    'ha',
    'ba',
    'pa',
    'hi',
    'bi',
    'pi',
    'hu',
    'bu',
    'pu',
    'he',
    'be',
    'pe',
    'ho',
    'bo',
    'po',
    'ma',
    'mi',
    'mu',
    'me',
    'mo',
    'ya',
    'ya',
    'yu',
    'yu',
    'yo',
    'yo',
    'ra',
    'ri',
    'ru',
    're',
    'ro',
    'wa',
    'wa',
    'wi',
    'we',
    'wo',
    'n',
    'vu',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    "",
    "\"",
    "\"",
    '[?]',
    '[?]',
    'a',
    'a',
    'i',
    'i',
    'u',
    'u',
    'e',
    'e',
    'o',
    'o',
    'ka',
    'ga',
    'ki',
    'gi',
    'ku',
    'gu',
    'ke',
    'ge',
    'ko',
    'go',
    'sa',
    'za',
    'si',
    'zi',
    'su',
    'zu',
    'se',
    'ze',
    'so',
    'zo',
    'ta',
    'da',
    'ti',
    'di',
    'tu',
    'tu',
    'du',
    'te',
    'de',
    'to',
    'do',
    'na',
    'ni',
    'nu',
    'ne',
    'no',
    'ha',
    'ba',
    'pa',
    'hi',
    'bi',
    'pi',
    'hu',
    'bu',
    'pu',
    'he',
    'be',
    'pe',
    'ho',
    'bo',
    'po',
    'ma',
    'mi',
    'mu',
    'me',
    'mo',
    'ya',
    'ya',
    'yu',
    'yu',
    'yo',
    'yo',
    'ra',
    'ri',
    'ru',
    're',
    'ro',
    'wa',
    'wa',
    'wi',
    'we',
    'wo',
    'n',
    'vu',
    'ka',
    'ke',
    'va',
    'vi',
    've',
    'vo',
    "",
    "",
    "\"",
    "\"",
    'koto'
];

},{}],"01Iq8":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:09:14 MDT"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'B',
    'P',
    'M',
    'F',
    'D',
    'T',
    'N',
    'L',
    'G',
    'K',
    'H',
    'J',
    'Q',
    'X',
    'ZH',
    'CH',
    'SH',
    'R',
    'Z',
    'C',
    'S',
    'A',
    'O',
    'E',
    'EH',
    'AI',
    'EI',
    'AU',
    'OU',
    'AN',
    'EN',
    'ANG',
    'ENG',
    'ER',
    'I',
    'U',
    'IU',
    'V',
    'NG',
    'GN',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'g',
    'gg',
    'gs',
    'n',
    'nj',
    'nh',
    'd',
    'dd',
    'r',
    'lg',
    'lm',
    'lb',
    'ls',
    'lt',
    'lp',
    'rh',
    'm',
    'b',
    'bb',
    'bs',
    's',
    'ss',
    "",
    'j',
    'jj',
    'c',
    'k',
    't',
    'p',
    'h',
    'a',
    'ae',
    'ya',
    'yae',
    'eo',
    'e',
    'yeo',
    'ye',
    'o',
    'wa',
    'wae',
    'oe',
    'yo',
    'u',
    'weo',
    'we',
    'wi',
    'yu',
    'eu',
    'yi',
    'i',
    "",
    'nn',
    'nd',
    'ns',
    'nZ',
    'lgs',
    'ld',
    'lbs',
    'lZ',
    'lQ',
    'mb',
    'ms',
    'mZ',
    'mN',
    'bg',
    "",
    'bsg',
    'bst',
    'bj',
    'bt',
    'bN',
    'bbN',
    'sg',
    'sn',
    'sd',
    'sb',
    'sj',
    'Z',
    "",
    'N',
    'Ns',
    'NZ',
    'pN',
    'hh',
    'Q',
    "yo-ya",
    "yo-yae",
    "yo-i",
    "yu-yeo",
    "yu-ye",
    "yu-i",
    'U',
    "U-i",
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    'BU',
    'ZI',
    'JI',
    'GU',
    'EE',
    'ENN',
    'OO',
    'ONN',
    'IR',
    'ANN',
    'INN',
    'UNN',
    'IM',
    'NGG',
    'AINN',
    'AUNN',
    'AM',
    'OM',
    'ONG',
    'INNN',
    'P',
    'T',
    'K',
    'H',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"hj9XP":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:10:43 MDT"
module.exports = [
    "(g)",
    "(n)",
    "(d)",
    "(r)",
    "(m)",
    "(b)",
    "(s)",
    "()",
    "(j)",
    "(c)",
    "(k)",
    "(t)",
    "(p)",
    "(h)",
    "(ga)",
    "(na)",
    "(da)",
    "(ra)",
    "(ma)",
    "(ba)",
    "(sa)",
    "(a)",
    "(ja)",
    "(ca)",
    "(ka)",
    "(ta)",
    "(pa)",
    "(ha)",
    "(ju)",
    '[?]',
    '[?]',
    '[?]',
    "(1) ",
    "(2) ",
    "(3) ",
    "(4) ",
    "(5) ",
    "(6) ",
    "(7) ",
    "(8) ",
    "(9) ",
    "(10) ",
    "(Yue) ",
    "(Huo) ",
    "(Shui) ",
    "(Mu) ",
    "(Jin) ",
    "(Tu) ",
    "(Ri) ",
    "(Zhu) ",
    "(You) ",
    "(She) ",
    "(Ming) ",
    "(Te) ",
    "(Cai) ",
    "(Zhu) ",
    "(Lao) ",
    "(Dai) ",
    "(Hu) ",
    "(Xue) ",
    "(Jian) ",
    "(Qi) ",
    "(Zi) ",
    "(Xie) ",
    "(Ji) ",
    "(Xiu) ",
    "<<",
    ">>",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "(g)",
    "(n)",
    "(d)",
    "(r)",
    "(m)",
    "(b)",
    "(s)",
    "()",
    "(j)",
    "(c)",
    "(k)",
    "(t)",
    "(p)",
    "(h)",
    "(ga)",
    "(na)",
    "(da)",
    "(ra)",
    "(ma)",
    "(ba)",
    "(sa)",
    "(a)",
    "(ja)",
    "(ca)",
    "(ka)",
    "(ta)",
    "(pa)",
    "(ha)",
    '[?]',
    '[?]',
    '[?]',
    'KIS ',
    "(1) ",
    "(2) ",
    "(3) ",
    "(4) ",
    "(5) ",
    "(6) ",
    "(7) ",
    "(8) ",
    "(9) ",
    "(10) ",
    "(Yue) ",
    "(Huo) ",
    "(Shui) ",
    "(Mu) ",
    "(Jin) ",
    "(Tu) ",
    "(Ri) ",
    "(Zhu) ",
    "(You) ",
    "(She) ",
    "(Ming) ",
    "(Te) ",
    "(Cai) ",
    "(Zhu) ",
    "(Lao) ",
    "(Mi) ",
    "(Nan) ",
    "(Nu) ",
    "(Shi) ",
    "(You) ",
    "(Yin) ",
    "(Zhu) ",
    "(Xiang) ",
    "(Xiu) ",
    "(Xie) ",
    "(Zheng) ",
    "(Shang) ",
    "(Zhong) ",
    "(Xia) ",
    "(Zuo) ",
    "(You) ",
    "(Yi) ",
    "(Zong) ",
    "(Xue) ",
    "(Jian) ",
    "(Qi) ",
    "(Zi) ",
    "(Xie) ",
    "(Ye) ",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '1M',
    '2M',
    '3M',
    '4M',
    '5M',
    '6M',
    '7M',
    '8M',
    '9M',
    '10M',
    '11M',
    '12M',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'a',
    'i',
    'u',
    'u',
    'o',
    'ka',
    'ki',
    'ku',
    'ke',
    'ko',
    'sa',
    'si',
    'su',
    'se',
    'so',
    'ta',
    'ti',
    'tu',
    'te',
    'to',
    'na',
    'ni',
    'nu',
    'ne',
    'no',
    'ha',
    'hi',
    'hu',
    'he',
    'ho',
    'ma',
    'mi',
    'mu',
    'me',
    'mo',
    'ya',
    'yu',
    'yo',
    'ra',
    'ri',
    'ru',
    're',
    'ro',
    'wa',
    'wi',
    'we',
    'wo',
    '[?]'
];

},{}],"cQy6T":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:11:15 MDT"
module.exports = [
    'apartment',
    'alpha',
    'ampere',
    'are',
    'inning',
    'inch',
    'won',
    'escudo',
    'acre',
    'ounce',
    'ohm',
    "kai-ri",
    'carat',
    'calorie',
    'gallon',
    'gamma',
    'giga',
    'guinea',
    'curie',
    'guilder',
    'kilo',
    'kilogram',
    'kilometer',
    'kilowatt',
    'gram',
    'gram ton',
    'cruzeiro',
    'krone',
    'case',
    'koruna',
    "co-op",
    'cycle',
    'centime',
    'shilling',
    'centi',
    'cent',
    'dozen',
    'desi',
    'dollar',
    'ton',
    'nano',
    'knot',
    'heights',
    'percent',
    'parts',
    'barrel',
    'piaster',
    'picul',
    'pico',
    'building',
    'farad',
    'feet',
    'bushel',
    'franc',
    'hectare',
    'peso',
    'pfennig',
    'hertz',
    'pence',
    'page',
    'beta',
    'point',
    'volt',
    'hon',
    'pound',
    'hall',
    'horn',
    'micro',
    'mile',
    'mach',
    'mark',
    'mansion',
    'micron',
    'milli',
    'millibar',
    'mega',
    'megaton',
    'meter',
    'yard',
    'yard',
    'yuan',
    'liter',
    'lira',
    'rupee',
    'ruble',
    'rem',
    'roentgen',
    'watt',
    '0h',
    '1h',
    '2h',
    '3h',
    '4h',
    '5h',
    '6h',
    '7h',
    '8h',
    '9h',
    '10h',
    '11h',
    '12h',
    '13h',
    '14h',
    '15h',
    '16h',
    '17h',
    '18h',
    '19h',
    '20h',
    '21h',
    '22h',
    '23h',
    '24h',
    'HPA',
    'da',
    'AU',
    'bar',
    'oV',
    'pc',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'Heisei',
    'Syouwa',
    'Taisyou',
    'Meiji',
    "Inc.",
    'pA',
    'nA',
    'microamp',
    'mA',
    'kA',
    'kB',
    'MB',
    'GB',
    'cal',
    'kcal',
    'pF',
    'nF',
    'microFarad',
    'microgram',
    'mg',
    'kg',
    'Hz',
    'kHz',
    'MHz',
    'GHz',
    'THz',
    'microliter',
    'ml',
    'dl',
    'kl',
    'fm',
    'nm',
    'micrometer',
    'mm',
    'cm',
    'km',
    "mm^2",
    "cm^2",
    "m^2",
    "km^2",
    "mm^4",
    "cm^3",
    "m^3",
    "km^3",
    "m/s",
    "m/s^2",
    'Pa',
    'kPa',
    'MPa',
    'GPa',
    'rad',
    "rad/s",
    "rad/s^2",
    'ps',
    'ns',
    'microsecond',
    'ms',
    'pV',
    'nV',
    'microvolt',
    'mV',
    'kV',
    'MV',
    'pW',
    'nW',
    'microwatt',
    'mW',
    'kW',
    'MW',
    'kOhm',
    'MOhm',
    "a.m.",
    'Bq',
    'cc',
    'cd',
    "C/kg",
    "Co.",
    'dB',
    'Gy',
    'ha',
    'HP',
    'in',
    "K.K.",
    'KM',
    'kt',
    'lm',
    'ln',
    'log',
    'lx',
    'mb',
    'mil',
    'mol',
    'pH',
    "p.m.",
    'PPM',
    'PR',
    'sr',
    'Sv',
    'Wb',
    '[?]',
    '[?]',
    '1d',
    '2d',
    '3d',
    '4d',
    '5d',
    '6d',
    '7d',
    '8d',
    '9d',
    '10d',
    '11d',
    '12d',
    '13d',
    '14d',
    '15d',
    '16d',
    '17d',
    '18d',
    '19d',
    '20d',
    '21d',
    '22d',
    '23d',
    '24d',
    '25d',
    '26d',
    '27d',
    '28d',
    '29d',
    '30d',
    '31d',
    'gal'
];

},{}],"hbylO":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:12:04 MDT"
module.exports = [
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"afUkn":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2014-01-24 23:59:56 MST sburke@cpan.org"
module.exports = [
    'Yi ',
    'Ding ',
    'Kao ',
    'Qi ',
    'Shang ',
    'Xia ',
    "[?] ",
    'Mo ',
    'Zhang ',
    'San ',
    'Shang ',
    'Xia ',
    'Ji ',
    'Bu ',
    'Yu ',
    'Mian ',
    'Gai ',
    'Chou ',
    'Chou ',
    'Zhuan ',
    'Qie ',
    'Pi ',
    'Shi ',
    'Shi ',
    'Qiu ',
    'Bing ',
    'Ye ',
    'Cong ',
    'Dong ',
    'Si ',
    'Cheng ',
    'Diu ',
    'Qiu ',
    'Liang ',
    'Diu ',
    'You ',
    'Liang ',
    'Yan ',
    'Bing ',
    'Sang ',
    'Gun ',
    'Jiu ',
    'Ge ',
    'Ya ',
    'Qiang ',
    'Zhong ',
    'Ji ',
    'Jie ',
    'Feng ',
    'Guan ',
    'Chuan ',
    'Chan ',
    'Lin ',
    'Zhuo ',
    'Zhu ',
    'Ha ',
    'Wan ',
    'Dan ',
    'Wei ',
    'Zhu ',
    'Jing ',
    'Li ',
    'Ju ',
    'Pie ',
    'Fu ',
    'Yi ',
    'Yi ',
    'Nai ',
    'Shime ',
    'Jiu ',
    'Jiu ',
    'Zhe ',
    'Yao ',
    'Yi ',
    "[?] ",
    'Zhi ',
    'Wu ',
    'Zha ',
    'Hu ',
    'Fa ',
    'Le ',
    'Zhong ',
    'Ping ',
    'Pang ',
    'Qiao ',
    'Hu ',
    'Guai ',
    'Cheng ',
    'Cheng ',
    'Yi ',
    'Yin ',
    "[?] ",
    'Mie ',
    'Jiu ',
    'Qi ',
    'Ye ',
    'Xi ',
    'Xiang ',
    'Gai ',
    'Diu ',
    'Hal ',
    "[?] ",
    'Shu ',
    'Twul ',
    'Shi ',
    'Ji ',
    'Nang ',
    'Jia ',
    'Kel ',
    'Shi ',
    "[?] ",
    'Ol ',
    'Mai ',
    'Luan ',
    'Cal ',
    'Ru ',
    'Xue ',
    'Yan ',
    'Fu ',
    'Sha ',
    'Na ',
    'Gan ',
    'Sol ',
    'El ',
    'Cwul ',
    "[?] ",
    'Gan ',
    'Chi ',
    'Gui ',
    'Gan ',
    'Luan ',
    'Lin ',
    'Yi ',
    'Jue ',
    'Liao ',
    'Ma ',
    'Yu ',
    'Zheng ',
    'Shi ',
    'Shi ',
    'Er ',
    'Chu ',
    'Yu ',
    'Yu ',
    'Yu ',
    'Yun ',
    'Hu ',
    'Qi ',
    'Wu ',
    'Jing ',
    'Si ',
    'Sui ',
    'Gen ',
    'Gen ',
    'Ya ',
    'Xie ',
    'Ya ',
    'Qi ',
    'Ya ',
    'Ji ',
    'Tou ',
    'Wang ',
    'Kang ',
    'Ta ',
    'Jiao ',
    'Hai ',
    'Yi ',
    'Chan ',
    'Heng ',
    'Mu ',
    "[?] ",
    'Xiang ',
    'Jing ',
    'Ting ',
    'Liang ',
    'Xiang ',
    'Jing ',
    'Ye ',
    'Qin ',
    'Bo ',
    'You ',
    'Xie ',
    'Dan ',
    'Lian ',
    'Duo ',
    'Wei ',
    'Ren ',
    'Ren ',
    'Ji ',
    'La ',
    'Wang ',
    'Yi ',
    'Shi ',
    'Ren ',
    'Le ',
    'Ding ',
    'Ze ',
    'Jin ',
    'Pu ',
    'Chou ',
    'Ba ',
    'Zhang ',
    'Jin ',
    'Jie ',
    'Bing ',
    'Reng ',
    'Cong ',
    'Fo ',
    'San ',
    'Lun ',
    'Sya ',
    'Cang ',
    'Zi ',
    'Shi ',
    'Ta ',
    'Zhang ',
    'Fu ',
    'Xian ',
    'Xian ',
    'Tuo ',
    'Hong ',
    'Tong ',
    'Ren ',
    'Qian ',
    'Gan ',
    'Yi ',
    'Di ',
    'Dai ',
    'Ling ',
    'Yi ',
    'Chao ',
    'Chang ',
    'Sa ',
    "[?] ",
    'Yi ',
    'Mu ',
    'Men ',
    'Ren ',
    'Jia ',
    'Chao ',
    'Yang ',
    'Qian ',
    'Zhong ',
    'Pi ',
    'Wan ',
    'Wu ',
    'Jian ',
    'Jie ',
    'Yao ',
    'Feng ',
    'Cang ',
    'Ren ',
    'Wang ',
    'Fen ',
    'Di ',
    'Fang '
];

},{}],"6hXSX":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:30 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Zhong ',
    'Qi ',
    'Pei ',
    'Yu ',
    'Diao ',
    'Dun ',
    'Wen ',
    'Yi ',
    'Xin ',
    'Kang ',
    'Yi ',
    'Ji ',
    'Ai ',
    'Wu ',
    'Ji ',
    'Fu ',
    'Fa ',
    'Xiu ',
    'Jin ',
    'Bei ',
    'Dan ',
    'Fu ',
    'Tang ',
    'Zhong ',
    'You ',
    'Huo ',
    'Hui ',
    'Yu ',
    'Cui ',
    'Chuan ',
    'San ',
    'Wei ',
    'Chuan ',
    'Che ',
    'Ya ',
    'Xian ',
    'Shang ',
    'Chang ',
    'Lun ',
    'Cang ',
    'Xun ',
    'Xin ',
    'Wei ',
    'Zhu ',
    "[?] ",
    'Xuan ',
    'Nu ',
    'Bo ',
    'Gu ',
    'Ni ',
    'Ni ',
    'Xie ',
    'Ban ',
    'Xu ',
    'Ling ',
    'Zhou ',
    'Shen ',
    'Qu ',
    'Si ',
    'Beng ',
    'Si ',
    'Jia ',
    'Pi ',
    'Yi ',
    'Si ',
    'Ai ',
    'Zheng ',
    'Dian ',
    'Han ',
    'Mai ',
    'Dan ',
    'Zhu ',
    'Bu ',
    'Qu ',
    'Bi ',
    'Shao ',
    'Ci ',
    'Wei ',
    'Di ',
    'Zhu ',
    'Zuo ',
    'You ',
    'Yang ',
    'Ti ',
    'Zhan ',
    'He ',
    'Bi ',
    'Tuo ',
    'She ',
    'Yu ',
    'Yi ',
    'Fo ',
    'Zuo ',
    'Kou ',
    'Ning ',
    'Tong ',
    'Ni ',
    'Xuan ',
    'Qu ',
    'Yong ',
    'Wa ',
    'Qian ',
    "[?] ",
    'Ka ',
    "[?] ",
    'Pei ',
    'Huai ',
    'He ',
    'Lao ',
    'Xiang ',
    'Ge ',
    'Yang ',
    'Bai ',
    'Fa ',
    'Ming ',
    'Jia ',
    'Er ',
    'Bing ',
    'Ji ',
    'Hen ',
    'Huo ',
    'Gui ',
    'Quan ',
    'Tiao ',
    'Jiao ',
    'Ci ',
    'Yi ',
    'Shi ',
    'Xing ',
    'Shen ',
    'Tuo ',
    'Kan ',
    'Zhi ',
    'Gai ',
    'Lai ',
    'Yi ',
    'Chi ',
    'Kua ',
    'Guang ',
    'Li ',
    'Yin ',
    'Shi ',
    'Mi ',
    'Zhu ',
    'Xu ',
    'You ',
    'An ',
    'Lu ',
    'Mou ',
    'Er ',
    'Lun ',
    'Tong ',
    'Cha ',
    'Chi ',
    'Xun ',
    'Gong ',
    'Zhou ',
    'Yi ',
    'Ru ',
    'Jian ',
    'Xia ',
    'Jia ',
    'Zai ',
    'Lu ',
    'Ko ',
    'Jiao ',
    'Zhen ',
    'Ce ',
    'Qiao ',
    'Kuai ',
    'Chai ',
    'Ning ',
    'Nong ',
    'Jin ',
    'Wu ',
    'Hou ',
    'Jiong ',
    'Cheng ',
    'Zhen ',
    'Zuo ',
    'Chou ',
    'Qin ',
    'Lu ',
    'Ju ',
    'Shu ',
    'Ting ',
    'Shen ',
    'Tuo ',
    'Bo ',
    'Nan ',
    'Hao ',
    'Bian ',
    'Tui ',
    'Yu ',
    'Xi ',
    'Cu ',
    'E ',
    'Qiu ',
    'Xu ',
    'Kuang ',
    'Ku ',
    'Wu ',
    'Jun ',
    'Yi ',
    'Fu ',
    'Lang ',
    'Zu ',
    'Qiao ',
    'Li ',
    'Yong ',
    'Hun ',
    'Jing ',
    'Xian ',
    'San ',
    'Pai ',
    'Su ',
    'Fu ',
    'Xi ',
    'Li ',
    'Fu ',
    'Ping ',
    'Bao ',
    'Yu ',
    'Si ',
    'Xia ',
    'Xin ',
    'Xiu ',
    'Yu ',
    'Ti ',
    'Che ',
    'Chou ',
    "[?] ",
    'Yan ',
    'Lia ',
    'Li ',
    'Lai ',
    "[?] ",
    'Jian ',
    'Xiu ',
    'Fu ',
    'He ',
    'Ju ',
    'Xiao ',
    'Pai ',
    'Jian ',
    'Biao ',
    'Chu ',
    'Fei ',
    'Feng ',
    'Ya ',
    'An ',
    'Bei ',
    'Yu ',
    'Xin ',
    'Bi ',
    'Jian '
];

},{}],"iMCqY":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:30 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Chang ',
    'Chi ',
    'Bing ',
    'Zan ',
    'Yao ',
    'Cui ',
    'Lia ',
    'Wan ',
    'Lai ',
    'Cang ',
    'Zong ',
    'Ge ',
    'Guan ',
    'Bei ',
    'Tian ',
    'Shu ',
    'Shu ',
    'Men ',
    'Dao ',
    'Tan ',
    'Jue ',
    'Chui ',
    'Xing ',
    'Peng ',
    'Tang ',
    'Hou ',
    'Yi ',
    'Qi ',
    'Ti ',
    'Gan ',
    'Jing ',
    'Jie ',
    'Sui ',
    'Chang ',
    'Jie ',
    'Fang ',
    'Zhi ',
    'Kong ',
    'Juan ',
    'Zong ',
    'Ju ',
    'Qian ',
    'Ni ',
    'Lun ',
    'Zhuo ',
    'Wei ',
    'Luo ',
    'Song ',
    'Leng ',
    'Hun ',
    'Dong ',
    'Zi ',
    'Ben ',
    'Wu ',
    'Ju ',
    'Nai ',
    'Cai ',
    'Jian ',
    'Zhai ',
    'Ye ',
    'Zhi ',
    'Sha ',
    'Qing ',
    "[?] ",
    'Ying ',
    'Cheng ',
    'Jian ',
    'Yan ',
    'Nuan ',
    'Zhong ',
    'Chun ',
    'Jia ',
    'Jie ',
    'Wei ',
    'Yu ',
    'Bing ',
    'Ruo ',
    'Ti ',
    'Wei ',
    'Pian ',
    'Yan ',
    'Feng ',
    'Tang ',
    'Wo ',
    'E ',
    'Xie ',
    'Che ',
    'Sheng ',
    'Kan ',
    'Di ',
    'Zuo ',
    'Cha ',
    'Ting ',
    'Bei ',
    'Ye ',
    'Huang ',
    'Yao ',
    'Zhan ',
    'Chou ',
    'Yan ',
    'You ',
    'Jian ',
    'Xu ',
    'Zha ',
    'Ci ',
    'Fu ',
    'Bi ',
    'Zhi ',
    'Zong ',
    'Mian ',
    'Ji ',
    'Yi ',
    'Xie ',
    'Xun ',
    'Si ',
    'Duan ',
    'Ce ',
    'Zhen ',
    'Ou ',
    'Tou ',
    'Tou ',
    'Bei ',
    'Za ',
    'Lu ',
    'Jie ',
    'Wei ',
    'Fen ',
    'Chang ',
    'Gui ',
    'Sou ',
    'Zhi ',
    'Su ',
    'Xia ',
    'Fu ',
    'Yuan ',
    'Rong ',
    'Li ',
    'Ru ',
    'Yun ',
    'Gou ',
    'Ma ',
    'Bang ',
    'Dian ',
    'Tang ',
    'Hao ',
    'Jie ',
    'Xi ',
    'Shan ',
    'Qian ',
    'Jue ',
    'Cang ',
    'Chu ',
    'San ',
    'Bei ',
    'Xiao ',
    'Yong ',
    'Yao ',
    'Tan ',
    'Suo ',
    'Yang ',
    'Fa ',
    'Bing ',
    'Jia ',
    'Dai ',
    'Zai ',
    'Tang ',
    "[?] ",
    'Bin ',
    'Chu ',
    'Nuo ',
    'Can ',
    'Lei ',
    'Cui ',
    'Yong ',
    'Zao ',
    'Zong ',
    'Peng ',
    'Song ',
    'Ao ',
    'Chuan ',
    'Yu ',
    'Zhai ',
    'Cou ',
    'Shang ',
    'Qiang ',
    'Jing ',
    'Chi ',
    'Sha ',
    'Han ',
    'Zhang ',
    'Qing ',
    'Yan ',
    'Di ',
    'Xi ',
    'Lu ',
    'Bei ',
    'Piao ',
    'Jin ',
    'Lian ',
    'Lu ',
    'Man ',
    'Qian ',
    'Xian ',
    'Tan ',
    'Ying ',
    'Dong ',
    'Zhuan ',
    'Xiang ',
    'Shan ',
    'Qiao ',
    'Jiong ',
    'Tui ',
    'Zun ',
    'Pu ',
    'Xi ',
    'Lao ',
    'Chang ',
    'Guang ',
    'Liao ',
    'Qi ',
    'Deng ',
    'Chan ',
    'Wei ',
    'Ji ',
    'Fan ',
    'Hui ',
    'Chuan ',
    'Jian ',
    'Dan ',
    'Jiao ',
    'Jiu ',
    'Seng ',
    'Fen ',
    'Xian ',
    'Jue ',
    'E ',
    'Jiao ',
    'Jian ',
    'Tong ',
    'Lin ',
    'Bo ',
    'Gu ',
    "[?] ",
    'Su ',
    'Xian ',
    'Jiang ',
    'Min ',
    'Ye ',
    'Jin ',
    'Jia ',
    'Qiao ',
    'Pi ',
    'Feng ',
    'Zhou ',
    'Ai ',
    'Sai '
];

},{}],"6FVQM":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:30 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Yi ',
    'Jun ',
    'Nong ',
    'Chan ',
    'Yi ',
    'Dang ',
    'Jing ',
    'Xuan ',
    'Kuai ',
    'Jian ',
    'Chu ',
    'Dan ',
    'Jiao ',
    'Sha ',
    'Zai ',
    "[?] ",
    'Bin ',
    'An ',
    'Ru ',
    'Tai ',
    'Chou ',
    'Chai ',
    'Lan ',
    'Ni ',
    'Jin ',
    'Qian ',
    'Meng ',
    'Wu ',
    'Ning ',
    'Qiong ',
    'Ni ',
    'Chang ',
    'Lie ',
    'Lei ',
    'Lu ',
    'Kuang ',
    'Bao ',
    'Du ',
    'Biao ',
    'Zan ',
    'Zhi ',
    'Si ',
    'You ',
    'Hao ',
    'Chen ',
    'Chen ',
    'Li ',
    'Teng ',
    'Wei ',
    'Long ',
    'Chu ',
    'Chan ',
    'Rang ',
    'Shu ',
    'Hui ',
    'Li ',
    'Luo ',
    'Zan ',
    'Nuo ',
    'Tang ',
    'Yan ',
    'Lei ',
    'Nang ',
    'Er ',
    'Wu ',
    'Yun ',
    'Zan ',
    'Yuan ',
    'Xiong ',
    'Chong ',
    'Zhao ',
    'Xiong ',
    'Xian ',
    'Guang ',
    'Dui ',
    'Ke ',
    'Dui ',
    'Mian ',
    'Tu ',
    'Chang ',
    'Er ',
    'Dui ',
    'Er ',
    'Xin ',
    'Tu ',
    'Si ',
    'Yan ',
    'Yan ',
    'Shi ',
    'Shi ',
    'Dang ',
    'Qian ',
    'Dou ',
    'Fen ',
    'Mao ',
    'Shen ',
    'Dou ',
    'Bai ',
    'Jing ',
    'Li ',
    'Huang ',
    'Ru ',
    'Wang ',
    'Nei ',
    'Quan ',
    'Liang ',
    'Yu ',
    'Ba ',
    'Gong ',
    'Liu ',
    'Xi ',
    "[?] ",
    'Lan ',
    'Gong ',
    'Tian ',
    'Guan ',
    'Xing ',
    'Bing ',
    'Qi ',
    'Ju ',
    'Dian ',
    'Zi ',
    'Ppwun ',
    'Yang ',
    'Jian ',
    'Shou ',
    'Ji ',
    'Yi ',
    'Ji ',
    'Chan ',
    'Jiong ',
    'Mao ',
    'Ran ',
    'Nei ',
    'Yuan ',
    'Mao ',
    'Gang ',
    'Ran ',
    'Ce ',
    'Jiong ',
    'Ce ',
    'Zai ',
    'Gua ',
    'Jiong ',
    'Mao ',
    'Zhou ',
    'Mou ',
    'Gou ',
    'Xu ',
    'Mian ',
    'Mi ',
    'Rong ',
    'Yin ',
    'Xie ',
    'Kan ',
    'Jun ',
    'Nong ',
    'Yi ',
    'Mi ',
    'Shi ',
    'Guan ',
    'Meng ',
    'Zhong ',
    'Ju ',
    'Yuan ',
    'Ming ',
    'Kou ',
    'Lam ',
    'Fu ',
    'Xie ',
    'Mi ',
    'Bing ',
    'Dong ',
    'Tai ',
    'Gang ',
    'Feng ',
    'Bing ',
    'Hu ',
    'Chong ',
    'Jue ',
    'Hu ',
    'Kuang ',
    'Ye ',
    'Leng ',
    'Pan ',
    'Fu ',
    'Min ',
    'Dong ',
    'Xian ',
    'Lie ',
    'Xia ',
    'Jian ',
    'Jing ',
    'Shu ',
    'Mei ',
    'Tu ',
    'Qi ',
    'Gu ',
    'Zhun ',
    'Song ',
    'Jing ',
    'Liang ',
    'Qing ',
    'Diao ',
    'Ling ',
    'Dong ',
    'Gan ',
    'Jian ',
    'Yin ',
    'Cou ',
    'Yi ',
    'Li ',
    'Cang ',
    'Ming ',
    'Zhuen ',
    'Cui ',
    'Si ',
    'Duo ',
    'Jin ',
    'Lin ',
    'Lin ',
    'Ning ',
    'Xi ',
    'Du ',
    'Ji ',
    'Fan ',
    'Fan ',
    'Fan ',
    'Feng ',
    'Ju ',
    'Chu ',
    'Tako ',
    'Feng ',
    'Mok ',
    'Ci ',
    'Fu ',
    'Feng ',
    'Ping ',
    'Feng ',
    'Kai ',
    'Huang ',
    'Kai ',
    'Gan ',
    'Deng ',
    'Ping ',
    'Qu ',
    'Xiong ',
    'Kuai ',
    'Tu ',
    'Ao ',
    'Chu ',
    'Ji ',
    'Dang ',
    'Han ',
    'Han ',
    'Zao '
];

},{}],"1ViFw":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:30 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Dao ',
    'Diao ',
    'Dao ',
    'Ren ',
    'Ren ',
    'Chuang ',
    'Fen ',
    'Qie ',
    'Yi ',
    'Ji ',
    'Kan ',
    'Qian ',
    'Cun ',
    'Chu ',
    'Wen ',
    'Ji ',
    'Dan ',
    'Xing ',
    'Hua ',
    'Wan ',
    'Jue ',
    'Li ',
    'Yue ',
    'Lie ',
    'Liu ',
    'Ze ',
    'Gang ',
    'Chuang ',
    'Fu ',
    'Chu ',
    'Qu ',
    'Ju ',
    'Shan ',
    'Min ',
    'Ling ',
    'Zhong ',
    'Pan ',
    'Bie ',
    'Jie ',
    'Jie ',
    'Bao ',
    'Li ',
    'Shan ',
    'Bie ',
    'Chan ',
    'Jing ',
    'Gua ',
    'Gen ',
    'Dao ',
    'Chuang ',
    'Kui ',
    'Ku ',
    'Duo ',
    'Er ',
    'Zhi ',
    'Shua ',
    'Quan ',
    'Cha ',
    'Ci ',
    'Ke ',
    'Jie ',
    'Gui ',
    'Ci ',
    'Gui ',
    'Kai ',
    'Duo ',
    'Ji ',
    'Ti ',
    'Jing ',
    'Lou ',
    'Gen ',
    'Ze ',
    'Yuan ',
    'Cuo ',
    'Xue ',
    'Ke ',
    'La ',
    'Qian ',
    'Cha ',
    'Chuang ',
    'Gua ',
    'Jian ',
    'Cuo ',
    'Li ',
    'Ti ',
    'Fei ',
    'Pou ',
    'Chan ',
    'Qi ',
    'Chuang ',
    'Zi ',
    'Gang ',
    'Wan ',
    'Bo ',
    'Ji ',
    'Duo ',
    'Qing ',
    'Yan ',
    'Zhuo ',
    'Jian ',
    'Ji ',
    'Bo ',
    'Yan ',
    'Ju ',
    'Huo ',
    'Sheng ',
    'Jian ',
    'Duo ',
    'Duan ',
    'Wu ',
    'Gua ',
    'Fu ',
    'Sheng ',
    'Jian ',
    'Ge ',
    'Zha ',
    'Kai ',
    'Chuang ',
    'Juan ',
    'Chan ',
    'Tuan ',
    'Lu ',
    'Li ',
    'Fou ',
    'Shan ',
    'Piao ',
    'Kou ',
    'Jiao ',
    'Gua ',
    'Qiao ',
    'Jue ',
    'Hua ',
    'Zha ',
    'Zhuo ',
    'Lian ',
    'Ju ',
    'Pi ',
    'Liu ',
    'Gui ',
    'Jiao ',
    'Gui ',
    'Jian ',
    'Jian ',
    'Tang ',
    'Huo ',
    'Ji ',
    'Jian ',
    'Yi ',
    'Jian ',
    'Zhi ',
    'Chan ',
    'Cuan ',
    'Mo ',
    'Li ',
    'Zhu ',
    'Li ',
    'Ya ',
    'Quan ',
    'Ban ',
    'Gong ',
    'Jia ',
    'Wu ',
    'Mai ',
    'Lie ',
    'Jin ',
    'Keng ',
    'Xie ',
    'Zhi ',
    'Dong ',
    'Zhu ',
    'Nu ',
    'Jie ',
    'Qu ',
    'Shao ',
    'Yi ',
    'Zhu ',
    'Miao ',
    'Li ',
    'Jing ',
    'Lao ',
    'Lao ',
    'Juan ',
    'Kou ',
    'Yang ',
    'Wa ',
    'Xiao ',
    'Mou ',
    'Kuang ',
    'Jie ',
    'Lie ',
    'He ',
    'Shi ',
    'Ke ',
    'Jing ',
    'Hao ',
    'Bo ',
    'Min ',
    'Chi ',
    'Lang ',
    'Yong ',
    'Yong ',
    'Mian ',
    'Ke ',
    'Xun ',
    'Juan ',
    'Qing ',
    'Lu ',
    'Pou ',
    'Meng ',
    'Lai ',
    'Le ',
    'Kai ',
    'Mian ',
    'Dong ',
    'Xu ',
    'Xu ',
    'Kan ',
    'Wu ',
    'Yi ',
    'Xun ',
    'Weng ',
    'Sheng ',
    'Lao ',
    'Mu ',
    'Lu ',
    'Piao ',
    'Shi ',
    'Ji ',
    'Qin ',
    'Qiang ',
    'Jiao ',
    'Quan ',
    'Yang ',
    'Yi ',
    'Jue ',
    'Fan ',
    'Juan ',
    'Tong ',
    'Ju ',
    'Dan ',
    'Xie ',
    'Mai ',
    'Xun ',
    'Xun ',
    'Lu ',
    'Li ',
    'Che ',
    'Rang ',
    'Quan ',
    'Bao ',
    'Shao ',
    'Yun ',
    'Jiu ',
    'Bao ',
    'Gou ',
    'Wu '
];

},{}],"4n55g":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:30 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Yun ',
    'Mwun ',
    'Nay ',
    'Gai ',
    'Gai ',
    'Bao ',
    'Cong ',
    "[?] ",
    'Xiong ',
    'Peng ',
    'Ju ',
    'Tao ',
    'Ge ',
    'Pu ',
    'An ',
    'Pao ',
    'Fu ',
    'Gong ',
    'Da ',
    'Jiu ',
    'Qiong ',
    'Bi ',
    'Hua ',
    'Bei ',
    'Nao ',
    'Chi ',
    'Fang ',
    'Jiu ',
    'Yi ',
    'Za ',
    'Jiang ',
    'Kang ',
    'Jiang ',
    'Kuang ',
    'Hu ',
    'Xia ',
    'Qu ',
    'Bian ',
    'Gui ',
    'Qie ',
    'Zang ',
    'Kuang ',
    'Fei ',
    'Hu ',
    'Tou ',
    'Gui ',
    'Gui ',
    'Hui ',
    'Dan ',
    'Gui ',
    'Lian ',
    'Lian ',
    'Suan ',
    'Du ',
    'Jiu ',
    'Qu ',
    'Xi ',
    'Pi ',
    'Qu ',
    'Yi ',
    'Qia ',
    'Yan ',
    'Bian ',
    'Ni ',
    'Qu ',
    'Shi ',
    'Xin ',
    'Qian ',
    'Nian ',
    'Sa ',
    'Zu ',
    'Sheng ',
    'Wu ',
    'Hui ',
    'Ban ',
    'Shi ',
    'Xi ',
    'Wan ',
    'Hua ',
    'Xie ',
    'Wan ',
    'Bei ',
    'Zu ',
    'Zhuo ',
    'Xie ',
    'Dan ',
    'Mai ',
    'Nan ',
    'Dan ',
    'Ji ',
    'Bo ',
    'Shuai ',
    'Bu ',
    'Kuang ',
    'Bian ',
    'Bu ',
    'Zhan ',
    'Qia ',
    'Lu ',
    'You ',
    'Lu ',
    'Xi ',
    'Gua ',
    'Wo ',
    'Xie ',
    'Jie ',
    'Jie ',
    'Wei ',
    'Ang ',
    'Qiong ',
    'Zhi ',
    'Mao ',
    'Yin ',
    'Wei ',
    'Shao ',
    'Ji ',
    'Que ',
    'Luan ',
    'Shi ',
    'Juan ',
    'Xie ',
    'Xu ',
    'Jin ',
    'Que ',
    'Wu ',
    'Ji ',
    'E ',
    'Qing ',
    'Xi ',
    "[?] ",
    'Han ',
    'Zhan ',
    'E ',
    'Ting ',
    'Li ',
    'Zhe ',
    'Han ',
    'Li ',
    'Ya ',
    'Ya ',
    'Yan ',
    'She ',
    'Zhi ',
    'Zha ',
    'Pang ',
    "[?] ",
    'He ',
    'Ya ',
    'Zhi ',
    'Ce ',
    'Pang ',
    'Ti ',
    'Li ',
    'She ',
    'Hou ',
    'Ting ',
    'Zui ',
    'Cuo ',
    'Fei ',
    'Yuan ',
    'Ce ',
    'Yuan ',
    'Xiang ',
    'Yan ',
    'Li ',
    'Jue ',
    'Sha ',
    'Dian ',
    'Chu ',
    'Jiu ',
    'Qin ',
    'Ao ',
    'Gui ',
    'Yan ',
    'Si ',
    'Li ',
    'Chang ',
    'Lan ',
    'Li ',
    'Yan ',
    'Yan ',
    'Yuan ',
    'Si ',
    'Gong ',
    'Lin ',
    'Qiu ',
    'Qu ',
    'Qu ',
    'Uk ',
    'Lei ',
    'Du ',
    'Xian ',
    'Zhuan ',
    'San ',
    'Can ',
    'Can ',
    'Can ',
    'Can ',
    'Ai ',
    'Dai ',
    'You ',
    'Cha ',
    'Ji ',
    'You ',
    'Shuang ',
    'Fan ',
    'Shou ',
    'Guai ',
    'Ba ',
    'Fa ',
    'Ruo ',
    'Shi ',
    'Shu ',
    'Zhuo ',
    'Qu ',
    'Shou ',
    'Bian ',
    'Xu ',
    'Jia ',
    'Pan ',
    'Sou ',
    'Gao ',
    'Wei ',
    'Sou ',
    'Die ',
    'Rui ',
    'Cong ',
    'Kou ',
    'Gu ',
    'Ju ',
    'Ling ',
    'Gua ',
    'Tao ',
    'Kou ',
    'Zhi ',
    'Jiao ',
    'Zhao ',
    'Ba ',
    'Ding ',
    'Ke ',
    'Tai ',
    'Chi ',
    'Shi ',
    'You ',
    'Qiu ',
    'Po ',
    'Xie ',
    'Hao ',
    'Si ',
    'Tan ',
    'Chi ',
    'Le ',
    'Diao ',
    'Ji ',
    "[?] ",
    'Hong '
];

},{}],"6tTi7":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:30 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Mie ',
    'Xu ',
    'Mang ',
    'Chi ',
    'Ge ',
    'Xuan ',
    'Yao ',
    'Zi ',
    'He ',
    'Ji ',
    'Diao ',
    'Cun ',
    'Tong ',
    'Ming ',
    'Hou ',
    'Li ',
    'Tu ',
    'Xiang ',
    'Zha ',
    'Xia ',
    'Ye ',
    'Lu ',
    'A ',
    'Ma ',
    'Ou ',
    'Xue ',
    'Yi ',
    'Jun ',
    'Chou ',
    'Lin ',
    'Tun ',
    'Yin ',
    'Fei ',
    'Bi ',
    'Qin ',
    'Qin ',
    'Jie ',
    'Bu ',
    'Fou ',
    'Ba ',
    'Dun ',
    'Fen ',
    'E ',
    'Han ',
    'Ting ',
    'Hang ',
    'Shun ',
    'Qi ',
    'Hong ',
    'Zhi ',
    'Shen ',
    'Wu ',
    'Wu ',
    'Chao ',
    'Ne ',
    'Xue ',
    'Xi ',
    'Chui ',
    'Dou ',
    'Wen ',
    'Hou ',
    'Ou ',
    'Wu ',
    'Gao ',
    'Ya ',
    'Jun ',
    'Lu ',
    'E ',
    'Ge ',
    'Mei ',
    'Ai ',
    'Qi ',
    'Cheng ',
    'Wu ',
    'Gao ',
    'Fu ',
    'Jiao ',
    'Hong ',
    'Chi ',
    'Sheng ',
    'Ne ',
    'Tun ',
    'Fu ',
    'Yi ',
    'Dai ',
    'Ou ',
    'Li ',
    'Bai ',
    'Yuan ',
    'Kuai ',
    "[?] ",
    'Qiang ',
    'Wu ',
    'E ',
    'Shi ',
    'Quan ',
    'Pen ',
    'Wen ',
    'Ni ',
    'M ',
    'Ling ',
    'Ran ',
    'You ',
    'Di ',
    'Zhou ',
    'Shi ',
    'Zhou ',
    'Tie ',
    'Xi ',
    'Yi ',
    'Qi ',
    'Ping ',
    'Zi ',
    'Gu ',
    'Zi ',
    'Wei ',
    'Xu ',
    'He ',
    'Nao ',
    'Xia ',
    'Pei ',
    'Yi ',
    'Xiao ',
    'Shen ',
    'Hu ',
    'Ming ',
    'Da ',
    'Qu ',
    'Ju ',
    'Gem ',
    'Za ',
    'Tuo ',
    'Duo ',
    'Pou ',
    'Pao ',
    'Bi ',
    'Fu ',
    'Yang ',
    'He ',
    'Zha ',
    'He ',
    'Hai ',
    'Jiu ',
    'Yong ',
    'Fu ',
    'Que ',
    'Zhou ',
    'Wa ',
    'Ka ',
    'Gu ',
    'Ka ',
    'Zuo ',
    'Bu ',
    'Long ',
    'Dong ',
    'Ning ',
    'Tha ',
    'Si ',
    'Xian ',
    'Huo ',
    'Qi ',
    'Er ',
    'E ',
    'Guang ',
    'Zha ',
    'Xi ',
    'Yi ',
    'Lie ',
    'Zi ',
    'Mie ',
    'Mi ',
    'Zhi ',
    'Yao ',
    'Ji ',
    'Zhou ',
    'Ge ',
    'Shuai ',
    'Zan ',
    'Xiao ',
    'Ke ',
    'Hui ',
    'Kua ',
    'Huai ',
    'Tao ',
    'Xian ',
    'E ',
    'Xuan ',
    'Xiu ',
    'Wai ',
    'Yan ',
    'Lao ',
    'Yi ',
    'Ai ',
    'Pin ',
    'Shen ',
    'Tong ',
    'Hong ',
    'Xiong ',
    'Chi ',
    'Wa ',
    'Ha ',
    'Zai ',
    'Yu ',
    'Di ',
    'Pai ',
    'Xiang ',
    'Ai ',
    'Hen ',
    'Kuang ',
    'Ya ',
    'Da ',
    'Xiao ',
    'Bi ',
    'Yue ',
    "[?] ",
    'Hua ',
    'Sasou ',
    'Kuai ',
    'Duo ',
    "[?] ",
    'Ji ',
    'Nong ',
    'Mou ',
    'Yo ',
    'Hao ',
    'Yuan ',
    'Long ',
    'Pou ',
    'Mang ',
    'Ge ',
    'E ',
    'Chi ',
    'Shao ',
    'Li ',
    'Na ',
    'Zu ',
    'He ',
    'Ku ',
    'Xiao ',
    'Xian ',
    'Lao ',
    'Bo ',
    'Zhe ',
    'Zha ',
    'Liang ',
    'Ba ',
    'Mie ',
    'Le ',
    'Sui ',
    'Fou ',
    'Bu ',
    'Han ',
    'Heng ',
    'Geng ',
    'Shuo ',
    'Ge '
];

},{}],"2rZIo":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:30 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'You ',
    'Yan ',
    'Gu ',
    'Gu ',
    'Bai ',
    'Han ',
    'Suo ',
    'Chun ',
    'Yi ',
    'Ai ',
    'Jia ',
    'Tu ',
    'Xian ',
    'Huan ',
    'Li ',
    'Xi ',
    'Tang ',
    'Zuo ',
    'Qiu ',
    'Che ',
    'Wu ',
    'Zao ',
    'Ya ',
    'Dou ',
    'Qi ',
    'Di ',
    'Qin ',
    'Ma ',
    'Mal ',
    'Hong ',
    'Dou ',
    'Kes ',
    'Lao ',
    'Liang ',
    'Suo ',
    'Zao ',
    'Huan ',
    'Lang ',
    'Sha ',
    'Ji ',
    'Zuo ',
    'Wo ',
    'Feng ',
    'Yin ',
    'Hu ',
    'Qi ',
    'Shou ',
    'Wei ',
    'Shua ',
    'Chang ',
    'Er ',
    'Li ',
    'Qiang ',
    'An ',
    'Jie ',
    'Yo ',
    'Nian ',
    'Yu ',
    'Tian ',
    'Lai ',
    'Sha ',
    'Xi ',
    'Tuo ',
    'Hu ',
    'Ai ',
    'Zhou ',
    'Nou ',
    'Ken ',
    'Zhuo ',
    'Zhuo ',
    'Shang ',
    'Di ',
    'Heng ',
    'Lan ',
    'A ',
    'Xiao ',
    'Xiang ',
    'Tun ',
    'Wu ',
    'Wen ',
    'Cui ',
    'Sha ',
    'Hu ',
    'Qi ',
    'Qi ',
    'Tao ',
    'Dan ',
    'Dan ',
    'Ye ',
    'Zi ',
    'Bi ',
    'Cui ',
    'Chuo ',
    'He ',
    'Ya ',
    'Qi ',
    'Zhe ',
    'Pei ',
    'Liang ',
    'Xian ',
    'Pi ',
    'Sha ',
    'La ',
    'Ze ',
    'Qing ',
    'Gua ',
    'Pa ',
    'Zhe ',
    'Se ',
    'Zhuan ',
    'Nie ',
    'Guo ',
    'Luo ',
    'Yan ',
    'Di ',
    'Quan ',
    'Tan ',
    'Bo ',
    'Ding ',
    'Lang ',
    'Xiao ',
    "[?] ",
    'Tang ',
    'Chi ',
    'Ti ',
    'An ',
    'Jiu ',
    'Dan ',
    'Ke ',
    'Yong ',
    'Wei ',
    'Nan ',
    'Shan ',
    'Yu ',
    'Zhe ',
    'La ',
    'Jie ',
    'Hou ',
    'Han ',
    'Die ',
    'Zhou ',
    'Chai ',
    'Wai ',
    'Re ',
    'Yu ',
    'Yin ',
    'Zan ',
    'Yao ',
    'Wo ',
    'Mian ',
    'Hu ',
    'Yun ',
    'Chuan ',
    'Hui ',
    'Huan ',
    'Huan ',
    'Xi ',
    'He ',
    'Ji ',
    'Kui ',
    'Zhong ',
    'Wei ',
    'Sha ',
    'Xu ',
    'Huang ',
    'Du ',
    'Nie ',
    'Xuan ',
    'Liang ',
    'Yu ',
    'Sang ',
    'Chi ',
    'Qiao ',
    'Yan ',
    'Dan ',
    'Pen ',
    'Can ',
    'Li ',
    'Yo ',
    'Zha ',
    'Wei ',
    'Miao ',
    'Ying ',
    'Pen ',
    'Phos ',
    'Kui ',
    'Xi ',
    'Yu ',
    'Jie ',
    'Lou ',
    'Ku ',
    'Sao ',
    'Huo ',
    'Ti ',
    'Yao ',
    'He ',
    'A ',
    'Xiu ',
    'Qiang ',
    'Se ',
    'Yong ',
    'Su ',
    'Hong ',
    'Xie ',
    'Yi ',
    'Suo ',
    'Ma ',
    'Cha ',
    'Hai ',
    'Ke ',
    'Ta ',
    'Sang ',
    'Tian ',
    'Ru ',
    'Sou ',
    'Wa ',
    'Ji ',
    'Pang ',
    'Wu ',
    'Xian ',
    'Shi ',
    'Ge ',
    'Zi ',
    'Jie ',
    'Luo ',
    'Weng ',
    'Wa ',
    'Si ',
    'Chi ',
    'Hao ',
    'Suo ',
    'Jia ',
    'Hai ',
    'Suo ',
    'Qin ',
    'Nie ',
    'He ',
    'Cis ',
    'Sai ',
    'Ng ',
    'Ge ',
    'Na ',
    'Dia ',
    'Ai ',
    "[?] ",
    'Tong ',
    'Bi ',
    'Ao ',
    'Ao ',
    'Lian ',
    'Cui ',
    'Zhe ',
    'Mo ',
    'Sou ',
    'Sou ',
    'Tan '
];

},{}],"7jLq7":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:30 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Di ',
    'Qi ',
    'Jiao ',
    'Chong ',
    'Jiao ',
    'Kai ',
    'Tan ',
    'San ',
    'Cao ',
    'Jia ',
    'Ai ',
    'Xiao ',
    'Piao ',
    'Lou ',
    'Ga ',
    'Gu ',
    'Xiao ',
    'Hu ',
    'Hui ',
    'Guo ',
    'Ou ',
    'Xian ',
    'Ze ',
    'Chang ',
    'Xu ',
    'Po ',
    'De ',
    'Ma ',
    'Ma ',
    'Hu ',
    'Lei ',
    'Du ',
    'Ga ',
    'Tang ',
    'Ye ',
    'Beng ',
    'Ying ',
    'Saai ',
    'Jiao ',
    'Mi ',
    'Xiao ',
    'Hua ',
    'Mai ',
    'Ran ',
    'Zuo ',
    'Peng ',
    'Lao ',
    'Xiao ',
    'Ji ',
    'Zhu ',
    'Chao ',
    'Kui ',
    'Zui ',
    'Xiao ',
    'Si ',
    'Hao ',
    'Fu ',
    'Liao ',
    'Qiao ',
    'Xi ',
    'Xiu ',
    'Tan ',
    'Tan ',
    'Mo ',
    'Xun ',
    'E ',
    'Zun ',
    'Fan ',
    'Chi ',
    'Hui ',
    'Zan ',
    'Chuang ',
    'Cu ',
    'Dan ',
    'Yu ',
    'Tun ',
    'Cheng ',
    'Jiao ',
    'Ye ',
    'Xi ',
    'Qi ',
    'Hao ',
    'Lian ',
    'Xu ',
    'Deng ',
    'Hui ',
    'Yin ',
    'Pu ',
    'Jue ',
    'Qin ',
    'Xun ',
    'Nie ',
    'Lu ',
    'Si ',
    'Yan ',
    'Ying ',
    'Da ',
    'Dan ',
    'Yu ',
    'Zhou ',
    'Jin ',
    'Nong ',
    'Yue ',
    'Hui ',
    'Qi ',
    'E ',
    'Zao ',
    'Yi ',
    'Shi ',
    'Jiao ',
    'Yuan ',
    'Ai ',
    'Yong ',
    'Jue ',
    'Kuai ',
    'Yu ',
    'Pen ',
    'Dao ',
    'Ge ',
    'Xin ',
    'Dun ',
    'Dang ',
    'Sin ',
    'Sai ',
    'Pi ',
    'Pi ',
    'Yin ',
    'Zui ',
    'Ning ',
    'Di ',
    'Lan ',
    'Ta ',
    'Huo ',
    'Ru ',
    'Hao ',
    'Xia ',
    'Ya ',
    'Duo ',
    'Xi ',
    'Chou ',
    'Ji ',
    'Jin ',
    'Hao ',
    'Ti ',
    'Chang ',
    "[?] ",
    "[?] ",
    'Ca ',
    'Ti ',
    'Lu ',
    'Hui ',
    'Bo ',
    'You ',
    'Nie ',
    'Yin ',
    'Hu ',
    'Mo ',
    'Huang ',
    'Zhe ',
    'Li ',
    'Liu ',
    'Haai ',
    'Nang ',
    'Xiao ',
    'Mo ',
    'Yan ',
    'Li ',
    'Lu ',
    'Long ',
    'Fu ',
    'Dan ',
    'Chen ',
    'Pin ',
    'Pi ',
    'Xiang ',
    'Huo ',
    'Mo ',
    'Xi ',
    'Duo ',
    'Ku ',
    'Yan ',
    'Chan ',
    'Ying ',
    'Rang ',
    'Dian ',
    'La ',
    'Ta ',
    'Xiao ',
    'Jiao ',
    'Chuo ',
    'Huan ',
    'Huo ',
    'Zhuan ',
    'Nie ',
    'Xiao ',
    'Ca ',
    'Li ',
    'Chan ',
    'Chai ',
    'Li ',
    'Yi ',
    'Luo ',
    'Nang ',
    'Zan ',
    'Su ',
    'Xi ',
    'So ',
    'Jian ',
    'Za ',
    'Zhu ',
    'Lan ',
    'Nie ',
    'Nang ',
    "[?] ",
    "[?] ",
    'Wei ',
    'Hui ',
    'Yin ',
    'Qiu ',
    'Si ',
    'Nin ',
    'Jian ',
    'Hui ',
    'Xin ',
    'Yin ',
    'Nan ',
    'Tuan ',
    'Tuan ',
    'Dun ',
    'Kang ',
    'Yuan ',
    'Jiong ',
    'Pian ',
    'Yun ',
    'Cong ',
    'Hu ',
    'Hui ',
    'Yuan ',
    'You ',
    'Guo ',
    'Kun ',
    'Cong ',
    'Wei ',
    'Tu ',
    'Wei ',
    'Lun ',
    'Guo ',
    'Qun ',
    'Ri ',
    'Ling ',
    'Gu ',
    'Guo ',
    'Tai ',
    'Guo ',
    'Tu ',
    'You '
];

},{}],"91Fbs":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:30 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Guo ',
    'Yin ',
    'Hun ',
    'Pu ',
    'Yu ',
    'Han ',
    'Yuan ',
    'Lun ',
    'Quan ',
    'Yu ',
    'Qing ',
    'Guo ',
    'Chuan ',
    'Wei ',
    'Yuan ',
    'Quan ',
    'Ku ',
    'Fu ',
    'Yuan ',
    'Yuan ',
    'E ',
    'Tu ',
    'Tu ',
    'Tu ',
    'Tuan ',
    'Lue ',
    'Hui ',
    'Yi ',
    'Yuan ',
    'Luan ',
    'Luan ',
    'Tu ',
    'Ya ',
    'Tu ',
    'Ting ',
    'Sheng ',
    'Pu ',
    'Lu ',
    'Iri ',
    'Ya ',
    'Zai ',
    'Wei ',
    'Ge ',
    'Yu ',
    'Wu ',
    'Gui ',
    'Pi ',
    'Yi ',
    'Di ',
    'Qian ',
    'Qian ',
    'Zhen ',
    'Zhuo ',
    'Dang ',
    'Qia ',
    'Akutsu ',
    'Yama ',
    'Kuang ',
    'Chang ',
    'Qi ',
    'Nie ',
    'Mo ',
    'Ji ',
    'Jia ',
    'Zhi ',
    'Zhi ',
    'Ban ',
    'Xun ',
    'Tou ',
    'Qin ',
    'Fen ',
    'Jun ',
    'Keng ',
    'Tun ',
    'Fang ',
    'Fen ',
    'Ben ',
    'Tan ',
    'Kan ',
    'Pi ',
    'Zuo ',
    'Keng ',
    'Bi ',
    'Xing ',
    'Di ',
    'Jing ',
    'Ji ',
    'Kuai ',
    'Di ',
    'Jing ',
    'Jian ',
    'Tan ',
    'Li ',
    'Ba ',
    'Wu ',
    'Fen ',
    'Zhui ',
    'Po ',
    'Pan ',
    'Tang ',
    'Kun ',
    'Qu ',
    'Tan ',
    'Zhi ',
    'Tuo ',
    'Gan ',
    'Ping ',
    'Dian ',
    'Gua ',
    'Ni ',
    'Tai ',
    'Pi ',
    'Jiong ',
    'Yang ',
    'Fo ',
    'Ao ',
    'Liu ',
    'Qiu ',
    'Mu ',
    'Ke ',
    'Gou ',
    'Xue ',
    'Ba ',
    'Chi ',
    'Che ',
    'Ling ',
    'Zhu ',
    'Fu ',
    'Hu ',
    'Zhi ',
    'Chui ',
    'La ',
    'Long ',
    'Long ',
    'Lu ',
    'Ao ',
    'Tay ',
    'Pao ',
    "[?] ",
    'Xing ',
    'Dong ',
    'Ji ',
    'Ke ',
    'Lu ',
    'Ci ',
    'Chi ',
    'Lei ',
    'Gai ',
    'Yin ',
    'Hou ',
    'Dui ',
    'Zhao ',
    'Fu ',
    'Guang ',
    'Yao ',
    'Duo ',
    'Duo ',
    'Gui ',
    'Cha ',
    'Yang ',
    'Yin ',
    'Fa ',
    'Gou ',
    'Yuan ',
    'Die ',
    'Xie ',
    'Ken ',
    'Jiong ',
    'Shou ',
    'E ',
    'Ha ',
    'Dian ',
    'Hong ',
    'Wu ',
    'Kua ',
    "[?] ",
    'Tao ',
    'Dang ',
    'Kai ',
    'Gake ',
    'Nao ',
    'An ',
    'Xing ',
    'Xian ',
    'Huan ',
    'Bang ',
    'Pei ',
    'Ba ',
    'Yi ',
    'Yin ',
    'Han ',
    'Xu ',
    'Chui ',
    'Cen ',
    'Geng ',
    'Ai ',
    'Peng ',
    'Fang ',
    'Que ',
    'Yong ',
    'Xun ',
    'Jia ',
    'Di ',
    'Mai ',
    'Lang ',
    'Xuan ',
    'Cheng ',
    'Yan ',
    'Jin ',
    'Zhe ',
    'Lei ',
    'Lie ',
    'Bu ',
    'Cheng ',
    'Gomi ',
    'Bu ',
    'Shi ',
    'Xun ',
    'Guo ',
    'Jiong ',
    'Ye ',
    'Nian ',
    'Di ',
    'Yu ',
    'Bu ',
    'Ya ',
    'Juan ',
    'Sui ',
    'Pi ',
    'Cheng ',
    'Wan ',
    'Ju ',
    'Lun ',
    'Zheng ',
    'Kong ',
    'Chong ',
    'Dong ',
    'Dai ',
    'Tan ',
    'An ',
    'Cai ',
    'Shu ',
    'Beng ',
    'Kan ',
    'Zhi ',
    'Duo ',
    'Yi ',
    'Zhi ',
    'Yi ',
    'Pei ',
    'Ji ',
    'Zhun ',
    'Qi ',
    'Sao ',
    'Ju ',
    'Ni '
];

},{}],"hS9jd":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:30 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Ku ',
    'Ke ',
    'Tang ',
    'Kun ',
    'Ni ',
    'Jian ',
    'Dui ',
    'Jin ',
    'Gang ',
    'Yu ',
    'E ',
    'Peng ',
    'Gu ',
    'Tu ',
    'Leng ',
    "[?] ",
    'Ya ',
    'Qian ',
    "[?] ",
    'An ',
    "[?] ",
    'Duo ',
    'Nao ',
    'Tu ',
    'Cheng ',
    'Yin ',
    'Hun ',
    'Bi ',
    'Lian ',
    'Guo ',
    'Die ',
    'Zhuan ',
    'Hou ',
    'Bao ',
    'Bao ',
    'Yu ',
    'Di ',
    'Mao ',
    'Jie ',
    'Ruan ',
    'E ',
    'Geng ',
    'Kan ',
    'Zong ',
    'Yu ',
    'Huang ',
    'E ',
    'Yao ',
    'Yan ',
    'Bao ',
    'Ji ',
    'Mei ',
    'Chang ',
    'Du ',
    'Tuo ',
    'Yin ',
    'Feng ',
    'Zhong ',
    'Jie ',
    'Zhen ',
    'Feng ',
    'Gang ',
    'Chuan ',
    'Jian ',
    'Pyeng ',
    'Toride ',
    'Xiang ',
    'Huang ',
    'Leng ',
    'Duan ',
    "[?] ",
    'Xuan ',
    'Ji ',
    'Ji ',
    'Kuai ',
    'Ying ',
    'Ta ',
    'Cheng ',
    'Yong ',
    'Kai ',
    'Su ',
    'Su ',
    'Shi ',
    'Mi ',
    'Ta ',
    'Weng ',
    'Cheng ',
    'Tu ',
    'Tang ',
    'Que ',
    'Zhong ',
    'Li ',
    'Peng ',
    'Bang ',
    'Sai ',
    'Zang ',
    'Dui ',
    'Tian ',
    'Wu ',
    'Cheng ',
    'Xun ',
    'Ge ',
    'Zhen ',
    'Ai ',
    'Gong ',
    'Yan ',
    'Kan ',
    'Tian ',
    'Yuan ',
    'Wen ',
    'Xie ',
    'Liu ',
    'Ama ',
    'Lang ',
    'Chang ',
    'Peng ',
    'Beng ',
    'Chen ',
    'Cu ',
    'Lu ',
    'Ou ',
    'Qian ',
    'Mei ',
    'Mo ',
    'Zhuan ',
    'Shuang ',
    'Shu ',
    'Lou ',
    'Chi ',
    'Man ',
    'Biao ',
    'Jing ',
    'Qi ',
    'Shu ',
    'Di ',
    'Zhang ',
    'Kan ',
    'Yong ',
    'Dian ',
    'Chen ',
    'Zhi ',
    'Xi ',
    'Guo ',
    'Qiang ',
    'Jin ',
    'Di ',
    'Shang ',
    'Mu ',
    'Cui ',
    'Yan ',
    'Ta ',
    'Zeng ',
    'Qi ',
    'Qiang ',
    'Liang ',
    "[?] ",
    'Zhui ',
    'Qiao ',
    'Zeng ',
    'Xu ',
    'Shan ',
    'Shan ',
    'Ba ',
    'Pu ',
    'Kuai ',
    'Dong ',
    'Fan ',
    'Que ',
    'Mo ',
    'Dun ',
    'Dun ',
    'Dun ',
    'Di ',
    'Sheng ',
    'Duo ',
    'Duo ',
    'Tan ',
    'Deng ',
    'Wu ',
    'Fen ',
    'Huang ',
    'Tan ',
    'Da ',
    'Ye ',
    'Sho ',
    'Mama ',
    'Yu ',
    'Qiang ',
    'Ji ',
    'Qiao ',
    'Ken ',
    'Yi ',
    'Pi ',
    'Bi ',
    'Dian ',
    'Jiang ',
    'Ye ',
    'Yong ',
    'Bo ',
    'Tan ',
    'Lan ',
    'Ju ',
    'Huai ',
    'Dang ',
    'Rang ',
    'Qian ',
    'Xun ',
    'Lan ',
    'Xi ',
    'He ',
    'Ai ',
    'Ya ',
    'Dao ',
    'Hao ',
    'Ruan ',
    'Mama ',
    'Lei ',
    'Kuang ',
    'Lu ',
    'Yan ',
    'Tan ',
    'Wei ',
    'Huai ',
    'Long ',
    'Long ',
    'Rui ',
    'Li ',
    'Lin ',
    'Rang ',
    'Ten ',
    'Xun ',
    'Yan ',
    'Lei ',
    'Ba ',
    "[?] ",
    'Shi ',
    'Ren ',
    "[?] ",
    'Zhuang ',
    'Zhuang ',
    'Sheng ',
    'Yi ',
    'Mai ',
    'Ke ',
    'Zhu ',
    'Zhuang ',
    'Hu ',
    'Hu ',
    'Kun ',
    'Yi ',
    'Hu ',
    'Xu ',
    'Kun ',
    'Shou ',
    'Mang ',
    'Zun '
];

},{}],"jsWtu":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Shou ',
    'Yi ',
    'Zhi ',
    'Gu ',
    'Chu ',
    'Jiang ',
    'Feng ',
    'Bei ',
    'Cay ',
    'Bian ',
    'Sui ',
    'Qun ',
    'Ling ',
    'Fu ',
    'Zuo ',
    'Xia ',
    'Xiong ',
    "[?] ",
    'Nao ',
    'Xia ',
    'Kui ',
    'Xi ',
    'Wai ',
    'Yuan ',
    'Mao ',
    'Su ',
    'Duo ',
    'Duo ',
    'Ye ',
    'Qing ',
    'Uys ',
    'Gou ',
    'Gou ',
    'Qi ',
    'Meng ',
    'Meng ',
    'Yin ',
    'Huo ',
    'Chen ',
    'Da ',
    'Ze ',
    'Tian ',
    'Tai ',
    'Fu ',
    'Guai ',
    'Yao ',
    'Yang ',
    'Hang ',
    'Gao ',
    'Shi ',
    'Ben ',
    'Tai ',
    'Tou ',
    'Yan ',
    'Bi ',
    'Yi ',
    'Kua ',
    'Jia ',
    'Duo ',
    'Kwu ',
    'Kuang ',
    'Yun ',
    'Jia ',
    'Pa ',
    'En ',
    'Lian ',
    'Huan ',
    'Di ',
    'Yan ',
    'Pao ',
    'Quan ',
    'Qi ',
    'Nai ',
    'Feng ',
    'Xie ',
    'Fen ',
    'Dian ',
    "[?] ",
    'Kui ',
    'Zou ',
    'Huan ',
    'Qi ',
    'Kai ',
    'Zha ',
    'Ben ',
    'Yi ',
    'Jiang ',
    'Tao ',
    'Zang ',
    'Ben ',
    'Xi ',
    'Xiang ',
    'Fei ',
    'Diao ',
    'Xun ',
    'Keng ',
    'Dian ',
    'Ao ',
    'She ',
    'Weng ',
    'Pan ',
    'Ao ',
    'Wu ',
    'Ao ',
    'Jiang ',
    'Lian ',
    'Duo ',
    'Yun ',
    'Jiang ',
    'Shi ',
    'Fen ',
    'Huo ',
    'Bi ',
    'Lian ',
    'Duo ',
    'Nu ',
    'Nu ',
    'Ding ',
    'Nai ',
    'Qian ',
    'Jian ',
    'Ta ',
    'Jiu ',
    'Nan ',
    'Cha ',
    'Hao ',
    'Xian ',
    'Fan ',
    'Ji ',
    'Shuo ',
    'Ru ',
    'Fei ',
    'Wang ',
    'Hong ',
    'Zhuang ',
    'Fu ',
    'Ma ',
    'Dan ',
    'Ren ',
    'Fu ',
    'Jing ',
    'Yan ',
    'Xie ',
    'Wen ',
    'Zhong ',
    'Pa ',
    'Du ',
    'Ji ',
    'Keng ',
    'Zhong ',
    'Yao ',
    'Jin ',
    'Yun ',
    'Miao ',
    'Pei ',
    'Shi ',
    'Yue ',
    'Zhuang ',
    'Niu ',
    'Yan ',
    'Na ',
    'Xin ',
    'Fen ',
    'Bi ',
    'Yu ',
    'Tuo ',
    'Feng ',
    'Yuan ',
    'Fang ',
    'Wu ',
    'Yu ',
    'Gui ',
    'Du ',
    'Ba ',
    'Ni ',
    'Zhou ',
    'Zhuo ',
    'Zhao ',
    'Da ',
    'Nai ',
    'Yuan ',
    'Tou ',
    'Xuan ',
    'Zhi ',
    'E ',
    'Mei ',
    'Mo ',
    'Qi ',
    'Bi ',
    'Shen ',
    'Qie ',
    'E ',
    'He ',
    'Xu ',
    'Fa ',
    'Zheng ',
    'Min ',
    'Ban ',
    'Mu ',
    'Fu ',
    'Ling ',
    'Zi ',
    'Zi ',
    'Shi ',
    'Ran ',
    'Shan ',
    'Yang ',
    'Man ',
    'Jie ',
    'Gu ',
    'Si ',
    'Xing ',
    'Wei ',
    'Zi ',
    'Ju ',
    'Shan ',
    'Pin ',
    'Ren ',
    'Yao ',
    'Tong ',
    'Jiang ',
    'Shu ',
    'Ji ',
    'Gai ',
    'Shang ',
    'Kuo ',
    'Juan ',
    'Jiao ',
    'Gou ',
    'Mu ',
    'Jian ',
    'Jian ',
    'Yi ',
    'Nian ',
    'Zhi ',
    'Ji ',
    'Ji ',
    'Xian ',
    'Heng ',
    'Guang ',
    'Jun ',
    'Kua ',
    'Yan ',
    'Ming ',
    'Lie ',
    'Pei ',
    'Yan ',
    'You ',
    'Yan ',
    'Cha ',
    'Shen ',
    'Yin ',
    'Chi ',
    'Gui ',
    'Quan ',
    'Zi '
];

},{}],"e0Yzt":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Song ',
    'Wei ',
    'Hong ',
    'Wa ',
    'Lou ',
    'Ya ',
    'Rao ',
    'Jiao ',
    'Luan ',
    'Ping ',
    'Xian ',
    'Shao ',
    'Li ',
    'Cheng ',
    'Xiao ',
    'Mang ',
    'Fu ',
    'Suo ',
    'Wu ',
    'Wei ',
    'Ke ',
    'Lai ',
    'Chuo ',
    'Ding ',
    'Niang ',
    'Xing ',
    'Nan ',
    'Yu ',
    'Nuo ',
    'Pei ',
    'Nei ',
    'Juan ',
    'Shen ',
    'Zhi ',
    'Han ',
    'Di ',
    'Zhuang ',
    'E ',
    'Pin ',
    'Tui ',
    'Han ',
    'Mian ',
    'Wu ',
    'Yan ',
    'Wu ',
    'Xi ',
    'Yan ',
    'Yu ',
    'Si ',
    'Yu ',
    'Wa ',
    "[?] ",
    'Xian ',
    'Ju ',
    'Qu ',
    'Shui ',
    'Qi ',
    'Xian ',
    'Zhui ',
    'Dong ',
    'Chang ',
    'Lu ',
    'Ai ',
    'E ',
    'E ',
    'Lou ',
    'Mian ',
    'Cong ',
    'Pou ',
    'Ju ',
    'Po ',
    'Cai ',
    'Ding ',
    'Wan ',
    'Biao ',
    'Xiao ',
    'Shu ',
    'Qi ',
    'Hui ',
    'Fu ',
    'E ',
    'Wo ',
    'Tan ',
    'Fei ',
    'Wei ',
    'Jie ',
    'Tian ',
    'Ni ',
    'Quan ',
    'Jing ',
    'Hun ',
    'Jing ',
    'Qian ',
    'Dian ',
    'Xing ',
    'Hu ',
    'Wa ',
    'Lai ',
    'Bi ',
    'Yin ',
    'Chou ',
    'Chuo ',
    'Fu ',
    'Jing ',
    'Lun ',
    'Yan ',
    'Lan ',
    'Kun ',
    'Yin ',
    'Ya ',
    'Ju ',
    'Li ',
    'Dian ',
    'Xian ',
    'Hwa ',
    'Hua ',
    'Ying ',
    'Chan ',
    'Shen ',
    'Ting ',
    'Dang ',
    'Yao ',
    'Wu ',
    'Nan ',
    'Ruo ',
    'Jia ',
    'Tou ',
    'Xu ',
    'Yu ',
    'Wei ',
    'Ti ',
    'Rou ',
    'Mei ',
    'Dan ',
    'Ruan ',
    'Qin ',
    'Hui ',
    'Wu ',
    'Qian ',
    'Chun ',
    'Mao ',
    'Fu ',
    'Jie ',
    'Duan ',
    'Xi ',
    'Zhong ',
    'Mei ',
    'Huang ',
    'Mian ',
    'An ',
    'Ying ',
    'Xuan ',
    'Jie ',
    'Wei ',
    'Mei ',
    'Yuan ',
    'Zhen ',
    'Qiu ',
    'Ti ',
    'Xie ',
    'Tuo ',
    'Lian ',
    'Mao ',
    'Ran ',
    'Si ',
    'Pian ',
    'Wei ',
    'Wa ',
    'Jiu ',
    'Hu ',
    'Ao ',
    "[?] ",
    'Bou ',
    'Xu ',
    'Tou ',
    'Gui ',
    'Zou ',
    'Yao ',
    'Pi ',
    'Xi ',
    'Yuan ',
    'Ying ',
    'Rong ',
    'Ru ',
    'Chi ',
    'Liu ',
    'Mei ',
    'Pan ',
    'Ao ',
    'Ma ',
    'Gou ',
    'Kui ',
    'Qin ',
    'Jia ',
    'Sao ',
    'Zhen ',
    'Yuan ',
    'Cha ',
    'Yong ',
    'Ming ',
    'Ying ',
    'Ji ',
    'Su ',
    'Niao ',
    'Xian ',
    'Tao ',
    'Pang ',
    'Lang ',
    'Nao ',
    'Bao ',
    'Ai ',
    'Pi ',
    'Pin ',
    'Yi ',
    'Piao ',
    'Yu ',
    'Lei ',
    'Xuan ',
    'Man ',
    'Yi ',
    'Zhang ',
    'Kang ',
    'Yong ',
    'Ni ',
    'Li ',
    'Di ',
    'Gui ',
    'Yan ',
    'Jin ',
    'Zhuan ',
    'Chang ',
    'Ce ',
    'Han ',
    'Nen ',
    'Lao ',
    'Mo ',
    'Zhe ',
    'Hu ',
    'Hu ',
    'Ao ',
    'Nen ',
    'Qiang ',
    'Ma ',
    'Pie ',
    'Gu ',
    'Wu ',
    'Jiao ',
    'Tuo ',
    'Zhan ',
    'Mao ',
    'Xian ',
    'Xian ',
    'Mo ',
    'Liao ',
    'Lian ',
    'Hua '
];

},{}],"fCEl5":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Gui ',
    'Deng ',
    'Zhi ',
    'Xu ',
    'Yi ',
    'Hua ',
    'Xi ',
    'Hui ',
    'Rao ',
    'Xi ',
    'Yan ',
    'Chan ',
    'Jiao ',
    'Mei ',
    'Fan ',
    'Fan ',
    'Xian ',
    'Yi ',
    'Wei ',
    'Jiao ',
    'Fu ',
    'Shi ',
    'Bi ',
    'Shan ',
    'Sui ',
    'Qiang ',
    'Lian ',
    'Huan ',
    'Xin ',
    'Niao ',
    'Dong ',
    'Yi ',
    'Can ',
    'Ai ',
    'Niang ',
    'Neng ',
    'Ma ',
    'Tiao ',
    'Chou ',
    'Jin ',
    'Ci ',
    'Yu ',
    'Pin ',
    'Yong ',
    'Xu ',
    'Nai ',
    'Yan ',
    'Tai ',
    'Ying ',
    'Can ',
    'Niao ',
    'Wo ',
    'Ying ',
    'Mian ',
    'Kaka ',
    'Ma ',
    'Shen ',
    'Xing ',
    'Ni ',
    'Du ',
    'Liu ',
    'Yuan ',
    'Lan ',
    'Yan ',
    'Shuang ',
    'Ling ',
    'Jiao ',
    'Niang ',
    'Lan ',
    'Xian ',
    'Ying ',
    'Shuang ',
    'Shuai ',
    'Quan ',
    'Mi ',
    'Li ',
    'Luan ',
    'Yan ',
    'Zhu ',
    'Lan ',
    'Zi ',
    'Jie ',
    'Jue ',
    'Jue ',
    'Kong ',
    'Yun ',
    'Zi ',
    'Zi ',
    'Cun ',
    'Sun ',
    'Fu ',
    'Bei ',
    'Zi ',
    'Xiao ',
    'Xin ',
    'Meng ',
    'Si ',
    'Tai ',
    'Bao ',
    'Ji ',
    'Gu ',
    'Nu ',
    'Xue ',
    "[?] ",
    'Zhuan ',
    'Hai ',
    'Luan ',
    'Sun ',
    'Huai ',
    'Mie ',
    'Cong ',
    'Qian ',
    'Shu ',
    'Chan ',
    'Ya ',
    'Zi ',
    'Ni ',
    'Fu ',
    'Zi ',
    'Li ',
    'Xue ',
    'Bo ',
    'Ru ',
    'Lai ',
    'Nie ',
    'Nie ',
    'Ying ',
    'Luan ',
    'Mian ',
    'Zhu ',
    'Rong ',
    'Ta ',
    'Gui ',
    'Zhai ',
    'Qiong ',
    'Yu ',
    'Shou ',
    'An ',
    'Tu ',
    'Song ',
    'Wan ',
    'Rou ',
    'Yao ',
    'Hong ',
    'Yi ',
    'Jing ',
    'Zhun ',
    'Mi ',
    'Zhu ',
    'Dang ',
    'Hong ',
    'Zong ',
    'Guan ',
    'Zhou ',
    'Ding ',
    'Wan ',
    'Yi ',
    'Bao ',
    'Shi ',
    'Shi ',
    'Chong ',
    'Shen ',
    'Ke ',
    'Xuan ',
    'Shi ',
    'You ',
    'Huan ',
    'Yi ',
    'Tiao ',
    'Shi ',
    'Xian ',
    'Gong ',
    'Cheng ',
    'Qun ',
    'Gong ',
    'Xiao ',
    'Zai ',
    'Zha ',
    'Bao ',
    'Hai ',
    'Yan ',
    'Xiao ',
    'Jia ',
    'Shen ',
    'Chen ',
    'Rong ',
    'Huang ',
    'Mi ',
    'Kou ',
    'Kuan ',
    'Bin ',
    'Su ',
    'Cai ',
    'Zan ',
    'Ji ',
    'Yuan ',
    'Ji ',
    'Yin ',
    'Mi ',
    'Kou ',
    'Qing ',
    'Que ',
    'Zhen ',
    'Jian ',
    'Fu ',
    'Ning ',
    'Bing ',
    'Huan ',
    'Mei ',
    'Qin ',
    'Han ',
    'Yu ',
    'Shi ',
    'Ning ',
    'Qin ',
    'Ning ',
    'Zhi ',
    'Yu ',
    'Bao ',
    'Kuan ',
    'Ning ',
    'Qin ',
    'Mo ',
    'Cha ',
    'Ju ',
    'Gua ',
    'Qin ',
    'Hu ',
    'Wu ',
    'Liao ',
    'Shi ',
    'Zhu ',
    'Zhai ',
    'Shen ',
    'Wei ',
    'Xie ',
    'Kuan ',
    'Hui ',
    'Liao ',
    'Jun ',
    'Huan ',
    'Yi ',
    'Yi ',
    'Bao ',
    'Qin ',
    'Chong ',
    'Bao ',
    'Feng ',
    'Cun ',
    'Dui ',
    'Si ',
    'Xun ',
    'Dao ',
    'Lu ',
    'Dui ',
    'Shou '
];

},{}],"xkWup":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Po ',
    'Feng ',
    'Zhuan ',
    'Fu ',
    'She ',
    'Ke ',
    'Jiang ',
    'Jiang ',
    'Zhuan ',
    'Wei ',
    'Zun ',
    'Xun ',
    'Shu ',
    'Dui ',
    'Dao ',
    'Xiao ',
    'Ji ',
    'Shao ',
    'Er ',
    'Er ',
    'Er ',
    'Ga ',
    'Jian ',
    'Shu ',
    'Chen ',
    'Shang ',
    'Shang ',
    'Mo ',
    'Ga ',
    'Chang ',
    'Liao ',
    'Xian ',
    'Xian ',
    "[?] ",
    'Wang ',
    'Wang ',
    'You ',
    'Liao ',
    'Liao ',
    'Yao ',
    'Mang ',
    'Wang ',
    'Wang ',
    'Wang ',
    'Ga ',
    'Yao ',
    'Duo ',
    'Kui ',
    'Zhong ',
    'Jiu ',
    'Gan ',
    'Gu ',
    'Gan ',
    'Tui ',
    'Gan ',
    'Gan ',
    'Shi ',
    'Yin ',
    'Chi ',
    'Kao ',
    'Ni ',
    'Jin ',
    'Wei ',
    'Niao ',
    'Ju ',
    'Pi ',
    'Ceng ',
    'Xi ',
    'Bi ',
    'Ju ',
    'Jie ',
    'Tian ',
    'Qu ',
    'Ti ',
    'Jie ',
    'Wu ',
    'Diao ',
    'Shi ',
    'Shi ',
    'Ping ',
    'Ji ',
    'Xie ',
    'Chen ',
    'Xi ',
    'Ni ',
    'Zhan ',
    'Xi ',
    "[?] ",
    'Man ',
    'E ',
    'Lou ',
    'Ping ',
    'Ti ',
    'Fei ',
    'Shu ',
    'Xie ',
    'Tu ',
    'Lu ',
    'Lu ',
    'Xi ',
    'Ceng ',
    'Lu ',
    'Ju ',
    'Xie ',
    'Ju ',
    'Jue ',
    'Liao ',
    'Jue ',
    'Shu ',
    'Xi ',
    'Che ',
    'Tun ',
    'Ni ',
    'Shan ',
    "[?] ",
    'Xian ',
    'Li ',
    'Xue ',
    'Nata ',
    "[?] ",
    'Long ',
    'Yi ',
    'Qi ',
    'Ren ',
    'Wu ',
    'Han ',
    'Shen ',
    'Yu ',
    'Chu ',
    'Sui ',
    'Qi ',
    "[?] ",
    'Yue ',
    'Ban ',
    'Yao ',
    'Ang ',
    'Ya ',
    'Wu ',
    'Jie ',
    'E ',
    'Ji ',
    'Qian ',
    'Fen ',
    'Yuan ',
    'Qi ',
    'Cen ',
    'Qian ',
    'Qi ',
    'Cha ',
    'Jie ',
    'Qu ',
    'Gang ',
    'Xian ',
    'Ao ',
    'Lan ',
    'Dao ',
    'Ba ',
    'Zuo ',
    'Zuo ',
    'Yang ',
    'Ju ',
    'Gang ',
    'Ke ',
    'Gou ',
    'Xue ',
    'Bei ',
    'Li ',
    'Tiao ',
    'Ju ',
    'Yan ',
    'Fu ',
    'Xiu ',
    'Jia ',
    'Ling ',
    'Tuo ',
    'Pei ',
    'You ',
    'Dai ',
    'Kuang ',
    'Yue ',
    'Qu ',
    'Hu ',
    'Po ',
    'Min ',
    'An ',
    'Tiao ',
    'Ling ',
    'Chi ',
    'Yuri ',
    'Dong ',
    'Cem ',
    'Kui ',
    'Xiu ',
    'Mao ',
    'Tong ',
    'Xue ',
    'Yi ',
    'Kura ',
    'He ',
    'Ke ',
    'Luo ',
    'E ',
    'Fu ',
    'Xun ',
    'Die ',
    'Lu ',
    'An ',
    'Er ',
    'Gai ',
    'Quan ',
    'Tong ',
    'Yi ',
    'Mu ',
    'Shi ',
    'An ',
    'Wei ',
    'Hu ',
    'Zhi ',
    'Mi ',
    'Li ',
    'Ji ',
    'Tong ',
    'Wei ',
    'You ',
    'Sang ',
    'Xia ',
    'Li ',
    'Yao ',
    'Jiao ',
    'Zheng ',
    'Luan ',
    'Jiao ',
    'E ',
    'E ',
    'Yu ',
    'Ye ',
    'Bu ',
    'Qiao ',
    'Qun ',
    'Feng ',
    'Feng ',
    'Nao ',
    'Li ',
    'You ',
    'Xian ',
    'Hong ',
    'Dao ',
    'Shen ',
    'Cheng ',
    'Tu ',
    'Geng ',
    'Jun ',
    'Hao ',
    'Xia ',
    'Yin ',
    'Yu '
];

},{}],"ioIwY":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Lang ',
    'Kan ',
    'Lao ',
    'Lai ',
    'Xian ',
    'Que ',
    'Kong ',
    'Chong ',
    'Chong ',
    'Ta ',
    'Lin ',
    'Hua ',
    'Ju ',
    'Lai ',
    'Qi ',
    'Min ',
    'Kun ',
    'Kun ',
    'Zu ',
    'Gu ',
    'Cui ',
    'Ya ',
    'Ya ',
    'Gang ',
    'Lun ',
    'Lun ',
    'Leng ',
    'Jue ',
    'Duo ',
    'Zheng ',
    'Guo ',
    'Yin ',
    'Dong ',
    'Han ',
    'Zheng ',
    'Wei ',
    'Yao ',
    'Pi ',
    'Yan ',
    'Song ',
    'Jie ',
    'Beng ',
    'Zu ',
    'Jue ',
    'Dong ',
    'Zhan ',
    'Gu ',
    'Yin ',
    "[?] ",
    'Ze ',
    'Huang ',
    'Yu ',
    'Wei ',
    'Yang ',
    'Feng ',
    'Qiu ',
    'Dun ',
    'Ti ',
    'Yi ',
    'Zhi ',
    'Shi ',
    'Zai ',
    'Yao ',
    'E ',
    'Zhu ',
    'Kan ',
    'Lu ',
    'Yan ',
    'Mei ',
    'Gan ',
    'Ji ',
    'Ji ',
    'Huan ',
    'Ting ',
    'Sheng ',
    'Mei ',
    'Qian ',
    'Wu ',
    'Yu ',
    'Zong ',
    'Lan ',
    'Jue ',
    'Yan ',
    'Yan ',
    'Wei ',
    'Zong ',
    'Cha ',
    'Sui ',
    'Rong ',
    'Yamashina ',
    'Qin ',
    'Yu ',
    'Kewashii ',
    'Lou ',
    'Tu ',
    'Dui ',
    'Xi ',
    'Weng ',
    'Cang ',
    'Dang ',
    'Hong ',
    'Jie ',
    'Ai ',
    'Liu ',
    'Wu ',
    'Song ',
    'Qiao ',
    'Zi ',
    'Wei ',
    'Beng ',
    'Dian ',
    'Cuo ',
    'Qian ',
    'Yong ',
    'Nie ',
    'Cuo ',
    'Ji ',
    "[?] ",
    'Tao ',
    'Song ',
    'Zong ',
    'Jiang ',
    'Liao ',
    'Kang ',
    'Chan ',
    'Die ',
    'Cen ',
    'Ding ',
    'Tu ',
    'Lou ',
    'Zhang ',
    'Zhan ',
    'Zhan ',
    'Ao ',
    'Cao ',
    'Qu ',
    'Qiang ',
    'Zui ',
    'Zui ',
    'Dao ',
    'Dao ',
    'Xi ',
    'Yu ',
    'Bo ',
    'Long ',
    'Xiang ',
    'Ceng ',
    'Bo ',
    'Qin ',
    'Jiao ',
    'Yan ',
    'Lao ',
    'Zhan ',
    'Lin ',
    'Liao ',
    'Liao ',
    'Jin ',
    'Deng ',
    'Duo ',
    'Zun ',
    'Jiao ',
    'Gui ',
    'Yao ',
    'Qiao ',
    'Yao ',
    'Jue ',
    'Zhan ',
    'Yi ',
    'Xue ',
    'Nao ',
    'Ye ',
    'Ye ',
    'Yi ',
    'E ',
    'Xian ',
    'Ji ',
    'Xie ',
    'Ke ',
    'Xi ',
    'Di ',
    'Ao ',
    'Zui ',
    "[?] ",
    'Ni ',
    'Rong ',
    'Dao ',
    'Ling ',
    'Za ',
    'Yu ',
    'Yue ',
    'Yin ',
    "[?] ",
    'Jie ',
    'Li ',
    'Sui ',
    'Long ',
    'Long ',
    'Dian ',
    'Ying ',
    'Xi ',
    'Ju ',
    'Chan ',
    'Ying ',
    'Kui ',
    'Yan ',
    'Wei ',
    'Nao ',
    'Quan ',
    'Chao ',
    'Cuan ',
    'Luan ',
    'Dian ',
    'Dian ',
    "[?] ",
    'Yan ',
    'Yan ',
    'Yan ',
    'Nao ',
    'Yan ',
    'Chuan ',
    'Gui ',
    'Chuan ',
    'Zhou ',
    'Huang ',
    'Jing ',
    'Xun ',
    'Chao ',
    'Chao ',
    'Lie ',
    'Gong ',
    'Zuo ',
    'Qiao ',
    'Ju ',
    'Gong ',
    'Kek ',
    'Wu ',
    'Pwu ',
    'Pwu ',
    'Chai ',
    'Qiu ',
    'Qiu ',
    'Ji ',
    'Yi ',
    'Si ',
    'Ba ',
    'Zhi ',
    'Zhao ',
    'Xiang ',
    'Yi ',
    'Jin ',
    'Xun ',
    'Juan ',
    'Phas ',
    'Xun ',
    'Jin ',
    'Fu '
];

},{}],"hM2C3":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Za ',
    'Bi ',
    'Shi ',
    'Bu ',
    'Ding ',
    'Shuai ',
    'Fan ',
    'Nie ',
    'Shi ',
    'Fen ',
    'Pa ',
    'Zhi ',
    'Xi ',
    'Hu ',
    'Dan ',
    'Wei ',
    'Zhang ',
    'Tang ',
    'Dai ',
    'Ma ',
    'Pei ',
    'Pa ',
    'Tie ',
    'Fu ',
    'Lian ',
    'Zhi ',
    'Zhou ',
    'Bo ',
    'Zhi ',
    'Di ',
    'Mo ',
    'Yi ',
    'Yi ',
    'Ping ',
    'Qia ',
    'Juan ',
    'Ru ',
    'Shuai ',
    'Dai ',
    'Zheng ',
    'Shui ',
    'Qiao ',
    'Zhen ',
    'Shi ',
    'Qun ',
    'Xi ',
    'Bang ',
    'Dai ',
    'Gui ',
    'Chou ',
    'Ping ',
    'Zhang ',
    'Sha ',
    'Wan ',
    'Dai ',
    'Wei ',
    'Chang ',
    'Sha ',
    'Qi ',
    'Ze ',
    'Guo ',
    'Mao ',
    'Du ',
    'Hou ',
    'Zheng ',
    'Xu ',
    'Mi ',
    'Wei ',
    'Wo ',
    'Fu ',
    'Yi ',
    'Bang ',
    'Ping ',
    'Tazuna ',
    'Gong ',
    'Pan ',
    'Huang ',
    'Dao ',
    'Mi ',
    'Jia ',
    'Teng ',
    'Hui ',
    'Zhong ',
    'Shan ',
    'Man ',
    'Mu ',
    'Biao ',
    'Guo ',
    'Ze ',
    'Mu ',
    'Bang ',
    'Zhang ',
    'Jiong ',
    'Chan ',
    'Fu ',
    'Zhi ',
    'Hu ',
    'Fan ',
    'Chuang ',
    'Bi ',
    'Hei ',
    "[?] ",
    'Mi ',
    'Qiao ',
    'Chan ',
    'Fen ',
    'Meng ',
    'Bang ',
    'Chou ',
    'Mie ',
    'Chu ',
    'Jie ',
    'Xian ',
    'Lan ',
    'Gan ',
    'Ping ',
    'Nian ',
    'Qian ',
    'Bing ',
    'Bing ',
    'Xing ',
    'Gan ',
    'Yao ',
    'Huan ',
    'You ',
    'You ',
    'Ji ',
    'Yan ',
    'Pi ',
    'Ting ',
    'Ze ',
    'Guang ',
    'Zhuang ',
    'Mo ',
    'Qing ',
    'Bi ',
    'Qin ',
    'Dun ',
    'Chuang ',
    'Gui ',
    'Ya ',
    'Bai ',
    'Jie ',
    'Xu ',
    'Lu ',
    'Wu ',
    "[?] ",
    'Ku ',
    'Ying ',
    'Di ',
    'Pao ',
    'Dian ',
    'Ya ',
    'Miao ',
    'Geng ',
    'Ci ',
    'Fu ',
    'Tong ',
    'Pang ',
    'Fei ',
    'Xiang ',
    'Yi ',
    'Zhi ',
    'Tiao ',
    'Zhi ',
    'Xiu ',
    'Du ',
    'Zuo ',
    'Xiao ',
    'Tu ',
    'Gui ',
    'Ku ',
    'Pang ',
    'Ting ',
    'You ',
    'Bu ',
    'Ding ',
    'Cheng ',
    'Lai ',
    'Bei ',
    'Ji ',
    'An ',
    'Shu ',
    'Kang ',
    'Yong ',
    'Tuo ',
    'Song ',
    'Shu ',
    'Qing ',
    'Yu ',
    'Yu ',
    'Miao ',
    'Sou ',
    'Ce ',
    'Xiang ',
    'Fei ',
    'Jiu ',
    'He ',
    'Hui ',
    'Liu ',
    'Sha ',
    'Lian ',
    'Lang ',
    'Sou ',
    'Jian ',
    'Pou ',
    'Qing ',
    'Jiu ',
    'Jiu ',
    'Qin ',
    'Ao ',
    'Kuo ',
    'Lou ',
    'Yin ',
    'Liao ',
    'Dai ',
    'Lu ',
    'Yi ',
    'Chu ',
    'Chan ',
    'Tu ',
    'Si ',
    'Xin ',
    'Miao ',
    'Chang ',
    'Wu ',
    'Fei ',
    'Guang ',
    'Koc ',
    'Kuai ',
    'Bi ',
    'Qiang ',
    'Xie ',
    'Lin ',
    'Lin ',
    'Liao ',
    'Lu ',
    "[?] ",
    'Ying ',
    'Xian ',
    'Ting ',
    'Yong ',
    'Li ',
    'Ting ',
    'Yin ',
    'Xun ',
    'Yan ',
    'Ting ',
    'Di ',
    'Po ',
    'Jian ',
    'Hui ',
    'Nai ',
    'Hui ',
    'Gong ',
    'Nian '
];

},{}],"7bKkm":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Kai ',
    'Bian ',
    'Yi ',
    'Qi ',
    'Nong ',
    'Fen ',
    'Ju ',
    'Yan ',
    'Yi ',
    'Zang ',
    'Bi ',
    'Yi ',
    'Yi ',
    'Er ',
    'San ',
    'Shi ',
    'Er ',
    'Shi ',
    'Shi ',
    'Gong ',
    'Diao ',
    'Yin ',
    'Hu ',
    'Fu ',
    'Hong ',
    'Wu ',
    'Tui ',
    'Chi ',
    'Jiang ',
    'Ba ',
    'Shen ',
    'Di ',
    'Zhang ',
    'Jue ',
    'Tao ',
    'Fu ',
    'Di ',
    'Mi ',
    'Xian ',
    'Hu ',
    'Chao ',
    'Nu ',
    'Jing ',
    'Zhen ',
    'Yi ',
    'Mi ',
    'Quan ',
    'Wan ',
    'Shao ',
    'Ruo ',
    'Xuan ',
    'Jing ',
    'Dun ',
    'Zhang ',
    'Jiang ',
    'Qiang ',
    'Peng ',
    'Dan ',
    'Qiang ',
    'Bi ',
    'Bi ',
    'She ',
    'Dan ',
    'Jian ',
    'Gou ',
    'Sei ',
    'Fa ',
    'Bi ',
    'Kou ',
    'Nagi ',
    'Bie ',
    'Xiao ',
    'Dan ',
    'Kuo ',
    'Qiang ',
    'Hong ',
    'Mi ',
    'Kuo ',
    'Wan ',
    'Jue ',
    'Ji ',
    'Ji ',
    'Gui ',
    'Dang ',
    'Lu ',
    'Lu ',
    'Tuan ',
    'Hui ',
    'Zhi ',
    'Hui ',
    'Hui ',
    'Yi ',
    'Yi ',
    'Yi ',
    'Yi ',
    'Huo ',
    'Huo ',
    'Shan ',
    'Xing ',
    'Wen ',
    'Tong ',
    'Yan ',
    'Yan ',
    'Yu ',
    'Chi ',
    'Cai ',
    'Biao ',
    'Diao ',
    'Bin ',
    'Peng ',
    'Yong ',
    'Piao ',
    'Zhang ',
    'Ying ',
    'Chi ',
    'Chi ',
    'Zhuo ',
    'Tuo ',
    'Ji ',
    'Pang ',
    'Zhong ',
    'Yi ',
    'Wang ',
    'Che ',
    'Bi ',
    'Chi ',
    'Ling ',
    'Fu ',
    'Wang ',
    'Zheng ',
    'Cu ',
    'Wang ',
    'Jing ',
    'Dai ',
    'Xi ',
    'Xun ',
    'Hen ',
    'Yang ',
    'Huai ',
    'Lu ',
    'Hou ',
    'Wa ',
    'Cheng ',
    'Zhi ',
    'Xu ',
    'Jing ',
    'Tu ',
    'Cong ',
    "[?] ",
    'Lai ',
    'Cong ',
    'De ',
    'Pai ',
    'Xi ',
    "[?] ",
    'Qi ',
    'Chang ',
    'Zhi ',
    'Cong ',
    'Zhou ',
    'Lai ',
    'Yu ',
    'Xie ',
    'Jie ',
    'Jian ',
    'Chi ',
    'Jia ',
    'Bian ',
    'Huang ',
    'Fu ',
    'Xun ',
    'Wei ',
    'Pang ',
    'Yao ',
    'Wei ',
    'Xi ',
    'Zheng ',
    'Piao ',
    'Chi ',
    'De ',
    'Zheng ',
    'Zheng ',
    'Bie ',
    'De ',
    'Chong ',
    'Che ',
    'Jiao ',
    'Wei ',
    'Jiao ',
    'Hui ',
    'Mei ',
    'Long ',
    'Xiang ',
    'Bao ',
    'Qu ',
    'Xin ',
    'Shu ',
    'Bi ',
    'Yi ',
    'Le ',
    'Ren ',
    'Dao ',
    'Ding ',
    'Gai ',
    'Ji ',
    'Ren ',
    'Ren ',
    'Chan ',
    'Tan ',
    'Te ',
    'Te ',
    'Gan ',
    'Qi ',
    'Shi ',
    'Cun ',
    'Zhi ',
    'Wang ',
    'Mang ',
    'Xi ',
    'Fan ',
    'Ying ',
    'Tian ',
    'Min ',
    'Min ',
    'Zhong ',
    'Chong ',
    'Wu ',
    'Ji ',
    'Wu ',
    'Xi ',
    'Ye ',
    'You ',
    'Wan ',
    'Cong ',
    'Zhong ',
    'Kuai ',
    'Yu ',
    'Bian ',
    'Zhi ',
    'Qi ',
    'Cui ',
    'Chen ',
    'Tai ',
    'Tun ',
    'Qian ',
    'Nian ',
    'Hun ',
    'Xiong ',
    'Niu ',
    'Wang ',
    'Xian ',
    'Xin ',
    'Kang ',
    'Hu ',
    'Kai ',
    'Fen '
];

},{}],"60aC0":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Huai ',
    'Tai ',
    'Song ',
    'Wu ',
    'Ou ',
    'Chang ',
    'Chuang ',
    'Ju ',
    'Yi ',
    'Bao ',
    'Chao ',
    'Min ',
    'Pei ',
    'Zuo ',
    'Zen ',
    'Yang ',
    'Kou ',
    'Ban ',
    'Nu ',
    'Nao ',
    'Zheng ',
    'Pa ',
    'Bu ',
    'Tie ',
    'Gu ',
    'Hu ',
    'Ju ',
    'Da ',
    'Lian ',
    'Si ',
    'Chou ',
    'Di ',
    'Dai ',
    'Yi ',
    'Tu ',
    'You ',
    'Fu ',
    'Ji ',
    'Peng ',
    'Xing ',
    'Yuan ',
    'Ni ',
    'Guai ',
    'Fu ',
    'Xi ',
    'Bi ',
    'You ',
    'Qie ',
    'Xuan ',
    'Cong ',
    'Bing ',
    'Huang ',
    'Xu ',
    'Chu ',
    'Pi ',
    'Xi ',
    'Xi ',
    'Tan ',
    'Koraeru ',
    'Zong ',
    'Dui ',
    "[?] ",
    'Ki ',
    'Yi ',
    'Chi ',
    'Ren ',
    'Xun ',
    'Shi ',
    'Xi ',
    'Lao ',
    'Heng ',
    'Kuang ',
    'Mu ',
    'Zhi ',
    'Xie ',
    'Lian ',
    'Tiao ',
    'Huang ',
    'Die ',
    'Hao ',
    'Kong ',
    'Gui ',
    'Heng ',
    'Xi ',
    'Xiao ',
    'Shu ',
    'S ',
    'Kua ',
    'Qiu ',
    'Yang ',
    'Hui ',
    'Hui ',
    'Chi ',
    'Jia ',
    'Yi ',
    'Xiong ',
    'Guai ',
    'Lin ',
    'Hui ',
    'Zi ',
    'Xu ',
    'Chi ',
    'Xiang ',
    'Nu ',
    'Hen ',
    'En ',
    'Ke ',
    'Tong ',
    'Tian ',
    'Gong ',
    'Quan ',
    'Xi ',
    'Qia ',
    'Yue ',
    'Peng ',
    'Ken ',
    'De ',
    'Hui ',
    'E ',
    'Kyuu ',
    'Tong ',
    'Yan ',
    'Kai ',
    'Ce ',
    'Nao ',
    'Yun ',
    'Mang ',
    'Yong ',
    'Yong ',
    'Yuan ',
    'Pi ',
    'Kun ',
    'Qiao ',
    'Yue ',
    'Yu ',
    'Yu ',
    'Jie ',
    'Xi ',
    'Zhe ',
    'Lin ',
    'Ti ',
    'Han ',
    'Hao ',
    'Qie ',
    'Ti ',
    'Bu ',
    'Yi ',
    'Qian ',
    'Hui ',
    'Xi ',
    'Bei ',
    'Man ',
    'Yi ',
    'Heng ',
    'Song ',
    'Quan ',
    'Cheng ',
    'Hui ',
    'Wu ',
    'Wu ',
    'You ',
    'Li ',
    'Liang ',
    'Huan ',
    'Cong ',
    'Yi ',
    'Yue ',
    'Li ',
    'Nin ',
    'Nao ',
    'E ',
    'Que ',
    'Xuan ',
    'Qian ',
    'Wu ',
    'Min ',
    'Cong ',
    'Fei ',
    'Bei ',
    'Duo ',
    'Cui ',
    'Chang ',
    'Men ',
    'Li ',
    'Ji ',
    'Guan ',
    'Guan ',
    'Xing ',
    'Dao ',
    'Qi ',
    'Kong ',
    'Tian ',
    'Lun ',
    'Xi ',
    'Kan ',
    'Kun ',
    'Ni ',
    'Qing ',
    'Chou ',
    'Dun ',
    'Guo ',
    'Chan ',
    'Liang ',
    'Wan ',
    'Yuan ',
    'Jin ',
    'Ji ',
    'Lin ',
    'Yu ',
    'Huo ',
    'He ',
    'Quan ',
    'Tan ',
    'Ti ',
    'Ti ',
    'Nie ',
    'Wang ',
    'Chuo ',
    'Bu ',
    'Hun ',
    'Xi ',
    'Tang ',
    'Xin ',
    'Wei ',
    'Hui ',
    'E ',
    'Rui ',
    'Zong ',
    'Jian ',
    'Yong ',
    'Dian ',
    'Ju ',
    'Can ',
    'Cheng ',
    'De ',
    'Bei ',
    'Qie ',
    'Can ',
    'Dan ',
    'Guan ',
    'Duo ',
    'Nao ',
    'Yun ',
    'Xiang ',
    'Zhui ',
    'Die ',
    'Huang ',
    'Chun ',
    'Qiong ',
    'Re ',
    'Xing ',
    'Ce ',
    'Bian ',
    'Hun ',
    'Zong ',
    'Ti '
];

},{}],"lJVZb":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Qiao ',
    'Chou ',
    'Bei ',
    'Xuan ',
    'Wei ',
    'Ge ',
    'Qian ',
    'Wei ',
    'Yu ',
    'Yu ',
    'Bi ',
    'Xuan ',
    'Huan ',
    'Min ',
    'Bi ',
    'Yi ',
    'Mian ',
    'Yong ',
    'Kai ',
    'Dang ',
    'Yin ',
    'E ',
    'Chen ',
    'Mou ',
    'Ke ',
    'Ke ',
    'Yu ',
    'Ai ',
    'Qie ',
    'Yan ',
    'Nuo ',
    'Gan ',
    'Yun ',
    'Zong ',
    'Sai ',
    'Leng ',
    'Fen ',
    "[?] ",
    'Kui ',
    'Kui ',
    'Que ',
    'Gong ',
    'Yun ',
    'Su ',
    'Su ',
    'Qi ',
    'Yao ',
    'Song ',
    'Huang ',
    'Ji ',
    'Gu ',
    'Ju ',
    'Chuang ',
    'Ni ',
    'Xie ',
    'Kai ',
    'Zheng ',
    'Yong ',
    'Cao ',
    'Sun ',
    'Shen ',
    'Bo ',
    'Kai ',
    'Yuan ',
    'Xie ',
    'Hun ',
    'Yong ',
    'Yang ',
    'Li ',
    'Sao ',
    'Tao ',
    'Yin ',
    'Ci ',
    'Xu ',
    'Qian ',
    'Tai ',
    'Huang ',
    'Yun ',
    'Shen ',
    'Ming ',
    "[?] ",
    'She ',
    'Cong ',
    'Piao ',
    'Mo ',
    'Mu ',
    'Guo ',
    'Chi ',
    'Can ',
    'Can ',
    'Can ',
    'Cui ',
    'Min ',
    'Te ',
    'Zhang ',
    'Tong ',
    'Ao ',
    'Shuang ',
    'Man ',
    'Guan ',
    'Que ',
    'Zao ',
    'Jiu ',
    'Hui ',
    'Kai ',
    'Lian ',
    'Ou ',
    'Song ',
    'Jin ',
    'Yin ',
    'Lu ',
    'Shang ',
    'Wei ',
    'Tuan ',
    'Man ',
    'Qian ',
    'She ',
    'Yong ',
    'Qing ',
    'Kang ',
    'Di ',
    'Zhi ',
    'Lou ',
    'Juan ',
    'Qi ',
    'Qi ',
    'Yu ',
    'Ping ',
    'Liao ',
    'Cong ',
    'You ',
    'Chong ',
    'Zhi ',
    'Tong ',
    'Cheng ',
    'Qi ',
    'Qu ',
    'Peng ',
    'Bei ',
    'Bie ',
    'Chun ',
    'Jiao ',
    'Zeng ',
    'Chi ',
    'Lian ',
    'Ping ',
    'Kui ',
    'Hui ',
    'Qiao ',
    'Cheng ',
    'Yin ',
    'Yin ',
    'Xi ',
    'Xi ',
    'Dan ',
    'Tan ',
    'Duo ',
    'Dui ',
    'Dui ',
    'Su ',
    'Jue ',
    'Ce ',
    'Xiao ',
    'Fan ',
    'Fen ',
    'Lao ',
    'Lao ',
    'Chong ',
    'Han ',
    'Qi ',
    'Xian ',
    'Min ',
    'Jing ',
    'Liao ',
    'Wu ',
    'Can ',
    'Jue ',
    'Cu ',
    'Xian ',
    'Tan ',
    'Sheng ',
    'Pi ',
    'Yi ',
    'Chu ',
    'Xian ',
    'Nao ',
    'Dan ',
    'Tan ',
    'Jing ',
    'Song ',
    'Han ',
    'Jiao ',
    'Wai ',
    'Huan ',
    'Dong ',
    'Qin ',
    'Qin ',
    'Qu ',
    'Cao ',
    'Ken ',
    'Xie ',
    'Ying ',
    'Ao ',
    'Mao ',
    'Yi ',
    'Lin ',
    'Se ',
    'Jun ',
    'Huai ',
    'Men ',
    'Lan ',
    'Ai ',
    'Lin ',
    'Yan ',
    'Gua ',
    'Xia ',
    'Chi ',
    'Yu ',
    'Yin ',
    'Dai ',
    'Meng ',
    'Ai ',
    'Meng ',
    'Dui ',
    'Qi ',
    'Mo ',
    'Lan ',
    'Men ',
    'Chou ',
    'Zhi ',
    'Nuo ',
    'Nuo ',
    'Yan ',
    'Yang ',
    'Bo ',
    'Zhi ',
    'Kuang ',
    'Kuang ',
    'You ',
    'Fu ',
    'Liu ',
    'Mie ',
    'Cheng ',
    "[?] ",
    'Chan ',
    'Meng ',
    'Lan ',
    'Huai ',
    'Xuan ',
    'Rang ',
    'Chan ',
    'Ji ',
    'Ju ',
    'Huan ',
    'She ',
    'Yi '
];

},{}],"iyfaK":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Lian ',
    'Nan ',
    'Mi ',
    'Tang ',
    'Jue ',
    'Gang ',
    'Gang ',
    'Gang ',
    'Ge ',
    'Yue ',
    'Wu ',
    'Jian ',
    'Xu ',
    'Shu ',
    'Rong ',
    'Xi ',
    'Cheng ',
    'Wo ',
    'Jie ',
    'Ge ',
    'Jian ',
    'Qiang ',
    'Huo ',
    'Qiang ',
    'Zhan ',
    'Dong ',
    'Qi ',
    'Jia ',
    'Die ',
    'Zei ',
    'Jia ',
    'Ji ',
    'Shi ',
    'Kan ',
    'Ji ',
    'Kui ',
    'Gai ',
    'Deng ',
    'Zhan ',
    'Chuang ',
    'Ge ',
    'Jian ',
    'Jie ',
    'Yu ',
    'Jian ',
    'Yan ',
    'Lu ',
    'Xi ',
    'Zhan ',
    'Xi ',
    'Xi ',
    'Chuo ',
    'Dai ',
    'Qu ',
    'Hu ',
    'Hu ',
    'Hu ',
    'E ',
    'Shi ',
    'Li ',
    'Mao ',
    'Hu ',
    'Li ',
    'Fang ',
    'Suo ',
    'Bian ',
    'Dian ',
    'Jiong ',
    'Shang ',
    'Yi ',
    'Yi ',
    'Shan ',
    'Hu ',
    'Fei ',
    'Yan ',
    'Shou ',
    'T ',
    'Cai ',
    'Zha ',
    'Qiu ',
    'Le ',
    'Bu ',
    'Ba ',
    'Da ',
    'Reng ',
    'Fu ',
    'Hameru ',
    'Zai ',
    'Tuo ',
    'Zhang ',
    'Diao ',
    'Kang ',
    'Yu ',
    'Ku ',
    'Han ',
    'Shen ',
    'Cha ',
    'Yi ',
    'Gu ',
    'Kou ',
    'Wu ',
    'Tuo ',
    'Qian ',
    'Zhi ',
    'Ren ',
    'Kuo ',
    'Men ',
    'Sao ',
    'Yang ',
    'Niu ',
    'Ban ',
    'Che ',
    'Rao ',
    'Xi ',
    'Qian ',
    'Ban ',
    'Jia ',
    'Yu ',
    'Fu ',
    'Ao ',
    'Xi ',
    'Pi ',
    'Zhi ',
    'Zi ',
    'E ',
    'Dun ',
    'Zhao ',
    'Cheng ',
    'Ji ',
    'Yan ',
    'Kuang ',
    'Bian ',
    'Chao ',
    'Ju ',
    'Wen ',
    'Hu ',
    'Yue ',
    'Jue ',
    'Ba ',
    'Qin ',
    'Zhen ',
    'Zheng ',
    'Yun ',
    'Wan ',
    'Nu ',
    'Yi ',
    'Shu ',
    'Zhua ',
    'Pou ',
    'Tou ',
    'Dou ',
    'Kang ',
    'Zhe ',
    'Pou ',
    'Fu ',
    'Pao ',
    'Ba ',
    'Ao ',
    'Ze ',
    'Tuan ',
    'Kou ',
    'Lun ',
    'Qiang ',
    "[?] ",
    'Hu ',
    'Bao ',
    'Bing ',
    'Zhi ',
    'Peng ',
    'Tan ',
    'Pu ',
    'Pi ',
    'Tai ',
    'Yao ',
    'Zhen ',
    'Zha ',
    'Yang ',
    'Bao ',
    'He ',
    'Ni ',
    'Yi ',
    'Di ',
    'Chi ',
    'Pi ',
    'Za ',
    'Mo ',
    'Mo ',
    'Shen ',
    'Ya ',
    'Chou ',
    'Qu ',
    'Min ',
    'Chu ',
    'Jia ',
    'Fu ',
    'Zhan ',
    'Zhu ',
    'Dan ',
    'Chai ',
    'Mu ',
    'Nian ',
    'La ',
    'Fu ',
    'Pao ',
    'Ban ',
    'Pai ',
    'Ling ',
    'Na ',
    'Guai ',
    'Qian ',
    'Ju ',
    'Tuo ',
    'Ba ',
    'Tuo ',
    'Tuo ',
    'Ao ',
    'Ju ',
    'Zhuo ',
    'Pan ',
    'Zhao ',
    'Bai ',
    'Bai ',
    'Di ',
    'Ni ',
    'Ju ',
    'Kuo ',
    'Long ',
    'Jian ',
    "[?] ",
    'Yong ',
    'Lan ',
    'Ning ',
    'Bo ',
    'Ze ',
    'Qian ',
    'Hen ',
    'Gua ',
    'Shi ',
    'Jie ',
    'Zheng ',
    'Nin ',
    'Gong ',
    'Gong ',
    'Quan ',
    'Shuan ',
    'Cun ',
    'Zan ',
    'Kao ',
    'Chi ',
    'Xie ',
    'Ce ',
    'Hui ',
    'Pin ',
    'Zhuai ',
    'Shi ',
    'Na '
];

},{}],"7SBaZ":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Bo ',
    'Chi ',
    'Gua ',
    'Zhi ',
    'Kuo ',
    'Duo ',
    'Duo ',
    'Zhi ',
    'Qie ',
    'An ',
    'Nong ',
    'Zhen ',
    'Ge ',
    'Jiao ',
    'Ku ',
    'Dong ',
    'Ru ',
    'Tiao ',
    'Lie ',
    'Zha ',
    'Lu ',
    'Die ',
    'Wa ',
    'Jue ',
    'Mushiru ',
    'Ju ',
    'Zhi ',
    'Luan ',
    'Ya ',
    'Zhua ',
    'Ta ',
    'Xie ',
    'Nao ',
    'Dang ',
    'Jiao ',
    'Zheng ',
    'Ji ',
    'Hui ',
    'Xun ',
    'Ku ',
    'Ai ',
    'Tuo ',
    'Nuo ',
    'Cuo ',
    'Bo ',
    'Geng ',
    'Ti ',
    'Zhen ',
    'Cheng ',
    'Suo ',
    'Suo ',
    'Keng ',
    'Mei ',
    'Long ',
    'Ju ',
    'Peng ',
    'Jian ',
    'Yi ',
    'Ting ',
    'Shan ',
    'Nuo ',
    'Wan ',
    'Xie ',
    'Cha ',
    'Feng ',
    'Jiao ',
    'Wu ',
    'Jun ',
    'Jiu ',
    'Tong ',
    'Kun ',
    'Huo ',
    'Tu ',
    'Zhuo ',
    'Pou ',
    'Le ',
    'Ba ',
    'Han ',
    'Shao ',
    'Nie ',
    'Juan ',
    'Ze ',
    'Song ',
    'Ye ',
    'Jue ',
    'Bu ',
    'Huan ',
    'Bu ',
    'Zun ',
    'Yi ',
    'Zhai ',
    'Lu ',
    'Sou ',
    'Tuo ',
    'Lao ',
    'Sun ',
    'Bang ',
    'Jian ',
    'Huan ',
    'Dao ',
    "[?] ",
    'Wan ',
    'Qin ',
    'Peng ',
    'She ',
    'Lie ',
    'Min ',
    'Men ',
    'Fu ',
    'Bai ',
    'Ju ',
    'Dao ',
    'Wo ',
    'Ai ',
    'Juan ',
    'Yue ',
    'Zong ',
    'Chen ',
    'Chui ',
    'Jie ',
    'Tu ',
    'Ben ',
    'Na ',
    'Nian ',
    'Nuo ',
    'Zu ',
    'Wo ',
    'Xi ',
    'Xian ',
    'Cheng ',
    'Dian ',
    'Sao ',
    'Lun ',
    'Qing ',
    'Gang ',
    'Duo ',
    'Shou ',
    'Diao ',
    'Pou ',
    'Di ',
    'Zhang ',
    'Gun ',
    'Ji ',
    'Tao ',
    'Qia ',
    'Qi ',
    'Pai ',
    'Shu ',
    'Qian ',
    'Ling ',
    'Yi ',
    'Ya ',
    'Jue ',
    'Zheng ',
    'Liang ',
    'Gua ',
    'Yi ',
    'Huo ',
    'Shan ',
    'Zheng ',
    'Lue ',
    'Cai ',
    'Tan ',
    'Che ',
    'Bing ',
    'Jie ',
    'Ti ',
    'Kong ',
    'Tui ',
    'Yan ',
    'Cuo ',
    'Zou ',
    'Ju ',
    'Tian ',
    'Qian ',
    'Ken ',
    'Bai ',
    'Shou ',
    'Jie ',
    'Lu ',
    'Guo ',
    'Haba ',
    "[?] ",
    'Zhi ',
    'Dan ',
    'Mang ',
    'Xian ',
    'Sao ',
    'Guan ',
    'Peng ',
    'Yuan ',
    'Nuo ',
    'Jian ',
    'Zhen ',
    'Jiu ',
    'Jian ',
    'Yu ',
    'Yan ',
    'Kui ',
    'Nan ',
    'Hong ',
    'Rou ',
    'Pi ',
    'Wei ',
    'Sai ',
    'Zou ',
    'Xuan ',
    'Miao ',
    'Ti ',
    'Nie ',
    'Cha ',
    'Shi ',
    'Zong ',
    'Zhen ',
    'Yi ',
    'Shun ',
    'Heng ',
    'Bian ',
    'Yang ',
    'Huan ',
    'Yan ',
    'Zuan ',
    'An ',
    'Xu ',
    'Ya ',
    'Wo ',
    'Ke ',
    'Chuai ',
    'Ji ',
    'Ti ',
    'La ',
    'La ',
    'Cheng ',
    'Kai ',
    'Jiu ',
    'Jiu ',
    'Tu ',
    'Jie ',
    'Hui ',
    'Geng ',
    'Chong ',
    'Shuo ',
    'She ',
    'Xie ',
    'Yuan ',
    'Qian ',
    'Ye ',
    'Cha ',
    'Zha ',
    'Bei ',
    'Yao ',
    "[?] ",
    "[?] ",
    'Lan ',
    'Wen ',
    'Qin '
];

},{}],"aPQEX":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Chan ',
    'Ge ',
    'Lou ',
    'Zong ',
    'Geng ',
    'Jiao ',
    'Gou ',
    'Qin ',
    'Yong ',
    'Que ',
    'Chou ',
    'Chi ',
    'Zhan ',
    'Sun ',
    'Sun ',
    'Bo ',
    'Chu ',
    'Rong ',
    'Beng ',
    'Cuo ',
    'Sao ',
    'Ke ',
    'Yao ',
    'Dao ',
    'Zhi ',
    'Nu ',
    'Xie ',
    'Jian ',
    'Sou ',
    'Qiu ',
    'Gao ',
    'Xian ',
    'Shuo ',
    'Sang ',
    'Jin ',
    'Mie ',
    'E ',
    'Chui ',
    'Nuo ',
    'Shan ',
    'Ta ',
    'Jie ',
    'Tang ',
    'Pan ',
    'Ban ',
    'Da ',
    'Li ',
    'Tao ',
    'Hu ',
    'Zhi ',
    'Wa ',
    'Xia ',
    'Qian ',
    'Wen ',
    'Qiang ',
    'Tian ',
    'Zhen ',
    'E ',
    'Xi ',
    'Nuo ',
    'Quan ',
    'Cha ',
    'Zha ',
    'Ge ',
    'Wu ',
    'En ',
    'She ',
    'Kang ',
    'She ',
    'Shu ',
    'Bai ',
    'Yao ',
    'Bin ',
    'Sou ',
    'Tan ',
    'Sa ',
    'Chan ',
    'Suo ',
    'Liao ',
    'Chong ',
    'Chuang ',
    'Guo ',
    'Bing ',
    'Feng ',
    'Shuai ',
    'Di ',
    'Qi ',
    'Sou ',
    'Zhai ',
    'Lian ',
    'Tang ',
    'Chi ',
    'Guan ',
    'Lu ',
    'Luo ',
    'Lou ',
    'Zong ',
    'Gai ',
    'Hu ',
    'Zha ',
    'Chuang ',
    'Tang ',
    'Hua ',
    'Cui ',
    'Nai ',
    'Mo ',
    'Jiang ',
    'Gui ',
    'Ying ',
    'Zhi ',
    'Ao ',
    'Zhi ',
    'Nie ',
    'Man ',
    'Shan ',
    'Kou ',
    'Shu ',
    'Suo ',
    'Tuan ',
    'Jiao ',
    'Mo ',
    'Mo ',
    'Zhe ',
    'Xian ',
    'Keng ',
    'Piao ',
    'Jiang ',
    'Yin ',
    'Gou ',
    'Qian ',
    'Lue ',
    'Ji ',
    'Ying ',
    'Jue ',
    'Pie ',
    'Pie ',
    'Lao ',
    'Dun ',
    'Xian ',
    'Ruan ',
    'Kui ',
    'Zan ',
    'Yi ',
    'Xun ',
    'Cheng ',
    'Cheng ',
    'Sa ',
    'Nao ',
    'Heng ',
    'Si ',
    'Qian ',
    'Huang ',
    'Da ',
    'Zun ',
    'Nian ',
    'Lin ',
    'Zheng ',
    'Hui ',
    'Zhuang ',
    'Jiao ',
    'Ji ',
    'Cao ',
    'Dan ',
    'Dan ',
    'Che ',
    'Bo ',
    'Che ',
    'Jue ',
    'Xiao ',
    'Liao ',
    'Ben ',
    'Fu ',
    'Qiao ',
    'Bo ',
    'Cuo ',
    'Zhuo ',
    'Zhuan ',
    'Tuo ',
    'Pu ',
    'Qin ',
    'Dun ',
    'Nian ',
    "[?] ",
    'Xie ',
    'Lu ',
    'Jiao ',
    'Cuan ',
    'Ta ',
    'Han ',
    'Qiao ',
    'Zhua ',
    'Jian ',
    'Gan ',
    'Yong ',
    'Lei ',
    'Kuo ',
    'Lu ',
    'Shan ',
    'Zhuo ',
    'Ze ',
    'Pu ',
    'Chuo ',
    'Ji ',
    'Dang ',
    'Suo ',
    'Cao ',
    'Qing ',
    'Jing ',
    'Huan ',
    'Jie ',
    'Qin ',
    'Kuai ',
    'Dan ',
    'Xi ',
    'Ge ',
    'Pi ',
    'Bo ',
    'Ao ',
    'Ju ',
    'Ye ',
    "[?] ",
    'Mang ',
    'Sou ',
    'Mi ',
    'Ji ',
    'Tai ',
    'Zhuo ',
    'Dao ',
    'Xing ',
    'Lan ',
    'Ca ',
    'Ju ',
    'Ye ',
    'Ru ',
    'Ye ',
    'Ye ',
    'Ni ',
    'Hu ',
    'Ji ',
    'Bin ',
    'Ning ',
    'Ge ',
    'Zhi ',
    'Jie ',
    'Kuo ',
    'Mo ',
    'Jian ',
    'Xie ',
    'Lie ',
    'Tan ',
    'Bai ',
    'Sou ',
    'Lu ',
    'Lue ',
    'Rao ',
    'Zhi '
];

},{}],"5K9I5":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Pan ',
    'Yang ',
    'Lei ',
    'Sa ',
    'Shu ',
    'Zan ',
    'Nian ',
    'Xian ',
    'Jun ',
    'Huo ',
    'Li ',
    'La ',
    'Han ',
    'Ying ',
    'Lu ',
    'Long ',
    'Qian ',
    'Qian ',
    'Zan ',
    'Qian ',
    'Lan ',
    'San ',
    'Ying ',
    'Mei ',
    'Rang ',
    'Chan ',
    "[?] ",
    'Cuan ',
    'Xi ',
    'She ',
    'Luo ',
    'Jun ',
    'Mi ',
    'Li ',
    'Zan ',
    'Luan ',
    'Tan ',
    'Zuan ',
    'Li ',
    'Dian ',
    'Wa ',
    'Dang ',
    'Jiao ',
    'Jue ',
    'Lan ',
    'Li ',
    'Nang ',
    'Zhi ',
    'Gui ',
    'Gui ',
    'Qi ',
    'Xin ',
    'Pu ',
    'Sui ',
    'Shou ',
    'Kao ',
    'You ',
    'Gai ',
    'Yi ',
    'Gong ',
    'Gan ',
    'Ban ',
    'Fang ',
    'Zheng ',
    'Bo ',
    'Dian ',
    'Kou ',
    'Min ',
    'Wu ',
    'Gu ',
    'He ',
    'Ce ',
    'Xiao ',
    'Mi ',
    'Chu ',
    'Ge ',
    'Di ',
    'Xu ',
    'Jiao ',
    'Min ',
    'Chen ',
    'Jiu ',
    'Zhen ',
    'Duo ',
    'Yu ',
    'Chi ',
    'Ao ',
    'Bai ',
    'Xu ',
    'Jiao ',
    'Duo ',
    'Lian ',
    'Nie ',
    'Bi ',
    'Chang ',
    'Dian ',
    'Duo ',
    'Yi ',
    'Gan ',
    'San ',
    'Ke ',
    'Yan ',
    'Dun ',
    'Qi ',
    'Dou ',
    'Xiao ',
    'Duo ',
    'Jiao ',
    'Jing ',
    'Yang ',
    'Xia ',
    'Min ',
    'Shu ',
    'Ai ',
    'Qiao ',
    'Ai ',
    'Zheng ',
    'Di ',
    'Zhen ',
    'Fu ',
    'Shu ',
    'Liao ',
    'Qu ',
    'Xiong ',
    'Xi ',
    'Jiao ',
    'Sen ',
    'Jiao ',
    'Zhuo ',
    'Yi ',
    'Lian ',
    'Bi ',
    'Li ',
    'Xiao ',
    'Xiao ',
    'Wen ',
    'Xue ',
    'Qi ',
    'Qi ',
    'Zhai ',
    'Bin ',
    'Jue ',
    'Zhai ',
    "[?] ",
    'Fei ',
    'Ban ',
    'Ban ',
    'Lan ',
    'Yu ',
    'Lan ',
    'Wei ',
    'Dou ',
    'Sheng ',
    'Liao ',
    'Jia ',
    'Hu ',
    'Xie ',
    'Jia ',
    'Yu ',
    'Zhen ',
    'Jiao ',
    'Wo ',
    'Tou ',
    'Chu ',
    'Jin ',
    'Chi ',
    'Yin ',
    'Fu ',
    'Qiang ',
    'Zhan ',
    'Qu ',
    'Zhuo ',
    'Zhan ',
    'Duan ',
    'Zhuo ',
    'Si ',
    'Xin ',
    'Zhuo ',
    'Zhuo ',
    'Qin ',
    'Lin ',
    'Zhuo ',
    'Chu ',
    'Duan ',
    'Zhu ',
    'Fang ',
    'Xie ',
    'Hang ',
    'Yu ',
    'Shi ',
    'Pei ',
    'You ',
    'Mye ',
    'Pang ',
    'Qi ',
    'Zhan ',
    'Mao ',
    'Lu ',
    'Pei ',
    'Pi ',
    'Liu ',
    'Fu ',
    'Fang ',
    'Xuan ',
    'Jing ',
    'Jing ',
    'Ni ',
    'Zu ',
    'Zhao ',
    'Yi ',
    'Liu ',
    'Shao ',
    'Jian ',
    'Es ',
    'Yi ',
    'Qi ',
    'Zhi ',
    'Fan ',
    'Piao ',
    'Fan ',
    'Zhan ',
    'Guai ',
    'Sui ',
    'Yu ',
    'Wu ',
    'Ji ',
    'Ji ',
    'Ji ',
    'Huo ',
    'Ri ',
    'Dan ',
    'Jiu ',
    'Zhi ',
    'Zao ',
    'Xie ',
    'Tiao ',
    'Xun ',
    'Xu ',
    'Xu ',
    'Xu ',
    'Gan ',
    'Han ',
    'Tai ',
    'Di ',
    'Xu ',
    'Chan ',
    'Shi ',
    'Kuang ',
    'Yang ',
    'Shi ',
    'Wang ',
    'Min ',
    'Min ',
    'Tun ',
    'Chun ',
    'Wu '
];

},{}],"Rwls2":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Yun ',
    'Bei ',
    'Ang ',
    'Ze ',
    'Ban ',
    'Jie ',
    'Kun ',
    'Sheng ',
    'Hu ',
    'Fang ',
    'Hao ',
    'Gui ',
    'Chang ',
    'Xuan ',
    'Ming ',
    'Hun ',
    'Fen ',
    'Qin ',
    'Hu ',
    'Yi ',
    'Xi ',
    'Xin ',
    'Yan ',
    'Ze ',
    'Fang ',
    'Tan ',
    'Shen ',
    'Ju ',
    'Yang ',
    'Zan ',
    'Bing ',
    'Xing ',
    'Ying ',
    'Xuan ',
    'Pei ',
    'Zhen ',
    'Ling ',
    'Chun ',
    'Hao ',
    'Mei ',
    'Zuo ',
    'Mo ',
    'Bian ',
    'Xu ',
    'Hun ',
    'Zhao ',
    'Zong ',
    'Shi ',
    'Shi ',
    'Yu ',
    'Fei ',
    'Die ',
    'Mao ',
    'Ni ',
    'Chang ',
    'Wen ',
    'Dong ',
    'Ai ',
    'Bing ',
    'Ang ',
    'Zhou ',
    'Long ',
    'Xian ',
    'Kuang ',
    'Tiao ',
    'Chao ',
    'Shi ',
    'Huang ',
    'Huang ',
    'Xuan ',
    'Kui ',
    'Xu ',
    'Jiao ',
    'Jin ',
    'Zhi ',
    'Jin ',
    'Shang ',
    'Tong ',
    'Hong ',
    'Yan ',
    'Gai ',
    'Xiang ',
    'Shai ',
    'Xiao ',
    'Ye ',
    'Yun ',
    'Hui ',
    'Han ',
    'Han ',
    'Jun ',
    'Wan ',
    'Xian ',
    'Kun ',
    'Zhou ',
    'Xi ',
    'Cheng ',
    'Sheng ',
    'Bu ',
    'Zhe ',
    'Zhe ',
    'Wu ',
    'Han ',
    'Hui ',
    'Hao ',
    'Chen ',
    'Wan ',
    'Tian ',
    'Zhuo ',
    'Zui ',
    'Zhou ',
    'Pu ',
    'Jing ',
    'Xi ',
    'Shan ',
    'Yi ',
    'Xi ',
    'Qing ',
    'Qi ',
    'Jing ',
    'Gui ',
    'Zhen ',
    'Yi ',
    'Zhi ',
    'An ',
    'Wan ',
    'Lin ',
    'Liang ',
    'Chang ',
    'Wang ',
    'Xiao ',
    'Zan ',
    'Hi ',
    'Xuan ',
    'Xuan ',
    'Yi ',
    'Xia ',
    'Yun ',
    'Hui ',
    'Fu ',
    'Min ',
    'Kui ',
    'He ',
    'Ying ',
    'Du ',
    'Wei ',
    'Shu ',
    'Qing ',
    'Mao ',
    'Nan ',
    'Jian ',
    'Nuan ',
    'An ',
    'Yang ',
    'Chun ',
    'Yao ',
    'Suo ',
    'Jin ',
    'Ming ',
    'Jiao ',
    'Kai ',
    'Gao ',
    'Weng ',
    'Chang ',
    'Qi ',
    'Hao ',
    'Yan ',
    'Li ',
    'Ai ',
    'Ji ',
    'Gui ',
    'Men ',
    'Zan ',
    'Xie ',
    'Hao ',
    'Mu ',
    'Mo ',
    'Cong ',
    'Ni ',
    'Zhang ',
    'Hui ',
    'Bao ',
    'Han ',
    'Xuan ',
    'Chuan ',
    'Liao ',
    'Xian ',
    'Dan ',
    'Jing ',
    'Pie ',
    'Lin ',
    'Tun ',
    'Xi ',
    'Yi ',
    'Ji ',
    'Huang ',
    'Tai ',
    'Ye ',
    'Ye ',
    'Li ',
    'Tan ',
    'Tong ',
    'Xiao ',
    'Fei ',
    'Qin ',
    'Zhao ',
    'Hao ',
    'Yi ',
    'Xiang ',
    'Xing ',
    'Sen ',
    'Jiao ',
    'Bao ',
    'Jing ',
    'Yian ',
    'Ai ',
    'Ye ',
    'Ru ',
    'Shu ',
    'Meng ',
    'Xun ',
    'Yao ',
    'Pu ',
    'Li ',
    'Chen ',
    'Kuang ',
    'Die ',
    "[?] ",
    'Yan ',
    'Huo ',
    'Lu ',
    'Xi ',
    'Rong ',
    'Long ',
    'Nang ',
    'Luo ',
    'Luan ',
    'Shai ',
    'Tang ',
    'Yan ',
    'Chu ',
    'Yue ',
    'Yue ',
    'Qu ',
    'Yi ',
    'Geng ',
    'Ye ',
    'Hu ',
    'He ',
    'Shu ',
    'Cao ',
    'Cao ',
    'Noboru ',
    'Man ',
    'Ceng ',
    'Ceng ',
    'Ti '
];

},{}],"bezhW":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Zui ',
    'Can ',
    'Xu ',
    'Hui ',
    'Yin ',
    'Qie ',
    'Fen ',
    'Pi ',
    'Yue ',
    'You ',
    'Ruan ',
    'Peng ',
    'Ban ',
    'Fu ',
    'Ling ',
    'Fei ',
    'Qu ',
    "[?] ",
    'Nu ',
    'Tiao ',
    'Shuo ',
    'Zhen ',
    'Lang ',
    'Lang ',
    'Juan ',
    'Ming ',
    'Huang ',
    'Wang ',
    'Tun ',
    'Zhao ',
    'Ji ',
    'Qi ',
    'Ying ',
    'Zong ',
    'Wang ',
    'Tong ',
    'Lang ',
    "[?] ",
    'Meng ',
    'Long ',
    'Mu ',
    'Deng ',
    'Wei ',
    'Mo ',
    'Ben ',
    'Zha ',
    'Zhu ',
    'Zhu ',
    "[?] ",
    'Zhu ',
    'Ren ',
    'Ba ',
    'Po ',
    'Duo ',
    'Duo ',
    'Dao ',
    'Li ',
    'Qiu ',
    'Ji ',
    'Jiu ',
    'Bi ',
    'Xiu ',
    'Ting ',
    'Ci ',
    'Sha ',
    'Eburi ',
    'Za ',
    'Quan ',
    'Qian ',
    'Yu ',
    'Gan ',
    'Wu ',
    'Cha ',
    'Shan ',
    'Xun ',
    'Fan ',
    'Wu ',
    'Zi ',
    'Li ',
    'Xing ',
    'Cai ',
    'Cun ',
    'Ren ',
    'Shao ',
    'Tuo ',
    'Di ',
    'Zhang ',
    'Mang ',
    'Chi ',
    'Yi ',
    'Gu ',
    'Gong ',
    'Du ',
    'Yi ',
    'Qi ',
    'Shu ',
    'Gang ',
    'Tiao ',
    'Moku ',
    'Soma ',
    'Tochi ',
    'Lai ',
    'Sugi ',
    'Mang ',
    'Yang ',
    'Ma ',
    'Miao ',
    'Si ',
    'Yuan ',
    'Hang ',
    'Fei ',
    'Bei ',
    'Jie ',
    'Dong ',
    'Gao ',
    'Yao ',
    'Xian ',
    'Chu ',
    'Qun ',
    'Pa ',
    'Shu ',
    'Hua ',
    'Xin ',
    'Chou ',
    'Zhu ',
    'Chou ',
    'Song ',
    'Ban ',
    'Song ',
    'Ji ',
    'Yue ',
    'Jin ',
    'Gou ',
    'Ji ',
    'Mao ',
    'Pi ',
    'Bi ',
    'Wang ',
    'Ang ',
    'Fang ',
    'Fen ',
    'Yi ',
    'Fu ',
    'Nan ',
    'Xi ',
    'Hu ',
    'Ya ',
    'Dou ',
    'Xun ',
    'Zhen ',
    'Yao ',
    'Lin ',
    'Rui ',
    'E ',
    'Mei ',
    'Zhao ',
    'Guo ',
    'Zhi ',
    'Cong ',
    'Yun ',
    'Waku ',
    'Dou ',
    'Shu ',
    'Zao ',
    "[?] ",
    'Li ',
    'Haze ',
    'Jian ',
    'Cheng ',
    'Matsu ',
    'Qiang ',
    'Feng ',
    'Nan ',
    'Xiao ',
    'Xian ',
    'Ku ',
    'Ping ',
    'Yi ',
    'Xi ',
    'Zhi ',
    'Guai ',
    'Xiao ',
    'Jia ',
    'Jia ',
    'Gou ',
    'Fu ',
    'Mo ',
    'Yi ',
    'Ye ',
    'Ye ',
    'Shi ',
    'Nie ',
    'Bi ',
    'Duo ',
    'Yi ',
    'Ling ',
    'Bing ',
    'Ni ',
    'La ',
    'He ',
    'Pan ',
    'Fan ',
    'Zhong ',
    'Dai ',
    'Ci ',
    'Yang ',
    'Fu ',
    'Bo ',
    'Mou ',
    'Gan ',
    'Qi ',
    'Ran ',
    'Rou ',
    'Mao ',
    'Zhao ',
    'Song ',
    'Zhe ',
    'Xia ',
    'You ',
    'Shen ',
    'Ju ',
    'Tuo ',
    'Zuo ',
    'Nan ',
    'Ning ',
    'Yong ',
    'Di ',
    'Zhi ',
    'Zha ',
    'Cha ',
    'Dan ',
    'Gu ',
    'Pu ',
    'Jiu ',
    'Ao ',
    'Fu ',
    'Jian ',
    'Bo ',
    'Duo ',
    'Ke ',
    'Nai ',
    'Zhu ',
    'Bi ',
    'Liu ',
    'Chai ',
    'Zha ',
    'Si ',
    'Zhu ',
    'Pei ',
    'Shi ',
    'Guai ',
    'Cha ',
    'Yao ',
    'Jue ',
    'Jiu ',
    'Shi '
];

},{}],"h3CUS":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:31 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Zhi ',
    'Liu ',
    'Mei ',
    'Hoy ',
    'Rong ',
    'Zha ',
    "[?] ",
    'Biao ',
    'Zhan ',
    'Jie ',
    'Long ',
    'Dong ',
    'Lu ',
    'Sayng ',
    'Li ',
    'Lan ',
    'Yong ',
    'Shu ',
    'Xun ',
    'Shuan ',
    'Qi ',
    'Zhen ',
    'Qi ',
    'Li ',
    'Yi ',
    'Xiang ',
    'Zhen ',
    'Li ',
    'Su ',
    'Gua ',
    'Kan ',
    'Bing ',
    'Ren ',
    'Xiao ',
    'Bo ',
    'Ren ',
    'Bing ',
    'Zi ',
    'Chou ',
    'Yi ',
    'Jie ',
    'Xu ',
    'Zhu ',
    'Jian ',
    'Zui ',
    'Er ',
    'Er ',
    'You ',
    'Fa ',
    'Gong ',
    'Kao ',
    'Lao ',
    'Zhan ',
    'Li ',
    'Yin ',
    'Yang ',
    'He ',
    'Gen ',
    'Zhi ',
    'Chi ',
    'Ge ',
    'Zai ',
    'Luan ',
    'Fu ',
    'Jie ',
    'Hang ',
    'Gui ',
    'Tao ',
    'Guang ',
    'Wei ',
    'Kuang ',
    'Ru ',
    'An ',
    'An ',
    'Juan ',
    'Yi ',
    'Zhuo ',
    'Ku ',
    'Zhi ',
    'Qiong ',
    'Tong ',
    'Sang ',
    'Sang ',
    'Huan ',
    'Jie ',
    'Jiu ',
    'Xue ',
    'Duo ',
    'Zhui ',
    'Yu ',
    'Zan ',
    'Kasei ',
    'Ying ',
    'Masu ',
    "[?] ",
    'Zhan ',
    'Ya ',
    'Nao ',
    'Zhen ',
    'Dang ',
    'Qi ',
    'Qiao ',
    'Hua ',
    'Kuai ',
    'Jiang ',
    'Zhuang ',
    'Xun ',
    'Suo ',
    'Sha ',
    'Zhen ',
    'Bei ',
    'Ting ',
    'Gua ',
    'Jing ',
    'Bo ',
    'Ben ',
    'Fu ',
    'Rui ',
    'Tong ',
    'Jue ',
    'Xi ',
    'Lang ',
    'Liu ',
    'Feng ',
    'Qi ',
    'Wen ',
    'Jun ',
    'Gan ',
    'Cu ',
    'Liang ',
    'Qiu ',
    'Ting ',
    'You ',
    'Mei ',
    'Bang ',
    'Long ',
    'Peng ',
    'Zhuang ',
    'Di ',
    'Xuan ',
    'Tu ',
    'Zao ',
    'Ao ',
    'Gu ',
    'Bi ',
    'Di ',
    'Han ',
    'Zi ',
    'Zhi ',
    'Ren ',
    'Bei ',
    'Geng ',
    'Jian ',
    'Huan ',
    'Wan ',
    'Nuo ',
    'Jia ',
    'Tiao ',
    'Ji ',
    'Xiao ',
    'Lu ',
    'Huan ',
    'Shao ',
    'Cen ',
    'Fen ',
    'Song ',
    'Meng ',
    'Wu ',
    'Li ',
    'Li ',
    'Dou ',
    'Cen ',
    'Ying ',
    'Suo ',
    'Ju ',
    'Ti ',
    'Jie ',
    'Kun ',
    'Zhuo ',
    'Shu ',
    'Chan ',
    'Fan ',
    'Wei ',
    'Jing ',
    'Li ',
    'Bing ',
    'Fumoto ',
    'Shikimi ',
    'Tao ',
    'Zhi ',
    'Lai ',
    'Lian ',
    'Jian ',
    'Zhuo ',
    'Ling ',
    'Li ',
    'Qi ',
    'Bing ',
    'Zhun ',
    'Cong ',
    'Qian ',
    'Mian ',
    'Qi ',
    'Qi ',
    'Cai ',
    'Gun ',
    'Chan ',
    'Te ',
    'Fei ',
    'Pai ',
    'Bang ',
    'Pou ',
    'Hun ',
    'Zong ',
    'Cheng ',
    'Zao ',
    'Ji ',
    'Li ',
    'Peng ',
    'Yu ',
    'Yu ',
    'Gu ',
    'Hun ',
    'Dong ',
    'Tang ',
    'Gang ',
    'Wang ',
    'Di ',
    'Xi ',
    'Fan ',
    'Cheng ',
    'Zhan ',
    'Qi ',
    'Yuan ',
    'Yan ',
    'Yu ',
    'Quan ',
    'Yi ',
    'Sen ',
    'Ren ',
    'Chui ',
    'Leng ',
    'Qi ',
    'Zhuo ',
    'Fu ',
    'Ke ',
    'Lai ',
    'Zou ',
    'Zou ',
    'Zhuo ',
    'Guan ',
    'Fen ',
    'Fen ',
    'Chen ',
    'Qiong ',
    'Nie '
];

},{}],"ancCc":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Wan ',
    'Guo ',
    'Lu ',
    'Hao ',
    'Jie ',
    'Yi ',
    'Chou ',
    'Ju ',
    'Ju ',
    'Cheng ',
    'Zuo ',
    'Liang ',
    'Qiang ',
    'Zhi ',
    'Zhui ',
    'Ya ',
    'Ju ',
    'Bei ',
    'Jiao ',
    'Zhuo ',
    'Zi ',
    'Bin ',
    'Peng ',
    'Ding ',
    'Chu ',
    'Chang ',
    'Kunugi ',
    'Momiji ',
    'Jian ',
    'Gui ',
    'Xi ',
    'Du ',
    'Qian ',
    'Kunugi ',
    'Soko ',
    'Shide ',
    'Luo ',
    'Zhi ',
    'Ken ',
    'Myeng ',
    'Tafu ',
    "[?] ",
    'Peng ',
    'Zhan ',
    "[?] ",
    'Tuo ',
    'Sen ',
    'Duo ',
    'Ye ',
    'Fou ',
    'Wei ',
    'Wei ',
    'Duan ',
    'Jia ',
    'Zong ',
    'Jian ',
    'Yi ',
    'Shen ',
    'Xi ',
    'Yan ',
    'Yan ',
    'Chuan ',
    'Zhan ',
    'Chun ',
    'Yu ',
    'He ',
    'Zha ',
    'Wo ',
    'Pian ',
    'Bi ',
    'Yao ',
    'Huo ',
    'Xu ',
    'Ruo ',
    'Yang ',
    'La ',
    'Yan ',
    'Ben ',
    'Hun ',
    'Kui ',
    'Jie ',
    'Kui ',
    'Si ',
    'Feng ',
    'Xie ',
    'Tuo ',
    'Zhi ',
    'Jian ',
    'Mu ',
    'Mao ',
    'Chu ',
    'Hu ',
    'Hu ',
    'Lian ',
    'Leng ',
    'Ting ',
    'Nan ',
    'Yu ',
    'You ',
    'Mei ',
    'Song ',
    'Xuan ',
    'Xuan ',
    'Ying ',
    'Zhen ',
    'Pian ',
    'Ye ',
    'Ji ',
    'Jie ',
    'Ye ',
    'Chu ',
    'Shun ',
    'Yu ',
    'Cou ',
    'Wei ',
    'Mei ',
    'Di ',
    'Ji ',
    'Jie ',
    'Kai ',
    'Qiu ',
    'Ying ',
    'Rou ',
    'Heng ',
    'Lou ',
    'Le ',
    'Hazou ',
    'Katsura ',
    'Pin ',
    'Muro ',
    'Gai ',
    'Tan ',
    'Lan ',
    'Yun ',
    'Yu ',
    'Chen ',
    'Lu ',
    'Ju ',
    'Sakaki ',
    "[?] ",
    'Pi ',
    'Xie ',
    'Jia ',
    'Yi ',
    'Zhan ',
    'Fu ',
    'Nai ',
    'Mi ',
    'Lang ',
    'Rong ',
    'Gu ',
    'Jian ',
    'Ju ',
    'Ta ',
    'Yao ',
    'Zhen ',
    'Bang ',
    'Sha ',
    'Yuan ',
    'Zi ',
    'Ming ',
    'Su ',
    'Jia ',
    'Yao ',
    'Jie ',
    'Huang ',
    'Gan ',
    'Fei ',
    'Zha ',
    'Qian ',
    'Ma ',
    'Sun ',
    'Yuan ',
    'Xie ',
    'Rong ',
    'Shi ',
    'Zhi ',
    'Cui ',
    'Yun ',
    'Ting ',
    'Liu ',
    'Rong ',
    'Tang ',
    'Que ',
    'Zhai ',
    'Si ',
    'Sheng ',
    'Ta ',
    'Ke ',
    'Xi ',
    'Gu ',
    'Qi ',
    'Kao ',
    'Gao ',
    'Sun ',
    'Pan ',
    'Tao ',
    'Ge ',
    'Xun ',
    'Dian ',
    'Nou ',
    'Ji ',
    'Shuo ',
    'Gou ',
    'Chui ',
    'Qiang ',
    'Cha ',
    'Qian ',
    'Huai ',
    'Mei ',
    'Xu ',
    'Gang ',
    'Gao ',
    'Zhuo ',
    'Tuo ',
    'Hashi ',
    'Yang ',
    'Dian ',
    'Jia ',
    'Jian ',
    'Zui ',
    'Kashi ',
    'Ori ',
    'Bin ',
    'Zhu ',
    "[?] ",
    'Xi ',
    'Qi ',
    'Lian ',
    'Hui ',
    'Yong ',
    'Qian ',
    'Guo ',
    'Gai ',
    'Gai ',
    'Tuan ',
    'Hua ',
    'Cu ',
    'Sen ',
    'Cui ',
    'Beng ',
    'You ',
    'Hu ',
    'Jiang ',
    'Hu ',
    'Huan ',
    'Kui ',
    'Yi ',
    'Nie ',
    'Gao ',
    'Kang ',
    'Gui ',
    'Gui ',
    'Cao ',
    'Man ',
    'Jin '
];

},{}],"baARH":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Di ',
    'Zhuang ',
    'Le ',
    'Lang ',
    'Chen ',
    'Cong ',
    'Li ',
    'Xiu ',
    'Qing ',
    'Shuang ',
    'Fan ',
    'Tong ',
    'Guan ',
    'Ji ',
    'Suo ',
    'Lei ',
    'Lu ',
    'Liang ',
    'Mi ',
    'Lou ',
    'Chao ',
    'Su ',
    'Ke ',
    'Shu ',
    'Tang ',
    'Biao ',
    'Lu ',
    'Jiu ',
    'Shu ',
    'Zha ',
    'Shu ',
    'Zhang ',
    'Men ',
    'Mo ',
    'Niao ',
    'Yang ',
    'Tiao ',
    'Peng ',
    'Zhu ',
    'Sha ',
    'Xi ',
    'Quan ',
    'Heng ',
    'Jian ',
    'Cong ',
    "[?] ",
    'Hokuso ',
    'Qiang ',
    'Tara ',
    'Ying ',
    'Er ',
    'Xin ',
    'Zhi ',
    'Qiao ',
    'Zui ',
    'Cong ',
    'Pu ',
    'Shu ',
    'Hua ',
    'Kui ',
    'Zhen ',
    'Zun ',
    'Yue ',
    'Zhan ',
    'Xi ',
    'Xun ',
    'Dian ',
    'Fa ',
    'Gan ',
    'Mo ',
    'Wu ',
    'Qiao ',
    'Nao ',
    'Lin ',
    'Liu ',
    'Qiao ',
    'Xian ',
    'Run ',
    'Fan ',
    'Zhan ',
    'Tuo ',
    'Lao ',
    'Yun ',
    'Shun ',
    'Tui ',
    'Cheng ',
    'Tang ',
    'Meng ',
    'Ju ',
    'Cheng ',
    'Su ',
    'Jue ',
    'Jue ',
    'Tan ',
    'Hui ',
    'Ji ',
    'Nuo ',
    'Xiang ',
    'Tuo ',
    'Ning ',
    'Rui ',
    'Zhu ',
    'Chuang ',
    'Zeng ',
    'Fen ',
    'Qiong ',
    'Ran ',
    'Heng ',
    'Cen ',
    'Gu ',
    'Liu ',
    'Lao ',
    'Gao ',
    'Chu ',
    'Zusa ',
    'Nude ',
    'Ca ',
    'San ',
    'Ji ',
    'Dou ',
    'Shou ',
    'Lu ',
    "[?] ",
    "[?] ",
    'Yuan ',
    'Ta ',
    'Shu ',
    'Jiang ',
    'Tan ',
    'Lin ',
    'Nong ',
    'Yin ',
    'Xi ',
    'Sui ',
    'Shan ',
    'Zui ',
    'Xuan ',
    'Cheng ',
    'Gan ',
    'Ju ',
    'Zui ',
    'Yi ',
    'Qin ',
    'Pu ',
    'Yan ',
    'Lei ',
    'Feng ',
    'Hui ',
    'Dang ',
    'Ji ',
    'Sui ',
    'Bo ',
    'Bi ',
    'Ding ',
    'Chu ',
    'Zhua ',
    'Kuai ',
    'Ji ',
    'Jie ',
    'Jia ',
    'Qing ',
    'Zhe ',
    'Jian ',
    'Qiang ',
    'Dao ',
    'Yi ',
    'Biao ',
    'Song ',
    'She ',
    'Lin ',
    'Kunugi ',
    'Cha ',
    'Meng ',
    'Yin ',
    'Tao ',
    'Tai ',
    'Mian ',
    'Qi ',
    'Toan ',
    'Bin ',
    'Huo ',
    'Ji ',
    'Qian ',
    'Mi ',
    'Ning ',
    'Yi ',
    'Gao ',
    'Jian ',
    'Yin ',
    'Er ',
    'Qing ',
    'Yan ',
    'Qi ',
    'Mi ',
    'Zhao ',
    'Gui ',
    'Chun ',
    'Ji ',
    'Kui ',
    'Po ',
    'Deng ',
    'Chu ',
    "[?] ",
    'Mian ',
    'You ',
    'Zhi ',
    'Guang ',
    'Qian ',
    'Lei ',
    'Lei ',
    'Sa ',
    'Lu ',
    'Li ',
    'Cuan ',
    'Lu ',
    'Mie ',
    'Hui ',
    'Ou ',
    'Lu ',
    'Jie ',
    'Gao ',
    'Du ',
    'Yuan ',
    'Li ',
    'Fei ',
    'Zhuo ',
    'Sou ',
    'Lian ',
    'Tamo ',
    'Chu ',
    "[?] ",
    'Zhu ',
    'Lu ',
    'Yan ',
    'Li ',
    'Zhu ',
    'Chen ',
    'Jie ',
    'E ',
    'Su ',
    'Huai ',
    'Nie ',
    'Yu ',
    'Long ',
    'Lai ',
    "[?] ",
    'Xian ',
    'Kwi ',
    'Ju ',
    'Xiao ',
    'Ling ',
    'Ying ',
    'Jian ',
    'Yin ',
    'You ',
    'Ying '
];

},{}],"5qSe9":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Xiang ',
    'Nong ',
    'Bo ',
    'Chan ',
    'Lan ',
    'Ju ',
    'Shuang ',
    'She ',
    'Wei ',
    'Cong ',
    'Quan ',
    'Qu ',
    'Cang ',
    "[?] ",
    'Yu ',
    'Luo ',
    'Li ',
    'Zan ',
    'Luan ',
    'Dang ',
    'Jue ',
    'Em ',
    'Lan ',
    'Lan ',
    'Zhu ',
    'Lei ',
    'Li ',
    'Ba ',
    'Nang ',
    'Yu ',
    'Ling ',
    'Tsuki ',
    'Qian ',
    'Ci ',
    'Huan ',
    'Xin ',
    'Yu ',
    'Yu ',
    'Qian ',
    'Ou ',
    'Xu ',
    'Chao ',
    'Chu ',
    'Chi ',
    'Kai ',
    'Yi ',
    'Jue ',
    'Xi ',
    'Xu ',
    'Xia ',
    'Yu ',
    'Kuai ',
    'Lang ',
    'Kuan ',
    'Shuo ',
    'Xi ',
    'Ai ',
    'Yi ',
    'Qi ',
    'Hu ',
    'Chi ',
    'Qin ',
    'Kuan ',
    'Kan ',
    'Kuan ',
    'Kan ',
    'Chuan ',
    'Sha ',
    'Gua ',
    'Yin ',
    'Xin ',
    'Xie ',
    'Yu ',
    'Qian ',
    'Xiao ',
    'Yi ',
    'Ge ',
    'Wu ',
    'Tan ',
    'Jin ',
    'Ou ',
    'Hu ',
    'Ti ',
    'Huan ',
    'Xu ',
    'Pen ',
    'Xi ',
    'Xiao ',
    'Xu ',
    'Xi ',
    'Sen ',
    'Lian ',
    'Chu ',
    'Yi ',
    'Kan ',
    'Yu ',
    'Chuo ',
    'Huan ',
    'Zhi ',
    'Zheng ',
    'Ci ',
    'Bu ',
    'Wu ',
    'Qi ',
    'Bu ',
    'Bu ',
    'Wai ',
    'Ju ',
    'Qian ',
    'Chi ',
    'Se ',
    'Chi ',
    'Se ',
    'Zhong ',
    'Sui ',
    'Sui ',
    'Li ',
    'Cuo ',
    'Yu ',
    'Li ',
    'Gui ',
    'Dai ',
    'Dai ',
    'Si ',
    'Jian ',
    'Zhe ',
    'Mo ',
    'Mo ',
    'Yao ',
    'Mo ',
    'Cu ',
    'Yang ',
    'Tian ',
    'Sheng ',
    'Dai ',
    'Shang ',
    'Xu ',
    'Xun ',
    'Shu ',
    'Can ',
    'Jue ',
    'Piao ',
    'Qia ',
    'Qiu ',
    'Su ',
    'Qing ',
    'Yun ',
    'Lian ',
    'Yi ',
    'Fou ',
    'Zhi ',
    'Ye ',
    'Can ',
    'Hun ',
    'Dan ',
    'Ji ',
    'Ye ',
    'Zhen ',
    'Yun ',
    'Wen ',
    'Chou ',
    'Bin ',
    'Ti ',
    'Jin ',
    'Shang ',
    'Yin ',
    'Diao ',
    'Cu ',
    'Hui ',
    'Cuan ',
    'Yi ',
    'Dan ',
    'Du ',
    'Jiang ',
    'Lian ',
    'Bin ',
    'Du ',
    'Tsukusu ',
    'Jian ',
    'Shu ',
    'Ou ',
    'Duan ',
    'Zhu ',
    'Yin ',
    'Qing ',
    'Yi ',
    'Sha ',
    'Que ',
    'Ke ',
    'Yao ',
    'Jun ',
    'Dian ',
    'Hui ',
    'Hui ',
    'Gu ',
    'Que ',
    'Ji ',
    'Yi ',
    'Ou ',
    'Hui ',
    'Duan ',
    'Yi ',
    'Xiao ',
    'Wu ',
    'Guan ',
    'Mu ',
    'Mei ',
    'Mei ',
    'Ai ',
    'Zuo ',
    'Du ',
    'Yu ',
    'Bi ',
    'Bi ',
    'Bi ',
    'Pi ',
    'Pi ',
    'Bi ',
    'Chan ',
    'Mao ',
    "[?] ",
    "[?] ",
    'Pu ',
    'Mushiru ',
    'Jia ',
    'Zhan ',
    'Sai ',
    'Mu ',
    'Tuo ',
    'Xun ',
    'Er ',
    'Rong ',
    'Xian ',
    'Ju ',
    'Mu ',
    'Hao ',
    'Qiu ',
    'Dou ',
    'Mushiru ',
    'Tan ',
    'Pei ',
    'Ju ',
    'Duo ',
    'Cui ',
    'Bi ',
    'San ',
    "[?] ",
    'Mao ',
    'Sui ',
    'Yu ',
    'Yu ',
    'Tuo ',
    'He ',
    'Jian ',
    'Ta ',
    'San '
];

},{}],"1h0Na":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Lu ',
    'Mu ',
    'Li ',
    'Tong ',
    'Rong ',
    'Chang ',
    'Pu ',
    'Luo ',
    'Zhan ',
    'Sao ',
    'Zhan ',
    'Meng ',
    'Luo ',
    'Qu ',
    'Die ',
    'Shi ',
    'Di ',
    'Min ',
    'Jue ',
    'Mang ',
    'Qi ',
    'Pie ',
    'Nai ',
    'Qi ',
    'Dao ',
    'Xian ',
    'Chuan ',
    'Fen ',
    'Ri ',
    'Nei ',
    "[?] ",
    'Fu ',
    'Shen ',
    'Dong ',
    'Qing ',
    'Qi ',
    'Yin ',
    'Xi ',
    'Hai ',
    'Yang ',
    'An ',
    'Ya ',
    'Ke ',
    'Qing ',
    'Ya ',
    'Dong ',
    'Dan ',
    'Lu ',
    'Qing ',
    'Yang ',
    'Yun ',
    'Yun ',
    'Shui ',
    'San ',
    'Zheng ',
    'Bing ',
    'Yong ',
    'Dang ',
    'Shitamizu ',
    'Le ',
    'Ni ',
    'Tun ',
    'Fan ',
    'Gui ',
    'Ting ',
    'Zhi ',
    'Qiu ',
    'Bin ',
    'Ze ',
    'Mian ',
    'Cuan ',
    'Hui ',
    'Diao ',
    'Yi ',
    'Cha ',
    'Zhuo ',
    'Chuan ',
    'Wan ',
    'Fan ',
    'Dai ',
    'Xi ',
    'Tuo ',
    'Mang ',
    'Qiu ',
    'Qi ',
    'Shan ',
    'Pai ',
    'Han ',
    'Qian ',
    'Wu ',
    'Wu ',
    'Xun ',
    'Si ',
    'Ru ',
    'Gong ',
    'Jiang ',
    'Chi ',
    'Wu ',
    'Tsuchi ',
    "[?] ",
    'Tang ',
    'Zhi ',
    'Chi ',
    'Qian ',
    'Mi ',
    'Yu ',
    'Wang ',
    'Qing ',
    'Jing ',
    'Rui ',
    'Jun ',
    'Hong ',
    'Tai ',
    'Quan ',
    'Ji ',
    'Bian ',
    'Bian ',
    'Gan ',
    'Wen ',
    'Zhong ',
    'Fang ',
    'Xiong ',
    'Jue ',
    'Hang ',
    'Niou ',
    'Qi ',
    'Fen ',
    'Xu ',
    'Xu ',
    'Qin ',
    'Yi ',
    'Wo ',
    'Yun ',
    'Yuan ',
    'Hang ',
    'Yan ',
    'Chen ',
    'Chen ',
    'Dan ',
    'You ',
    'Dun ',
    'Hu ',
    'Huo ',
    'Qie ',
    'Mu ',
    'Rou ',
    'Mei ',
    'Ta ',
    'Mian ',
    'Wu ',
    'Chong ',
    'Tian ',
    'Bi ',
    'Sha ',
    'Zhi ',
    'Pei ',
    'Pan ',
    'Zhui ',
    'Za ',
    'Gou ',
    'Liu ',
    'Mei ',
    'Ze ',
    'Feng ',
    'Ou ',
    'Li ',
    'Lun ',
    'Cang ',
    'Feng ',
    'Wei ',
    'Hu ',
    'Mo ',
    'Mei ',
    'Shu ',
    'Ju ',
    'Zan ',
    'Tuo ',
    'Tuo ',
    'Tuo ',
    'He ',
    'Li ',
    'Mi ',
    'Yi ',
    'Fa ',
    'Fei ',
    'You ',
    'Tian ',
    'Zhi ',
    'Zhao ',
    'Gu ',
    'Zhan ',
    'Yan ',
    'Si ',
    'Kuang ',
    'Jiong ',
    'Ju ',
    'Xie ',
    'Qiu ',
    'Yi ',
    'Jia ',
    'Zhong ',
    'Quan ',
    'Bo ',
    'Hui ',
    'Mi ',
    'Ben ',
    'Zhuo ',
    'Chu ',
    'Le ',
    'You ',
    'Gu ',
    'Hong ',
    'Gan ',
    'Fa ',
    'Mao ',
    'Si ',
    'Hu ',
    'Ping ',
    'Ci ',
    'Fan ',
    'Chi ',
    'Su ',
    'Ning ',
    'Cheng ',
    'Ling ',
    'Pao ',
    'Bo ',
    'Qi ',
    'Si ',
    'Ni ',
    'Ju ',
    'Yue ',
    'Zhu ',
    'Sheng ',
    'Lei ',
    'Xuan ',
    'Xue ',
    'Fu ',
    'Pan ',
    'Min ',
    'Tai ',
    'Yang ',
    'Ji ',
    'Yong ',
    'Guan ',
    'Beng ',
    'Xue ',
    'Long ',
    'Lu ',
    "[?] ",
    'Bo ',
    'Xie ',
    'Po ',
    'Ze ',
    'Jing ',
    'Yin '
];

},{}],"jK2LT":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Zhou ',
    'Ji ',
    'Yi ',
    'Hui ',
    'Hui ',
    'Zui ',
    'Cheng ',
    'Yin ',
    'Wei ',
    'Hou ',
    'Jian ',
    'Yang ',
    'Lie ',
    'Si ',
    'Ji ',
    'Er ',
    'Xing ',
    'Fu ',
    'Sa ',
    'Suo ',
    'Zhi ',
    'Yin ',
    'Wu ',
    'Xi ',
    'Kao ',
    'Zhu ',
    'Jiang ',
    'Luo ',
    "[?] ",
    'An ',
    'Dong ',
    'Yi ',
    'Mou ',
    'Lei ',
    'Yi ',
    'Mi ',
    'Quan ',
    'Jin ',
    'Mo ',
    'Wei ',
    'Xiao ',
    'Xie ',
    'Hong ',
    'Xu ',
    'Shuo ',
    'Kuang ',
    'Tao ',
    'Qie ',
    'Ju ',
    'Er ',
    'Zhou ',
    'Ru ',
    'Ping ',
    'Xun ',
    'Xiong ',
    'Zhi ',
    'Guang ',
    'Huan ',
    'Ming ',
    'Huo ',
    'Wa ',
    'Qia ',
    'Pai ',
    'Wu ',
    'Qu ',
    'Liu ',
    'Yi ',
    'Jia ',
    'Jing ',
    'Qian ',
    'Jiang ',
    'Jiao ',
    'Cheng ',
    'Shi ',
    'Zhuo ',
    'Ce ',
    'Pal ',
    'Kuai ',
    'Ji ',
    'Liu ',
    'Chan ',
    'Hun ',
    'Hu ',
    'Nong ',
    'Xun ',
    'Jin ',
    'Lie ',
    'Qiu ',
    'Wei ',
    'Zhe ',
    'Jun ',
    'Han ',
    'Bang ',
    'Mang ',
    'Zhuo ',
    'You ',
    'Xi ',
    'Bo ',
    'Dou ',
    'Wan ',
    'Hong ',
    'Yi ',
    'Pu ',
    'Ying ',
    'Lan ',
    'Hao ',
    'Lang ',
    'Han ',
    'Li ',
    'Geng ',
    'Fu ',
    'Wu ',
    'Lian ',
    'Chun ',
    'Feng ',
    'Yi ',
    'Yu ',
    'Tong ',
    'Lao ',
    'Hai ',
    'Jin ',
    'Jia ',
    'Chong ',
    'Weng ',
    'Mei ',
    'Sui ',
    'Cheng ',
    'Pei ',
    'Xian ',
    'Shen ',
    'Tu ',
    'Kun ',
    'Pin ',
    'Nie ',
    'Han ',
    'Jing ',
    'Xiao ',
    'She ',
    'Nian ',
    'Tu ',
    'Yong ',
    'Xiao ',
    'Xian ',
    'Ting ',
    'E ',
    'Su ',
    'Tun ',
    'Juan ',
    'Cen ',
    'Ti ',
    'Li ',
    'Shui ',
    'Si ',
    'Lei ',
    'Shui ',
    'Tao ',
    'Du ',
    'Lao ',
    'Lai ',
    'Lian ',
    'Wei ',
    'Wo ',
    'Yun ',
    'Huan ',
    'Di ',
    "[?] ",
    'Run ',
    'Jian ',
    'Zhang ',
    'Se ',
    'Fu ',
    'Guan ',
    'Xing ',
    'Shou ',
    'Shuan ',
    'Ya ',
    'Chuo ',
    'Zhang ',
    'Ye ',
    'Kong ',
    'Wo ',
    'Han ',
    'Tuo ',
    'Dong ',
    'He ',
    'Wo ',
    'Ju ',
    'Gan ',
    'Liang ',
    'Hun ',
    'Ta ',
    'Zhuo ',
    'Dian ',
    'Qie ',
    'De ',
    'Juan ',
    'Zi ',
    'Xi ',
    'Yao ',
    'Qi ',
    'Gu ',
    'Guo ',
    'Han ',
    'Lin ',
    'Tang ',
    'Zhou ',
    'Peng ',
    'Hao ',
    'Chang ',
    'Shu ',
    'Qi ',
    'Fang ',
    'Chi ',
    'Lu ',
    'Nao ',
    'Ju ',
    'Tao ',
    'Cong ',
    'Lei ',
    'Zhi ',
    'Peng ',
    'Fei ',
    'Song ',
    'Tian ',
    'Pi ',
    'Dan ',
    'Yu ',
    'Ni ',
    'Yu ',
    'Lu ',
    'Gan ',
    'Mi ',
    'Jing ',
    'Ling ',
    'Lun ',
    'Yin ',
    'Cui ',
    'Qu ',
    'Huai ',
    'Yu ',
    'Nian ',
    'Shen ',
    'Piao ',
    'Chun ',
    'Wa ',
    'Yuan ',
    'Lai ',
    'Hun ',
    'Qing ',
    'Yan ',
    'Qian ',
    'Tian ',
    'Miao ',
    'Zhi ',
    'Yin ',
    'Mi '
];

},{}],"jwwwq":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Ben ',
    'Yuan ',
    'Wen ',
    'Re ',
    'Fei ',
    'Qing ',
    'Yuan ',
    'Ke ',
    'Ji ',
    'She ',
    'Yuan ',
    'Shibui ',
    'Lu ',
    'Zi ',
    'Du ',
    "[?] ",
    'Jian ',
    'Min ',
    'Pi ',
    'Tani ',
    'Yu ',
    'Yuan ',
    'Shen ',
    'Shen ',
    'Rou ',
    'Huan ',
    'Zhu ',
    'Jian ',
    'Nuan ',
    'Yu ',
    'Qiu ',
    'Ting ',
    'Qu ',
    'Du ',
    'Feng ',
    'Zha ',
    'Bo ',
    'Wo ',
    'Wo ',
    'Di ',
    'Wei ',
    'Wen ',
    'Ru ',
    'Xie ',
    'Ce ',
    'Wei ',
    'Ge ',
    'Gang ',
    'Yan ',
    'Hong ',
    'Xuan ',
    'Mi ',
    'Ke ',
    'Mao ',
    'Ying ',
    'Yan ',
    'You ',
    'Hong ',
    'Miao ',
    'Xing ',
    'Mei ',
    'Zai ',
    'Hun ',
    'Nai ',
    'Kui ',
    'Shi ',
    'E ',
    'Pai ',
    'Mei ',
    'Lian ',
    'Qi ',
    'Qi ',
    'Mei ',
    'Tian ',
    'Cou ',
    'Wei ',
    'Can ',
    'Tuan ',
    'Mian ',
    'Hui ',
    'Mo ',
    'Xu ',
    'Ji ',
    'Pen ',
    'Jian ',
    'Jian ',
    'Hu ',
    'Feng ',
    'Xiang ',
    'Yi ',
    'Yin ',
    'Zhan ',
    'Shi ',
    'Jie ',
    'Cheng ',
    'Huang ',
    'Tan ',
    'Yu ',
    'Bi ',
    'Min ',
    'Shi ',
    'Tu ',
    'Sheng ',
    'Yong ',
    'Qu ',
    'Zhong ',
    'Suei ',
    'Jiu ',
    'Jiao ',
    'Qiou ',
    'Yin ',
    'Tang ',
    'Long ',
    'Huo ',
    'Yuan ',
    'Nan ',
    'Ban ',
    'You ',
    'Quan ',
    'Chui ',
    'Liang ',
    'Chan ',
    'Yan ',
    'Chun ',
    'Nie ',
    'Zi ',
    'Wan ',
    'Shi ',
    'Man ',
    'Ying ',
    'Ratsu ',
    'Kui ',
    "[?] ",
    'Jian ',
    'Xu ',
    'Lu ',
    'Gui ',
    'Gai ',
    "[?] ",
    "[?] ",
    'Po ',
    'Jin ',
    'Gui ',
    'Tang ',
    'Yuan ',
    'Suo ',
    'Yuan ',
    'Lian ',
    'Yao ',
    'Meng ',
    'Zhun ',
    'Sheng ',
    'Ke ',
    'Tai ',
    'Da ',
    'Wa ',
    'Liu ',
    'Gou ',
    'Sao ',
    'Ming ',
    'Zha ',
    'Shi ',
    'Yi ',
    'Lun ',
    'Ma ',
    'Pu ',
    'Wei ',
    'Li ',
    'Cai ',
    'Wu ',
    'Xi ',
    'Wen ',
    'Qiang ',
    'Ze ',
    'Shi ',
    'Su ',
    'Yi ',
    'Zhen ',
    'Sou ',
    'Yun ',
    'Xiu ',
    'Yin ',
    'Rong ',
    'Hun ',
    'Su ',
    'Su ',
    'Ni ',
    'Ta ',
    'Shi ',
    'Ru ',
    'Wei ',
    'Pan ',
    'Chu ',
    'Chu ',
    'Pang ',
    'Weng ',
    'Cang ',
    'Mie ',
    'He ',
    'Dian ',
    'Hao ',
    'Huang ',
    'Xi ',
    'Zi ',
    'Di ',
    'Zhi ',
    'Ying ',
    'Fu ',
    'Jie ',
    'Hua ',
    'Ge ',
    'Zi ',
    'Tao ',
    'Teng ',
    'Sui ',
    'Bi ',
    'Jiao ',
    'Hui ',
    'Gun ',
    'Yin ',
    'Gao ',
    'Long ',
    'Zhi ',
    'Yan ',
    'She ',
    'Man ',
    'Ying ',
    'Chun ',
    'Lu ',
    'Lan ',
    'Luan ',
    "[?] ",
    'Bin ',
    'Tan ',
    'Yu ',
    'Sou ',
    'Hu ',
    'Bi ',
    'Biao ',
    'Zhi ',
    'Jiang ',
    'Kou ',
    'Shen ',
    'Shang ',
    'Di ',
    'Mi ',
    'Ao ',
    'Lu ',
    'Hu ',
    'Hu ',
    'You ',
    'Chan ',
    'Fan ',
    'Yong ',
    'Gun ',
    'Man '
];

},{}],"bKFl0":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Qing ',
    'Yu ',
    'Piao ',
    'Ji ',
    'Ya ',
    'Jiao ',
    'Qi ',
    'Xi ',
    'Ji ',
    'Lu ',
    'Lu ',
    'Long ',
    'Jin ',
    'Guo ',
    'Cong ',
    'Lou ',
    'Zhi ',
    'Gai ',
    'Qiang ',
    'Li ',
    'Yan ',
    'Cao ',
    'Jiao ',
    'Cong ',
    'Qun ',
    'Tuan ',
    'Ou ',
    'Teng ',
    'Ye ',
    'Xi ',
    'Mi ',
    'Tang ',
    'Mo ',
    'Shang ',
    'Han ',
    'Lian ',
    'Lan ',
    'Wa ',
    'Li ',
    'Qian ',
    'Feng ',
    'Xuan ',
    'Yi ',
    'Man ',
    'Zi ',
    'Mang ',
    'Kang ',
    'Lei ',
    'Peng ',
    'Shu ',
    'Zhang ',
    'Zhang ',
    'Chong ',
    'Xu ',
    'Huan ',
    'Kuo ',
    'Jian ',
    'Yan ',
    'Chuang ',
    'Liao ',
    'Cui ',
    'Ti ',
    'Yang ',
    'Jiang ',
    'Cong ',
    'Ying ',
    'Hong ',
    'Xun ',
    'Shu ',
    'Guan ',
    'Ying ',
    'Xiao ',
    "[?] ",
    "[?] ",
    'Xu ',
    'Lian ',
    'Zhi ',
    'Wei ',
    'Pi ',
    'Jue ',
    'Jiao ',
    'Po ',
    'Dang ',
    'Hui ',
    'Jie ',
    'Wu ',
    'Pa ',
    'Ji ',
    'Pan ',
    'Gui ',
    'Xiao ',
    'Qian ',
    'Qian ',
    'Xi ',
    'Lu ',
    'Xi ',
    'Xuan ',
    'Dun ',
    'Huang ',
    'Min ',
    'Run ',
    'Su ',
    'Liao ',
    'Zhen ',
    'Zhong ',
    'Yi ',
    'Di ',
    'Wan ',
    'Dan ',
    'Tan ',
    'Chao ',
    'Xun ',
    'Kui ',
    'Yie ',
    'Shao ',
    'Tu ',
    'Zhu ',
    'San ',
    'Hei ',
    'Bi ',
    'Shan ',
    'Chan ',
    'Chan ',
    'Shu ',
    'Tong ',
    'Pu ',
    'Lin ',
    'Wei ',
    'Se ',
    'Se ',
    'Cheng ',
    'Jiong ',
    'Cheng ',
    'Hua ',
    'Jiao ',
    'Lao ',
    'Che ',
    'Gan ',
    'Cun ',
    'Heng ',
    'Si ',
    'Shu ',
    'Peng ',
    'Han ',
    'Yun ',
    'Liu ',
    'Hong ',
    'Fu ',
    'Hao ',
    'He ',
    'Xian ',
    'Jian ',
    'Shan ',
    'Xi ',
    'Oki ',
    "[?] ",
    'Lan ',
    "[?] ",
    'Yu ',
    'Lin ',
    'Min ',
    'Zao ',
    'Dang ',
    'Wan ',
    'Ze ',
    'Xie ',
    'Yu ',
    'Li ',
    'Shi ',
    'Xue ',
    'Ling ',
    'Man ',
    'Zi ',
    'Yong ',
    'Kuai ',
    'Can ',
    'Lian ',
    'Dian ',
    'Ye ',
    'Ao ',
    'Huan ',
    'Zhen ',
    'Chan ',
    'Man ',
    'Dan ',
    'Dan ',
    'Yi ',
    'Sui ',
    'Pi ',
    'Ju ',
    'Ta ',
    'Qin ',
    'Ji ',
    'Zhuo ',
    'Lian ',
    'Nong ',
    'Guo ',
    'Jin ',
    'Fen ',
    'Se ',
    'Ji ',
    'Sui ',
    'Hui ',
    'Chu ',
    'Ta ',
    'Song ',
    'Ding ',
    "[?] ",
    'Zhu ',
    'Lai ',
    'Bin ',
    'Lian ',
    'Mi ',
    'Shi ',
    'Shu ',
    'Mi ',
    'Ning ',
    'Ying ',
    'Ying ',
    'Meng ',
    'Jin ',
    'Qi ',
    'Pi ',
    'Ji ',
    'Hao ',
    'Ru ',
    'Zui ',
    'Wo ',
    'Tao ',
    'Yin ',
    'Yin ',
    'Dui ',
    'Ci ',
    'Huo ',
    'Jing ',
    'Lan ',
    'Jun ',
    'Ai ',
    'Pu ',
    'Zhuo ',
    'Wei ',
    'Bin ',
    'Gu ',
    'Qian ',
    'Xing ',
    'Hama ',
    'Kuo ',
    'Fei ',
    "[?] ",
    'Boku ',
    'Jian ',
    'Wei ',
    'Luo ',
    'Zan ',
    'Lu ',
    'Li '
];

},{}],"lf5mY":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'You ',
    'Yang ',
    'Lu ',
    'Si ',
    'Jie ',
    'Ying ',
    'Du ',
    'Wang ',
    'Hui ',
    'Xie ',
    'Pan ',
    'Shen ',
    'Biao ',
    'Chan ',
    'Mo ',
    'Liu ',
    'Jian ',
    'Pu ',
    'Se ',
    'Cheng ',
    'Gu ',
    'Bin ',
    'Huo ',
    'Xian ',
    'Lu ',
    'Qin ',
    'Han ',
    'Ying ',
    'Yong ',
    'Li ',
    'Jing ',
    'Xiao ',
    'Ying ',
    'Sui ',
    'Wei ',
    'Xie ',
    'Huai ',
    'Hao ',
    'Zhu ',
    'Long ',
    'Lai ',
    'Dui ',
    'Fan ',
    'Hu ',
    'Lai ',
    "[?] ",
    "[?] ",
    'Ying ',
    'Mi ',
    'Ji ',
    'Lian ',
    'Jian ',
    'Ying ',
    'Fen ',
    'Lin ',
    'Yi ',
    'Jian ',
    'Yue ',
    'Chan ',
    'Dai ',
    'Rang ',
    'Jian ',
    'Lan ',
    'Fan ',
    'Shuang ',
    'Yuan ',
    'Zhuo ',
    'Feng ',
    'She ',
    'Lei ',
    'Lan ',
    'Cong ',
    'Qu ',
    'Yong ',
    'Qian ',
    'Fa ',
    'Guan ',
    'Que ',
    'Yan ',
    'Hao ',
    'Hyeng ',
    'Sa ',
    'Zan ',
    'Luan ',
    'Yan ',
    'Li ',
    'Mi ',
    'Shan ',
    'Tan ',
    'Dang ',
    'Jiao ',
    'Chan ',
    "[?] ",
    'Hao ',
    'Ba ',
    'Zhu ',
    'Lan ',
    'Lan ',
    'Nang ',
    'Wan ',
    'Luan ',
    'Xun ',
    'Xian ',
    'Yan ',
    'Gan ',
    'Yan ',
    'Yu ',
    'Huo ',
    'Si ',
    'Mie ',
    'Guang ',
    'Deng ',
    'Hui ',
    'Xiao ',
    'Xiao ',
    'Hu ',
    'Hong ',
    'Ling ',
    'Zao ',
    'Zhuan ',
    'Jiu ',
    'Zha ',
    'Xie ',
    'Chi ',
    'Zhuo ',
    'Zai ',
    'Zai ',
    'Can ',
    'Yang ',
    'Qi ',
    'Zhong ',
    'Fen ',
    'Niu ',
    'Jiong ',
    'Wen ',
    'Po ',
    'Yi ',
    'Lu ',
    'Chui ',
    'Pi ',
    'Kai ',
    'Pan ',
    'Yan ',
    'Kai ',
    'Pang ',
    'Mu ',
    'Chao ',
    'Liao ',
    'Gui ',
    'Kang ',
    'Tun ',
    'Guang ',
    'Xin ',
    'Zhi ',
    'Guang ',
    'Guang ',
    'Wei ',
    'Qiang ',
    "[?] ",
    'Da ',
    'Xia ',
    'Zheng ',
    'Zhu ',
    'Ke ',
    'Zhao ',
    'Fu ',
    'Ba ',
    'Duo ',
    'Duo ',
    'Ling ',
    'Zhuo ',
    'Xuan ',
    'Ju ',
    'Tan ',
    'Pao ',
    'Jiong ',
    'Pao ',
    'Tai ',
    'Tai ',
    'Bing ',
    'Yang ',
    'Tong ',
    'Han ',
    'Zhu ',
    'Zha ',
    'Dian ',
    'Wei ',
    'Shi ',
    'Lian ',
    'Chi ',
    'Huang ',
    "[?] ",
    'Hu ',
    'Shuo ',
    'Lan ',
    'Jing ',
    'Jiao ',
    'Xu ',
    'Xing ',
    'Quan ',
    'Lie ',
    'Huan ',
    'Yang ',
    'Xiao ',
    'Xiu ',
    'Xian ',
    'Yin ',
    'Wu ',
    'Zhou ',
    'Yao ',
    'Shi ',
    'Wei ',
    'Tong ',
    'Xue ',
    'Zai ',
    'Kai ',
    'Hong ',
    'Luo ',
    'Xia ',
    'Zhu ',
    'Xuan ',
    'Zheng ',
    'Po ',
    'Yan ',
    'Hui ',
    'Guang ',
    'Zhe ',
    'Hui ',
    'Kao ',
    "[?] ",
    'Fan ',
    'Shao ',
    'Ye ',
    'Hui ',
    "[?] ",
    'Tang ',
    'Jin ',
    'Re ',
    "[?] ",
    'Xi ',
    'Fu ',
    'Jiong ',
    'Che ',
    'Pu ',
    'Jing ',
    'Zhuo ',
    'Ting ',
    'Wan ',
    'Hai ',
    'Peng ',
    'Lang ',
    'Shan ',
    'Hu ',
    'Feng ',
    'Chi ',
    'Rong '
];

},{}],"1kC3b":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Hu ',
    'Xi ',
    'Shu ',
    'He ',
    'Xun ',
    'Ku ',
    'Jue ',
    'Xiao ',
    'Xi ',
    'Yan ',
    'Han ',
    'Zhuang ',
    'Jun ',
    'Di ',
    'Xie ',
    'Ji ',
    'Wu ',
    "[?] ",
    "[?] ",
    'Han ',
    'Yan ',
    'Huan ',
    'Men ',
    'Ju ',
    'Chou ',
    'Bei ',
    'Fen ',
    'Lin ',
    'Kun ',
    'Hun ',
    'Tun ',
    'Xi ',
    'Cui ',
    'Wu ',
    'Hong ',
    'Ju ',
    'Fu ',
    'Wo ',
    'Jiao ',
    'Cong ',
    'Feng ',
    'Ping ',
    'Qiong ',
    'Ruo ',
    'Xi ',
    'Qiong ',
    'Xin ',
    'Zhuo ',
    'Yan ',
    'Yan ',
    'Yi ',
    'Jue ',
    'Yu ',
    'Gang ',
    'Ran ',
    'Pi ',
    'Gu ',
    "[?] ",
    'Sheng ',
    'Chang ',
    'Shao ',
    "[?] ",
    "[?] ",
    "[?] ",
    "[?] ",
    'Chen ',
    'He ',
    'Kui ',
    'Zhong ',
    'Duan ',
    'Xia ',
    'Hui ',
    'Feng ',
    'Lian ',
    'Xuan ',
    'Xing ',
    'Huang ',
    'Jiao ',
    'Jian ',
    'Bi ',
    'Ying ',
    'Zhu ',
    'Wei ',
    'Tuan ',
    'Tian ',
    'Xi ',
    'Nuan ',
    'Nuan ',
    'Chan ',
    'Yan ',
    'Jiong ',
    'Jiong ',
    'Yu ',
    'Mei ',
    'Sha ',
    'Wei ',
    'Ye ',
    'Xin ',
    'Qiong ',
    'Rou ',
    'Mei ',
    'Huan ',
    'Xu ',
    'Zhao ',
    'Wei ',
    'Fan ',
    'Qiu ',
    'Sui ',
    'Yang ',
    'Lie ',
    'Zhu ',
    'Jie ',
    'Gao ',
    'Gua ',
    'Bao ',
    'Hu ',
    'Yun ',
    'Xia ',
    "[?] ",
    "[?] ",
    'Bian ',
    'Gou ',
    'Tui ',
    'Tang ',
    'Chao ',
    'Shan ',
    'N ',
    'Bo ',
    'Huang ',
    'Xie ',
    'Xi ',
    'Wu ',
    'Xi ',
    'Yun ',
    'He ',
    'He ',
    'Xi ',
    'Yun ',
    'Xiong ',
    'Nai ',
    'Shan ',
    'Qiong ',
    'Yao ',
    'Xun ',
    'Mi ',
    'Lian ',
    'Ying ',
    'Wen ',
    'Rong ',
    'Oozutsu ',
    "[?] ",
    'Qiang ',
    'Liu ',
    'Xi ',
    'Bi ',
    'Biao ',
    'Zong ',
    'Lu ',
    'Jian ',
    'Shou ',
    'Yi ',
    'Lou ',
    'Feng ',
    'Sui ',
    'Yi ',
    'Tong ',
    'Jue ',
    'Zong ',
    'Yun ',
    'Hu ',
    'Yi ',
    'Zhi ',
    'Ao ',
    'Wei ',
    'Liao ',
    'Han ',
    'Ou ',
    'Re ',
    'Jiong ',
    'Man ',
    "[?] ",
    'Shang ',
    'Cuan ',
    'Zeng ',
    'Jian ',
    'Xi ',
    'Xi ',
    'Xi ',
    'Yi ',
    'Xiao ',
    'Chi ',
    'Huang ',
    'Chan ',
    'Ye ',
    'Qian ',
    'Ran ',
    'Yan ',
    'Xian ',
    'Qiao ',
    'Zun ',
    'Deng ',
    'Dun ',
    'Shen ',
    'Jiao ',
    'Fen ',
    'Si ',
    'Liao ',
    'Yu ',
    'Lin ',
    'Tong ',
    'Shao ',
    'Fen ',
    'Fan ',
    'Yan ',
    'Xun ',
    'Lan ',
    'Mei ',
    'Tang ',
    'Yi ',
    'Jing ',
    'Men ',
    "[?] ",
    "[?] ",
    'Ying ',
    'Yu ',
    'Yi ',
    'Xue ',
    'Lan ',
    'Tai ',
    'Zao ',
    'Can ',
    'Sui ',
    'Xi ',
    'Que ',
    'Cong ',
    'Lian ',
    'Hui ',
    'Zhu ',
    'Xie ',
    'Ling ',
    'Wei ',
    'Yi ',
    'Xie ',
    'Zhao ',
    'Hui ',
    'Tatsu ',
    'Nung ',
    'Lan ',
    'Ru ',
    'Xian ',
    'Kao ',
    'Xun ',
    'Jin ',
    'Chou ',
    'Chou ',
    'Yao '
];

},{}],"kXeHy":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'He ',
    'Lan ',
    'Biao ',
    'Rong ',
    'Li ',
    'Mo ',
    'Bao ',
    'Ruo ',
    'Lu ',
    'La ',
    'Ao ',
    'Xun ',
    'Kuang ',
    'Shuo ',
    "[?] ",
    'Li ',
    'Lu ',
    'Jue ',
    'Liao ',
    'Yan ',
    'Xi ',
    'Xie ',
    'Long ',
    'Ye ',
    "[?] ",
    'Rang ',
    'Yue ',
    'Lan ',
    'Cong ',
    'Jue ',
    'Tong ',
    'Guan ',
    "[?] ",
    'Che ',
    'Mi ',
    'Tang ',
    'Lan ',
    'Zhu ',
    "[?] ",
    'Ling ',
    'Cuan ',
    'Yu ',
    'Zhua ',
    'Tsumekanmuri ',
    'Pa ',
    'Zheng ',
    'Pao ',
    'Cheng ',
    'Yuan ',
    'Ai ',
    'Wei ',
    "[?] ",
    'Jue ',
    'Jue ',
    'Fu ',
    'Ye ',
    'Ba ',
    'Die ',
    'Ye ',
    'Yao ',
    'Zu ',
    'Shuang ',
    'Er ',
    'Qiang ',
    'Chuang ',
    'Ge ',
    'Zang ',
    'Die ',
    'Qiang ',
    'Yong ',
    'Qiang ',
    'Pian ',
    'Ban ',
    'Pan ',
    'Shao ',
    'Jian ',
    'Pai ',
    'Du ',
    'Chuang ',
    'Tou ',
    'Zha ',
    'Bian ',
    'Die ',
    'Bang ',
    'Bo ',
    'Chuang ',
    'You ',
    "[?] ",
    'Du ',
    'Ya ',
    'Cheng ',
    'Niu ',
    'Ushihen ',
    'Pin ',
    'Jiu ',
    'Mou ',
    'Tuo ',
    'Mu ',
    'Lao ',
    'Ren ',
    'Mang ',
    'Fang ',
    'Mao ',
    'Mu ',
    'Gang ',
    'Wu ',
    'Yan ',
    'Ge ',
    'Bei ',
    'Si ',
    'Jian ',
    'Gu ',
    'You ',
    'Ge ',
    'Sheng ',
    'Mu ',
    'Di ',
    'Qian ',
    'Quan ',
    'Quan ',
    'Zi ',
    'Te ',
    'Xi ',
    'Mang ',
    'Keng ',
    'Qian ',
    'Wu ',
    'Gu ',
    'Xi ',
    'Li ',
    'Li ',
    'Pou ',
    'Ji ',
    'Gang ',
    'Zhi ',
    'Ben ',
    'Quan ',
    'Run ',
    'Du ',
    'Ju ',
    'Jia ',
    'Jian ',
    'Feng ',
    'Pian ',
    'Ke ',
    'Ju ',
    'Kao ',
    'Chu ',
    'Xi ',
    'Bei ',
    'Luo ',
    'Jie ',
    'Ma ',
    'San ',
    'Wei ',
    'Li ',
    'Dun ',
    'Tong ',
    "[?] ",
    'Jiang ',
    'Ikenie ',
    'Li ',
    'Du ',
    'Lie ',
    'Pi ',
    'Piao ',
    'Bao ',
    'Xi ',
    'Chou ',
    'Wei ',
    'Kui ',
    'Chou ',
    'Quan ',
    'Fan ',
    'Ba ',
    'Fan ',
    'Qiu ',
    'Ji ',
    'Cai ',
    'Chuo ',
    'An ',
    'Jie ',
    'Zhuang ',
    'Guang ',
    'Ma ',
    'You ',
    'Kang ',
    'Bo ',
    'Hou ',
    'Ya ',
    'Yin ',
    'Huan ',
    'Zhuang ',
    'Yun ',
    'Kuang ',
    'Niu ',
    'Di ',
    'Qing ',
    'Zhong ',
    'Mu ',
    'Bei ',
    'Pi ',
    'Ju ',
    'Ni ',
    'Sheng ',
    'Pao ',
    'Xia ',
    'Tuo ',
    'Hu ',
    'Ling ',
    'Fei ',
    'Pi ',
    'Ni ',
    'Ao ',
    'You ',
    'Gou ',
    'Yue ',
    'Ju ',
    'Dan ',
    'Po ',
    'Gu ',
    'Xian ',
    'Ning ',
    'Huan ',
    'Hen ',
    'Jiao ',
    'He ',
    'Zhao ',
    'Ji ',
    'Xun ',
    'Shan ',
    'Ta ',
    'Rong ',
    'Shou ',
    'Tong ',
    'Lao ',
    'Du ',
    'Xia ',
    'Shi ',
    'Hua ',
    'Zheng ',
    'Yu ',
    'Sun ',
    'Yu ',
    'Bi ',
    'Mang ',
    'Xi ',
    'Juan ',
    'Li ',
    'Xia ',
    'Yin ',
    'Suan ',
    'Lang ',
    'Bei ',
    'Zhi ',
    'Yan '
];

},{}],"8gHCc":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Sha ',
    'Li ',
    'Han ',
    'Xian ',
    'Jing ',
    'Pai ',
    'Fei ',
    'Yao ',
    'Ba ',
    'Qi ',
    'Ni ',
    'Biao ',
    'Yin ',
    'Lai ',
    'Xi ',
    'Jian ',
    'Qiang ',
    'Kun ',
    'Yan ',
    'Guo ',
    'Zong ',
    'Mi ',
    'Chang ',
    'Yi ',
    'Zhi ',
    'Zheng ',
    'Ya ',
    'Meng ',
    'Cai ',
    'Cu ',
    'She ',
    'Kari ',
    'Cen ',
    'Luo ',
    'Hu ',
    'Zong ',
    'Ji ',
    'Wei ',
    'Feng ',
    'Wo ',
    'Yuan ',
    'Xing ',
    'Zhu ',
    'Mao ',
    'Wei ',
    'Yuan ',
    'Xian ',
    'Tuan ',
    'Ya ',
    'Nao ',
    'Xie ',
    'Jia ',
    'Hou ',
    'Bian ',
    'You ',
    'You ',
    'Mei ',
    'Zha ',
    'Yao ',
    'Sun ',
    'Bo ',
    'Ming ',
    'Hua ',
    'Yuan ',
    'Sou ',
    'Ma ',
    'Yuan ',
    'Dai ',
    'Yu ',
    'Shi ',
    'Hao ',
    "[?] ",
    'Yi ',
    'Zhen ',
    'Chuang ',
    'Hao ',
    'Man ',
    'Jing ',
    'Jiang ',
    'Mu ',
    'Zhang ',
    'Chan ',
    'Ao ',
    'Ao ',
    'Hao ',
    'Cui ',
    'Fen ',
    'Jue ',
    'Bi ',
    'Bi ',
    'Huang ',
    'Pu ',
    'Lin ',
    'Yu ',
    'Tong ',
    'Yao ',
    'Liao ',
    'Shuo ',
    'Xiao ',
    'Swu ',
    'Ton ',
    'Xi ',
    'Ge ',
    'Juan ',
    'Du ',
    'Hui ',
    'Kuai ',
    'Xian ',
    'Xie ',
    'Ta ',
    'Xian ',
    'Xun ',
    'Ning ',
    'Pin ',
    'Huo ',
    'Nou ',
    'Meng ',
    'Lie ',
    'Nao ',
    'Guang ',
    'Shou ',
    'Lu ',
    'Ta ',
    'Xian ',
    'Mi ',
    'Rang ',
    'Huan ',
    'Nao ',
    'Luo ',
    'Xian ',
    'Qi ',
    'Jue ',
    'Xuan ',
    'Miao ',
    'Zi ',
    'Lu ',
    'Lu ',
    'Yu ',
    'Su ',
    'Wang ',
    'Qiu ',
    'Ga ',
    'Ding ',
    'Le ',
    'Ba ',
    'Ji ',
    'Hong ',
    'Di ',
    'Quan ',
    'Gan ',
    'Jiu ',
    'Yu ',
    'Ji ',
    'Yu ',
    'Yang ',
    'Ma ',
    'Gong ',
    'Wu ',
    'Fu ',
    'Wen ',
    'Jie ',
    'Ya ',
    'Fen ',
    'Bian ',
    'Beng ',
    'Yue ',
    'Jue ',
    'Yun ',
    'Jue ',
    'Wan ',
    'Jian ',
    'Mei ',
    'Dan ',
    'Pi ',
    'Wei ',
    'Huan ',
    'Xian ',
    'Qiang ',
    'Ling ',
    'Dai ',
    'Yi ',
    'An ',
    'Ping ',
    'Dian ',
    'Fu ',
    'Xuan ',
    'Xi ',
    'Bo ',
    'Ci ',
    'Gou ',
    'Jia ',
    'Shao ',
    'Po ',
    'Ci ',
    'Ke ',
    'Ran ',
    'Sheng ',
    'Shen ',
    'Yi ',
    'Zu ',
    'Jia ',
    'Min ',
    'Shan ',
    'Liu ',
    'Bi ',
    'Zhen ',
    'Zhen ',
    'Jue ',
    'Fa ',
    'Long ',
    'Jin ',
    'Jiao ',
    'Jian ',
    'Li ',
    'Guang ',
    'Xian ',
    'Zhou ',
    'Gong ',
    'Yan ',
    'Xiu ',
    'Yang ',
    'Xu ',
    'Luo ',
    'Su ',
    'Zhu ',
    'Qin ',
    'Ken ',
    'Xun ',
    'Bao ',
    'Er ',
    'Xiang ',
    'Yao ',
    'Xia ',
    'Heng ',
    'Gui ',
    'Chong ',
    'Xu ',
    'Ban ',
    'Pei ',
    "[?] ",
    'Dang ',
    'Ei ',
    'Hun ',
    'Wen ',
    'E ',
    'Cheng ',
    'Ti ',
    'Wu ',
    'Wu ',
    'Cheng ',
    'Jun ',
    'Mei ',
    'Bei ',
    'Ting ',
    'Xian ',
    'Chuo '
];

},{}],"6PUNT":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Han ',
    'Xuan ',
    'Yan ',
    'Qiu ',
    'Quan ',
    'Lang ',
    'Li ',
    'Xiu ',
    'Fu ',
    'Liu ',
    'Ye ',
    'Xi ',
    'Ling ',
    'Li ',
    'Jin ',
    'Lian ',
    'Suo ',
    'Chiisai ',
    "[?] ",
    'Wan ',
    'Dian ',
    'Pin ',
    'Zhan ',
    'Cui ',
    'Min ',
    'Yu ',
    'Ju ',
    'Chen ',
    'Lai ',
    'Wen ',
    'Sheng ',
    'Wei ',
    'Dian ',
    'Chu ',
    'Zhuo ',
    'Pei ',
    'Cheng ',
    'Hu ',
    'Qi ',
    'E ',
    'Kun ',
    'Chang ',
    'Qi ',
    'Beng ',
    'Wan ',
    'Lu ',
    'Cong ',
    'Guan ',
    'Yan ',
    'Diao ',
    'Bei ',
    'Lin ',
    'Qin ',
    'Pi ',
    'Pa ',
    'Que ',
    'Zhuo ',
    'Qin ',
    'Fa ',
    "[?] ",
    'Qiong ',
    'Du ',
    'Jie ',
    'Hun ',
    'Yu ',
    'Mao ',
    'Mei ',
    'Chun ',
    'Xuan ',
    'Ti ',
    'Xing ',
    'Dai ',
    'Rou ',
    'Min ',
    'Zhen ',
    'Wei ',
    'Ruan ',
    'Huan ',
    'Jie ',
    'Chuan ',
    'Jian ',
    'Zhuan ',
    'Yang ',
    'Lian ',
    'Quan ',
    'Xia ',
    'Duan ',
    'Yuan ',
    'Ye ',
    'Nao ',
    'Hu ',
    'Ying ',
    'Yu ',
    'Huang ',
    'Rui ',
    'Se ',
    'Liu ',
    'Shi ',
    'Rong ',
    'Suo ',
    'Yao ',
    'Wen ',
    'Wu ',
    'Jin ',
    'Jin ',
    'Ying ',
    'Ma ',
    'Tao ',
    'Liu ',
    'Tang ',
    'Li ',
    'Lang ',
    'Gui ',
    'Zhen ',
    'Qiang ',
    'Cuo ',
    'Jue ',
    'Zhao ',
    'Yao ',
    'Ai ',
    'Bin ',
    'Tu ',
    'Chang ',
    'Kun ',
    'Zhuan ',
    'Cong ',
    'Jin ',
    'Yi ',
    'Cui ',
    'Cong ',
    'Qi ',
    'Li ',
    'Ying ',
    'Suo ',
    'Qiu ',
    'Xuan ',
    'Ao ',
    'Lian ',
    'Man ',
    'Zhang ',
    'Yin ',
    "[?] ",
    'Ying ',
    'Zhi ',
    'Lu ',
    'Wu ',
    'Deng ',
    'Xiou ',
    'Zeng ',
    'Xun ',
    'Qu ',
    'Dang ',
    'Lin ',
    'Liao ',
    'Qiong ',
    'Su ',
    'Huang ',
    'Gui ',
    'Pu ',
    'Jing ',
    'Fan ',
    'Jin ',
    'Liu ',
    'Ji ',
    "[?] ",
    'Jing ',
    'Ai ',
    'Bi ',
    'Can ',
    'Qu ',
    'Zao ',
    'Dang ',
    'Jiao ',
    'Gun ',
    'Tan ',
    'Hui ',
    'Huan ',
    'Se ',
    'Sui ',
    'Tian ',
    "[?] ",
    'Yu ',
    'Jin ',
    'Lu ',
    'Bin ',
    'Shou ',
    'Wen ',
    'Zui ',
    'Lan ',
    'Xi ',
    'Ji ',
    'Xuan ',
    'Ruan ',
    'Huo ',
    'Gai ',
    'Lei ',
    'Du ',
    'Li ',
    'Zhi ',
    'Rou ',
    'Li ',
    'Zan ',
    'Qiong ',
    'Zhe ',
    'Gui ',
    'Sui ',
    'La ',
    'Long ',
    'Lu ',
    'Li ',
    'Zan ',
    'Lan ',
    'Ying ',
    'Mi ',
    'Xiang ',
    'Xi ',
    'Guan ',
    'Dao ',
    'Zan ',
    'Huan ',
    'Gua ',
    'Bo ',
    'Die ',
    'Bao ',
    'Hu ',
    'Zhi ',
    'Piao ',
    'Ban ',
    'Rang ',
    'Li ',
    'Wa ',
    'Dekaguramu ',
    'Jiang ',
    'Qian ',
    'Fan ',
    'Pen ',
    'Fang ',
    'Dan ',
    'Weng ',
    'Ou ',
    'Deshiguramu ',
    'Miriguramu ',
    'Thon ',
    'Hu ',
    'Ling ',
    'Yi ',
    'Ping ',
    'Ci ',
    'Hekutogura ',
    'Juan ',
    'Chang ',
    'Chi ',
    'Sarake ',
    'Dang ',
    'Meng ',
    'Pou '
];

},{}],"8nNhZ":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Zhui ',
    'Ping ',
    'Bian ',
    'Zhou ',
    'Zhen ',
    'Senchigura ',
    'Ci ',
    'Ying ',
    'Qi ',
    'Xian ',
    'Lou ',
    'Di ',
    'Ou ',
    'Meng ',
    'Zhuan ',
    'Peng ',
    'Lin ',
    'Zeng ',
    'Wu ',
    'Pi ',
    'Dan ',
    'Weng ',
    'Ying ',
    'Yan ',
    'Gan ',
    'Dai ',
    'Shen ',
    'Tian ',
    'Tian ',
    'Han ',
    'Chang ',
    'Sheng ',
    'Qing ',
    'Sheng ',
    'Chan ',
    'Chan ',
    'Rui ',
    'Sheng ',
    'Su ',
    'Sen ',
    'Yong ',
    'Shuai ',
    'Lu ',
    'Fu ',
    'Yong ',
    'Beng ',
    'Feng ',
    'Ning ',
    'Tian ',
    'You ',
    'Jia ',
    'Shen ',
    'Zha ',
    'Dian ',
    'Fu ',
    'Nan ',
    'Dian ',
    'Ping ',
    'Ting ',
    'Hua ',
    'Ting ',
    'Quan ',
    'Zi ',
    'Meng ',
    'Bi ',
    'Qi ',
    'Liu ',
    'Xun ',
    'Liu ',
    'Chang ',
    'Mu ',
    'Yun ',
    'Fan ',
    'Fu ',
    'Geng ',
    'Tian ',
    'Jie ',
    'Jie ',
    'Quan ',
    'Wei ',
    'Fu ',
    'Tian ',
    'Mu ',
    'Tap ',
    'Pan ',
    'Jiang ',
    'Wa ',
    'Da ',
    'Nan ',
    'Liu ',
    'Ben ',
    'Zhen ',
    'Chu ',
    'Mu ',
    'Mu ',
    'Ce ',
    'Cen ',
    'Gai ',
    'Bi ',
    'Da ',
    'Zhi ',
    'Lue ',
    'Qi ',
    'Lue ',
    'Pan ',
    'Kesa ',
    'Fan ',
    'Hua ',
    'Yu ',
    'Yu ',
    'Mu ',
    'Jun ',
    'Yi ',
    'Liu ',
    'Yu ',
    'Die ',
    'Chou ',
    'Hua ',
    'Dang ',
    'Chuo ',
    'Ji ',
    'Wan ',
    'Jiang ',
    'Sheng ',
    'Chang ',
    'Tuan ',
    'Lei ',
    'Ji ',
    'Cha ',
    'Liu ',
    'Tatamu ',
    'Tuan ',
    'Lin ',
    'Jiang ',
    'Jiang ',
    'Chou ',
    'Bo ',
    'Die ',
    'Die ',
    'Pi ',
    'Nie ',
    'Dan ',
    'Shu ',
    'Shu ',
    'Zhi ',
    'Yi ',
    'Chuang ',
    'Nai ',
    'Ding ',
    'Bi ',
    'Jie ',
    'Liao ',
    'Gong ',
    'Ge ',
    'Jiu ',
    'Zhou ',
    'Xia ',
    'Shan ',
    'Xu ',
    'Nue ',
    'Li ',
    'Yang ',
    'Chen ',
    'You ',
    'Ba ',
    'Jie ',
    'Jue ',
    'Zhi ',
    'Xia ',
    'Cui ',
    'Bi ',
    'Yi ',
    'Li ',
    'Zong ',
    'Chuang ',
    'Feng ',
    'Zhu ',
    'Pao ',
    'Pi ',
    'Gan ',
    'Ke ',
    'Ci ',
    'Xie ',
    'Qi ',
    'Dan ',
    'Zhen ',
    'Fa ',
    'Zhi ',
    'Teng ',
    'Ju ',
    'Ji ',
    'Fei ',
    'Qu ',
    'Dian ',
    'Jia ',
    'Xian ',
    'Cha ',
    'Bing ',
    'Ni ',
    'Zheng ',
    'Yong ',
    'Jing ',
    'Quan ',
    'Chong ',
    'Tong ',
    'Yi ',
    'Kai ',
    'Wei ',
    'Hui ',
    'Duo ',
    'Yang ',
    'Chi ',
    'Zhi ',
    'Hen ',
    'Ya ',
    'Mei ',
    'Dou ',
    'Jing ',
    'Xiao ',
    'Tong ',
    'Tu ',
    'Mang ',
    'Pi ',
    'Xiao ',
    'Suan ',
    'Pu ',
    'Li ',
    'Zhi ',
    'Cuo ',
    'Duo ',
    'Wu ',
    'Sha ',
    'Lao ',
    'Shou ',
    'Huan ',
    'Xian ',
    'Yi ',
    'Peng ',
    'Zhang ',
    'Guan ',
    'Tan ',
    'Fei ',
    'Ma ',
    'Lin ',
    'Chi ',
    'Ji ',
    'Dian ',
    'An ',
    'Chi ',
    'Bi ',
    'Bei ',
    'Min ',
    'Gu ',
    'Dui ',
    'E ',
    'Wei '
];

},{}],"6h7yr":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Yu ',
    'Cui ',
    'Ya ',
    'Zhu ',
    'Cu ',
    'Dan ',
    'Shen ',
    'Zhung ',
    'Ji ',
    'Yu ',
    'Hou ',
    'Feng ',
    'La ',
    'Yang ',
    'Shen ',
    'Tu ',
    'Yu ',
    'Gua ',
    'Wen ',
    'Huan ',
    'Ku ',
    'Jia ',
    'Yin ',
    'Yi ',
    'Lu ',
    'Sao ',
    'Jue ',
    'Chi ',
    'Xi ',
    'Guan ',
    'Yi ',
    'Wen ',
    'Ji ',
    'Chuang ',
    'Ban ',
    'Lei ',
    'Liu ',
    'Chai ',
    'Shou ',
    'Nue ',
    'Dian ',
    'Da ',
    'Pie ',
    'Tan ',
    'Zhang ',
    'Biao ',
    'Shen ',
    'Cu ',
    'Luo ',
    'Yi ',
    'Zong ',
    'Chou ',
    'Zhang ',
    'Zhai ',
    'Sou ',
    'Suo ',
    'Que ',
    'Diao ',
    'Lou ',
    'Lu ',
    'Mo ',
    'Jin ',
    'Yin ',
    'Ying ',
    'Huang ',
    'Fu ',
    'Liao ',
    'Long ',
    'Qiao ',
    'Liu ',
    'Lao ',
    'Xian ',
    'Fei ',
    'Dan ',
    'Yin ',
    'He ',
    'Yan ',
    'Ban ',
    'Xian ',
    'Guan ',
    'Guai ',
    'Nong ',
    'Yu ',
    'Wei ',
    'Yi ',
    'Yong ',
    'Pi ',
    'Lei ',
    'Li ',
    'Shu ',
    'Dan ',
    'Lin ',
    'Dian ',
    'Lin ',
    'Lai ',
    'Pie ',
    'Ji ',
    'Chi ',
    'Yang ',
    'Xian ',
    'Jie ',
    'Zheng ',
    "[?] ",
    'Li ',
    'Huo ',
    'Lai ',
    'Shaku ',
    'Dian ',
    'Xian ',
    'Ying ',
    'Yin ',
    'Qu ',
    'Yong ',
    'Tan ',
    'Dian ',
    'Luo ',
    'Luan ',
    'Luan ',
    'Bo ',
    "[?] ",
    'Gui ',
    'Po ',
    'Fa ',
    'Deng ',
    'Fa ',
    'Bai ',
    'Bai ',
    'Qie ',
    'Bi ',
    'Zao ',
    'Zao ',
    'Mao ',
    'De ',
    'Pa ',
    'Jie ',
    'Huang ',
    'Gui ',
    'Ci ',
    'Ling ',
    'Gao ',
    'Mo ',
    'Ji ',
    'Jiao ',
    'Peng ',
    'Gao ',
    'Ai ',
    'E ',
    'Hao ',
    'Han ',
    'Bi ',
    'Wan ',
    'Chou ',
    'Qian ',
    'Xi ',
    'Ai ',
    'Jiong ',
    'Hao ',
    'Huang ',
    'Hao ',
    'Ze ',
    'Cui ',
    'Hao ',
    'Xiao ',
    'Ye ',
    'Po ',
    'Hao ',
    'Jiao ',
    'Ai ',
    'Xing ',
    'Huang ',
    'Li ',
    'Piao ',
    'He ',
    'Jiao ',
    'Pi ',
    'Gan ',
    'Pao ',
    'Zhou ',
    'Jun ',
    'Qiu ',
    'Cun ',
    'Que ',
    'Zha ',
    'Gu ',
    'Jun ',
    'Jun ',
    'Zhou ',
    'Zha ',
    'Gu ',
    'Zhan ',
    'Du ',
    'Min ',
    'Qi ',
    'Ying ',
    'Yu ',
    'Bei ',
    'Zhao ',
    'Zhong ',
    'Pen ',
    'He ',
    'Ying ',
    'He ',
    'Yi ',
    'Bo ',
    'Wan ',
    'He ',
    'Ang ',
    'Zhan ',
    'Yan ',
    'Jian ',
    'He ',
    'Yu ',
    'Kui ',
    'Fan ',
    'Gai ',
    'Dao ',
    'Pan ',
    'Fu ',
    'Qiu ',
    'Sheng ',
    'Dao ',
    'Lu ',
    'Zhan ',
    'Meng ',
    'Li ',
    'Jin ',
    'Xu ',
    'Jian ',
    'Pan ',
    'Guan ',
    'An ',
    'Lu ',
    'Shu ',
    'Zhou ',
    'Dang ',
    'An ',
    'Gu ',
    'Li ',
    'Mu ',
    'Cheng ',
    'Gan ',
    'Xu ',
    'Mang ',
    'Mang ',
    'Zhi ',
    'Qi ',
    'Ruan ',
    'Tian ',
    'Xiang ',
    'Dun ',
    'Xin ',
    'Xi ',
    'Pan ',
    'Feng ',
    'Dun ',
    'Min '
];

},{}],"c9gcj":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:32 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Ming ',
    'Sheng ',
    'Shi ',
    'Yun ',
    'Mian ',
    'Pan ',
    'Fang ',
    'Miao ',
    'Dan ',
    'Mei ',
    'Mao ',
    'Kan ',
    'Xian ',
    'Ou ',
    'Shi ',
    'Yang ',
    'Zheng ',
    'Yao ',
    'Shen ',
    'Huo ',
    'Da ',
    'Zhen ',
    'Kuang ',
    'Ju ',
    'Shen ',
    'Chi ',
    'Sheng ',
    'Mei ',
    'Mo ',
    'Zhu ',
    'Zhen ',
    'Zhen ',
    'Mian ',
    'Di ',
    'Yuan ',
    'Die ',
    'Yi ',
    'Zi ',
    'Zi ',
    'Chao ',
    'Zha ',
    'Xuan ',
    'Bing ',
    'Mi ',
    'Long ',
    'Sui ',
    'Dong ',
    'Mi ',
    'Die ',
    'Yi ',
    'Er ',
    'Ming ',
    'Xuan ',
    'Chi ',
    'Kuang ',
    'Juan ',
    'Mou ',
    'Zhen ',
    'Tiao ',
    'Yang ',
    'Yan ',
    'Mo ',
    'Zhong ',
    'Mai ',
    'Zhao ',
    'Zheng ',
    'Mei ',
    'Jun ',
    'Shao ',
    'Han ',
    'Huan ',
    'Di ',
    'Cheng ',
    'Cuo ',
    'Juan ',
    'E ',
    'Wan ',
    'Xian ',
    'Xi ',
    'Kun ',
    'Lai ',
    'Jian ',
    'Shan ',
    'Tian ',
    'Hun ',
    'Wan ',
    'Ling ',
    'Shi ',
    'Qiong ',
    'Lie ',
    'Yai ',
    'Jing ',
    'Zheng ',
    'Li ',
    'Lai ',
    'Sui ',
    'Juan ',
    'Shui ',
    'Sui ',
    'Du ',
    'Bi ',
    'Bi ',
    'Mu ',
    'Hun ',
    'Ni ',
    'Lu ',
    'Yi ',
    'Jie ',
    'Cai ',
    'Zhou ',
    'Yu ',
    'Hun ',
    'Ma ',
    'Xia ',
    'Xing ',
    'Xi ',
    'Gun ',
    'Cai ',
    'Chun ',
    'Jian ',
    'Mei ',
    'Du ',
    'Hou ',
    'Xuan ',
    'Ti ',
    'Kui ',
    'Gao ',
    'Rui ',
    'Mou ',
    'Xu ',
    'Fa ',
    'Wen ',
    'Miao ',
    'Chou ',
    'Kui ',
    'Mi ',
    'Weng ',
    'Kou ',
    'Dang ',
    'Chen ',
    'Ke ',
    'Sou ',
    'Xia ',
    'Qiong ',
    'Mao ',
    'Ming ',
    'Man ',
    'Shui ',
    'Ze ',
    'Zhang ',
    'Yi ',
    'Diao ',
    'Ou ',
    'Mo ',
    'Shun ',
    'Cong ',
    'Lou ',
    'Chi ',
    'Man ',
    'Piao ',
    'Cheng ',
    'Ji ',
    'Meng ',
    "[?] ",
    'Run ',
    'Pie ',
    'Xi ',
    'Qiao ',
    'Pu ',
    'Zhu ',
    'Deng ',
    'Shen ',
    'Shun ',
    'Liao ',
    'Che ',
    'Xian ',
    'Kan ',
    'Ye ',
    'Xu ',
    'Tong ',
    'Mou ',
    'Lin ',
    'Kui ',
    'Xian ',
    'Ye ',
    'Ai ',
    'Hui ',
    'Zhan ',
    'Jian ',
    'Gu ',
    'Zhao ',
    'Qu ',
    'Wei ',
    'Chou ',
    'Sao ',
    'Ning ',
    'Xun ',
    'Yao ',
    'Huo ',
    'Meng ',
    'Mian ',
    'Bin ',
    'Mian ',
    'Li ',
    'Kuang ',
    'Jue ',
    'Xuan ',
    'Mian ',
    'Huo ',
    'Lu ',
    'Meng ',
    'Long ',
    'Guan ',
    'Man ',
    'Xi ',
    'Chu ',
    'Tang ',
    'Kan ',
    'Zhu ',
    'Mao ',
    'Jin ',
    'Lin ',
    'Yu ',
    'Shuo ',
    'Ce ',
    'Jue ',
    'Shi ',
    'Yi ',
    'Shen ',
    'Zhi ',
    'Hou ',
    'Shen ',
    'Ying ',
    'Ju ',
    'Zhou ',
    'Jiao ',
    'Cuo ',
    'Duan ',
    'Ai ',
    'Jiao ',
    'Zeng ',
    'Huo ',
    'Bai ',
    'Shi ',
    'Ding ',
    'Qi ',
    'Ji ',
    'Zi ',
    'Gan ',
    'Wu ',
    'Tuo ',
    'Ku ',
    'Qiang ',
    'Xi ',
    'Fan ',
    'Kuang '
];

},{}],"icPWK":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Dang ',
    'Ma ',
    'Sha ',
    'Dan ',
    'Jue ',
    'Li ',
    'Fu ',
    'Min ',
    'Nuo ',
    'Huo ',
    'Kang ',
    'Zhi ',
    'Qi ',
    'Kan ',
    'Jie ',
    'Fen ',
    'E ',
    'Ya ',
    'Pi ',
    'Zhe ',
    'Yan ',
    'Sui ',
    'Zhuan ',
    'Che ',
    'Dun ',
    'Pan ',
    'Yan ',
    "[?] ",
    'Feng ',
    'Fa ',
    'Mo ',
    'Zha ',
    'Qu ',
    'Yu ',
    'Luo ',
    'Tuo ',
    'Tuo ',
    'Di ',
    'Zhai ',
    'Zhen ',
    'Ai ',
    'Fei ',
    'Mu ',
    'Zhu ',
    'Li ',
    'Bian ',
    'Nu ',
    'Ping ',
    'Peng ',
    'Ling ',
    'Pao ',
    'Le ',
    'Po ',
    'Bo ',
    'Po ',
    'Shen ',
    'Za ',
    'Nuo ',
    'Li ',
    'Long ',
    'Tong ',
    "[?] ",
    'Li ',
    'Aragane ',
    'Chu ',
    'Keng ',
    'Quan ',
    'Zhu ',
    'Kuang ',
    'Huo ',
    'E ',
    'Nao ',
    'Jia ',
    'Lu ',
    'Wei ',
    'Ai ',
    'Luo ',
    'Ken ',
    'Xing ',
    'Yan ',
    'Tong ',
    'Peng ',
    'Xi ',
    "[?] ",
    'Hong ',
    'Shuo ',
    'Xia ',
    'Qiao ',
    "[?] ",
    'Wei ',
    'Qiao ',
    "[?] ",
    'Keng ',
    'Xiao ',
    'Que ',
    'Chan ',
    'Lang ',
    'Hong ',
    'Yu ',
    'Xiao ',
    'Xia ',
    'Mang ',
    'Long ',
    'Iong ',
    'Che ',
    'Che ',
    'E ',
    'Liu ',
    'Ying ',
    'Mang ',
    'Que ',
    'Yan ',
    'Sha ',
    'Kun ',
    'Yu ',
    "[?] ",
    'Kaki ',
    'Lu ',
    'Chen ',
    'Jian ',
    'Nue ',
    'Song ',
    'Zhuo ',
    'Keng ',
    'Peng ',
    'Yan ',
    'Zhui ',
    'Kong ',
    'Ceng ',
    'Qi ',
    'Zong ',
    'Qing ',
    'Lin ',
    'Jun ',
    'Bo ',
    'Ding ',
    'Min ',
    'Diao ',
    'Jian ',
    'He ',
    'Lu ',
    'Ai ',
    'Sui ',
    'Que ',
    'Ling ',
    'Bei ',
    'Yin ',
    'Dui ',
    'Wu ',
    'Qi ',
    'Lun ',
    'Wan ',
    'Dian ',
    'Gang ',
    'Pei ',
    'Qi ',
    'Chen ',
    'Ruan ',
    'Yan ',
    'Die ',
    'Ding ',
    'Du ',
    'Tuo ',
    'Jie ',
    'Ying ',
    'Bian ',
    'Ke ',
    'Bi ',
    'Wei ',
    'Shuo ',
    'Zhen ',
    'Duan ',
    'Xia ',
    'Dang ',
    'Ti ',
    'Nao ',
    'Peng ',
    'Jian ',
    'Di ',
    'Tan ',
    'Cha ',
    'Seki ',
    'Qi ',
    "[?] ",
    'Feng ',
    'Xuan ',
    'Que ',
    'Que ',
    'Ma ',
    'Gong ',
    'Nian ',
    'Su ',
    'E ',
    'Ci ',
    'Liu ',
    'Si ',
    'Tang ',
    'Bang ',
    'Hua ',
    'Pi ',
    'Wei ',
    'Sang ',
    'Lei ',
    'Cuo ',
    'Zhen ',
    'Xia ',
    'Qi ',
    'Lian ',
    'Pan ',
    'Wei ',
    'Yun ',
    'Dui ',
    'Zhe ',
    'Ke ',
    'La ',
    "[?] ",
    'Qing ',
    'Gun ',
    'Zhuan ',
    'Chan ',
    'Qi ',
    'Ao ',
    'Peng ',
    'Lu ',
    'Lu ',
    'Kan ',
    'Qiang ',
    'Chen ',
    'Yin ',
    'Lei ',
    'Biao ',
    'Qi ',
    'Mo ',
    'Qi ',
    'Cui ',
    'Zong ',
    'Qing ',
    'Chuo ',
    "[?] ",
    'Ji ',
    'Shan ',
    'Lao ',
    'Qu ',
    'Zeng ',
    'Deng ',
    'Jian ',
    'Xi ',
    'Lin ',
    'Ding ',
    'Dian ',
    'Huang ',
    'Pan ',
    'Za ',
    'Qiao ',
    'Di ',
    'Li '
];

},{}],"94Kxb":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Tani ',
    'Jiao ',
    "[?] ",
    'Zhang ',
    'Qiao ',
    'Dun ',
    'Xian ',
    'Yu ',
    'Zhui ',
    'He ',
    'Huo ',
    'Zhai ',
    'Lei ',
    'Ke ',
    'Chu ',
    'Ji ',
    'Que ',
    'Dang ',
    'Yi ',
    'Jiang ',
    'Pi ',
    'Pi ',
    'Yu ',
    'Pin ',
    'Qi ',
    'Ai ',
    'Kai ',
    'Jian ',
    'Yu ',
    'Ruan ',
    'Meng ',
    'Pao ',
    'Ci ',
    "[?] ",
    "[?] ",
    'Mie ',
    'Ca ',
    'Xian ',
    'Kuang ',
    'Lei ',
    'Lei ',
    'Zhi ',
    'Li ',
    'Li ',
    'Fan ',
    'Que ',
    'Pao ',
    'Ying ',
    'Li ',
    'Long ',
    'Long ',
    'Mo ',
    'Bo ',
    'Shuang ',
    'Guan ',
    'Lan ',
    'Zan ',
    'Yan ',
    'Shi ',
    'Shi ',
    'Li ',
    'Reng ',
    'She ',
    'Yue ',
    'Si ',
    'Qi ',
    'Ta ',
    'Ma ',
    'Xie ',
    'Xian ',
    'Xian ',
    'Zhi ',
    'Qi ',
    'Zhi ',
    'Beng ',
    'Dui ',
    'Zhong ',
    "[?] ",
    'Yi ',
    'Shi ',
    'You ',
    'Zhi ',
    'Tiao ',
    'Fu ',
    'Fu ',
    'Mi ',
    'Zu ',
    'Zhi ',
    'Suan ',
    'Mei ',
    'Zuo ',
    'Qu ',
    'Hu ',
    'Zhu ',
    'Shen ',
    'Sui ',
    'Ci ',
    'Chai ',
    'Mi ',
    'Lu ',
    'Yu ',
    'Xiang ',
    'Wu ',
    'Tiao ',
    'Piao ',
    'Zhu ',
    'Gui ',
    'Xia ',
    'Zhi ',
    'Ji ',
    'Gao ',
    'Zhen ',
    'Gao ',
    'Shui ',
    'Jin ',
    'Chen ',
    'Gai ',
    'Kun ',
    'Di ',
    'Dao ',
    'Huo ',
    'Tao ',
    'Qi ',
    'Gu ',
    'Guan ',
    'Zui ',
    'Ling ',
    'Lu ',
    'Bing ',
    'Jin ',
    'Dao ',
    'Zhi ',
    'Lu ',
    'Shan ',
    'Bei ',
    'Zhe ',
    'Hui ',
    'You ',
    'Xi ',
    'Yin ',
    'Zi ',
    'Huo ',
    'Zhen ',
    'Fu ',
    'Yuan ',
    'Wu ',
    'Xian ',
    'Yang ',
    'Ti ',
    'Yi ',
    'Mei ',
    'Si ',
    'Di ',
    "[?] ",
    'Zhuo ',
    'Zhen ',
    'Yong ',
    'Ji ',
    'Gao ',
    'Tang ',
    'Si ',
    'Ma ',
    'Ta ',
    "[?] ",
    'Xuan ',
    'Qi ',
    'Yu ',
    'Xi ',
    'Ji ',
    'Si ',
    'Chan ',
    'Tan ',
    'Kuai ',
    'Sui ',
    'Li ',
    'Nong ',
    'Ni ',
    'Dao ',
    'Li ',
    'Rang ',
    'Yue ',
    'Ti ',
    'Zan ',
    'Lei ',
    'Rou ',
    'Yu ',
    'Yu ',
    'Chi ',
    'Xie ',
    'Qin ',
    'He ',
    'Tu ',
    'Xiu ',
    'Si ',
    'Ren ',
    'Tu ',
    'Zi ',
    'Cha ',
    'Gan ',
    'Yi ',
    'Xian ',
    'Bing ',
    'Nian ',
    'Qiu ',
    'Qiu ',
    'Chong ',
    'Fen ',
    'Hao ',
    'Yun ',
    'Ke ',
    'Miao ',
    'Zhi ',
    'Geng ',
    'Bi ',
    'Zhi ',
    'Yu ',
    'Mi ',
    'Ku ',
    'Ban ',
    'Pi ',
    'Ni ',
    'Li ',
    'You ',
    'Zu ',
    'Pi ',
    'Ba ',
    'Ling ',
    'Mo ',
    'Cheng ',
    'Nian ',
    'Qin ',
    'Yang ',
    'Zuo ',
    'Zhi ',
    'Zhi ',
    'Shu ',
    'Ju ',
    'Zi ',
    'Huo ',
    'Ji ',
    'Cheng ',
    'Tong ',
    'Zhi ',
    'Huo ',
    'He ',
    'Yin ',
    'Zi ',
    'Zhi ',
    'Jie ',
    'Ren ',
    'Du ',
    'Yi ',
    'Zhu ',
    'Hui ',
    'Nong ',
    'Fu '
];

},{}],"3Tffl":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Xi ',
    'Kao ',
    'Lang ',
    'Fu ',
    'Ze ',
    'Shui ',
    'Lu ',
    'Kun ',
    'Gan ',
    'Geng ',
    'Ti ',
    'Cheng ',
    'Tu ',
    'Shao ',
    'Shui ',
    'Ya ',
    'Lun ',
    'Lu ',
    'Gu ',
    'Zuo ',
    'Ren ',
    'Zhun ',
    'Bang ',
    'Bai ',
    'Ji ',
    'Zhi ',
    'Zhi ',
    'Kun ',
    'Leng ',
    'Peng ',
    'Ke ',
    'Bing ',
    'Chou ',
    'Zu ',
    'Yu ',
    'Su ',
    'Lue ',
    "[?] ",
    'Yi ',
    'Xi ',
    'Bian ',
    'Ji ',
    'Fu ',
    'Bi ',
    'Nuo ',
    'Jie ',
    'Zhong ',
    'Zong ',
    'Xu ',
    'Cheng ',
    'Dao ',
    'Wen ',
    'Lian ',
    'Zi ',
    'Yu ',
    'Ji ',
    'Xu ',
    'Zhen ',
    'Zhi ',
    'Dao ',
    'Jia ',
    'Ji ',
    'Gao ',
    'Gao ',
    'Gu ',
    'Rong ',
    'Sui ',
    'You ',
    'Ji ',
    'Kang ',
    'Mu ',
    'Shan ',
    'Men ',
    'Zhi ',
    'Ji ',
    'Lu ',
    'Su ',
    'Ji ',
    'Ying ',
    'Wen ',
    'Qiu ',
    'Se ',
    "[?] ",
    'Yi ',
    'Huang ',
    'Qie ',
    'Ji ',
    'Sui ',
    'Xiao ',
    'Pu ',
    'Jiao ',
    'Zhuo ',
    'Tong ',
    'Sai ',
    'Lu ',
    'Sui ',
    'Nong ',
    'Se ',
    'Hui ',
    'Rang ',
    'Nuo ',
    'Yu ',
    'Bin ',
    'Ji ',
    'Tui ',
    'Wen ',
    'Cheng ',
    'Huo ',
    'Gong ',
    'Lu ',
    'Biao ',
    "[?] ",
    'Rang ',
    'Zhuo ',
    'Li ',
    'Zan ',
    'Xue ',
    'Wa ',
    'Jiu ',
    'Qiong ',
    'Xi ',
    'Qiong ',
    'Kong ',
    'Yu ',
    'Sen ',
    'Jing ',
    'Yao ',
    'Chuan ',
    'Zhun ',
    'Tu ',
    'Lao ',
    'Qie ',
    'Zhai ',
    'Yao ',
    'Bian ',
    'Bao ',
    'Yao ',
    'Bing ',
    'Wa ',
    'Zhu ',
    'Jiao ',
    'Qiao ',
    'Diao ',
    'Wu ',
    'Gui ',
    'Yao ',
    'Zhi ',
    'Chuang ',
    'Yao ',
    'Tiao ',
    'Jiao ',
    'Chuang ',
    'Jiong ',
    'Xiao ',
    'Cheng ',
    'Kou ',
    'Cuan ',
    'Wo ',
    'Dan ',
    'Ku ',
    'Ke ',
    'Zhui ',
    'Xu ',
    'Su ',
    'Guan ',
    'Kui ',
    'Dou ',
    "[?] ",
    'Yin ',
    'Wo ',
    'Wa ',
    'Ya ',
    'Yu ',
    'Ju ',
    'Qiong ',
    'Yao ',
    'Yao ',
    'Tiao ',
    'Chao ',
    'Yu ',
    'Tian ',
    'Diao ',
    'Ju ',
    'Liao ',
    'Xi ',
    'Wu ',
    'Kui ',
    'Chuang ',
    'Zhao ',
    "[?] ",
    'Kuan ',
    'Long ',
    'Cheng ',
    'Cui ',
    'Piao ',
    'Zao ',
    'Cuan ',
    'Qiao ',
    'Qiong ',
    'Dou ',
    'Zao ',
    'Long ',
    'Qie ',
    'Li ',
    'Chu ',
    'Shi ',
    'Fou ',
    'Qian ',
    'Chu ',
    'Hong ',
    'Qi ',
    'Qian ',
    'Gong ',
    'Shi ',
    'Shu ',
    'Miao ',
    'Ju ',
    'Zhan ',
    'Zhu ',
    'Ling ',
    'Long ',
    'Bing ',
    'Jing ',
    'Jing ',
    'Zhang ',
    'Yi ',
    'Si ',
    'Jun ',
    'Hong ',
    'Tong ',
    'Song ',
    'Jing ',
    'Diao ',
    'Yi ',
    'Shu ',
    'Jing ',
    'Qu ',
    'Jie ',
    'Ping ',
    'Duan ',
    'Shao ',
    'Zhuan ',
    'Ceng ',
    'Deng ',
    'Cui ',
    'Huai ',
    'Jing ',
    'Kan ',
    'Jing ',
    'Zhu ',
    'Zhu ',
    'Le ',
    'Peng ',
    'Yu ',
    'Chi ',
    'Gan '
];

},{}],"30zwm":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Mang ',
    'Zhu ',
    'Utsubo ',
    'Du ',
    'Ji ',
    'Xiao ',
    'Ba ',
    'Suan ',
    'Ji ',
    'Zhen ',
    'Zhao ',
    'Sun ',
    'Ya ',
    'Zhui ',
    'Yuan ',
    'Hu ',
    'Gang ',
    'Xiao ',
    'Cen ',
    'Pi ',
    'Bi ',
    'Jian ',
    'Yi ',
    'Dong ',
    'Shan ',
    'Sheng ',
    'Xia ',
    'Di ',
    'Zhu ',
    'Na ',
    'Chi ',
    'Gu ',
    'Li ',
    'Qie ',
    'Min ',
    'Bao ',
    'Tiao ',
    'Si ',
    'Fu ',
    'Ce ',
    'Ben ',
    'Pei ',
    'Da ',
    'Zi ',
    'Di ',
    'Ling ',
    'Ze ',
    'Nu ',
    'Fu ',
    'Gou ',
    'Fan ',
    'Jia ',
    'Ge ',
    'Fan ',
    'Shi ',
    'Mao ',
    'Po ',
    'Sey ',
    'Jian ',
    'Qiong ',
    'Long ',
    'Souke ',
    'Bian ',
    'Luo ',
    'Gui ',
    'Qu ',
    'Chi ',
    'Yin ',
    'Yao ',
    'Xian ',
    'Bi ',
    'Qiong ',
    'Gua ',
    'Deng ',
    'Jiao ',
    'Jin ',
    'Quan ',
    'Sun ',
    'Ru ',
    'Fa ',
    'Kuang ',
    'Zhu ',
    'Tong ',
    'Ji ',
    'Da ',
    'Xing ',
    'Ce ',
    'Zhong ',
    'Kou ',
    'Lai ',
    'Bi ',
    'Shai ',
    'Dang ',
    'Zheng ',
    'Ce ',
    'Fu ',
    'Yun ',
    'Tu ',
    'Pa ',
    'Li ',
    'Lang ',
    'Ju ',
    'Guan ',
    'Jian ',
    'Han ',
    'Tong ',
    'Xia ',
    'Zhi ',
    'Cheng ',
    'Suan ',
    'Shi ',
    'Zhu ',
    'Zuo ',
    'Xiao ',
    'Shao ',
    'Ting ',
    'Ce ',
    'Yan ',
    'Gao ',
    'Kuai ',
    'Gan ',
    'Chou ',
    'Kago ',
    'Gang ',
    'Yun ',
    'O ',
    'Qian ',
    'Xiao ',
    'Jian ',
    'Pu ',
    'Lai ',
    'Zou ',
    'Bi ',
    'Bi ',
    'Bi ',
    'Ge ',
    'Chi ',
    'Guai ',
    'Yu ',
    'Jian ',
    'Zhao ',
    'Gu ',
    'Chi ',
    'Zheng ',
    'Jing ',
    'Sha ',
    'Zhou ',
    'Lu ',
    'Bo ',
    'Ji ',
    'Lin ',
    'Suan ',
    'Jun ',
    'Fu ',
    'Zha ',
    'Gu ',
    'Kong ',
    'Qian ',
    'Quan ',
    'Jun ',
    'Chui ',
    'Guan ',
    'Yuan ',
    'Ce ',
    'Ju ',
    'Bo ',
    'Ze ',
    'Qie ',
    'Tuo ',
    'Luo ',
    'Dan ',
    'Xiao ',
    'Ruo ',
    'Jian ',
    'Xuan ',
    'Bian ',
    'Sun ',
    'Xiang ',
    'Xian ',
    'Ping ',
    'Zhen ',
    'Sheng ',
    'Hu ',
    'Shi ',
    'Zhu ',
    'Yue ',
    'Chun ',
    'Lu ',
    'Wu ',
    'Dong ',
    'Xiao ',
    'Ji ',
    'Jie ',
    'Huang ',
    'Xing ',
    'Mei ',
    'Fan ',
    'Chui ',
    'Zhuan ',
    'Pian ',
    'Feng ',
    'Zhu ',
    'Hong ',
    'Qie ',
    'Hou ',
    'Qiu ',
    'Miao ',
    'Qian ',
    "[?] ",
    'Kui ',
    'Sik ',
    'Lou ',
    'Yun ',
    'He ',
    'Tang ',
    'Yue ',
    'Chou ',
    'Gao ',
    'Fei ',
    'Ruo ',
    'Zheng ',
    'Gou ',
    'Nie ',
    'Qian ',
    'Xiao ',
    'Cuan ',
    'Gong ',
    'Pang ',
    'Du ',
    'Li ',
    'Bi ',
    'Zhuo ',
    'Chu ',
    'Shai ',
    'Chi ',
    'Zhu ',
    'Qiang ',
    'Long ',
    'Lan ',
    'Jian ',
    'Bu ',
    'Li ',
    'Hui ',
    'Bi ',
    'Di ',
    'Cong ',
    'Yan ',
    'Peng ',
    'Sen ',
    'Zhuan ',
    'Pai ',
    'Piao ',
    'Dou ',
    'Yu ',
    'Mie ',
    'Zhuan '
];

},{}],"9ScTc":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Ze ',
    'Xi ',
    'Guo ',
    'Yi ',
    'Hu ',
    'Chan ',
    'Kou ',
    'Cu ',
    'Ping ',
    'Chou ',
    'Ji ',
    'Gui ',
    'Su ',
    'Lou ',
    'Zha ',
    'Lu ',
    'Nian ',
    'Suo ',
    'Cuan ',
    'Sasara ',
    'Suo ',
    'Le ',
    'Duan ',
    'Yana ',
    'Xiao ',
    'Bo ',
    'Mi ',
    'Si ',
    'Dang ',
    'Liao ',
    'Dan ',
    'Dian ',
    'Fu ',
    'Jian ',
    'Min ',
    'Kui ',
    'Dai ',
    'Qiao ',
    'Deng ',
    'Huang ',
    'Sun ',
    'Lao ',
    'Zan ',
    'Xiao ',
    'Du ',
    'Shi ',
    'Zan ',
    "[?] ",
    'Pai ',
    'Hata ',
    'Pai ',
    'Gan ',
    'Ju ',
    'Du ',
    'Lu ',
    'Yan ',
    'Bo ',
    'Dang ',
    'Sai ',
    'Ke ',
    'Long ',
    'Qian ',
    'Lian ',
    'Bo ',
    'Zhou ',
    'Lai ',
    "[?] ",
    'Lan ',
    'Kui ',
    'Yu ',
    'Yue ',
    'Hao ',
    'Zhen ',
    'Tai ',
    'Ti ',
    'Mi ',
    'Chou ',
    'Ji ',
    "[?] ",
    'Hata ',
    'Teng ',
    'Zhuan ',
    'Zhou ',
    'Fan ',
    'Sou ',
    'Zhou ',
    'Kuji ',
    'Zhuo ',
    'Teng ',
    'Lu ',
    'Lu ',
    'Jian ',
    'Tuo ',
    'Ying ',
    'Yu ',
    'Lai ',
    'Long ',
    'Shinshi ',
    'Lian ',
    'Lan ',
    'Qian ',
    'Yue ',
    'Zhong ',
    'Qu ',
    'Lian ',
    'Bian ',
    'Duan ',
    'Zuan ',
    'Li ',
    'Si ',
    'Luo ',
    'Ying ',
    'Yue ',
    'Zhuo ',
    'Xu ',
    'Mi ',
    'Di ',
    'Fan ',
    'Shen ',
    'Zhe ',
    'Shen ',
    'Nu ',
    'Xie ',
    'Lei ',
    'Xian ',
    'Zi ',
    'Ni ',
    'Cun ',
    "[?] ",
    'Qian ',
    'Kume ',
    'Bi ',
    'Ban ',
    'Wu ',
    'Sha ',
    'Kang ',
    'Rou ',
    'Fen ',
    'Bi ',
    'Cui ',
    "[?] ",
    'Li ',
    'Chi ',
    'Nukamiso ',
    'Ro ',
    'Ba ',
    'Li ',
    'Gan ',
    'Ju ',
    'Po ',
    'Mo ',
    'Cu ',
    'Nian ',
    'Zhou ',
    'Li ',
    'Su ',
    'Tiao ',
    'Li ',
    'Qi ',
    'Su ',
    'Hong ',
    'Tong ',
    'Zi ',
    'Ce ',
    'Yue ',
    'Zhou ',
    'Lin ',
    'Zhuang ',
    'Bai ',
    "[?] ",
    'Fen ',
    'Ji ',
    "[?] ",
    'Sukumo ',
    'Liang ',
    'Xian ',
    'Fu ',
    'Liang ',
    'Can ',
    'Geng ',
    'Li ',
    'Yue ',
    'Lu ',
    'Ju ',
    'Qi ',
    'Cui ',
    'Bai ',
    'Zhang ',
    'Lin ',
    'Zong ',
    'Jing ',
    'Guo ',
    'Kouji ',
    'San ',
    'San ',
    'Tang ',
    'Bian ',
    'Rou ',
    'Mian ',
    'Hou ',
    'Xu ',
    'Zong ',
    'Hu ',
    'Jian ',
    'Zan ',
    'Ci ',
    'Li ',
    'Xie ',
    'Fu ',
    'Ni ',
    'Bei ',
    'Gu ',
    'Xiu ',
    'Gao ',
    'Tang ',
    'Qiu ',
    'Sukumo ',
    'Cao ',
    'Zhuang ',
    'Tang ',
    'Mi ',
    'San ',
    'Fen ',
    'Zao ',
    'Kang ',
    'Jiang ',
    'Mo ',
    'San ',
    'San ',
    'Nuo ',
    'Xi ',
    'Liang ',
    'Jiang ',
    'Kuai ',
    'Bo ',
    'Huan ',
    "[?] ",
    'Zong ',
    'Xian ',
    'Nuo ',
    'Tuan ',
    'Nie ',
    'Li ',
    'Zuo ',
    'Di ',
    'Nie ',
    'Tiao ',
    'Lan ',
    'Mi ',
    'Jiao ',
    'Jiu ',
    'Xi ',
    'Gong ',
    'Zheng ',
    'Jiu ',
    'You '
];

},{}],"oHKRD":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Ji ',
    'Cha ',
    'Zhou ',
    'Xun ',
    'Yue ',
    'Hong ',
    'Yu ',
    'He ',
    'Wan ',
    'Ren ',
    'Wen ',
    'Wen ',
    'Qiu ',
    'Na ',
    'Zi ',
    'Tou ',
    'Niu ',
    'Fou ',
    'Jie ',
    'Shu ',
    'Chun ',
    'Pi ',
    'Yin ',
    'Sha ',
    'Hong ',
    'Zhi ',
    'Ji ',
    'Fen ',
    'Yun ',
    'Ren ',
    'Dan ',
    'Jin ',
    'Su ',
    'Fang ',
    'Suo ',
    'Cui ',
    'Jiu ',
    'Zha ',
    'Kinu ',
    'Jin ',
    'Fu ',
    'Zhi ',
    'Ci ',
    'Zi ',
    'Chou ',
    'Hong ',
    'Zha ',
    'Lei ',
    'Xi ',
    'Fu ',
    'Xie ',
    'Shen ',
    'Bei ',
    'Zhu ',
    'Qu ',
    'Ling ',
    'Zhu ',
    'Shao ',
    'Gan ',
    'Yang ',
    'Fu ',
    'Tuo ',
    'Zhen ',
    'Dai ',
    'Zhuo ',
    'Shi ',
    'Zhong ',
    'Xian ',
    'Zu ',
    'Jiong ',
    'Ban ',
    'Ju ',
    'Mo ',
    'Shu ',
    'Zui ',
    'Wata ',
    'Jing ',
    'Ren ',
    'Heng ',
    'Xie ',
    'Jie ',
    'Zhu ',
    'Chou ',
    'Gua ',
    'Bai ',
    'Jue ',
    'Kuang ',
    'Hu ',
    'Ci ',
    'Geng ',
    'Geng ',
    'Tao ',
    'Xie ',
    'Ku ',
    'Jiao ',
    'Quan ',
    'Gai ',
    'Luo ',
    'Xuan ',
    'Bing ',
    'Xian ',
    'Fu ',
    'Gei ',
    'Tong ',
    'Rong ',
    'Tiao ',
    'Yin ',
    'Lei ',
    'Xie ',
    'Quan ',
    'Xu ',
    'Lun ',
    'Die ',
    'Tong ',
    'Si ',
    'Jiang ',
    'Xiang ',
    'Hui ',
    'Jue ',
    'Zhi ',
    'Jian ',
    'Juan ',
    'Chi ',
    'Mian ',
    'Zhen ',
    'Lu ',
    'Cheng ',
    'Qiu ',
    'Shu ',
    'Bang ',
    'Tong ',
    'Xiao ',
    'Wan ',
    'Qin ',
    'Geng ',
    'Xiu ',
    'Ti ',
    'Xiu ',
    'Xie ',
    'Hong ',
    'Xi ',
    'Fu ',
    'Ting ',
    'Sui ',
    'Dui ',
    'Kun ',
    'Fu ',
    'Jing ',
    'Hu ',
    'Zhi ',
    'Yan ',
    'Jiong ',
    'Feng ',
    'Ji ',
    'Sok ',
    'Kase ',
    'Zong ',
    'Lin ',
    'Duo ',
    'Li ',
    'Lu ',
    'Liang ',
    'Chou ',
    'Quan ',
    'Shao ',
    'Qi ',
    'Qi ',
    'Zhun ',
    'Qi ',
    'Wan ',
    'Qian ',
    'Xian ',
    'Shou ',
    'Wei ',
    'Qi ',
    'Tao ',
    'Wan ',
    'Gang ',
    'Wang ',
    'Beng ',
    'Zhui ',
    'Cai ',
    'Guo ',
    'Cui ',
    'Lun ',
    'Liu ',
    'Qi ',
    'Zhan ',
    'Bei ',
    'Chuo ',
    'Ling ',
    'Mian ',
    'Qi ',
    'Qie ',
    'Tan ',
    'Zong ',
    'Gun ',
    'Zou ',
    'Yi ',
    'Zi ',
    'Xing ',
    'Liang ',
    'Jin ',
    'Fei ',
    'Rui ',
    'Min ',
    'Yu ',
    'Zong ',
    'Fan ',
    'Lu ',
    'Xu ',
    'Yingl ',
    'Zhang ',
    'Kasuri ',
    'Xu ',
    'Xiang ',
    'Jian ',
    'Ke ',
    'Xian ',
    'Ruan ',
    'Mian ',
    'Qi ',
    'Duan ',
    'Zhong ',
    'Di ',
    'Min ',
    'Miao ',
    'Yuan ',
    'Xie ',
    'Bao ',
    'Si ',
    'Qiu ',
    'Bian ',
    'Huan ',
    'Geng ',
    'Cong ',
    'Mian ',
    'Wei ',
    'Fu ',
    'Wei ',
    'Yu ',
    'Gou ',
    'Miao ',
    'Xie ',
    'Lian ',
    'Zong ',
    'Bian ',
    'Yun ',
    'Yin ',
    'Ti ',
    'Gua ',
    'Zhi ',
    'Yun ',
    'Cheng ',
    'Chan ',
    'Dai '
];

},{}],"CfAp4":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Xia ',
    'Yuan ',
    'Zong ',
    'Xu ',
    'Nawa ',
    'Odoshi ',
    'Geng ',
    'Sen ',
    'Ying ',
    'Jin ',
    'Yi ',
    'Zhui ',
    'Ni ',
    'Bang ',
    'Gu ',
    'Pan ',
    'Zhou ',
    'Jian ',
    'Cuo ',
    'Quan ',
    'Shuang ',
    'Yun ',
    'Xia ',
    'Shuai ',
    'Xi ',
    'Rong ',
    'Tao ',
    'Fu ',
    'Yun ',
    'Zhen ',
    'Gao ',
    'Ru ',
    'Hu ',
    'Zai ',
    'Teng ',
    'Xian ',
    'Su ',
    'Zhen ',
    'Zong ',
    'Tao ',
    'Horo ',
    'Cai ',
    'Bi ',
    'Feng ',
    'Cu ',
    'Li ',
    'Suo ',
    'Yin ',
    'Xi ',
    'Zong ',
    'Lei ',
    'Zhuan ',
    'Qian ',
    'Man ',
    'Zhi ',
    'Lu ',
    'Mo ',
    'Piao ',
    'Lian ',
    'Mi ',
    'Xuan ',
    'Zong ',
    'Ji ',
    'Shan ',
    'Sui ',
    'Fan ',
    'Shuai ',
    'Beng ',
    'Yi ',
    'Sao ',
    'Mou ',
    'Zhou ',
    'Qiang ',
    'Hun ',
    'Sem ',
    'Xi ',
    'Jung ',
    'Xiu ',
    'Ran ',
    'Xuan ',
    'Hui ',
    'Qiao ',
    'Zeng ',
    'Zuo ',
    'Zhi ',
    'Shan ',
    'San ',
    'Lin ',
    'Yu ',
    'Fan ',
    'Liao ',
    'Chuo ',
    'Zun ',
    'Jian ',
    'Rao ',
    'Chan ',
    'Rui ',
    'Xiu ',
    'Hui ',
    'Hua ',
    'Zuan ',
    'Xi ',
    'Qiang ',
    'Un ',
    'Da ',
    'Sheng ',
    'Hui ',
    'Xi ',
    'Se ',
    'Jian ',
    'Jiang ',
    'Huan ',
    'Zao ',
    'Cong ',
    'Jie ',
    'Jiao ',
    'Bo ',
    'Chan ',
    'Yi ',
    'Nao ',
    'Sui ',
    'Yi ',
    'Shai ',
    'Xu ',
    'Ji ',
    'Bin ',
    'Qian ',
    'Lan ',
    'Pu ',
    'Xun ',
    'Zuan ',
    'Qi ',
    'Peng ',
    'Li ',
    'Mo ',
    'Lei ',
    'Xie ',
    'Zuan ',
    'Kuang ',
    'You ',
    'Xu ',
    'Lei ',
    'Xian ',
    'Chan ',
    'Kou ',
    'Lu ',
    'Chan ',
    'Ying ',
    'Cai ',
    'Xiang ',
    'Xian ',
    'Zui ',
    'Zuan ',
    'Luo ',
    'Xi ',
    'Dao ',
    'Lan ',
    'Lei ',
    'Lian ',
    'Si ',
    'Jiu ',
    'Yu ',
    'Hong ',
    'Zhou ',
    'Xian ',
    'He ',
    'Yue ',
    'Ji ',
    'Wan ',
    'Kuang ',
    'Ji ',
    'Ren ',
    'Wei ',
    'Yun ',
    'Hong ',
    'Chun ',
    'Pi ',
    'Sha ',
    'Gang ',
    'Na ',
    'Ren ',
    'Zong ',
    'Lun ',
    'Fen ',
    'Zhi ',
    'Wen ',
    'Fang ',
    'Zhu ',
    'Yin ',
    'Niu ',
    'Shu ',
    'Xian ',
    'Gan ',
    'Xie ',
    'Fu ',
    'Lian ',
    'Zu ',
    'Shen ',
    'Xi ',
    'Zhi ',
    'Zhong ',
    'Zhou ',
    'Ban ',
    'Fu ',
    'Zhuo ',
    'Shao ',
    'Yi ',
    'Jing ',
    'Dai ',
    'Bang ',
    'Rong ',
    'Jie ',
    'Ku ',
    'Rao ',
    'Die ',
    'Heng ',
    'Hui ',
    'Gei ',
    'Xuan ',
    'Jiang ',
    'Luo ',
    'Jue ',
    'Jiao ',
    'Tong ',
    'Geng ',
    'Xiao ',
    'Juan ',
    'Xiu ',
    'Xi ',
    'Sui ',
    'Tao ',
    'Ji ',
    'Ti ',
    'Ji ',
    'Xu ',
    'Ling ',
    "[?] ",
    'Xu ',
    'Qi ',
    'Fei ',
    'Chuo ',
    'Zhang ',
    'Gun ',
    'Sheng ',
    'Wei ',
    'Mian ',
    'Shou ',
    'Beng ',
    'Chou ',
    'Tao ',
    'Liu ',
    'Quan ',
    'Zong ',
    'Zhan ',
    'Wan ',
    'Lu '
];

},{}],"1dOun":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Zhui ',
    'Zi ',
    'Ke ',
    'Xiang ',
    'Jian ',
    'Mian ',
    'Lan ',
    'Ti ',
    'Miao ',
    'Qi ',
    'Yun ',
    'Hui ',
    'Si ',
    'Duo ',
    'Duan ',
    'Bian ',
    'Xian ',
    'Gou ',
    'Zhui ',
    'Huan ',
    'Di ',
    'Lu ',
    'Bian ',
    'Min ',
    'Yuan ',
    'Jin ',
    'Fu ',
    'Ru ',
    'Zhen ',
    'Feng ',
    'Shuai ',
    'Gao ',
    'Chan ',
    'Li ',
    'Yi ',
    'Jian ',
    'Bin ',
    'Piao ',
    'Man ',
    'Lei ',
    'Ying ',
    'Suo ',
    'Mou ',
    'Sao ',
    'Xie ',
    'Liao ',
    'Shan ',
    'Zeng ',
    'Jiang ',
    'Qian ',
    'Zao ',
    'Huan ',
    'Jiao ',
    'Zuan ',
    'Fou ',
    'Xie ',
    'Gang ',
    'Fou ',
    'Que ',
    'Fou ',
    'Kaakeru ',
    'Bo ',
    'Ping ',
    'Hou ',
    "[?] ",
    'Gang ',
    'Ying ',
    'Ying ',
    'Qing ',
    'Xia ',
    'Guan ',
    'Zun ',
    'Tan ',
    'Chang ',
    'Qi ',
    'Weng ',
    'Ying ',
    'Lei ',
    'Tan ',
    'Lu ',
    'Guan ',
    'Wang ',
    'Wang ',
    'Gang ',
    'Wang ',
    'Han ',
    "[?] ",
    'Luo ',
    'Fu ',
    'Mi ',
    'Fa ',
    'Gu ',
    'Zhu ',
    'Ju ',
    'Mao ',
    'Gu ',
    'Min ',
    'Gang ',
    'Ba ',
    'Gua ',
    'Ti ',
    'Juan ',
    'Fu ',
    'Lin ',
    'Yan ',
    'Zhao ',
    'Zui ',
    'Gua ',
    'Zhuo ',
    'Yu ',
    'Zhi ',
    'An ',
    'Fa ',
    'Nan ',
    'Shu ',
    'Si ',
    'Pi ',
    'Ma ',
    'Liu ',
    'Ba ',
    'Fa ',
    'Li ',
    'Chao ',
    'Wei ',
    'Bi ',
    'Ji ',
    'Zeng ',
    'Tong ',
    'Liu ',
    'Ji ',
    'Juan ',
    'Mi ',
    'Zhao ',
    'Luo ',
    'Pi ',
    'Ji ',
    'Ji ',
    'Luan ',
    'Yang ',
    'Mie ',
    'Qiang ',
    'Ta ',
    'Mei ',
    'Yang ',
    'You ',
    'You ',
    'Fen ',
    'Ba ',
    'Gao ',
    'Yang ',
    'Gu ',
    'Qiang ',
    'Zang ',
    'Gao ',
    'Ling ',
    'Yi ',
    'Zhu ',
    'Di ',
    'Xiu ',
    'Qian ',
    'Yi ',
    'Xian ',
    'Rong ',
    'Qun ',
    'Qun ',
    'Qian ',
    'Huan ',
    'Zui ',
    'Xian ',
    'Yi ',
    'Yashinau ',
    'Qiang ',
    'Xian ',
    'Yu ',
    'Geng ',
    'Jie ',
    'Tang ',
    'Yuan ',
    'Xi ',
    'Fan ',
    'Shan ',
    'Fen ',
    'Shan ',
    'Lian ',
    'Lei ',
    'Geng ',
    'Nou ',
    'Qiang ',
    'Chan ',
    'Yu ',
    'Gong ',
    'Yi ',
    'Chong ',
    'Weng ',
    'Fen ',
    'Hong ',
    'Chi ',
    'Chi ',
    'Cui ',
    'Fu ',
    'Xia ',
    'Pen ',
    'Yi ',
    'La ',
    'Yi ',
    'Pi ',
    'Ling ',
    'Liu ',
    'Zhi ',
    'Qu ',
    'Xi ',
    'Xie ',
    'Xiang ',
    'Xi ',
    'Xi ',
    'Qi ',
    'Qiao ',
    'Hui ',
    'Hui ',
    'Xiao ',
    'Se ',
    'Hong ',
    'Jiang ',
    'Di ',
    'Cui ',
    'Fei ',
    'Tao ',
    'Sha ',
    'Chi ',
    'Zhu ',
    'Jian ',
    'Xuan ',
    'Shi ',
    'Pian ',
    'Zong ',
    'Wan ',
    'Hui ',
    'Hou ',
    'He ',
    'He ',
    'Han ',
    'Ao ',
    'Piao ',
    'Yi ',
    'Lian ',
    'Qu ',
    "[?] ",
    'Lin ',
    'Pen ',
    'Qiao ',
    'Ao ',
    'Fan ',
    'Yi ',
    'Hui ',
    'Xuan ',
    'Dao '
];

},{}],"6VpqN":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Yao ',
    'Lao ',
    "[?] ",
    'Kao ',
    'Mao ',
    'Zhe ',
    'Qi ',
    'Gou ',
    'Gou ',
    'Gou ',
    'Die ',
    'Die ',
    'Er ',
    'Shua ',
    'Ruan ',
    'Er ',
    'Nai ',
    'Zhuan ',
    'Lei ',
    'Ting ',
    'Zi ',
    'Geng ',
    'Chao ',
    'Hao ',
    'Yun ',
    'Pa ',
    'Pi ',
    'Chi ',
    'Si ',
    'Chu ',
    'Jia ',
    'Ju ',
    'He ',
    'Chu ',
    'Lao ',
    'Lun ',
    'Ji ',
    'Tang ',
    'Ou ',
    'Lou ',
    'Nou ',
    'Gou ',
    'Pang ',
    'Ze ',
    'Lou ',
    'Ji ',
    'Lao ',
    'Huo ',
    'You ',
    'Mo ',
    'Huai ',
    'Er ',
    'Zhe ',
    'Ting ',
    'Ye ',
    'Da ',
    'Song ',
    'Qin ',
    'Yun ',
    'Chi ',
    'Dan ',
    'Dan ',
    'Hong ',
    'Geng ',
    'Zhi ',
    "[?] ",
    'Nie ',
    'Dan ',
    'Zhen ',
    'Che ',
    'Ling ',
    'Zheng ',
    'You ',
    'Wa ',
    'Liao ',
    'Long ',
    'Zhi ',
    'Ning ',
    'Tiao ',
    'Er ',
    'Ya ',
    'Die ',
    'Gua ',
    "[?] ",
    'Lian ',
    'Hao ',
    'Sheng ',
    'Lie ',
    'Pin ',
    'Jing ',
    'Ju ',
    'Bi ',
    'Di ',
    'Guo ',
    'Wen ',
    'Xu ',
    'Ping ',
    'Cong ',
    'Shikato ',
    "[?] ",
    'Ting ',
    'Yu ',
    'Cong ',
    'Kui ',
    'Tsuraneru ',
    'Kui ',
    'Cong ',
    'Lian ',
    'Weng ',
    'Kui ',
    'Lian ',
    'Lian ',
    'Cong ',
    'Ao ',
    'Sheng ',
    'Song ',
    'Ting ',
    'Kui ',
    'Nie ',
    'Zhi ',
    'Dan ',
    'Ning ',
    'Qie ',
    'Ji ',
    'Ting ',
    'Ting ',
    'Long ',
    'Yu ',
    'Yu ',
    'Zhao ',
    'Si ',
    'Su ',
    'Yi ',
    'Su ',
    'Si ',
    'Zhao ',
    'Zhao ',
    'Rou ',
    'Yi ',
    'Le ',
    'Ji ',
    'Qiu ',
    'Ken ',
    'Cao ',
    'Ge ',
    'Di ',
    'Huan ',
    'Huang ',
    'Yi ',
    'Ren ',
    'Xiao ',
    'Ru ',
    'Zhou ',
    'Yuan ',
    'Du ',
    'Gang ',
    'Rong ',
    'Gan ',
    'Cha ',
    'Wo ',
    'Chang ',
    'Gu ',
    'Zhi ',
    'Han ',
    'Fu ',
    'Fei ',
    'Fen ',
    'Pei ',
    'Pang ',
    'Jian ',
    'Fang ',
    'Zhun ',
    'You ',
    'Na ',
    'Hang ',
    'Ken ',
    'Ran ',
    'Gong ',
    'Yu ',
    'Wen ',
    'Yao ',
    'Jin ',
    'Pi ',
    'Qian ',
    'Xi ',
    'Xi ',
    'Fei ',
    'Ken ',
    'Jing ',
    'Tai ',
    'Shen ',
    'Zhong ',
    'Zhang ',
    'Xie ',
    'Shen ',
    'Wei ',
    'Zhou ',
    'Die ',
    'Dan ',
    'Fei ',
    'Ba ',
    'Bo ',
    'Qu ',
    'Tian ',
    'Bei ',
    'Gua ',
    'Tai ',
    'Zi ',
    'Ku ',
    'Zhi ',
    'Ni ',
    'Ping ',
    'Zi ',
    'Fu ',
    'Pang ',
    'Zhen ',
    'Xian ',
    'Zuo ',
    'Pei ',
    'Jia ',
    'Sheng ',
    'Zhi ',
    'Bao ',
    'Mu ',
    'Qu ',
    'Hu ',
    'Ke ',
    'Yi ',
    'Yin ',
    'Xu ',
    'Yang ',
    'Long ',
    'Dong ',
    'Ka ',
    'Lu ',
    'Jing ',
    'Nu ',
    'Yan ',
    'Pang ',
    'Kua ',
    'Yi ',
    'Guang ',
    'Gai ',
    'Ge ',
    'Dong ',
    'Zhi ',
    'Xiao ',
    'Xiong ',
    'Xiong ',
    'Er ',
    'E ',
    'Xing ',
    'Pian ',
    'Neng ',
    'Zi ',
    'Gui '
];

},{}],"8zZFx":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Cheng ',
    'Tiao ',
    'Zhi ',
    'Cui ',
    'Mei ',
    'Xie ',
    'Cui ',
    'Xie ',
    'Mo ',
    'Mai ',
    'Ji ',
    'Obiyaakasu ',
    "[?] ",
    'Kuai ',
    'Sa ',
    'Zang ',
    'Qi ',
    'Nao ',
    'Mi ',
    'Nong ',
    'Luan ',
    'Wan ',
    'Bo ',
    'Wen ',
    'Guan ',
    'Qiu ',
    'Jiao ',
    'Jing ',
    'Rou ',
    'Heng ',
    'Cuo ',
    'Lie ',
    'Shan ',
    'Ting ',
    'Mei ',
    'Chun ',
    'Shen ',
    'Xie ',
    'De ',
    'Zui ',
    'Cu ',
    'Xiu ',
    'Xin ',
    'Tuo ',
    'Pao ',
    'Cheng ',
    'Nei ',
    'Fu ',
    'Dou ',
    'Tuo ',
    'Niao ',
    'Noy ',
    'Pi ',
    'Gu ',
    'Gua ',
    'Li ',
    'Lian ',
    'Zhang ',
    'Cui ',
    'Jie ',
    'Liang ',
    'Zhou ',
    'Pi ',
    'Biao ',
    'Lun ',
    'Pian ',
    'Guo ',
    'Kui ',
    'Chui ',
    'Dan ',
    'Tian ',
    'Nei ',
    'Jing ',
    'Jie ',
    'La ',
    'Yi ',
    'An ',
    'Ren ',
    'Shen ',
    'Chuo ',
    'Fu ',
    'Fu ',
    'Ju ',
    'Fei ',
    'Qiang ',
    'Wan ',
    'Dong ',
    'Pi ',
    'Guo ',
    'Zong ',
    'Ding ',
    'Wu ',
    'Mei ',
    'Ruan ',
    'Zhuan ',
    'Zhi ',
    'Cou ',
    'Gua ',
    'Ou ',
    'Di ',
    'An ',
    'Xing ',
    'Nao ',
    'Yu ',
    'Chuan ',
    'Nan ',
    'Yun ',
    'Zhong ',
    'Rou ',
    'E ',
    'Sai ',
    'Tu ',
    'Yao ',
    'Jian ',
    'Wei ',
    'Jiao ',
    'Yu ',
    'Jia ',
    'Duan ',
    'Bi ',
    'Chang ',
    'Fu ',
    'Xian ',
    'Ni ',
    'Mian ',
    'Wa ',
    'Teng ',
    'Tui ',
    'Bang ',
    'Qian ',
    'Lu ',
    'Wa ',
    'Sou ',
    'Tang ',
    'Su ',
    'Zhui ',
    'Ge ',
    'Yi ',
    'Bo ',
    'Liao ',
    'Ji ',
    'Pi ',
    'Xie ',
    'Gao ',
    'Lu ',
    'Bin ',
    'Ou ',
    'Chang ',
    'Lu ',
    'Guo ',
    'Pang ',
    'Chuai ',
    'Piao ',
    'Jiang ',
    'Fu ',
    'Tang ',
    'Mo ',
    'Xi ',
    'Zhuan ',
    'Lu ',
    'Jiao ',
    'Ying ',
    'Lu ',
    'Zhi ',
    'Tara ',
    'Chun ',
    'Lian ',
    'Tong ',
    'Peng ',
    'Ni ',
    'Zha ',
    'Liao ',
    'Cui ',
    'Gui ',
    'Xiao ',
    'Teng ',
    'Fan ',
    'Zhi ',
    'Jiao ',
    'Shan ',
    'Wu ',
    'Cui ',
    'Run ',
    'Xiang ',
    'Sui ',
    'Fen ',
    'Ying ',
    'Tan ',
    'Zhua ',
    'Dan ',
    'Kuai ',
    'Nong ',
    'Tun ',
    'Lian ',
    'Bi ',
    'Yong ',
    'Jue ',
    'Chu ',
    'Yi ',
    'Juan ',
    'La ',
    'Lian ',
    'Sao ',
    'Tun ',
    'Gu ',
    'Qi ',
    'Cui ',
    'Bin ',
    'Xun ',
    'Ru ',
    'Huo ',
    'Zang ',
    'Xian ',
    'Biao ',
    'Xing ',
    'Kuan ',
    'La ',
    'Yan ',
    'Lu ',
    'Huo ',
    'Zang ',
    'Luo ',
    'Qu ',
    'Zang ',
    'Luan ',
    'Ni ',
    'Zang ',
    'Chen ',
    'Qian ',
    'Wo ',
    'Guang ',
    'Zang ',
    'Lin ',
    'Guang ',
    'Zi ',
    'Jiao ',
    'Nie ',
    'Chou ',
    'Ji ',
    'Gao ',
    'Chou ',
    'Mian ',
    'Nie ',
    'Zhi ',
    'Zhi ',
    'Ge ',
    'Jian ',
    'Die ',
    'Zhi ',
    'Xiu ',
    'Tai ',
    'Zhen ',
    'Jiu ',
    'Xian ',
    'Yu ',
    'Cha '
];

},{}],"6qmC9":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Yao ',
    'Yu ',
    'Chong ',
    'Xi ',
    'Xi ',
    'Jiu ',
    'Yu ',
    'Yu ',
    'Xing ',
    'Ju ',
    'Jiu ',
    'Xin ',
    'She ',
    'She ',
    'Yadoru ',
    'Jiu ',
    'Shi ',
    'Tan ',
    'Shu ',
    'Shi ',
    'Tian ',
    'Dan ',
    'Pu ',
    'Pu ',
    'Guan ',
    'Hua ',
    'Tan ',
    'Chuan ',
    'Shun ',
    'Xia ',
    'Wu ',
    'Zhou ',
    'Dao ',
    'Gang ',
    'Shan ',
    'Yi ',
    "[?] ",
    'Pa ',
    'Tai ',
    'Fan ',
    'Ban ',
    'Chuan ',
    'Hang ',
    'Fang ',
    'Ban ',
    'Que ',
    'Hesaki ',
    'Zhong ',
    'Jian ',
    'Cang ',
    'Ling ',
    'Zhu ',
    'Ze ',
    'Duo ',
    'Bo ',
    'Xian ',
    'Ge ',
    'Chuan ',
    'Jia ',
    'Lu ',
    'Hong ',
    'Pang ',
    'Xi ',
    "[?] ",
    'Fu ',
    'Zao ',
    'Feng ',
    'Li ',
    'Shao ',
    'Yu ',
    'Lang ',
    'Ting ',
    "[?] ",
    'Wei ',
    'Bo ',
    'Meng ',
    'Nian ',
    'Ju ',
    'Huang ',
    'Shou ',
    'Zong ',
    'Bian ',
    'Mao ',
    'Die ',
    "[?] ",
    'Bang ',
    'Cha ',
    'Yi ',
    'Sao ',
    'Cang ',
    'Cao ',
    'Lou ',
    'Dai ',
    'Sori ',
    'Yao ',
    'Tong ',
    'Yofune ',
    'Dang ',
    'Tan ',
    'Lu ',
    'Yi ',
    'Jie ',
    'Jian ',
    'Huo ',
    'Meng ',
    'Qi ',
    'Lu ',
    'Lu ',
    'Chan ',
    'Shuang ',
    'Gen ',
    'Liang ',
    'Jian ',
    'Jian ',
    'Se ',
    'Yan ',
    'Fu ',
    'Ping ',
    'Yan ',
    'Yan ',
    'Cao ',
    'Cao ',
    'Yi ',
    'Le ',
    'Ting ',
    'Qiu ',
    'Ai ',
    'Nai ',
    'Tiao ',
    'Jiao ',
    'Jie ',
    'Peng ',
    'Wan ',
    'Yi ',
    'Chai ',
    'Mian ',
    'Mie ',
    'Gan ',
    'Qian ',
    'Yu ',
    'Yu ',
    'Shuo ',
    'Qiong ',
    'Tu ',
    'Xia ',
    'Qi ',
    'Mang ',
    'Zi ',
    'Hui ',
    'Sui ',
    'Zhi ',
    'Xiang ',
    'Bi ',
    'Fu ',
    'Tun ',
    'Wei ',
    'Wu ',
    'Zhi ',
    'Qi ',
    'Shan ',
    'Wen ',
    'Qian ',
    'Ren ',
    'Fou ',
    'Kou ',
    'Jie ',
    'Lu ',
    'Xu ',
    'Ji ',
    'Qin ',
    'Qi ',
    'Yuan ',
    'Fen ',
    'Ba ',
    'Rui ',
    'Xin ',
    'Ji ',
    'Hua ',
    'Hua ',
    'Fang ',
    'Wu ',
    'Jue ',
    'Gou ',
    'Zhi ',
    'Yun ',
    'Qin ',
    'Ao ',
    'Chu ',
    'Mao ',
    'Ya ',
    'Fei ',
    'Reng ',
    'Hang ',
    'Cong ',
    'Yin ',
    'You ',
    'Bian ',
    'Yi ',
    'Susa ',
    'Wei ',
    'Li ',
    'Pi ',
    'E ',
    'Xian ',
    'Chang ',
    'Cang ',
    'Meng ',
    'Su ',
    'Yi ',
    'Yuan ',
    'Ran ',
    'Ling ',
    'Tai ',
    'Tiao ',
    'Di ',
    'Miao ',
    'Qiong ',
    'Li ',
    'Yong ',
    'Ke ',
    'Mu ',
    'Pei ',
    'Bao ',
    'Gou ',
    'Min ',
    'Yi ',
    'Yi ',
    'Ju ',
    'Pi ',
    'Ruo ',
    'Ku ',
    'Zhu ',
    'Ni ',
    'Bo ',
    'Bing ',
    'Shan ',
    'Qiu ',
    'Yao ',
    'Xian ',
    'Ben ',
    'Hong ',
    'Ying ',
    'Zha ',
    'Dong ',
    'Ju ',
    'Die ',
    'Nie ',
    'Gan ',
    'Hu ',
    'Ping ',
    'Mei ',
    'Fu ',
    'Sheng ',
    'Gu ',
    'Bi ',
    'Wei '
];

},{}],"bDdix":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Fu ',
    'Zhuo ',
    'Mao ',
    'Fan ',
    'Qie ',
    'Mao ',
    'Mao ',
    'Ba ',
    'Zi ',
    'Mo ',
    'Zi ',
    'Di ',
    'Chi ',
    'Ji ',
    'Jing ',
    'Long ',
    "[?] ",
    'Niao ',
    "[?] ",
    'Xue ',
    'Ying ',
    'Qiong ',
    'Ge ',
    'Ming ',
    'Li ',
    'Rong ',
    'Yin ',
    'Gen ',
    'Qian ',
    'Chai ',
    'Chen ',
    'Yu ',
    'Xiu ',
    'Zi ',
    'Lie ',
    'Wu ',
    'Ji ',
    'Kui ',
    'Ce ',
    'Chong ',
    'Ci ',
    'Gou ',
    'Guang ',
    'Mang ',
    'Chi ',
    'Jiao ',
    'Jiao ',
    'Fu ',
    'Yu ',
    'Zhu ',
    'Zi ',
    'Jiang ',
    'Hui ',
    'Yin ',
    'Cha ',
    'Fa ',
    'Rong ',
    'Ru ',
    'Chong ',
    'Mang ',
    'Tong ',
    'Zhong ',
    "[?] ",
    'Zhu ',
    'Xun ',
    'Huan ',
    'Kua ',
    'Quan ',
    'Gai ',
    'Da ',
    'Jing ',
    'Xing ',
    'Quan ',
    'Cao ',
    'Jing ',
    'Er ',
    'An ',
    'Shou ',
    'Chi ',
    'Ren ',
    'Jian ',
    'Ti ',
    'Huang ',
    'Ping ',
    'Li ',
    'Jin ',
    'Lao ',
    'Shu ',
    'Zhuang ',
    'Da ',
    'Jia ',
    'Rao ',
    'Bi ',
    'Ze ',
    'Qiao ',
    'Hui ',
    'Qi ',
    'Dang ',
    "[?] ",
    'Rong ',
    'Hun ',
    'Ying ',
    'Luo ',
    'Ying ',
    'Xun ',
    'Jin ',
    'Sun ',
    'Yin ',
    'Mai ',
    'Hong ',
    'Zhou ',
    'Yao ',
    'Du ',
    'Wei ',
    'Chu ',
    'Dou ',
    'Fu ',
    'Ren ',
    'Yin ',
    'He ',
    'Bi ',
    'Bu ',
    'Yun ',
    'Di ',
    'Tu ',
    'Sui ',
    'Sui ',
    'Cheng ',
    'Chen ',
    'Wu ',
    'Bie ',
    'Xi ',
    'Geng ',
    'Li ',
    'Fu ',
    'Zhu ',
    'Mo ',
    'Li ',
    'Zhuang ',
    'Ji ',
    'Duo ',
    'Qiu ',
    'Sha ',
    'Suo ',
    'Chen ',
    'Feng ',
    'Ju ',
    'Mei ',
    'Meng ',
    'Xing ',
    'Jing ',
    'Che ',
    'Xin ',
    'Jun ',
    'Yan ',
    'Ting ',
    'Diao ',
    'Cuo ',
    'Wan ',
    'Han ',
    'You ',
    'Cuo ',
    'Jia ',
    'Wang ',
    'You ',
    'Niu ',
    'Shao ',
    'Xian ',
    'Lang ',
    'Fu ',
    'E ',
    'Mo ',
    'Wen ',
    'Jie ',
    'Nan ',
    'Mu ',
    'Kan ',
    'Lai ',
    'Lian ',
    'Shi ',
    'Wo ',
    'Usagi ',
    'Lian ',
    'Huo ',
    'You ',
    'Ying ',
    'Ying ',
    'Nuc ',
    'Chun ',
    'Mang ',
    'Mang ',
    'Ci ',
    'Wan ',
    'Jing ',
    'Di ',
    'Qu ',
    'Dong ',
    'Jian ',
    'Zou ',
    'Gu ',
    'La ',
    'Lu ',
    'Ju ',
    'Wei ',
    'Jun ',
    'Nie ',
    'Kun ',
    'He ',
    'Pu ',
    'Zi ',
    'Gao ',
    'Guo ',
    'Fu ',
    'Lun ',
    'Chang ',
    'Chou ',
    'Song ',
    'Chui ',
    'Zhan ',
    'Men ',
    'Cai ',
    'Ba ',
    'Li ',
    'Tu ',
    'Bo ',
    'Han ',
    'Bao ',
    'Qin ',
    'Juan ',
    'Xi ',
    'Qin ',
    'Di ',
    'Jie ',
    'Pu ',
    'Dang ',
    'Jin ',
    'Zhao ',
    'Tai ',
    'Geng ',
    'Hua ',
    'Gu ',
    'Ling ',
    'Fei ',
    'Jin ',
    'An ',
    'Wang ',
    'Beng ',
    'Zhou ',
    'Yan ',
    'Ju ',
    'Jian ',
    'Lin ',
    'Tan ',
    'Shu ',
    'Tian ',
    'Dao '
];

},{}],"4cVP2":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Hu ',
    'Qi ',
    'He ',
    'Cui ',
    'Tao ',
    'Chun ',
    'Bei ',
    'Chang ',
    'Huan ',
    'Fei ',
    'Lai ',
    'Qi ',
    'Meng ',
    'Ping ',
    'Wei ',
    'Dan ',
    'Sha ',
    'Huan ',
    'Yan ',
    'Yi ',
    'Tiao ',
    'Qi ',
    'Wan ',
    'Ce ',
    'Nai ',
    'Kutabireru ',
    'Tuo ',
    'Jiu ',
    'Tie ',
    'Luo ',
    "[?] ",
    "[?] ",
    'Meng ',
    "[?] ",
    'Yaji ',
    "[?] ",
    'Ying ',
    'Ying ',
    'Ying ',
    'Xiao ',
    'Sa ',
    'Qiu ',
    'Ke ',
    'Xiang ',
    'Wan ',
    'Yu ',
    'Yu ',
    'Fu ',
    'Lian ',
    'Xuan ',
    'Yuan ',
    'Nan ',
    'Ze ',
    'Wo ',
    'Chun ',
    'Xiao ',
    'Yu ',
    'Pian ',
    'Mao ',
    'An ',
    'E ',
    'Luo ',
    'Ying ',
    'Huo ',
    'Gua ',
    'Jiang ',
    'Mian ',
    'Zuo ',
    'Zuo ',
    'Ju ',
    'Bao ',
    'Rou ',
    'Xi ',
    'Xie ',
    'An ',
    'Qu ',
    'Jian ',
    'Fu ',
    'Lu ',
    'Jing ',
    'Pen ',
    'Feng ',
    'Hong ',
    'Hong ',
    'Hou ',
    'Yan ',
    'Tu ',
    'Zhu ',
    'Zi ',
    'Xiang ',
    'Shen ',
    'Ge ',
    'Jie ',
    'Jing ',
    'Mi ',
    'Huang ',
    'Shen ',
    'Pu ',
    'Gai ',
    'Dong ',
    'Zhou ',
    'Qian ',
    'Wei ',
    'Bo ',
    'Wei ',
    'Pa ',
    'Ji ',
    'Hu ',
    'Zang ',
    'Jia ',
    'Duan ',
    'Yao ',
    'Jun ',
    'Cong ',
    'Quan ',
    'Wei ',
    'Xian ',
    'Kui ',
    'Ting ',
    'Hun ',
    'Xi ',
    'Shi ',
    'Qi ',
    'Lan ',
    'Zong ',
    'Yao ',
    'Yuan ',
    'Mei ',
    'Yun ',
    'Shu ',
    'Di ',
    'Zhuan ',
    'Guan ',
    'Sukumo ',
    'Xue ',
    'Chan ',
    'Kai ',
    'Kui ',
    "[?] ",
    'Jiang ',
    'Lou ',
    'Wei ',
    'Pai ',
    "[?] ",
    'Sou ',
    'Yin ',
    'Shi ',
    'Chun ',
    'Shi ',
    'Yun ',
    'Zhen ',
    'Lang ',
    'Nu ',
    'Meng ',
    'He ',
    'Que ',
    'Suan ',
    'Yuan ',
    'Li ',
    'Ju ',
    'Xi ',
    'Pang ',
    'Chu ',
    'Xu ',
    'Tu ',
    'Liu ',
    'Wo ',
    'Zhen ',
    'Qian ',
    'Zu ',
    'Po ',
    'Cuo ',
    'Yuan ',
    'Chu ',
    'Yu ',
    'Kuai ',
    'Pan ',
    'Pu ',
    'Pu ',
    'Na ',
    'Shuo ',
    'Xi ',
    'Fen ',
    'Yun ',
    'Zheng ',
    'Jian ',
    'Ji ',
    'Ruo ',
    'Cang ',
    'En ',
    'Mi ',
    'Hao ',
    'Sun ',
    'Zhen ',
    'Ming ',
    'Sou ',
    'Xu ',
    'Liu ',
    'Xi ',
    'Gu ',
    'Lang ',
    'Rong ',
    'Weng ',
    'Gai ',
    'Cuo ',
    'Shi ',
    'Tang ',
    'Luo ',
    'Ru ',
    'Suo ',
    'Xian ',
    'Bei ',
    'Yao ',
    'Gui ',
    'Bi ',
    'Zong ',
    'Gun ',
    'Za ',
    'Xiu ',
    'Ce ',
    'Hai ',
    'Lan ',
    "[?] ",
    'Ji ',
    'Li ',
    'Can ',
    'Lang ',
    'Yu ',
    "[?] ",
    'Ying ',
    'Mo ',
    'Diao ',
    'Tiao ',
    'Mao ',
    'Tong ',
    'Zhu ',
    'Peng ',
    'An ',
    'Lian ',
    'Cong ',
    'Xi ',
    'Ping ',
    'Qiu ',
    'Jin ',
    'Chun ',
    'Jie ',
    'Wei ',
    'Tui ',
    'Cao ',
    'Yu ',
    'Yi ',
    'Ji ',
    'Liao ',
    'Bi ',
    'Lu ',
    'Su '
];

},{}],"k9RTY":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Bu ',
    'Zhang ',
    'Luo ',
    'Jiang ',
    'Man ',
    'Yan ',
    'Ling ',
    'Ji ',
    'Piao ',
    'Gun ',
    'Han ',
    'Di ',
    'Su ',
    'Lu ',
    'She ',
    'Shang ',
    'Di ',
    'Mie ',
    'Xun ',
    'Man ',
    'Bo ',
    'Di ',
    'Cuo ',
    'Zhe ',
    'Sen ',
    'Xuan ',
    'Wei ',
    'Hu ',
    'Ao ',
    'Mi ',
    'Lou ',
    'Cu ',
    'Zhong ',
    'Cai ',
    'Po ',
    'Jiang ',
    'Mi ',
    'Cong ',
    'Niao ',
    'Hui ',
    'Jun ',
    'Yin ',
    'Jian ',
    'Yan ',
    'Shu ',
    'Yin ',
    'Kui ',
    'Chen ',
    'Hu ',
    'Sha ',
    'Kou ',
    'Qian ',
    'Ma ',
    'Zang ',
    'Sonoko ',
    'Qiang ',
    'Dou ',
    'Lian ',
    'Lin ',
    'Kou ',
    'Ai ',
    'Bi ',
    'Li ',
    'Wei ',
    'Ji ',
    'Xun ',
    'Sheng ',
    'Fan ',
    'Meng ',
    'Ou ',
    'Chan ',
    'Dian ',
    'Xun ',
    'Jiao ',
    'Rui ',
    'Rui ',
    'Lei ',
    'Yu ',
    'Qiao ',
    'Chu ',
    'Hua ',
    'Jian ',
    'Mai ',
    'Yun ',
    'Bao ',
    'You ',
    'Qu ',
    'Lu ',
    'Rao ',
    'Hui ',
    'E ',
    'Teng ',
    'Fei ',
    'Jue ',
    'Zui ',
    'Fa ',
    'Ru ',
    'Fen ',
    'Kui ',
    'Shun ',
    'Rui ',
    'Ya ',
    'Xu ',
    'Fu ',
    'Jue ',
    'Dang ',
    'Wu ',
    'Tong ',
    'Si ',
    'Xiao ',
    'Xi ',
    'Long ',
    'Yun ',
    "[?] ",
    'Qi ',
    'Jian ',
    'Yun ',
    'Sun ',
    'Ling ',
    'Yu ',
    'Xia ',
    'Yong ',
    'Ji ',
    'Hong ',
    'Si ',
    'Nong ',
    'Lei ',
    'Xuan ',
    'Yun ',
    'Yu ',
    'Xi ',
    'Hao ',
    'Bo ',
    'Hao ',
    'Ai ',
    'Wei ',
    'Hui ',
    'Wei ',
    'Ji ',
    'Ci ',
    'Xiang ',
    'Luan ',
    'Mie ',
    'Yi ',
    'Leng ',
    'Jiang ',
    'Can ',
    'Shen ',
    'Qiang ',
    'Lian ',
    'Ke ',
    'Yuan ',
    'Da ',
    'Ti ',
    'Tang ',
    'Xie ',
    'Bi ',
    'Zhan ',
    'Sun ',
    'Lian ',
    'Fan ',
    'Ding ',
    'Jie ',
    'Gu ',
    'Xie ',
    'Shu ',
    'Jian ',
    'Kao ',
    'Hong ',
    'Sa ',
    'Xin ',
    'Xun ',
    'Yao ',
    'Hie ',
    'Sou ',
    'Shu ',
    'Xun ',
    'Dui ',
    'Pin ',
    'Wei ',
    'Neng ',
    'Chou ',
    'Mai ',
    'Ru ',
    'Piao ',
    'Tai ',
    'Qi ',
    'Zao ',
    'Chen ',
    'Zhen ',
    'Er ',
    'Ni ',
    'Ying ',
    'Gao ',
    'Cong ',
    'Xiao ',
    'Qi ',
    'Fa ',
    'Jian ',
    'Xu ',
    'Kui ',
    'Jie ',
    'Bian ',
    'Diao ',
    'Mi ',
    'Lan ',
    'Jin ',
    'Cang ',
    'Miao ',
    'Qiong ',
    'Qie ',
    'Xian ',
    "[?] ",
    'Ou ',
    'Xian ',
    'Su ',
    'Lu ',
    'Yi ',
    'Xu ',
    'Xie ',
    'Li ',
    'Yi ',
    'La ',
    'Lei ',
    'Xiao ',
    'Di ',
    'Zhi ',
    'Bei ',
    'Teng ',
    'Yao ',
    'Mo ',
    'Huan ',
    'Piao ',
    'Fan ',
    'Sou ',
    'Tan ',
    'Tui ',
    'Qiong ',
    'Qiao ',
    'Wei ',
    'Liu ',
    'Hui ',
    "[?] ",
    'Gao ',
    'Yun ',
    "[?] ",
    'Li ',
    'Shu ',
    'Chu ',
    'Ai ',
    'Lin ',
    'Zao ',
    'Xuan ',
    'Chen ',
    'Lai ',
    'Huo '
];

},{}],"kQ118":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Tuo ',
    'Wu ',
    'Rui ',
    'Rui ',
    'Qi ',
    'Heng ',
    'Lu ',
    'Su ',
    'Tui ',
    'Mang ',
    'Yun ',
    'Pin ',
    'Yu ',
    'Xun ',
    'Ji ',
    'Jiong ',
    'Xian ',
    'Mo ',
    'Hagi ',
    'Su ',
    'Jiong ',
    "[?] ",
    'Nie ',
    'Bo ',
    'Rang ',
    'Yi ',
    'Xian ',
    'Yu ',
    'Ju ',
    'Lian ',
    'Lian ',
    'Yin ',
    'Qiang ',
    'Ying ',
    'Long ',
    'Tong ',
    'Wei ',
    'Yue ',
    'Ling ',
    'Qu ',
    'Yao ',
    'Fan ',
    'Mi ',
    'Lan ',
    'Kui ',
    'Lan ',
    'Ji ',
    'Dang ',
    'Katsura ',
    'Lei ',
    'Lei ',
    'Hua ',
    'Feng ',
    'Zhi ',
    'Wei ',
    'Kui ',
    'Zhan ',
    'Huai ',
    'Li ',
    'Ji ',
    'Mi ',
    'Lei ',
    'Huai ',
    'Luo ',
    'Ji ',
    'Kui ',
    'Lu ',
    'Jian ',
    'San ',
    "[?] ",
    'Lei ',
    'Quan ',
    'Xiao ',
    'Yi ',
    'Luan ',
    'Men ',
    'Bie ',
    'Hu ',
    'Hu ',
    'Lu ',
    'Nue ',
    'Lu ',
    'Si ',
    'Xiao ',
    'Qian ',
    'Chu ',
    'Hu ',
    'Xu ',
    'Cuo ',
    'Fu ',
    'Xu ',
    'Xu ',
    'Lu ',
    'Hu ',
    'Yu ',
    'Hao ',
    'Jiao ',
    'Ju ',
    'Guo ',
    'Bao ',
    'Yan ',
    'Zhan ',
    'Zhan ',
    'Kui ',
    'Ban ',
    'Xi ',
    'Shu ',
    'Chong ',
    'Qiu ',
    'Diao ',
    'Ji ',
    'Qiu ',
    'Cheng ',
    'Shi ',
    "[?] ",
    'Di ',
    'Zhe ',
    'She ',
    'Yu ',
    'Gan ',
    'Zi ',
    'Hong ',
    'Hui ',
    'Meng ',
    'Ge ',
    'Sui ',
    'Xia ',
    'Chai ',
    'Shi ',
    'Yi ',
    'Ma ',
    'Xiang ',
    'Fang ',
    'E ',
    'Pa ',
    'Chi ',
    'Qian ',
    'Wen ',
    'Wen ',
    'Rui ',
    'Bang ',
    'Bi ',
    'Yue ',
    'Yue ',
    'Jun ',
    'Qi ',
    'Ran ',
    'Yin ',
    'Qi ',
    'Tian ',
    'Yuan ',
    'Jue ',
    'Hui ',
    'Qin ',
    'Qi ',
    'Zhong ',
    'Ya ',
    'Ci ',
    'Mu ',
    'Wang ',
    'Fen ',
    'Fen ',
    'Hang ',
    'Gong ',
    'Zao ',
    'Fu ',
    'Ran ',
    'Jie ',
    'Fu ',
    'Chi ',
    'Dou ',
    'Piao ',
    'Xian ',
    'Ni ',
    'Te ',
    'Qiu ',
    'You ',
    'Zha ',
    'Ping ',
    'Chi ',
    'You ',
    'He ',
    'Han ',
    'Ju ',
    'Li ',
    'Fu ',
    'Ran ',
    'Zha ',
    'Gou ',
    'Pi ',
    'Bo ',
    'Xian ',
    'Zhu ',
    'Diao ',
    'Bie ',
    'Bing ',
    'Gu ',
    'Ran ',
    'Qu ',
    'She ',
    'Tie ',
    'Ling ',
    'Gu ',
    'Dan ',
    'Gu ',
    'Ying ',
    'Li ',
    'Cheng ',
    'Qu ',
    'Mou ',
    'Ge ',
    'Ci ',
    'Hui ',
    'Hui ',
    'Mang ',
    'Fu ',
    'Yang ',
    'Wa ',
    'Lie ',
    'Zhu ',
    'Yi ',
    'Xian ',
    'Kuo ',
    'Jiao ',
    'Li ',
    'Yi ',
    'Ping ',
    'Ji ',
    'Ha ',
    'She ',
    'Yi ',
    'Wang ',
    'Mo ',
    'Qiong ',
    'Qie ',
    'Gui ',
    'Gong ',
    'Zhi ',
    'Man ',
    'Ebi ',
    'Zhi ',
    'Jia ',
    'Rao ',
    'Si ',
    'Qi ',
    'Xing ',
    'Lie ',
    'Qiu ',
    'Shao ',
    'Yong ',
    'Jia ',
    'Shui ',
    'Che ',
    'Bai ',
    'E ',
    'Han '
];

},{}],"hpvyz":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:33 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Shu ',
    'Xuan ',
    'Feng ',
    'Shen ',
    'Zhen ',
    'Fu ',
    'Xian ',
    'Zhe ',
    'Wu ',
    'Fu ',
    'Li ',
    'Lang ',
    'Bi ',
    'Chu ',
    'Yuan ',
    'You ',
    'Jie ',
    'Dan ',
    'Yan ',
    'Ting ',
    'Dian ',
    'Shui ',
    'Hui ',
    'Gua ',
    'Zhi ',
    'Song ',
    'Fei ',
    'Ju ',
    'Mi ',
    'Qi ',
    'Qi ',
    'Yu ',
    'Jun ',
    'Zha ',
    'Meng ',
    'Qiang ',
    'Si ',
    'Xi ',
    'Lun ',
    'Li ',
    'Die ',
    'Tiao ',
    'Tao ',
    'Kun ',
    'Gan ',
    'Han ',
    'Yu ',
    'Bang ',
    'Fei ',
    'Pi ',
    'Wei ',
    'Dun ',
    'Yi ',
    'Yuan ',
    'Su ',
    'Quan ',
    'Qian ',
    'Rui ',
    'Ni ',
    'Qing ',
    'Wei ',
    'Liang ',
    'Guo ',
    'Wan ',
    'Dong ',
    'E ',
    'Ban ',
    'Di ',
    'Wang ',
    'Can ',
    'Yang ',
    'Ying ',
    'Guo ',
    'Chan ',
    "[?] ",
    'La ',
    'Ke ',
    'Ji ',
    'He ',
    'Ting ',
    'Mai ',
    'Xu ',
    'Mian ',
    'Yu ',
    'Jie ',
    'Shi ',
    'Xuan ',
    'Huang ',
    'Yan ',
    'Bian ',
    'Rou ',
    'Wei ',
    'Fu ',
    'Yuan ',
    'Mei ',
    'Wei ',
    'Fu ',
    'Ruan ',
    'Xie ',
    'You ',
    'Qiu ',
    'Mao ',
    'Xia ',
    'Ying ',
    'Shi ',
    'Chong ',
    'Tang ',
    'Zhu ',
    'Zong ',
    'Ti ',
    'Fu ',
    'Yuan ',
    'Hui ',
    'Meng ',
    'La ',
    'Du ',
    'Hu ',
    'Qiu ',
    'Die ',
    'Li ',
    'Gua ',
    'Yun ',
    'Ju ',
    'Nan ',
    'Lou ',
    'Qun ',
    'Rong ',
    'Ying ',
    'Jiang ',
    "[?] ",
    'Lang ',
    'Pang ',
    'Si ',
    'Xi ',
    'Ci ',
    'Xi ',
    'Yuan ',
    'Weng ',
    'Lian ',
    'Sou ',
    'Ban ',
    'Rong ',
    'Rong ',
    'Ji ',
    'Wu ',
    'Qiu ',
    'Han ',
    'Qin ',
    'Yi ',
    'Bi ',
    'Hua ',
    'Tang ',
    'Yi ',
    'Du ',
    'Nai ',
    'He ',
    'Hu ',
    'Hui ',
    'Ma ',
    'Ming ',
    'Yi ',
    'Wen ',
    'Ying ',
    'Teng ',
    'Yu ',
    'Cang ',
    'So ',
    'Ebi ',
    'Man ',
    "[?] ",
    'Shang ',
    'Zhe ',
    'Cao ',
    'Chi ',
    'Di ',
    'Ao ',
    'Lu ',
    'Wei ',
    'Zhi ',
    'Tang ',
    'Chen ',
    'Piao ',
    'Qu ',
    'Pi ',
    'Yu ',
    'Jian ',
    'Luo ',
    'Lou ',
    'Qin ',
    'Zhong ',
    'Yin ',
    'Jiang ',
    'Shuai ',
    'Wen ',
    'Jiao ',
    'Wan ',
    'Zhi ',
    'Zhe ',
    'Ma ',
    'Ma ',
    'Guo ',
    'Liu ',
    'Mao ',
    'Xi ',
    'Cong ',
    'Li ',
    'Man ',
    'Xiao ',
    'Kamakiri ',
    'Zhang ',
    'Mang ',
    'Xiang ',
    'Mo ',
    'Zui ',
    'Si ',
    'Qiu ',
    'Te ',
    'Zhi ',
    'Peng ',
    'Peng ',
    'Jiao ',
    'Qu ',
    'Bie ',
    'Liao ',
    'Pan ',
    'Gui ',
    'Xi ',
    'Ji ',
    'Zhuan ',
    'Huang ',
    'Fei ',
    'Lao ',
    'Jue ',
    'Jue ',
    'Hui ',
    'Yin ',
    'Chan ',
    'Jiao ',
    'Shan ',
    'Rao ',
    'Xiao ',
    'Mou ',
    'Chong ',
    'Xun ',
    'Si ',
    "[?] ",
    'Cheng ',
    'Dang ',
    'Li ',
    'Xie ',
    'Shan ',
    'Yi ',
    'Jing ',
    'Da ',
    'Chan ',
    'Qi '
];

},{}],"hwBdK":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:34 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Ci ',
    'Xiang ',
    'She ',
    'Luo ',
    'Qin ',
    'Ying ',
    'Chai ',
    'Li ',
    'Ze ',
    'Xuan ',
    'Lian ',
    'Zhu ',
    'Ze ',
    'Xie ',
    'Mang ',
    'Xie ',
    'Qi ',
    'Rong ',
    'Jian ',
    'Meng ',
    'Hao ',
    'Ruan ',
    'Huo ',
    'Zhuo ',
    'Jie ',
    'Bin ',
    'He ',
    'Mie ',
    'Fan ',
    'Lei ',
    'Jie ',
    'La ',
    'Mi ',
    'Li ',
    'Chun ',
    'Li ',
    'Qiu ',
    'Nie ',
    'Lu ',
    'Du ',
    'Xiao ',
    'Zhu ',
    'Long ',
    'Li ',
    'Long ',
    'Feng ',
    'Ye ',
    'Beng ',
    'Shang ',
    'Gu ',
    'Juan ',
    'Ying ',
    "[?] ",
    'Xi ',
    'Can ',
    'Qu ',
    'Quan ',
    'Du ',
    'Can ',
    'Man ',
    'Jue ',
    'Jie ',
    'Zhu ',
    'Zha ',
    'Xie ',
    'Huang ',
    'Niu ',
    'Pei ',
    'Nu ',
    'Xin ',
    'Zhong ',
    'Mo ',
    'Er ',
    'Ke ',
    'Mie ',
    'Xi ',
    'Xing ',
    'Yan ',
    'Kan ',
    'Yuan ',
    "[?] ",
    'Ling ',
    'Xuan ',
    'Shu ',
    'Xian ',
    'Tong ',
    'Long ',
    'Jie ',
    'Xian ',
    'Ya ',
    'Hu ',
    'Wei ',
    'Dao ',
    'Chong ',
    'Wei ',
    'Dao ',
    'Zhun ',
    'Heng ',
    'Qu ',
    'Yi ',
    'Yi ',
    'Bu ',
    'Gan ',
    'Yu ',
    'Biao ',
    'Cha ',
    'Yi ',
    'Shan ',
    'Chen ',
    'Fu ',
    'Gun ',
    'Fen ',
    'Shuai ',
    'Jie ',
    'Na ',
    'Zhong ',
    'Dan ',
    'Ri ',
    'Zhong ',
    'Zhong ',
    'Xie ',
    'Qi ',
    'Xie ',
    'Ran ',
    'Zhi ',
    'Ren ',
    'Qin ',
    'Jin ',
    'Jun ',
    'Yuan ',
    'Mei ',
    'Chai ',
    'Ao ',
    'Niao ',
    'Hui ',
    'Ran ',
    'Jia ',
    'Tuo ',
    'Ling ',
    'Dai ',
    'Bao ',
    'Pao ',
    'Yao ',
    'Zuo ',
    'Bi ',
    'Shao ',
    'Tan ',
    'Ju ',
    'He ',
    'Shu ',
    'Xiu ',
    'Zhen ',
    'Yi ',
    'Pa ',
    'Bo ',
    'Di ',
    'Wa ',
    'Fu ',
    'Gun ',
    'Zhi ',
    'Zhi ',
    'Ran ',
    'Pan ',
    'Yi ',
    'Mao ',
    'Tuo ',
    'Na ',
    'Kou ',
    'Xian ',
    'Chan ',
    'Qu ',
    'Bei ',
    'Gun ',
    'Xi ',
    'Ne ',
    'Bo ',
    'Horo ',
    'Fu ',
    'Yi ',
    'Chi ',
    'Ku ',
    'Ren ',
    'Jiang ',
    'Jia ',
    'Cun ',
    'Mo ',
    'Jie ',
    'Er ',
    'Luo ',
    'Ru ',
    'Zhu ',
    'Gui ',
    'Yin ',
    'Cai ',
    'Lie ',
    'Kamishimo ',
    'Yuki ',
    'Zhuang ',
    'Dang ',
    "[?] ",
    'Kun ',
    'Ken ',
    'Niao ',
    'Shu ',
    'Jia ',
    'Kun ',
    'Cheng ',
    'Li ',
    'Juan ',
    'Shen ',
    'Pou ',
    'Ge ',
    'Yi ',
    'Yu ',
    'Zhen ',
    'Liu ',
    'Qiu ',
    'Qun ',
    'Ji ',
    'Yi ',
    'Bu ',
    'Zhuang ',
    'Shui ',
    'Sha ',
    'Qun ',
    'Li ',
    'Lian ',
    'Lian ',
    'Ku ',
    'Jian ',
    'Fou ',
    'Chan ',
    'Bi ',
    'Gun ',
    'Tao ',
    'Yuan ',
    'Ling ',
    'Chi ',
    'Chang ',
    'Chou ',
    'Duo ',
    'Biao ',
    'Liang ',
    'Chang ',
    'Pei ',
    'Pei ',
    'Fei ',
    'Yuan ',
    'Luo ',
    'Guo ',
    'Yan ',
    'Du ',
    'Xi ',
    'Zhi ',
    'Ju ',
    'Qi '
];

},{}],"6ABk8":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:34 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Ji ',
    'Zhi ',
    'Gua ',
    'Ken ',
    'Che ',
    'Ti ',
    'Ti ',
    'Fu ',
    'Chong ',
    'Xie ',
    'Bian ',
    'Die ',
    'Kun ',
    'Duan ',
    'Xiu ',
    'Xiu ',
    'He ',
    'Yuan ',
    'Bao ',
    'Bao ',
    'Fu ',
    'Yu ',
    'Tuan ',
    'Yan ',
    'Hui ',
    'Bei ',
    'Chu ',
    'Lu ',
    'Ena ',
    'Hitoe ',
    'Yun ',
    'Da ',
    'Gou ',
    'Da ',
    'Huai ',
    'Rong ',
    'Yuan ',
    'Ru ',
    'Nai ',
    'Jiong ',
    'Suo ',
    'Ban ',
    'Tun ',
    'Chi ',
    'Sang ',
    'Niao ',
    'Ying ',
    'Jie ',
    'Qian ',
    'Huai ',
    'Ku ',
    'Lian ',
    'Bao ',
    'Li ',
    'Zhe ',
    'Shi ',
    'Lu ',
    'Yi ',
    'Die ',
    'Xie ',
    'Xian ',
    'Wei ',
    'Biao ',
    'Cao ',
    'Ji ',
    'Jiang ',
    'Sen ',
    'Bao ',
    'Xiang ',
    'Chihaya ',
    'Pu ',
    'Jian ',
    'Zhuan ',
    'Jian ',
    'Zui ',
    'Ji ',
    'Dan ',
    'Za ',
    'Fan ',
    'Bo ',
    'Xiang ',
    'Xin ',
    'Bie ',
    'Rao ',
    'Man ',
    'Lan ',
    'Ao ',
    'Duo ',
    'Gui ',
    'Cao ',
    'Sui ',
    'Nong ',
    'Chan ',
    'Lian ',
    'Bi ',
    'Jin ',
    'Dang ',
    'Shu ',
    'Tan ',
    'Bi ',
    'Lan ',
    'Pu ',
    'Ru ',
    'Zhi ',
    "[?] ",
    'Shu ',
    'Wa ',
    'Shi ',
    'Bai ',
    'Xie ',
    'Bo ',
    'Chen ',
    'Lai ',
    'Long ',
    'Xi ',
    'Xian ',
    'Lan ',
    'Zhe ',
    'Dai ',
    'Tasuki ',
    'Zan ',
    'Shi ',
    'Jian ',
    'Pan ',
    'Yi ',
    'Ran ',
    'Ya ',
    'Xi ',
    'Xi ',
    'Yao ',
    'Feng ',
    'Tan ',
    "[?] ",
    'Biao ',
    'Fu ',
    'Ba ',
    'He ',
    'Ji ',
    'Ji ',
    'Jian ',
    'Guan ',
    'Bian ',
    'Yan ',
    'Gui ',
    'Jue ',
    'Pian ',
    'Mao ',
    'Mi ',
    'Mi ',
    'Mie ',
    'Shi ',
    'Si ',
    'Zhan ',
    'Luo ',
    'Jue ',
    'Mi ',
    'Tiao ',
    'Lian ',
    'Yao ',
    'Zhi ',
    'Jun ',
    'Xi ',
    'Shan ',
    'Wei ',
    'Xi ',
    'Tian ',
    'Yu ',
    'Lan ',
    'E ',
    'Du ',
    'Qin ',
    'Pang ',
    'Ji ',
    'Ming ',
    'Ying ',
    'Gou ',
    'Qu ',
    'Zhan ',
    'Jin ',
    'Guan ',
    'Deng ',
    'Jian ',
    'Luo ',
    'Qu ',
    'Jian ',
    'Wei ',
    'Jue ',
    'Qu ',
    'Luo ',
    'Lan ',
    'Shen ',
    'Di ',
    'Guan ',
    'Jian ',
    'Guan ',
    'Yan ',
    'Gui ',
    'Mi ',
    'Shi ',
    'Zhan ',
    'Lan ',
    'Jue ',
    'Ji ',
    'Xi ',
    'Di ',
    'Tian ',
    'Yu ',
    'Gou ',
    'Jin ',
    'Qu ',
    'Jiao ',
    'Jiu ',
    'Jin ',
    'Cu ',
    'Jue ',
    'Zhi ',
    'Chao ',
    'Ji ',
    'Gu ',
    'Dan ',
    'Zui ',
    'Di ',
    'Shang ',
    'Hua ',
    'Quan ',
    'Ge ',
    'Chi ',
    'Jie ',
    'Gui ',
    'Gong ',
    'Hong ',
    'Jie ',
    'Hun ',
    'Qiu ',
    'Xing ',
    'Su ',
    'Ni ',
    'Ji ',
    'Lu ',
    'Zhi ',
    'Zha ',
    'Bi ',
    'Xing ',
    'Hu ',
    'Shang ',
    'Gong ',
    'Zhi ',
    'Xue ',
    'Chu ',
    'Xi ',
    'Yi ',
    'Lu ',
    'Jue ',
    'Xi ',
    'Yan ',
    'Xi '
];

},{}],"aFGdV":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:34 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Yan ',
    'Yan ',
    'Ding ',
    'Fu ',
    'Qiu ',
    'Qiu ',
    'Jiao ',
    'Hong ',
    'Ji ',
    'Fan ',
    'Xun ',
    'Diao ',
    'Hong ',
    'Cha ',
    'Tao ',
    'Xu ',
    'Jie ',
    'Yi ',
    'Ren ',
    'Xun ',
    'Yin ',
    'Shan ',
    'Qi ',
    'Tuo ',
    'Ji ',
    'Xun ',
    'Yin ',
    'E ',
    'Fen ',
    'Ya ',
    'Yao ',
    'Song ',
    'Shen ',
    'Yin ',
    'Xin ',
    'Jue ',
    'Xiao ',
    'Ne ',
    'Chen ',
    'You ',
    'Zhi ',
    'Xiong ',
    'Fang ',
    'Xin ',
    'Chao ',
    'She ',
    'Xian ',
    'Sha ',
    'Tun ',
    'Xu ',
    'Yi ',
    'Yi ',
    'Su ',
    'Chi ',
    'He ',
    'Shen ',
    'He ',
    'Xu ',
    'Zhen ',
    'Zhu ',
    'Zheng ',
    'Gou ',
    'Zi ',
    'Zi ',
    'Zhan ',
    'Gu ',
    'Fu ',
    'Quan ',
    'Die ',
    'Ling ',
    'Di ',
    'Yang ',
    'Li ',
    'Nao ',
    'Pan ',
    'Zhou ',
    'Gan ',
    'Yi ',
    'Ju ',
    'Ao ',
    'Zha ',
    'Tuo ',
    'Yi ',
    'Qu ',
    'Zhao ',
    'Ping ',
    'Bi ',
    'Xiong ',
    'Qu ',
    'Ba ',
    'Da ',
    'Zu ',
    'Tao ',
    'Zhu ',
    'Ci ',
    'Zhe ',
    'Yong ',
    'Xu ',
    'Xun ',
    'Yi ',
    'Huang ',
    'He ',
    'Shi ',
    'Cha ',
    'Jiao ',
    'Shi ',
    'Hen ',
    'Cha ',
    'Gou ',
    'Gui ',
    'Quan ',
    'Hui ',
    'Jie ',
    'Hua ',
    'Gai ',
    'Xiang ',
    'Wei ',
    'Shen ',
    'Chou ',
    'Tong ',
    'Mi ',
    'Zhan ',
    'Ming ',
    'E ',
    'Hui ',
    'Yan ',
    'Xiong ',
    'Gua ',
    'Er ',
    'Beng ',
    'Tiao ',
    'Chi ',
    'Lei ',
    'Zhu ',
    'Kuang ',
    'Kua ',
    'Wu ',
    'Yu ',
    'Teng ',
    'Ji ',
    'Zhi ',
    'Ren ',
    'Su ',
    'Lang ',
    'E ',
    'Kuang ',
    'E ',
    'Shi ',
    'Ting ',
    'Dan ',
    'Bo ',
    'Chan ',
    'You ',
    'Heng ',
    'Qiao ',
    'Qin ',
    'Shua ',
    'An ',
    'Yu ',
    'Xiao ',
    'Cheng ',
    'Jie ',
    'Xian ',
    'Wu ',
    'Wu ',
    'Gao ',
    'Song ',
    'Pu ',
    'Hui ',
    'Jing ',
    'Shuo ',
    'Zhen ',
    'Shuo ',
    'Du ',
    'Yasashi ',
    'Chang ',
    'Shui ',
    'Jie ',
    'Ke ',
    'Qu ',
    'Cong ',
    'Xiao ',
    'Sui ',
    'Wang ',
    'Xuan ',
    'Fei ',
    'Chi ',
    'Ta ',
    'Yi ',
    'Na ',
    'Yin ',
    'Diao ',
    'Pi ',
    'Chuo ',
    'Chan ',
    'Chen ',
    'Zhun ',
    'Ji ',
    'Qi ',
    'Tan ',
    'Zhui ',
    'Wei ',
    'Ju ',
    'Qing ',
    'Jian ',
    'Zheng ',
    'Ze ',
    'Zou ',
    'Qian ',
    'Zhuo ',
    'Liang ',
    'Jian ',
    'Zhu ',
    'Hao ',
    'Lun ',
    'Shen ',
    'Biao ',
    'Huai ',
    'Pian ',
    'Yu ',
    'Die ',
    'Xu ',
    'Pian ',
    'Shi ',
    'Xuan ',
    'Shi ',
    'Hun ',
    'Hua ',
    'E ',
    'Zhong ',
    'Di ',
    'Xie ',
    'Fu ',
    'Pu ',
    'Ting ',
    'Jian ',
    'Qi ',
    'Yu ',
    'Zi ',
    'Chuan ',
    'Xi ',
    'Hui ',
    'Yin ',
    'An ',
    'Xian ',
    'Nan ',
    'Chen ',
    'Feng ',
    'Zhu ',
    'Yang ',
    'Yan ',
    'Heng ',
    'Xuan ',
    'Ge ',
    'Nuo ',
    'Qi '
];

},{}],"31OMH":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:34 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Mou ',
    'Ye ',
    'Wei ',
    "[?] ",
    'Teng ',
    'Zou ',
    'Shan ',
    'Jian ',
    'Bo ',
    'Ku ',
    'Huang ',
    'Huo ',
    'Ge ',
    'Ying ',
    'Mi ',
    'Xiao ',
    'Mi ',
    'Xi ',
    'Qiang ',
    'Chen ',
    'Nue ',
    'Ti ',
    'Su ',
    'Bang ',
    'Chi ',
    'Qian ',
    'Shi ',
    'Jiang ',
    'Yuan ',
    'Xie ',
    'Xue ',
    'Tao ',
    'Yao ',
    'Yao ',
    "[?] ",
    'Yu ',
    'Biao ',
    'Cong ',
    'Qing ',
    'Li ',
    'Mo ',
    'Mo ',
    'Shang ',
    'Zhe ',
    'Miu ',
    'Jian ',
    'Ze ',
    'Jie ',
    'Lian ',
    'Lou ',
    'Can ',
    'Ou ',
    'Guan ',
    'Xi ',
    'Zhuo ',
    'Ao ',
    'Ao ',
    'Jin ',
    'Zhe ',
    'Yi ',
    'Hu ',
    'Jiang ',
    'Man ',
    'Chao ',
    'Han ',
    'Hua ',
    'Chan ',
    'Xu ',
    'Zeng ',
    'Se ',
    'Xi ',
    'She ',
    'Dui ',
    'Zheng ',
    'Nao ',
    'Lan ',
    'E ',
    'Ying ',
    'Jue ',
    'Ji ',
    'Zun ',
    'Jiao ',
    'Bo ',
    'Hui ',
    'Zhuan ',
    'Mu ',
    'Zen ',
    'Zha ',
    'Shi ',
    'Qiao ',
    'Tan ',
    'Zen ',
    'Pu ',
    'Sheng ',
    'Xuan ',
    'Zao ',
    'Tan ',
    'Dang ',
    'Sui ',
    'Qian ',
    'Ji ',
    'Jiao ',
    'Jing ',
    'Lian ',
    'Nou ',
    'Yi ',
    'Ai ',
    'Zhan ',
    'Pi ',
    'Hui ',
    'Hua ',
    'Yi ',
    'Yi ',
    'Shan ',
    'Rang ',
    'Nou ',
    'Qian ',
    'Zhui ',
    'Ta ',
    'Hu ',
    'Zhou ',
    'Hao ',
    'Ye ',
    'Ying ',
    'Jian ',
    'Yu ',
    'Jian ',
    'Hui ',
    'Du ',
    'Zhe ',
    'Xuan ',
    'Zan ',
    'Lei ',
    'Shen ',
    'Wei ',
    'Chan ',
    'Li ',
    'Yi ',
    'Bian ',
    'Zhe ',
    'Yan ',
    'E ',
    'Chou ',
    'Wei ',
    'Chou ',
    'Yao ',
    'Chan ',
    'Rang ',
    'Yin ',
    'Lan ',
    'Chen ',
    'Huo ',
    'Zhe ',
    'Huan ',
    'Zan ',
    'Yi ',
    'Dang ',
    'Zhan ',
    'Yan ',
    'Du ',
    'Yan ',
    'Ji ',
    'Ding ',
    'Fu ',
    'Ren ',
    'Ji ',
    'Jie ',
    'Hong ',
    'Tao ',
    'Rang ',
    'Shan ',
    'Qi ',
    'Tuo ',
    'Xun ',
    'Yi ',
    'Xun ',
    'Ji ',
    'Ren ',
    'Jiang ',
    'Hui ',
    'Ou ',
    'Ju ',
    'Ya ',
    'Ne ',
    'Xu ',
    'E ',
    'Lun ',
    'Xiong ',
    'Song ',
    'Feng ',
    'She ',
    'Fang ',
    'Jue ',
    'Zheng ',
    'Gu ',
    'He ',
    'Ping ',
    'Zu ',
    'Shi ',
    'Xiong ',
    'Zha ',
    'Su ',
    'Zhen ',
    'Di ',
    'Zou ',
    'Ci ',
    'Qu ',
    'Zhao ',
    'Bi ',
    'Yi ',
    'Yi ',
    'Kuang ',
    'Lei ',
    'Shi ',
    'Gua ',
    'Shi ',
    'Jie ',
    'Hui ',
    'Cheng ',
    'Zhu ',
    'Shen ',
    'Hua ',
    'Dan ',
    'Gou ',
    'Quan ',
    'Gui ',
    'Xun ',
    'Yi ',
    'Zheng ',
    'Gai ',
    'Xiang ',
    'Cha ',
    'Hun ',
    'Xu ',
    'Zhou ',
    'Jie ',
    'Wu ',
    'Yu ',
    'Qiao ',
    'Wu ',
    'Gao ',
    'You ',
    'Hui ',
    'Kuang ',
    'Shuo ',
    'Song ',
    'Ai ',
    'Qing ',
    'Zhu ',
    'Zou ',
    'Nuo ',
    'Du ',
    'Zhuo ',
    'Fei ',
    'Ke ',
    'Wei '
];

},{}],"fqfUC":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:34 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Yu ',
    'Shui ',
    'Shen ',
    'Diao ',
    'Chan ',
    'Liang ',
    'Zhun ',
    'Sui ',
    'Tan ',
    'Shen ',
    'Yi ',
    'Mou ',
    'Chen ',
    'Die ',
    'Huang ',
    'Jian ',
    'Xie ',
    'Nue ',
    'Ye ',
    'Wei ',
    'E ',
    'Yu ',
    'Xuan ',
    'Chan ',
    'Zi ',
    'An ',
    'Yan ',
    'Di ',
    'Mi ',
    'Pian ',
    'Xu ',
    'Mo ',
    'Dang ',
    'Su ',
    'Xie ',
    'Yao ',
    'Bang ',
    'Shi ',
    'Qian ',
    'Mi ',
    'Jin ',
    'Man ',
    'Zhe ',
    'Jian ',
    'Miu ',
    'Tan ',
    'Zen ',
    'Qiao ',
    'Lan ',
    'Pu ',
    'Jue ',
    'Yan ',
    'Qian ',
    'Zhan ',
    'Chen ',
    'Gu ',
    'Qian ',
    'Hong ',
    'Xia ',
    'Jue ',
    'Hong ',
    'Han ',
    'Hong ',
    'Xi ',
    'Xi ',
    'Huo ',
    'Liao ',
    'Han ',
    'Du ',
    'Long ',
    'Dou ',
    'Jiang ',
    'Qi ',
    'Shi ',
    'Li ',
    'Deng ',
    'Wan ',
    'Bi ',
    'Shu ',
    'Xian ',
    'Feng ',
    'Zhi ',
    'Zhi ',
    'Yan ',
    'Yan ',
    'Shi ',
    'Chu ',
    'Hui ',
    'Tun ',
    'Yi ',
    'Tun ',
    'Yi ',
    'Jian ',
    'Ba ',
    'Hou ',
    'E ',
    'Cu ',
    'Xiang ',
    'Huan ',
    'Jian ',
    'Ken ',
    'Gai ',
    'Qu ',
    'Fu ',
    'Xi ',
    'Bin ',
    'Hao ',
    'Yu ',
    'Zhu ',
    'Jia ',
    "[?] ",
    'Xi ',
    'Bo ',
    'Wen ',
    'Huan ',
    'Bin ',
    'Di ',
    'Zong ',
    'Fen ',
    'Yi ',
    'Zhi ',
    'Bao ',
    'Chai ',
    'Han ',
    'Pi ',
    'Na ',
    'Pi ',
    'Gou ',
    'Na ',
    'You ',
    'Diao ',
    'Mo ',
    'Si ',
    'Xiu ',
    'Huan ',
    'Kun ',
    'He ',
    'He ',
    'Mo ',
    'Han ',
    'Mao ',
    'Li ',
    'Ni ',
    'Bi ',
    'Yu ',
    'Jia ',
    'Tuan ',
    'Mao ',
    'Pi ',
    'Xi ',
    'E ',
    'Ju ',
    'Mo ',
    'Chu ',
    'Tan ',
    'Huan ',
    'Jue ',
    'Bei ',
    'Zhen ',
    'Yuan ',
    'Fu ',
    'Cai ',
    'Gong ',
    'Te ',
    'Yi ',
    'Hang ',
    'Wan ',
    'Pin ',
    'Huo ',
    'Fan ',
    'Tan ',
    'Guan ',
    'Ze ',
    'Zhi ',
    'Er ',
    'Zhu ',
    'Shi ',
    'Bi ',
    'Zi ',
    'Er ',
    'Gui ',
    'Pian ',
    'Bian ',
    'Mai ',
    'Dai ',
    'Sheng ',
    'Kuang ',
    'Fei ',
    'Tie ',
    'Yi ',
    'Chi ',
    'Mao ',
    'He ',
    'Bi ',
    'Lu ',
    'Ren ',
    'Hui ',
    'Gai ',
    'Pian ',
    'Zi ',
    'Jia ',
    'Xu ',
    'Zei ',
    'Jiao ',
    'Gai ',
    'Zang ',
    'Jian ',
    'Ying ',
    'Xun ',
    'Zhen ',
    'She ',
    'Bin ',
    'Bin ',
    'Qiu ',
    'She ',
    'Chuan ',
    'Zang ',
    'Zhou ',
    'Lai ',
    'Zan ',
    'Si ',
    'Chen ',
    'Shang ',
    'Tian ',
    'Pei ',
    'Geng ',
    'Xian ',
    'Mai ',
    'Jian ',
    'Sui ',
    'Fu ',
    'Tan ',
    'Cong ',
    'Cong ',
    'Zhi ',
    'Ji ',
    'Zhang ',
    'Du ',
    'Jin ',
    'Xiong ',
    'Shun ',
    'Yun ',
    'Bao ',
    'Zai ',
    'Lai ',
    'Feng ',
    'Cang ',
    'Ji ',
    'Sheng ',
    'Ai ',
    'Zhuan ',
    'Fu ',
    'Gou ',
    'Sai ',
    'Ze ',
    'Liao '
];

},{}],"5xlbc":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:34 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Wei ',
    'Bai ',
    'Chen ',
    'Zhuan ',
    'Zhi ',
    'Zhui ',
    'Biao ',
    'Yun ',
    'Zeng ',
    'Tan ',
    'Zan ',
    'Yan ',
    "[?] ",
    'Shan ',
    'Wan ',
    'Ying ',
    'Jin ',
    'Gan ',
    'Xian ',
    'Zang ',
    'Bi ',
    'Du ',
    'Shu ',
    'Yan ',
    "[?] ",
    'Xuan ',
    'Long ',
    'Gan ',
    'Zang ',
    'Bei ',
    'Zhen ',
    'Fu ',
    'Yuan ',
    'Gong ',
    'Cai ',
    'Ze ',
    'Xian ',
    'Bai ',
    'Zhang ',
    'Huo ',
    'Zhi ',
    'Fan ',
    'Tan ',
    'Pin ',
    'Bian ',
    'Gou ',
    'Zhu ',
    'Guan ',
    'Er ',
    'Jian ',
    'Bi ',
    'Shi ',
    'Tie ',
    'Gui ',
    'Kuang ',
    'Dai ',
    'Mao ',
    'Fei ',
    'He ',
    'Yi ',
    'Zei ',
    'Zhi ',
    'Jia ',
    'Hui ',
    'Zi ',
    'Ren ',
    'Lu ',
    'Zang ',
    'Zi ',
    'Gai ',
    'Jin ',
    'Qiu ',
    'Zhen ',
    'Lai ',
    'She ',
    'Fu ',
    'Du ',
    'Ji ',
    'Shu ',
    'Shang ',
    'Si ',
    'Bi ',
    'Zhou ',
    'Geng ',
    'Pei ',
    'Tan ',
    'Lai ',
    'Feng ',
    'Zhui ',
    'Fu ',
    'Zhuan ',
    'Sai ',
    'Ze ',
    'Yan ',
    'Zan ',
    'Yun ',
    'Zeng ',
    'Shan ',
    'Ying ',
    'Gan ',
    'Chi ',
    'Xi ',
    'She ',
    'Nan ',
    'Xiong ',
    'Xi ',
    'Cheng ',
    'He ',
    'Cheng ',
    'Zhe ',
    'Xia ',
    'Tang ',
    'Zou ',
    'Zou ',
    'Li ',
    'Jiu ',
    'Fu ',
    'Zhao ',
    'Gan ',
    'Qi ',
    'Shan ',
    'Qiong ',
    'Qin ',
    'Xian ',
    'Ci ',
    'Jue ',
    'Qin ',
    'Chi ',
    'Ci ',
    'Chen ',
    'Chen ',
    'Die ',
    'Ju ',
    'Chao ',
    'Di ',
    'Se ',
    'Zhan ',
    'Zhu ',
    'Yue ',
    'Qu ',
    'Jie ',
    'Chi ',
    'Chu ',
    'Gua ',
    'Xue ',
    'Ci ',
    'Tiao ',
    'Duo ',
    'Lie ',
    'Gan ',
    'Suo ',
    'Cu ',
    'Xi ',
    'Zhao ',
    'Su ',
    'Yin ',
    'Ju ',
    'Jian ',
    'Que ',
    'Tang ',
    'Chuo ',
    'Cui ',
    'Lu ',
    'Qu ',
    'Dang ',
    'Qiu ',
    'Zi ',
    'Ti ',
    'Qu ',
    'Chi ',
    'Huang ',
    'Qiao ',
    'Qiao ',
    'Yao ',
    'Zao ',
    'Ti ',
    "[?] ",
    'Zan ',
    'Zan ',
    'Zu ',
    'Pa ',
    'Bao ',
    'Ku ',
    'Ke ',
    'Dun ',
    'Jue ',
    'Fu ',
    'Chen ',
    'Jian ',
    'Fang ',
    'Zhi ',
    'Sa ',
    'Yue ',
    'Pa ',
    'Qi ',
    'Yue ',
    'Qiang ',
    'Tuo ',
    'Tai ',
    'Yi ',
    'Nian ',
    'Ling ',
    'Mei ',
    'Ba ',
    'Die ',
    'Ku ',
    'Tuo ',
    'Jia ',
    'Ci ',
    'Pao ',
    'Qia ',
    'Zhu ',
    'Ju ',
    'Die ',
    'Zhi ',
    'Fu ',
    'Pan ',
    'Ju ',
    'Shan ',
    'Bo ',
    'Ni ',
    'Ju ',
    'Li ',
    'Gen ',
    'Yi ',
    'Ji ',
    'Dai ',
    'Xian ',
    'Jiao ',
    'Duo ',
    'Zhu ',
    'Zhuan ',
    'Kua ',
    'Zhuai ',
    'Gui ',
    'Qiong ',
    'Kui ',
    'Xiang ',
    'Chi ',
    'Lu ',
    'Beng ',
    'Zhi ',
    'Jia ',
    'Tiao ',
    'Cai ',
    'Jian ',
    'Ta ',
    'Qiao ',
    'Bi ',
    'Xian ',
    'Duo ',
    'Ji ',
    'Ju ',
    'Ji ',
    'Shu ',
    'Tu '
];

},{}],"evrv7":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:34 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Chu ',
    'Jing ',
    'Nie ',
    'Xiao ',
    'Bo ',
    'Chi ',
    'Qun ',
    'Mou ',
    'Shu ',
    'Lang ',
    'Yong ',
    'Jiao ',
    'Chou ',
    'Qiao ',
    "[?] ",
    'Ta ',
    'Jian ',
    'Qi ',
    'Wo ',
    'Wei ',
    'Zhuo ',
    'Jie ',
    'Ji ',
    'Nie ',
    'Ju ',
    'Ju ',
    'Lun ',
    'Lu ',
    'Leng ',
    'Huai ',
    'Ju ',
    'Chi ',
    'Wan ',
    'Quan ',
    'Ti ',
    'Bo ',
    'Zu ',
    'Qie ',
    'Ji ',
    'Cu ',
    'Zong ',
    'Cai ',
    'Zong ',
    'Peng ',
    'Zhi ',
    'Zheng ',
    'Dian ',
    'Zhi ',
    'Yu ',
    'Duo ',
    'Dun ',
    'Chun ',
    'Yong ',
    'Zhong ',
    'Di ',
    'Zhe ',
    'Chen ',
    'Chuai ',
    'Jian ',
    'Gua ',
    'Tang ',
    'Ju ',
    'Fu ',
    'Zu ',
    'Die ',
    'Pian ',
    'Rou ',
    'Nuo ',
    'Ti ',
    'Cha ',
    'Tui ',
    'Jian ',
    'Dao ',
    'Cuo ',
    'Xi ',
    'Ta ',
    'Qiang ',
    'Zhan ',
    'Dian ',
    'Ti ',
    'Ji ',
    'Nie ',
    'Man ',
    'Liu ',
    'Zhan ',
    'Bi ',
    'Chong ',
    'Lu ',
    'Liao ',
    'Cu ',
    'Tang ',
    'Dai ',
    'Suo ',
    'Xi ',
    'Kui ',
    'Ji ',
    'Zhi ',
    'Qiang ',
    'Di ',
    'Man ',
    'Zong ',
    'Lian ',
    'Beng ',
    'Zao ',
    'Nian ',
    'Bie ',
    'Tui ',
    'Ju ',
    'Deng ',
    'Ceng ',
    'Xian ',
    'Fan ',
    'Chu ',
    'Zhong ',
    'Dun ',
    'Bo ',
    'Cu ',
    'Zu ',
    'Jue ',
    'Jue ',
    'Lin ',
    'Ta ',
    'Qiao ',
    'Qiao ',
    'Pu ',
    'Liao ',
    'Dun ',
    'Cuan ',
    'Kuang ',
    'Zao ',
    'Ta ',
    'Bi ',
    'Bi ',
    'Zhu ',
    'Ju ',
    'Chu ',
    'Qiao ',
    'Dun ',
    'Chou ',
    'Ji ',
    'Wu ',
    'Yue ',
    'Nian ',
    'Lin ',
    'Lie ',
    'Zhi ',
    'Li ',
    'Zhi ',
    'Chan ',
    'Chu ',
    'Duan ',
    'Wei ',
    'Long ',
    'Lin ',
    'Xian ',
    'Wei ',
    'Zuan ',
    'Lan ',
    'Xie ',
    'Rang ',
    'Xie ',
    'Nie ',
    'Ta ',
    'Qu ',
    'Jie ',
    'Cuan ',
    'Zuan ',
    'Xi ',
    'Kui ',
    'Jue ',
    'Lin ',
    'Shen ',
    'Gong ',
    'Dan ',
    'Segare ',
    'Qu ',
    'Ti ',
    'Duo ',
    'Duo ',
    'Gong ',
    'Lang ',
    'Nerau ',
    'Luo ',
    'Ai ',
    'Ji ',
    'Ju ',
    'Tang ',
    'Utsuke ',
    "[?] ",
    'Yan ',
    'Shitsuke ',
    'Kang ',
    'Qu ',
    'Lou ',
    'Lao ',
    'Tuo ',
    'Zhi ',
    'Yagate ',
    'Ti ',
    'Dao ',
    'Yagate ',
    'Yu ',
    'Che ',
    'Ya ',
    'Gui ',
    'Jun ',
    'Wei ',
    'Yue ',
    'Xin ',
    'Di ',
    'Xuan ',
    'Fan ',
    'Ren ',
    'Shan ',
    'Qiang ',
    'Shu ',
    'Tun ',
    'Chen ',
    'Dai ',
    'E ',
    'Na ',
    'Qi ',
    'Mao ',
    'Ruan ',
    'Ren ',
    'Fan ',
    'Zhuan ',
    'Hong ',
    'Hu ',
    'Qu ',
    'Huang ',
    'Di ',
    'Ling ',
    'Dai ',
    'Ao ',
    'Zhen ',
    'Fan ',
    'Kuang ',
    'Ang ',
    'Peng ',
    'Bei ',
    'Gu ',
    'Ku ',
    'Pao ',
    'Zhu ',
    'Rong ',
    'E ',
    'Ba ',
    'Zhou ',
    'Zhi ',
    'Yao ',
    'Ke ',
    'Yi ',
    'Qing ',
    'Shi ',
    'Ping '
];

},{}],"hpdQl":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:34 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Er ',
    'Qiong ',
    'Ju ',
    'Jiao ',
    'Guang ',
    'Lu ',
    'Kai ',
    'Quan ',
    'Zhou ',
    'Zai ',
    'Zhi ',
    'She ',
    'Liang ',
    'Yu ',
    'Shao ',
    'You ',
    'Huan ',
    'Yun ',
    'Zhe ',
    'Wan ',
    'Fu ',
    'Qing ',
    'Zhou ',
    'Ni ',
    'Ling ',
    'Zhe ',
    'Zhan ',
    'Liang ',
    'Zi ',
    'Hui ',
    'Wang ',
    'Chuo ',
    'Guo ',
    'Kan ',
    'Yi ',
    'Peng ',
    'Qian ',
    'Gun ',
    'Nian ',
    'Pian ',
    'Guan ',
    'Bei ',
    'Lun ',
    'Pai ',
    'Liang ',
    'Ruan ',
    'Rou ',
    'Ji ',
    'Yang ',
    'Xian ',
    'Chuan ',
    'Cou ',
    'Qun ',
    'Ge ',
    'You ',
    'Hong ',
    'Shu ',
    'Fu ',
    'Zi ',
    'Fu ',
    'Wen ',
    'Ben ',
    'Zhan ',
    'Yu ',
    'Wen ',
    'Tao ',
    'Gu ',
    'Zhen ',
    'Xia ',
    'Yuan ',
    'Lu ',
    'Jiu ',
    'Chao ',
    'Zhuan ',
    'Wei ',
    'Hun ',
    'Sori ',
    'Che ',
    'Jiao ',
    'Zhan ',
    'Pu ',
    'Lao ',
    'Fen ',
    'Fan ',
    'Lin ',
    'Ge ',
    'Se ',
    'Kan ',
    'Huan ',
    'Yi ',
    'Ji ',
    'Dui ',
    'Er ',
    'Yu ',
    'Xian ',
    'Hong ',
    'Lei ',
    'Pei ',
    'Li ',
    'Li ',
    'Lu ',
    'Lin ',
    'Che ',
    'Ya ',
    'Gui ',
    'Xuan ',
    'Di ',
    'Ren ',
    'Zhuan ',
    'E ',
    'Lun ',
    'Ruan ',
    'Hong ',
    'Ku ',
    'Ke ',
    'Lu ',
    'Zhou ',
    'Zhi ',
    'Yi ',
    'Hu ',
    'Zhen ',
    'Li ',
    'Yao ',
    'Qing ',
    'Shi ',
    'Zai ',
    'Zhi ',
    'Jiao ',
    'Zhou ',
    'Quan ',
    'Lu ',
    'Jiao ',
    'Zhe ',
    'Fu ',
    'Liang ',
    'Nian ',
    'Bei ',
    'Hui ',
    'Gun ',
    'Wang ',
    'Liang ',
    'Chuo ',
    'Zi ',
    'Cou ',
    'Fu ',
    'Ji ',
    'Wen ',
    'Shu ',
    'Pei ',
    'Yuan ',
    'Xia ',
    'Zhan ',
    'Lu ',
    'Che ',
    'Lin ',
    'Xin ',
    'Gu ',
    'Ci ',
    'Ci ',
    'Pi ',
    'Zui ',
    'Bian ',
    'La ',
    'La ',
    'Ci ',
    'Xue ',
    'Ban ',
    'Bian ',
    'Bian ',
    'Bian ',
    "[?] ",
    'Bian ',
    'Ban ',
    'Ci ',
    'Bian ',
    'Bian ',
    'Chen ',
    'Ru ',
    'Nong ',
    'Nong ',
    'Zhen ',
    'Chuo ',
    'Chuo ',
    'Suberu ',
    'Reng ',
    'Bian ',
    'Bian ',
    'Sip ',
    'Ip ',
    'Liao ',
    'Da ',
    'Chan ',
    'Gan ',
    'Qian ',
    'Yu ',
    'Yu ',
    'Qi ',
    'Xun ',
    'Yi ',
    'Guo ',
    'Mai ',
    'Qi ',
    'Za ',
    'Wang ',
    'Jia ',
    'Zhun ',
    'Ying ',
    'Ti ',
    'Yun ',
    'Jin ',
    'Hang ',
    'Ya ',
    'Fan ',
    'Wu ',
    'Da ',
    'E ',
    'Huan ',
    'Zhe ',
    'Totemo ',
    'Jin ',
    'Yuan ',
    'Wei ',
    'Lian ',
    'Chi ',
    'Che ',
    'Ni ',
    'Tiao ',
    'Zhi ',
    'Yi ',
    'Jiong ',
    'Jia ',
    'Chen ',
    'Dai ',
    'Er ',
    'Di ',
    'Po ',
    'Wang ',
    'Die ',
    'Ze ',
    'Tao ',
    'Shu ',
    'Tuo ',
    'Kep ',
    'Jing ',
    'Hui ',
    'Tong ',
    'You ',
    'Mi ',
    'Beng ',
    'Ji ',
    'Nai ',
    'Yi ',
    'Jie ',
    'Zhui ',
    'Lie ',
    'Xun '
];

},{}],"YZ7y6":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:34 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Tui ',
    'Song ',
    'Gua ',
    'Tao ',
    'Pang ',
    'Hou ',
    'Ni ',
    'Dun ',
    'Jiong ',
    'Xuan ',
    'Xun ',
    'Bu ',
    'You ',
    'Xiao ',
    'Qiu ',
    'Tou ',
    'Zhu ',
    'Qiu ',
    'Di ',
    'Di ',
    'Tu ',
    'Jing ',
    'Ti ',
    'Dou ',
    'Yi ',
    'Zhe ',
    'Tong ',
    'Guang ',
    'Wu ',
    'Shi ',
    'Cheng ',
    'Su ',
    'Zao ',
    'Qun ',
    'Feng ',
    'Lian ',
    'Suo ',
    'Hui ',
    'Li ',
    'Sako ',
    'Lai ',
    'Ben ',
    'Cuo ',
    'Jue ',
    'Beng ',
    'Huan ',
    'Dai ',
    'Lu ',
    'You ',
    'Zhou ',
    'Jin ',
    'Yu ',
    'Chuo ',
    'Kui ',
    'Wei ',
    'Ti ',
    'Yi ',
    'Da ',
    'Yuan ',
    'Luo ',
    'Bi ',
    'Nuo ',
    'Yu ',
    'Dang ',
    'Sui ',
    'Dun ',
    'Sui ',
    'Yan ',
    'Chuan ',
    'Chi ',
    'Ti ',
    'Yu ',
    'Shi ',
    'Zhen ',
    'You ',
    'Yun ',
    'E ',
    'Bian ',
    'Guo ',
    'E ',
    'Xia ',
    'Huang ',
    'Qiu ',
    'Dao ',
    'Da ',
    'Wei ',
    'Appare ',
    'Yi ',
    'Gou ',
    'Yao ',
    'Chu ',
    'Liu ',
    'Xun ',
    'Ta ',
    'Di ',
    'Chi ',
    'Yuan ',
    'Su ',
    'Ta ',
    'Qian ',
    "[?] ",
    'Yao ',
    'Guan ',
    'Zhang ',
    'Ao ',
    'Shi ',
    'Ce ',
    'Chi ',
    'Su ',
    'Zao ',
    'Zhe ',
    'Dun ',
    'Di ',
    'Lou ',
    'Chi ',
    'Cuo ',
    'Lin ',
    'Zun ',
    'Rao ',
    'Qian ',
    'Xuan ',
    'Yu ',
    'Yi ',
    'Wu ',
    'Liao ',
    'Ju ',
    'Shi ',
    'Bi ',
    'Yao ',
    'Mai ',
    'Xie ',
    'Sui ',
    'Huan ',
    'Zhan ',
    'Teng ',
    'Er ',
    'Miao ',
    'Bian ',
    'Bian ',
    'La ',
    'Li ',
    'Yuan ',
    'Yao ',
    'Luo ',
    'Li ',
    'Yi ',
    'Ting ',
    'Deng ',
    'Qi ',
    'Yong ',
    'Shan ',
    'Han ',
    'Yu ',
    'Mang ',
    'Ru ',
    'Qiong ',
    "[?] ",
    'Kuang ',
    'Fu ',
    'Kang ',
    'Bin ',
    'Fang ',
    'Xing ',
    'Na ',
    'Xin ',
    'Shen ',
    'Bang ',
    'Yuan ',
    'Cun ',
    'Huo ',
    'Xie ',
    'Bang ',
    'Wu ',
    'Ju ',
    'You ',
    'Han ',
    'Tai ',
    'Qiu ',
    'Bi ',
    'Pei ',
    'Bing ',
    'Shao ',
    'Bei ',
    'Wa ',
    'Di ',
    'Zou ',
    'Ye ',
    'Lin ',
    'Kuang ',
    'Gui ',
    'Zhu ',
    'Shi ',
    'Ku ',
    'Yu ',
    'Gai ',
    'Ge ',
    'Xi ',
    'Zhi ',
    'Ji ',
    'Xun ',
    'Hou ',
    'Xing ',
    'Jiao ',
    'Xi ',
    'Gui ',
    'Nuo ',
    'Lang ',
    'Jia ',
    'Kuai ',
    'Zheng ',
    'Otoko ',
    'Yun ',
    'Yan ',
    'Cheng ',
    'Dou ',
    'Chi ',
    'Lu ',
    'Fu ',
    'Wu ',
    'Fu ',
    'Gao ',
    'Hao ',
    'Lang ',
    'Jia ',
    'Geng ',
    'Jun ',
    'Ying ',
    'Bo ',
    'Xi ',
    'Bei ',
    'Li ',
    'Yun ',
    'Bu ',
    'Xiao ',
    'Qi ',
    'Pi ',
    'Qing ',
    'Guo ',
    'Zhou ',
    'Tan ',
    'Zou ',
    'Ping ',
    'Lai ',
    'Ni ',
    'Chen ',
    'You ',
    'Bu ',
    'Xiang ',
    'Dan ',
    'Ju ',
    'Yong ',
    'Qiao ',
    'Yi ',
    'Du ',
    'Yan ',
    'Mei '
];

},{}],"fMu3g":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:35 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Ruo ',
    'Bei ',
    'E ',
    'Yu ',
    'Juan ',
    'Yu ',
    'Yun ',
    'Hou ',
    'Kui ',
    'Xiang ',
    'Xiang ',
    'Sou ',
    'Tang ',
    'Ming ',
    'Xi ',
    'Ru ',
    'Chu ',
    'Zi ',
    'Zou ',
    'Ju ',
    'Wu ',
    'Xiang ',
    'Yun ',
    'Hao ',
    'Yong ',
    'Bi ',
    'Mo ',
    'Chao ',
    'Fu ',
    'Liao ',
    'Yin ',
    'Zhuan ',
    'Hu ',
    'Qiao ',
    'Yan ',
    'Zhang ',
    'Fan ',
    'Qiao ',
    'Xu ',
    'Deng ',
    'Bi ',
    'Xin ',
    'Bi ',
    'Ceng ',
    'Wei ',
    'Zheng ',
    'Mao ',
    'Shan ',
    'Lin ',
    'Po ',
    'Dan ',
    'Meng ',
    'Ye ',
    'Cao ',
    'Kuai ',
    'Feng ',
    'Meng ',
    'Zou ',
    'Kuang ',
    'Lian ',
    'Zan ',
    'Chan ',
    'You ',
    'Qi ',
    'Yan ',
    'Chan ',
    'Zan ',
    'Ling ',
    'Huan ',
    'Xi ',
    'Feng ',
    'Zan ',
    'Li ',
    'You ',
    'Ding ',
    'Qiu ',
    'Zhuo ',
    'Pei ',
    'Zhou ',
    'Yi ',
    'Hang ',
    'Yu ',
    'Jiu ',
    'Yan ',
    'Zui ',
    'Mao ',
    'Dan ',
    'Xu ',
    'Tou ',
    'Zhen ',
    'Fen ',
    'Sakenomoto ',
    "[?] ",
    'Yun ',
    'Tai ',
    'Tian ',
    'Qia ',
    'Tuo ',
    'Zuo ',
    'Han ',
    'Gu ',
    'Su ',
    'Po ',
    'Chou ',
    'Zai ',
    'Ming ',
    'Luo ',
    'Chuo ',
    'Chou ',
    'You ',
    'Tong ',
    'Zhi ',
    'Xian ',
    'Jiang ',
    'Cheng ',
    'Yin ',
    'Tu ',
    'Xiao ',
    'Mei ',
    'Ku ',
    'Suan ',
    'Lei ',
    'Pu ',
    'Zui ',
    'Hai ',
    'Yan ',
    'Xi ',
    'Niang ',
    'Wei ',
    'Lu ',
    'Lan ',
    'Yan ',
    'Tao ',
    'Pei ',
    'Zhan ',
    'Chun ',
    'Tan ',
    'Zui ',
    'Chuo ',
    'Cu ',
    'Kun ',
    'Ti ',
    'Mian ',
    'Du ',
    'Hu ',
    'Xu ',
    'Xing ',
    'Tan ',
    'Jiu ',
    'Chun ',
    'Yun ',
    'Po ',
    'Ke ',
    'Sou ',
    'Mi ',
    'Quan ',
    'Chou ',
    'Cuo ',
    'Yun ',
    'Yong ',
    'Ang ',
    'Zha ',
    'Hai ',
    'Tang ',
    'Jiang ',
    'Piao ',
    'Shan ',
    'Yu ',
    'Li ',
    'Zao ',
    'Lao ',
    'Yi ',
    'Jiang ',
    'Pu ',
    'Jiao ',
    'Xi ',
    'Tan ',
    'Po ',
    'Nong ',
    'Yi ',
    'Li ',
    'Ju ',
    'Jiao ',
    'Yi ',
    'Niang ',
    'Ru ',
    'Xun ',
    'Chou ',
    'Yan ',
    'Ling ',
    'Mi ',
    'Mi ',
    'Niang ',
    'Xin ',
    'Jiao ',
    'Xi ',
    'Mi ',
    'Yan ',
    'Bian ',
    'Cai ',
    'Shi ',
    'You ',
    'Shi ',
    'Shi ',
    'Li ',
    'Zhong ',
    'Ye ',
    'Liang ',
    'Li ',
    'Jin ',
    'Jin ',
    'Qiu ',
    'Yi ',
    'Diao ',
    'Dao ',
    'Zhao ',
    'Ding ',
    'Po ',
    'Qiu ',
    'He ',
    'Fu ',
    'Zhen ',
    'Zhi ',
    'Ba ',
    'Luan ',
    'Fu ',
    'Nai ',
    'Diao ',
    'Shan ',
    'Qiao ',
    'Kou ',
    'Chuan ',
    'Zi ',
    'Fan ',
    'Yu ',
    'Hua ',
    'Han ',
    'Gong ',
    'Qi ',
    'Mang ',
    'Ri ',
    'Di ',
    'Si ',
    'Xi ',
    'Yi ',
    'Chai ',
    'Shi ',
    'Tu ',
    'Xi ',
    'Nu ',
    'Qian ',
    'Ishiyumi ',
    'Jian ',
    'Pi ',
    'Ye ',
    'Yin '
];

},{}],"lWyjj":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:35 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Ba ',
    'Fang ',
    'Chen ',
    'Xing ',
    'Tou ',
    'Yue ',
    'Yan ',
    'Fu ',
    'Pi ',
    'Na ',
    'Xin ',
    'E ',
    'Jue ',
    'Dun ',
    'Gou ',
    'Yin ',
    'Qian ',
    'Ban ',
    'Ji ',
    'Ren ',
    'Chao ',
    'Niu ',
    'Fen ',
    'Yun ',
    'Ji ',
    'Qin ',
    'Pi ',
    'Guo ',
    'Hong ',
    'Yin ',
    'Jun ',
    'Shi ',
    'Yi ',
    'Zhong ',
    'Nie ',
    'Gai ',
    'Ri ',
    'Huo ',
    'Tai ',
    'Kang ',
    'Habaki ',
    'Irori ',
    'Ngaak ',
    "[?] ",
    'Duo ',
    'Zi ',
    'Ni ',
    'Tu ',
    'Shi ',
    'Min ',
    'Gu ',
    'E ',
    'Ling ',
    'Bing ',
    'Yi ',
    'Gu ',
    'Ba ',
    'Pi ',
    'Yu ',
    'Si ',
    'Zuo ',
    'Bu ',
    'You ',
    'Dian ',
    'Jia ',
    'Zhen ',
    'Shi ',
    'Shi ',
    'Tie ',
    'Ju ',
    'Zhan ',
    'Shi ',
    'She ',
    'Xuan ',
    'Zhao ',
    'Bao ',
    'He ',
    'Bi ',
    'Sheng ',
    'Chu ',
    'Shi ',
    'Bo ',
    'Zhu ',
    'Chi ',
    'Za ',
    'Po ',
    'Tong ',
    'Qian ',
    'Fu ',
    'Zhai ',
    'Liu ',
    'Qian ',
    'Fu ',
    'Li ',
    'Yue ',
    'Pi ',
    'Yang ',
    'Ban ',
    'Bo ',
    'Jie ',
    'Gou ',
    'Shu ',
    'Zheng ',
    'Mu ',
    'Ni ',
    'Nie ',
    'Di ',
    'Jia ',
    'Mu ',
    'Dan ',
    'Shen ',
    'Yi ',
    'Si ',
    'Kuang ',
    'Ka ',
    'Bei ',
    'Jian ',
    'Tong ',
    'Xing ',
    'Hong ',
    'Jiao ',
    'Chi ',
    'Er ',
    'Ge ',
    'Bing ',
    'Shi ',
    'Mou ',
    'Jia ',
    'Yin ',
    'Jun ',
    'Zhou ',
    'Chong ',
    'Shang ',
    'Tong ',
    'Mo ',
    'Lei ',
    'Ji ',
    'Yu ',
    'Xu ',
    'Ren ',
    'Zun ',
    'Zhi ',
    'Qiong ',
    'Shan ',
    'Chi ',
    'Xian ',
    'Xing ',
    'Quan ',
    'Pi ',
    'Tie ',
    'Zhu ',
    'Hou ',
    'Ming ',
    'Kua ',
    'Yao ',
    'Xian ',
    'Xian ',
    'Xiu ',
    'Jun ',
    'Cha ',
    'Lao ',
    'Ji ',
    'Pi ',
    'Ru ',
    'Mi ',
    'Yi ',
    'Yin ',
    'Guang ',
    'An ',
    'Diou ',
    'You ',
    'Se ',
    'Kao ',
    'Qian ',
    'Luan ',
    'Kasugai ',
    'Ai ',
    'Diao ',
    'Han ',
    'Rui ',
    'Shi ',
    'Keng ',
    'Qiu ',
    'Xiao ',
    'Zhe ',
    'Xiu ',
    'Zang ',
    'Ti ',
    'Cuo ',
    'Gua ',
    'Gong ',
    'Zhong ',
    'Dou ',
    'Lu ',
    'Mei ',
    'Lang ',
    'Wan ',
    'Xin ',
    'Yun ',
    'Bei ',
    'Wu ',
    'Su ',
    'Yu ',
    'Chan ',
    'Ting ',
    'Bo ',
    'Han ',
    'Jia ',
    'Hong ',
    'Cuan ',
    'Feng ',
    'Chan ',
    'Wan ',
    'Zhi ',
    'Si ',
    'Xuan ',
    'Wu ',
    'Wu ',
    'Tiao ',
    'Gong ',
    'Zhuo ',
    'Lue ',
    'Xing ',
    'Qian ',
    'Shen ',
    'Han ',
    'Lue ',
    'Xie ',
    'Chu ',
    'Zheng ',
    'Ju ',
    'Xian ',
    'Tie ',
    'Mang ',
    'Pu ',
    'Li ',
    'Pan ',
    'Rui ',
    'Cheng ',
    'Gao ',
    'Li ',
    'Te ',
    'Pyeng ',
    'Zhu ',
    "[?] ",
    'Tu ',
    'Liu ',
    'Zui ',
    'Ju ',
    'Chang ',
    'Yuan ',
    'Jian ',
    'Gang ',
    'Diao ',
    'Tao ',
    'Chang '
];

},{}],"gNXHz":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:35 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Lun ',
    'Kua ',
    'Ling ',
    'Bei ',
    'Lu ',
    'Li ',
    'Qiang ',
    'Pou ',
    'Juan ',
    'Min ',
    'Zui ',
    'Peng ',
    'An ',
    'Pi ',
    'Xian ',
    'Ya ',
    'Zhui ',
    'Lei ',
    'A ',
    'Kong ',
    'Ta ',
    'Kun ',
    'Du ',
    'Wei ',
    'Chui ',
    'Zi ',
    'Zheng ',
    'Ben ',
    'Nie ',
    'Cong ',
    'Qun ',
    'Tan ',
    'Ding ',
    'Qi ',
    'Qian ',
    'Zhuo ',
    'Qi ',
    'Yu ',
    'Jin ',
    'Guan ',
    'Mao ',
    'Chang ',
    'Tian ',
    'Xi ',
    'Lian ',
    'Tao ',
    'Gu ',
    'Cuo ',
    'Shu ',
    'Zhen ',
    'Lu ',
    'Meng ',
    'Lu ',
    'Hua ',
    'Biao ',
    'Ga ',
    'Lai ',
    'Ken ',
    'Kazari ',
    'Bu ',
    'Nai ',
    'Wan ',
    'Zan ',
    "[?] ",
    'De ',
    'Xian ',
    "[?] ",
    'Huo ',
    'Liang ',
    "[?] ",
    'Men ',
    'Kai ',
    'Ying ',
    'Di ',
    'Lian ',
    'Guo ',
    'Xian ',
    'Du ',
    'Tu ',
    'Wei ',
    'Cong ',
    'Fu ',
    'Rou ',
    'Ji ',
    'E ',
    'Rou ',
    'Chen ',
    'Ti ',
    'Zha ',
    'Hong ',
    'Yang ',
    'Duan ',
    'Xia ',
    'Yu ',
    'Keng ',
    'Xing ',
    'Huang ',
    'Wei ',
    'Fu ',
    'Zhao ',
    'Cha ',
    'Qie ',
    'She ',
    'Hong ',
    'Kui ',
    'Tian ',
    'Mou ',
    'Qiao ',
    'Qiao ',
    'Hou ',
    'Tou ',
    'Cong ',
    'Huan ',
    'Ye ',
    'Min ',
    'Jian ',
    'Duan ',
    'Jian ',
    'Song ',
    'Kui ',
    'Hu ',
    'Xuan ',
    'Duo ',
    'Jie ',
    'Zhen ',
    'Bian ',
    'Zhong ',
    'Zi ',
    'Xiu ',
    'Ye ',
    'Mei ',
    'Pai ',
    'Ai ',
    'Jie ',
    "[?] ",
    'Mei ',
    'Chuo ',
    'Ta ',
    'Bang ',
    'Xia ',
    'Lian ',
    'Suo ',
    'Xi ',
    'Liu ',
    'Zu ',
    'Ye ',
    'Nou ',
    'Weng ',
    'Rong ',
    'Tang ',
    'Suo ',
    'Qiang ',
    'Ge ',
    'Shuo ',
    'Chui ',
    'Bo ',
    'Pan ',
    'Sa ',
    'Bi ',
    'Sang ',
    'Gang ',
    'Zi ',
    'Wu ',
    'Ying ',
    'Huang ',
    'Tiao ',
    'Liu ',
    'Kai ',
    'Sun ',
    'Sha ',
    'Sou ',
    'Wan ',
    'Hao ',
    'Zhen ',
    'Zhen ',
    'Luo ',
    'Yi ',
    'Yuan ',
    'Tang ',
    'Nie ',
    'Xi ',
    'Jia ',
    'Ge ',
    'Ma ',
    'Juan ',
    'Kasugai ',
    'Habaki ',
    'Suo ',
    "[?] ",
    "[?] ",
    "[?] ",
    'Na ',
    'Lu ',
    'Suo ',
    'Ou ',
    'Zu ',
    'Tuan ',
    'Xiu ',
    'Guan ',
    'Xuan ',
    'Lian ',
    'Shou ',
    'Ao ',
    'Man ',
    'Mo ',
    'Luo ',
    'Bi ',
    'Wei ',
    'Liu ',
    'Di ',
    'Qiao ',
    'Cong ',
    'Yi ',
    'Lu ',
    'Ao ',
    'Keng ',
    'Qiang ',
    'Cui ',
    'Qi ',
    'Chang ',
    'Tang ',
    'Man ',
    'Yong ',
    'Chan ',
    'Feng ',
    'Jing ',
    'Biao ',
    'Shu ',
    'Lou ',
    'Xiu ',
    'Cong ',
    'Long ',
    'Zan ',
    'Jian ',
    'Cao ',
    'Li ',
    'Xia ',
    'Xi ',
    'Kang ',
    "[?] ",
    'Beng ',
    "[?] ",
    "[?] ",
    'Zheng ',
    'Lu ',
    'Hua ',
    'Ji ',
    'Pu ',
    'Hui ',
    'Qiang ',
    'Po ',
    'Lin ',
    'Suo ',
    'Xiu ',
    'San ',
    'Cheng '
];

},{}],"he6RC":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:35 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Kui ',
    'Si ',
    'Liu ',
    'Nao ',
    'Heng ',
    'Pie ',
    'Sui ',
    'Fan ',
    'Qiao ',
    'Quan ',
    'Yang ',
    'Tang ',
    'Xiang ',
    'Jue ',
    'Jiao ',
    'Zun ',
    'Liao ',
    'Jie ',
    'Lao ',
    'Dui ',
    'Tan ',
    'Zan ',
    'Ji ',
    'Jian ',
    'Zhong ',
    'Deng ',
    'Ya ',
    'Ying ',
    'Dui ',
    'Jue ',
    'Nou ',
    'Ti ',
    'Pu ',
    'Tie ',
    "[?] ",
    "[?] ",
    'Ding ',
    'Shan ',
    'Kai ',
    'Jian ',
    'Fei ',
    'Sui ',
    'Lu ',
    'Juan ',
    'Hui ',
    'Yu ',
    'Lian ',
    'Zhuo ',
    'Qiao ',
    'Qian ',
    'Zhuo ',
    'Lei ',
    'Bi ',
    'Tie ',
    'Huan ',
    'Ye ',
    'Duo ',
    'Guo ',
    'Dang ',
    'Ju ',
    'Fen ',
    'Da ',
    'Bei ',
    'Yi ',
    'Ai ',
    'Zong ',
    'Xun ',
    'Diao ',
    'Zhu ',
    'Heng ',
    'Zhui ',
    'Ji ',
    'Nie ',
    'Ta ',
    'Huo ',
    'Qing ',
    'Bin ',
    'Ying ',
    'Kui ',
    'Ning ',
    'Xu ',
    'Jian ',
    'Jian ',
    'Yari ',
    'Cha ',
    'Zhi ',
    'Mie ',
    'Li ',
    'Lei ',
    'Ji ',
    'Zuan ',
    'Kuang ',
    'Shang ',
    'Peng ',
    'La ',
    'Du ',
    'Shuo ',
    'Chuo ',
    'Lu ',
    'Biao ',
    'Bao ',
    'Lu ',
    "[?] ",
    "[?] ",
    'Long ',
    'E ',
    'Lu ',
    'Xin ',
    'Jian ',
    'Lan ',
    'Bo ',
    'Jian ',
    'Yao ',
    'Chan ',
    'Xiang ',
    'Jian ',
    'Xi ',
    'Guan ',
    'Cang ',
    'Nie ',
    'Lei ',
    'Cuan ',
    'Qu ',
    'Pan ',
    'Luo ',
    'Zuan ',
    'Luan ',
    'Zao ',
    'Nie ',
    'Jue ',
    'Tang ',
    'Shu ',
    'Lan ',
    'Jin ',
    'Qiu ',
    'Yi ',
    'Zhen ',
    'Ding ',
    'Zhao ',
    'Po ',
    'Diao ',
    'Tu ',
    'Qian ',
    'Chuan ',
    'Shan ',
    'Ji ',
    'Fan ',
    'Diao ',
    'Men ',
    'Nu ',
    'Xi ',
    'Chai ',
    'Xing ',
    'Gai ',
    'Bu ',
    'Tai ',
    'Ju ',
    'Dun ',
    'Chao ',
    'Zhong ',
    'Na ',
    'Bei ',
    'Gang ',
    'Ban ',
    'Qian ',
    'Yao ',
    'Qin ',
    'Jun ',
    'Wu ',
    'Gou ',
    'Kang ',
    'Fang ',
    'Huo ',
    'Tou ',
    'Niu ',
    'Ba ',
    'Yu ',
    'Qian ',
    'Zheng ',
    'Qian ',
    'Gu ',
    'Bo ',
    'E ',
    'Po ',
    'Bu ',
    'Ba ',
    'Yue ',
    'Zuan ',
    'Mu ',
    'Dan ',
    'Jia ',
    'Dian ',
    'You ',
    'Tie ',
    'Bo ',
    'Ling ',
    'Shuo ',
    'Qian ',
    'Liu ',
    'Bao ',
    'Shi ',
    'Xuan ',
    'She ',
    'Bi ',
    'Ni ',
    'Pi ',
    'Duo ',
    'Xing ',
    'Kao ',
    'Lao ',
    'Er ',
    'Mang ',
    'Ya ',
    'You ',
    'Cheng ',
    'Jia ',
    'Ye ',
    'Nao ',
    'Zhi ',
    'Dang ',
    'Tong ',
    'Lu ',
    'Diao ',
    'Yin ',
    'Kai ',
    'Zha ',
    'Zhu ',
    'Xian ',
    'Ting ',
    'Diu ',
    'Xian ',
    'Hua ',
    'Quan ',
    'Sha ',
    'Jia ',
    'Yao ',
    'Ge ',
    'Ming ',
    'Zheng ',
    'Se ',
    'Jiao ',
    'Yi ',
    'Chan ',
    'Chong ',
    'Tang ',
    'An ',
    'Yin ',
    'Ru ',
    'Zhu ',
    'Lao ',
    'Pu ',
    'Wu ',
    'Lai ',
    'Te ',
    'Lian ',
    'Keng '
];

},{}],"ldtmX":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:35 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Xiao ',
    'Suo ',
    'Li ',
    'Zheng ',
    'Chu ',
    'Guo ',
    'Gao ',
    'Tie ',
    'Xiu ',
    'Cuo ',
    'Lue ',
    'Feng ',
    'Xin ',
    'Liu ',
    'Kai ',
    'Jian ',
    'Rui ',
    'Ti ',
    'Lang ',
    'Qian ',
    'Ju ',
    'A ',
    'Qiang ',
    'Duo ',
    'Tian ',
    'Cuo ',
    'Mao ',
    'Ben ',
    'Qi ',
    'De ',
    'Kua ',
    'Kun ',
    'Chang ',
    'Xi ',
    'Gu ',
    'Luo ',
    'Chui ',
    'Zhui ',
    'Jin ',
    'Zhi ',
    'Xian ',
    'Juan ',
    'Huo ',
    'Pou ',
    'Tan ',
    'Ding ',
    'Jian ',
    'Ju ',
    'Meng ',
    'Zi ',
    'Qie ',
    'Ying ',
    'Kai ',
    'Qiang ',
    'Song ',
    'E ',
    'Cha ',
    'Qiao ',
    'Zhong ',
    'Duan ',
    'Sou ',
    'Huang ',
    'Huan ',
    'Ai ',
    'Du ',
    'Mei ',
    'Lou ',
    'Zi ',
    'Fei ',
    'Mei ',
    'Mo ',
    'Zhen ',
    'Bo ',
    'Ge ',
    'Nie ',
    'Tang ',
    'Juan ',
    'Nie ',
    'Na ',
    'Liu ',
    'Hao ',
    'Bang ',
    'Yi ',
    'Jia ',
    'Bin ',
    'Rong ',
    'Biao ',
    'Tang ',
    'Man ',
    'Luo ',
    'Beng ',
    'Yong ',
    'Jing ',
    'Di ',
    'Zu ',
    'Xuan ',
    'Liu ',
    'Tan ',
    'Jue ',
    'Liao ',
    'Pu ',
    'Lu ',
    'Dui ',
    'Lan ',
    'Pu ',
    'Cuan ',
    'Qiang ',
    'Deng ',
    'Huo ',
    'Lei ',
    'Huan ',
    'Zhuo ',
    'Lian ',
    'Yi ',
    'Cha ',
    'Biao ',
    'La ',
    'Chan ',
    'Xiang ',
    'Chang ',
    'Chang ',
    'Jiu ',
    'Ao ',
    'Die ',
    'Qu ',
    'Liao ',
    'Mi ',
    'Chang ',
    'Men ',
    'Ma ',
    'Shuan ',
    'Shan ',
    'Huo ',
    'Men ',
    'Yan ',
    'Bi ',
    'Han ',
    'Bi ',
    'San ',
    'Kai ',
    'Kang ',
    'Beng ',
    'Hong ',
    'Run ',
    'San ',
    'Xian ',
    'Xian ',
    'Jian ',
    'Min ',
    'Xia ',
    'Yuru ',
    'Dou ',
    'Zha ',
    'Nao ',
    'Jian ',
    'Peng ',
    'Xia ',
    'Ling ',
    'Bian ',
    'Bi ',
    'Run ',
    'He ',
    'Guan ',
    'Ge ',
    'Ge ',
    'Fa ',
    'Chu ',
    'Hong ',
    'Gui ',
    'Min ',
    'Se ',
    'Kun ',
    'Lang ',
    'Lu ',
    'Ting ',
    'Sha ',
    'Ju ',
    'Yue ',
    'Yue ',
    'Chan ',
    'Qu ',
    'Lin ',
    'Chang ',
    'Shai ',
    'Kun ',
    'Yan ',
    'Min ',
    'Yan ',
    'E ',
    'Hun ',
    'Yu ',
    'Wen ',
    'Xiang ',
    'Bao ',
    'Xiang ',
    'Qu ',
    'Yao ',
    'Wen ',
    'Ban ',
    'An ',
    'Wei ',
    'Yin ',
    'Kuo ',
    'Que ',
    'Lan ',
    'Du ',
    "[?] ",
    'Phwung ',
    'Tian ',
    'Nie ',
    'Ta ',
    'Kai ',
    'He ',
    'Que ',
    'Chuang ',
    'Guan ',
    'Dou ',
    'Qi ',
    'Kui ',
    'Tang ',
    'Guan ',
    'Piao ',
    'Kan ',
    'Xi ',
    'Hui ',
    'Chan ',
    'Pi ',
    'Dang ',
    'Huan ',
    'Ta ',
    'Wen ',
    "[?] ",
    'Men ',
    'Shuan ',
    'Shan ',
    'Yan ',
    'Han ',
    'Bi ',
    'Wen ',
    'Chuang ',
    'Run ',
    'Wei ',
    'Xian ',
    'Hong ',
    'Jian ',
    'Min ',
    'Kang ',
    'Men ',
    'Zha ',
    'Nao ',
    'Gui ',
    'Wen ',
    'Ta ',
    'Min ',
    'Lu ',
    'Kai '
];

},{}],"dBfqF":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:35 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Fa ',
    'Ge ',
    'He ',
    'Kun ',
    'Jiu ',
    'Yue ',
    'Lang ',
    'Du ',
    'Yu ',
    'Yan ',
    'Chang ',
    'Xi ',
    'Wen ',
    'Hun ',
    'Yan ',
    'E ',
    'Chan ',
    'Lan ',
    'Qu ',
    'Hui ',
    'Kuo ',
    'Que ',
    'Ge ',
    'Tian ',
    'Ta ',
    'Que ',
    'Kan ',
    'Huan ',
    'Fu ',
    'Fu ',
    'Le ',
    'Dui ',
    'Xin ',
    'Qian ',
    'Wu ',
    'Yi ',
    'Tuo ',
    'Yin ',
    'Yang ',
    'Dou ',
    'E ',
    'Sheng ',
    'Ban ',
    'Pei ',
    'Keng ',
    'Yun ',
    'Ruan ',
    'Zhi ',
    'Pi ',
    'Jing ',
    'Fang ',
    'Yang ',
    'Yin ',
    'Zhen ',
    'Jie ',
    'Cheng ',
    'E ',
    'Qu ',
    'Di ',
    'Zu ',
    'Zuo ',
    'Dian ',
    'Ling ',
    'A ',
    'Tuo ',
    'Tuo ',
    'Po ',
    'Bing ',
    'Fu ',
    'Ji ',
    'Lu ',
    'Long ',
    'Chen ',
    'Xing ',
    'Duo ',
    'Lou ',
    'Mo ',
    'Jiang ',
    'Shu ',
    'Duo ',
    'Xian ',
    'Er ',
    'Gui ',
    'Yu ',
    'Gai ',
    'Shan ',
    'Xun ',
    'Qiao ',
    'Xing ',
    'Chun ',
    'Fu ',
    'Bi ',
    'Xia ',
    'Shan ',
    'Sheng ',
    'Zhi ',
    'Pu ',
    'Dou ',
    'Yuan ',
    'Zhen ',
    'Chu ',
    'Xian ',
    'Tou ',
    'Nie ',
    'Yun ',
    'Xian ',
    'Pei ',
    'Pei ',
    'Zou ',
    'Yi ',
    'Dui ',
    'Lun ',
    'Yin ',
    'Ju ',
    'Chui ',
    'Chen ',
    'Pi ',
    'Ling ',
    'Tao ',
    'Xian ',
    'Lu ',
    'Sheng ',
    'Xian ',
    'Yin ',
    'Zhu ',
    'Yang ',
    'Reng ',
    'Shan ',
    'Chong ',
    'Yan ',
    'Yin ',
    'Yu ',
    'Ti ',
    'Yu ',
    'Long ',
    'Wei ',
    'Wei ',
    'Nie ',
    'Dui ',
    'Sui ',
    'An ',
    'Huang ',
    'Jie ',
    'Sui ',
    'Yin ',
    'Gai ',
    'Yan ',
    'Hui ',
    'Ge ',
    'Yun ',
    'Wu ',
    'Wei ',
    'Ai ',
    'Xi ',
    'Tang ',
    'Ji ',
    'Zhang ',
    'Dao ',
    'Ao ',
    'Xi ',
    'Yin ',
    "[?] ",
    'Rao ',
    'Lin ',
    'Tui ',
    'Deng ',
    'Pi ',
    'Sui ',
    'Sui ',
    'Yu ',
    'Xian ',
    'Fen ',
    'Ni ',
    'Er ',
    'Ji ',
    'Dao ',
    'Xi ',
    'Yin ',
    'E ',
    'Hui ',
    'Long ',
    'Xi ',
    'Li ',
    'Li ',
    'Li ',
    'Zhui ',
    'He ',
    'Zhi ',
    'Zhun ',
    'Jun ',
    'Nan ',
    'Yi ',
    'Que ',
    'Yan ',
    'Qian ',
    'Ya ',
    'Xiong ',
    'Ya ',
    'Ji ',
    'Gu ',
    'Huan ',
    'Zhi ',
    'Gou ',
    'Jun ',
    'Ci ',
    'Yong ',
    'Ju ',
    'Chu ',
    'Hu ',
    'Za ',
    'Luo ',
    'Yu ',
    'Chou ',
    'Diao ',
    'Sui ',
    'Han ',
    'Huo ',
    'Shuang ',
    'Guan ',
    'Chu ',
    'Za ',
    'Yong ',
    'Ji ',
    'Xi ',
    'Chou ',
    'Liu ',
    'Li ',
    'Nan ',
    'Xue ',
    'Za ',
    'Ji ',
    'Ji ',
    'Yu ',
    'Yu ',
    'Xue ',
    'Na ',
    'Fou ',
    'Se ',
    'Mu ',
    'Wen ',
    'Fen ',
    'Pang ',
    'Yun ',
    'Li ',
    'Li ',
    'Ang ',
    'Ling ',
    'Lei ',
    'An ',
    'Bao ',
    'Meng ',
    'Dian ',
    'Dang ',
    'Xing ',
    'Wu ',
    'Zhao '
];

},{}],"fSQ4W":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:35 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Xu ',
    'Ji ',
    'Mu ',
    'Chen ',
    'Xiao ',
    'Zha ',
    'Ting ',
    'Zhen ',
    'Pei ',
    'Mei ',
    'Ling ',
    'Qi ',
    'Chou ',
    'Huo ',
    'Sha ',
    'Fei ',
    'Weng ',
    'Zhan ',
    'Yin ',
    'Ni ',
    'Chou ',
    'Tun ',
    'Lin ',
    "[?] ",
    'Dong ',
    'Ying ',
    'Wu ',
    'Ling ',
    'Shuang ',
    'Ling ',
    'Xia ',
    'Hong ',
    'Yin ',
    'Mo ',
    'Mai ',
    'Yun ',
    'Liu ',
    'Meng ',
    'Bin ',
    'Wu ',
    'Wei ',
    'Huo ',
    'Yin ',
    'Xi ',
    'Yi ',
    'Ai ',
    'Dan ',
    'Deng ',
    'Xian ',
    'Yu ',
    'Lu ',
    'Long ',
    'Dai ',
    'Ji ',
    'Pang ',
    'Yang ',
    'Ba ',
    'Pi ',
    'Wei ',
    "[?] ",
    'Xi ',
    'Ji ',
    'Mai ',
    'Meng ',
    'Meng ',
    'Lei ',
    'Li ',
    'Huo ',
    'Ai ',
    'Fei ',
    'Dai ',
    'Long ',
    'Ling ',
    'Ai ',
    'Feng ',
    'Li ',
    'Bao ',
    "[?] ",
    'He ',
    'He ',
    'Bing ',
    'Qing ',
    'Qing ',
    'Jing ',
    'Tian ',
    'Zhen ',
    'Jing ',
    'Cheng ',
    'Qing ',
    'Jing ',
    'Jing ',
    'Dian ',
    'Jing ',
    'Tian ',
    'Fei ',
    'Fei ',
    'Kao ',
    'Mi ',
    'Mian ',
    'Mian ',
    'Pao ',
    'Ye ',
    'Tian ',
    'Hui ',
    'Ye ',
    'Ge ',
    'Ding ',
    'Cha ',
    'Jian ',
    'Ren ',
    'Di ',
    'Du ',
    'Wu ',
    'Ren ',
    'Qin ',
    'Jin ',
    'Xue ',
    'Niu ',
    'Ba ',
    'Yin ',
    'Sa ',
    'Na ',
    'Mo ',
    'Zu ',
    'Da ',
    'Ban ',
    'Yi ',
    'Yao ',
    'Tao ',
    'Tuo ',
    'Jia ',
    'Hong ',
    'Pao ',
    'Yang ',
    'Tomo ',
    'Yin ',
    'Jia ',
    'Tao ',
    'Ji ',
    'Xie ',
    'An ',
    'An ',
    'Hen ',
    'Gong ',
    'Kohaze ',
    'Da ',
    'Qiao ',
    'Ting ',
    'Wan ',
    'Ying ',
    'Sui ',
    'Tiao ',
    'Qiao ',
    'Xuan ',
    'Kong ',
    'Beng ',
    'Ta ',
    'Zhang ',
    'Bing ',
    'Kuo ',
    'Ju ',
    'La ',
    'Xie ',
    'Rou ',
    'Bang ',
    'Yi ',
    'Qiu ',
    'Qiu ',
    'He ',
    'Xiao ',
    'Mu ',
    'Ju ',
    'Jian ',
    'Bian ',
    'Di ',
    'Jian ',
    'On ',
    'Tao ',
    'Gou ',
    'Ta ',
    'Bei ',
    'Xie ',
    'Pan ',
    'Ge ',
    'Bi ',
    'Kuo ',
    'Tang ',
    'Lou ',
    'Gui ',
    'Qiao ',
    'Xue ',
    'Ji ',
    'Jian ',
    'Jiang ',
    'Chan ',
    'Da ',
    'Huo ',
    'Xian ',
    'Qian ',
    'Du ',
    'Wa ',
    'Jian ',
    'Lan ',
    'Wei ',
    'Ren ',
    'Fu ',
    'Mei ',
    'Juan ',
    'Ge ',
    'Wei ',
    'Qiao ',
    'Han ',
    'Chang ',
    "[?] ",
    'Rou ',
    'Xun ',
    'She ',
    'Wei ',
    'Ge ',
    'Bei ',
    'Tao ',
    'Gou ',
    'Yun ',
    "[?] ",
    'Bi ',
    'Wei ',
    'Hui ',
    'Du ',
    'Wa ',
    'Du ',
    'Wei ',
    'Ren ',
    'Fu ',
    'Han ',
    'Wei ',
    'Yun ',
    'Tao ',
    'Jiu ',
    'Jiu ',
    'Xian ',
    'Xie ',
    'Xian ',
    'Ji ',
    'Yin ',
    'Za ',
    'Yun ',
    'Shao ',
    'Le ',
    'Peng ',
    'Heng ',
    'Ying ',
    'Yun ',
    'Peng ',
    'Yin ',
    'Yin ',
    'Xiang '
];

},{}],"2quN2":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:35 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Hu ',
    'Ye ',
    'Ding ',
    'Qing ',
    'Pan ',
    'Xiang ',
    'Shun ',
    'Han ',
    'Xu ',
    'Yi ',
    'Xu ',
    'Gu ',
    'Song ',
    'Kui ',
    'Qi ',
    'Hang ',
    'Yu ',
    'Wan ',
    'Ban ',
    'Dun ',
    'Di ',
    'Dan ',
    'Pan ',
    'Po ',
    'Ling ',
    'Ce ',
    'Jing ',
    'Lei ',
    'He ',
    'Qiao ',
    'E ',
    'E ',
    'Wei ',
    'Jie ',
    'Gua ',
    'Shen ',
    'Yi ',
    'Shen ',
    'Hai ',
    'Dui ',
    'Pian ',
    'Ping ',
    'Lei ',
    'Fu ',
    'Jia ',
    'Tou ',
    'Hui ',
    'Kui ',
    'Jia ',
    'Le ',
    'Tian ',
    'Cheng ',
    'Ying ',
    'Jun ',
    'Hu ',
    'Han ',
    'Jing ',
    'Tui ',
    'Tui ',
    'Pin ',
    'Lai ',
    'Tui ',
    'Zi ',
    'Zi ',
    'Chui ',
    'Ding ',
    'Lai ',
    'Yan ',
    'Han ',
    'Jian ',
    'Ke ',
    'Cui ',
    'Jiong ',
    'Qin ',
    'Yi ',
    'Sai ',
    'Ti ',
    'E ',
    'E ',
    'Yan ',
    'Hun ',
    'Kan ',
    'Yong ',
    'Zhuan ',
    'Yan ',
    'Xian ',
    'Xin ',
    'Yi ',
    'Yuan ',
    'Sang ',
    'Dian ',
    'Dian ',
    'Jiang ',
    'Ku ',
    'Lei ',
    'Liao ',
    'Piao ',
    'Yi ',
    'Man ',
    'Qi ',
    'Rao ',
    'Hao ',
    'Qiao ',
    'Gu ',
    'Xun ',
    'Qian ',
    'Hui ',
    'Zhan ',
    'Ru ',
    'Hong ',
    'Bin ',
    'Xian ',
    'Pin ',
    'Lu ',
    'Lan ',
    'Nie ',
    'Quan ',
    'Ye ',
    'Ding ',
    'Qing ',
    'Han ',
    'Xiang ',
    'Shun ',
    'Xu ',
    'Xu ',
    'Wan ',
    'Gu ',
    'Dun ',
    'Qi ',
    'Ban ',
    'Song ',
    'Hang ',
    'Yu ',
    'Lu ',
    'Ling ',
    'Po ',
    'Jing ',
    'Jie ',
    'Jia ',
    'Tian ',
    'Han ',
    'Ying ',
    'Jiong ',
    'Hai ',
    'Yi ',
    'Pin ',
    'Hui ',
    'Tui ',
    'Han ',
    'Ying ',
    'Ying ',
    'Ke ',
    'Ti ',
    'Yong ',
    'E ',
    'Zhuan ',
    'Yan ',
    'E ',
    'Nie ',
    'Man ',
    'Dian ',
    'Sang ',
    'Hao ',
    'Lei ',
    'Zhan ',
    'Ru ',
    'Pin ',
    'Quan ',
    'Feng ',
    'Biao ',
    'Oroshi ',
    'Fu ',
    'Xia ',
    'Zhan ',
    'Biao ',
    'Sa ',
    'Ba ',
    'Tai ',
    'Lie ',
    'Gua ',
    'Xuan ',
    'Shao ',
    'Ju ',
    'Bi ',
    'Si ',
    'Wei ',
    'Yang ',
    'Yao ',
    'Sou ',
    'Kai ',
    'Sao ',
    'Fan ',
    'Liu ',
    'Xi ',
    'Liao ',
    'Piao ',
    'Piao ',
    'Liu ',
    'Biao ',
    'Biao ',
    'Biao ',
    'Liao ',
    "[?] ",
    'Se ',
    'Feng ',
    'Biao ',
    'Feng ',
    'Yang ',
    'Zhan ',
    'Biao ',
    'Sa ',
    'Ju ',
    'Si ',
    'Sou ',
    'Yao ',
    'Liu ',
    'Piao ',
    'Biao ',
    'Biao ',
    'Fei ',
    'Fan ',
    'Fei ',
    'Fei ',
    'Shi ',
    'Shi ',
    'Can ',
    'Ji ',
    'Ding ',
    'Si ',
    'Tuo ',
    'Zhan ',
    'Sun ',
    'Xiang ',
    'Tun ',
    'Ren ',
    'Yu ',
    'Juan ',
    'Chi ',
    'Yin ',
    'Fan ',
    'Fan ',
    'Sun ',
    'Yin ',
    'Zhu ',
    'Yi ',
    'Zhai ',
    'Bi ',
    'Jie ',
    'Tao ',
    'Liu ',
    'Ci ',
    'Tie ',
    'Si ',
    'Bao ',
    'Shi ',
    'Duo '
];

},{}],"7bzlO":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:35 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Hai ',
    'Ren ',
    'Tian ',
    'Jiao ',
    'Jia ',
    'Bing ',
    'Yao ',
    'Tong ',
    'Ci ',
    'Xiang ',
    'Yang ',
    'Yang ',
    'Er ',
    'Yan ',
    'Le ',
    'Yi ',
    'Can ',
    'Bo ',
    'Nei ',
    'E ',
    'Bu ',
    'Jun ',
    'Dou ',
    'Su ',
    'Yu ',
    'Shi ',
    'Yao ',
    'Hun ',
    'Guo ',
    'Shi ',
    'Jian ',
    'Zhui ',
    'Bing ',
    'Xian ',
    'Bu ',
    'Ye ',
    'Tan ',
    'Fei ',
    'Zhang ',
    'Wei ',
    'Guan ',
    'E ',
    'Nuan ',
    'Hun ',
    'Hu ',
    'Huang ',
    'Tie ',
    'Hui ',
    'Jian ',
    'Hou ',
    'He ',
    'Xing ',
    'Fen ',
    'Wei ',
    'Gu ',
    'Cha ',
    'Song ',
    'Tang ',
    'Bo ',
    'Gao ',
    'Xi ',
    'Kui ',
    'Liu ',
    'Sou ',
    'Tao ',
    'Ye ',
    'Yun ',
    'Mo ',
    'Tang ',
    'Man ',
    'Bi ',
    'Yu ',
    'Xiu ',
    'Jin ',
    'San ',
    'Kui ',
    'Zhuan ',
    'Shan ',
    'Chi ',
    'Dan ',
    'Yi ',
    'Ji ',
    'Rao ',
    'Cheng ',
    'Yong ',
    'Tao ',
    'Hui ',
    'Xiang ',
    'Zhan ',
    'Fen ',
    'Hai ',
    'Meng ',
    'Yan ',
    'Mo ',
    'Chan ',
    'Xiang ',
    'Luo ',
    'Zuan ',
    'Nang ',
    'Shi ',
    'Ding ',
    'Ji ',
    'Tuo ',
    'Xing ',
    'Tun ',
    'Xi ',
    'Ren ',
    'Yu ',
    'Chi ',
    'Fan ',
    'Yin ',
    'Jian ',
    'Shi ',
    'Bao ',
    'Si ',
    'Duo ',
    'Yi ',
    'Er ',
    'Rao ',
    'Xiang ',
    'Jia ',
    'Le ',
    'Jiao ',
    'Yi ',
    'Bing ',
    'Bo ',
    'Dou ',
    'E ',
    'Yu ',
    'Nei ',
    'Jun ',
    'Guo ',
    'Hun ',
    'Xian ',
    'Guan ',
    'Cha ',
    'Kui ',
    'Gu ',
    'Sou ',
    'Chan ',
    'Ye ',
    'Mo ',
    'Bo ',
    'Liu ',
    'Xiu ',
    'Jin ',
    'Man ',
    'San ',
    'Zhuan ',
    'Nang ',
    'Shou ',
    'Kui ',
    'Guo ',
    'Xiang ',
    'Fen ',
    'Ba ',
    'Ni ',
    'Bi ',
    'Bo ',
    'Tu ',
    'Han ',
    'Fei ',
    'Jian ',
    'An ',
    'Ai ',
    'Fu ',
    'Xian ',
    'Wen ',
    'Xin ',
    'Fen ',
    'Bin ',
    'Xing ',
    'Ma ',
    'Yu ',
    'Feng ',
    'Han ',
    'Di ',
    'Tuo ',
    'Tuo ',
    'Chi ',
    'Xun ',
    'Zhu ',
    'Zhi ',
    'Pei ',
    'Xin ',
    'Ri ',
    'Sa ',
    'Yin ',
    'Wen ',
    'Zhi ',
    'Dan ',
    'Lu ',
    'You ',
    'Bo ',
    'Bao ',
    'Kuai ',
    'Tuo ',
    'Yi ',
    'Qu ',
    "[?] ",
    'Qu ',
    'Jiong ',
    'Bo ',
    'Zhao ',
    'Yuan ',
    'Peng ',
    'Zhou ',
    'Ju ',
    'Zhu ',
    'Nu ',
    'Ju ',
    'Pi ',
    'Zang ',
    'Jia ',
    'Ling ',
    'Zhen ',
    'Tai ',
    'Fu ',
    'Yang ',
    'Shi ',
    'Bi ',
    'Tuo ',
    'Tuo ',
    'Si ',
    'Liu ',
    'Ma ',
    'Pian ',
    'Tao ',
    'Zhi ',
    'Rong ',
    'Teng ',
    'Dong ',
    'Xun ',
    'Quan ',
    'Shen ',
    'Jiong ',
    'Er ',
    'Hai ',
    'Bo ',
    'Zhu ',
    'Yin ',
    'Luo ',
    'Shuu ',
    'Dan ',
    'Xie ',
    'Liu ',
    'Ju ',
    'Song ',
    'Qin ',
    'Mang ',
    'Liang ',
    'Han ',
    'Tu ',
    'Xuan ',
    'Tui ',
    'Jun '
];

},{}],"aLPv2":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:35 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'E ',
    'Cheng ',
    'Xin ',
    'Ai ',
    'Lu ',
    'Zhui ',
    'Zhou ',
    'She ',
    'Pian ',
    'Kun ',
    'Tao ',
    'Lai ',
    'Zong ',
    'Ke ',
    'Qi ',
    'Qi ',
    'Yan ',
    'Fei ',
    'Sao ',
    'Yan ',
    'Jie ',
    'Yao ',
    'Wu ',
    'Pian ',
    'Cong ',
    'Pian ',
    'Qian ',
    'Fei ',
    'Huang ',
    'Jian ',
    'Huo ',
    'Yu ',
    'Ti ',
    'Quan ',
    'Xia ',
    'Zong ',
    'Kui ',
    'Rou ',
    'Si ',
    'Gua ',
    'Tuo ',
    'Kui ',
    'Sou ',
    'Qian ',
    'Cheng ',
    'Zhi ',
    'Liu ',
    'Pang ',
    'Teng ',
    'Xi ',
    'Cao ',
    'Du ',
    'Yan ',
    'Yuan ',
    'Zou ',
    'Sao ',
    'Shan ',
    'Li ',
    'Zhi ',
    'Shuang ',
    'Lu ',
    'Xi ',
    'Luo ',
    'Zhang ',
    'Mo ',
    'Ao ',
    'Can ',
    'Piao ',
    'Cong ',
    'Qu ',
    'Bi ',
    'Zhi ',
    'Yu ',
    'Xu ',
    'Hua ',
    'Bo ',
    'Su ',
    'Xiao ',
    'Lin ',
    'Chan ',
    'Dun ',
    'Liu ',
    'Tuo ',
    'Zeng ',
    'Tan ',
    'Jiao ',
    'Tie ',
    'Yan ',
    'Luo ',
    'Zhan ',
    'Jing ',
    'Yi ',
    'Ye ',
    'Tuo ',
    'Bin ',
    'Zou ',
    'Yan ',
    'Peng ',
    'Lu ',
    'Teng ',
    'Xiang ',
    'Ji ',
    'Shuang ',
    'Ju ',
    'Xi ',
    'Huan ',
    'Li ',
    'Biao ',
    'Ma ',
    'Yu ',
    'Tuo ',
    'Xun ',
    'Chi ',
    'Qu ',
    'Ri ',
    'Bo ',
    'Lu ',
    'Zang ',
    'Shi ',
    'Si ',
    'Fu ',
    'Ju ',
    'Zou ',
    'Zhu ',
    'Tuo ',
    'Nu ',
    'Jia ',
    'Yi ',
    'Tai ',
    'Xiao ',
    'Ma ',
    'Yin ',
    'Jiao ',
    'Hua ',
    'Luo ',
    'Hai ',
    'Pian ',
    'Biao ',
    'Li ',
    'Cheng ',
    'Yan ',
    'Xin ',
    'Qin ',
    'Jun ',
    'Qi ',
    'Qi ',
    'Ke ',
    'Zhui ',
    'Zong ',
    'Su ',
    'Can ',
    'Pian ',
    'Zhi ',
    'Kui ',
    'Sao ',
    'Wu ',
    'Ao ',
    'Liu ',
    'Qian ',
    'Shan ',
    'Piao ',
    'Luo ',
    'Cong ',
    'Chan ',
    'Zou ',
    'Ji ',
    'Shuang ',
    'Xiang ',
    'Gu ',
    'Wei ',
    'Wei ',
    'Wei ',
    'Yu ',
    'Gan ',
    'Yi ',
    'Ang ',
    'Tou ',
    'Xie ',
    'Bao ',
    'Bi ',
    'Chi ',
    'Ti ',
    'Di ',
    'Ku ',
    'Hai ',
    'Qiao ',
    'Gou ',
    'Kua ',
    'Ge ',
    'Tui ',
    'Geng ',
    'Pian ',
    'Bi ',
    'Ke ',
    'Ka ',
    'Yu ',
    'Sui ',
    'Lou ',
    'Bo ',
    'Xiao ',
    'Pang ',
    'Bo ',
    'Ci ',
    'Kuan ',
    'Bin ',
    'Mo ',
    'Liao ',
    'Lou ',
    'Nao ',
    'Du ',
    'Zang ',
    'Sui ',
    'Ti ',
    'Bin ',
    'Kuan ',
    'Lu ',
    'Gao ',
    'Gao ',
    'Qiao ',
    'Kao ',
    'Qiao ',
    'Lao ',
    'Zao ',
    'Biao ',
    'Kun ',
    'Kun ',
    'Ti ',
    'Fang ',
    'Xiu ',
    'Ran ',
    'Mao ',
    'Dan ',
    'Kun ',
    'Bin ',
    'Fa ',
    'Tiao ',
    'Peng ',
    'Zi ',
    'Fa ',
    'Ran ',
    'Ti ',
    'Pao ',
    'Pi ',
    'Mao ',
    'Fu ',
    'Er ',
    'Rong ',
    'Qu ',
    'Gong ',
    'Xiu ',
    'Gua ',
    'Ji ',
    'Peng ',
    'Zhua ',
    'Shao ',
    'Sha '
];

},{}],"kDhaC":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:36 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Ti ',
    'Li ',
    'Bin ',
    'Zong ',
    'Ti ',
    'Peng ',
    'Song ',
    'Zheng ',
    'Quan ',
    'Zong ',
    'Shun ',
    'Jian ',
    'Duo ',
    'Hu ',
    'La ',
    'Jiu ',
    'Qi ',
    'Lian ',
    'Zhen ',
    'Bin ',
    'Peng ',
    'Mo ',
    'San ',
    'Man ',
    'Man ',
    'Seng ',
    'Xu ',
    'Lie ',
    'Qian ',
    'Qian ',
    'Nong ',
    'Huan ',
    'Kuai ',
    'Ning ',
    'Bin ',
    'Lie ',
    'Rang ',
    'Dou ',
    'Dou ',
    'Nao ',
    'Hong ',
    'Xi ',
    'Dou ',
    'Han ',
    'Dou ',
    'Dou ',
    'Jiu ',
    'Chang ',
    'Yu ',
    'Yu ',
    'Li ',
    'Juan ',
    'Fu ',
    'Qian ',
    'Gui ',
    'Zong ',
    'Liu ',
    'Gui ',
    'Shang ',
    'Yu ',
    'Gui ',
    'Mei ',
    'Ji ',
    'Qi ',
    'Jie ',
    'Kui ',
    'Hun ',
    'Ba ',
    'Po ',
    'Mei ',
    'Xu ',
    'Yan ',
    'Xiao ',
    'Liang ',
    'Yu ',
    'Tui ',
    'Qi ',
    'Wang ',
    'Liang ',
    'Wei ',
    'Jian ',
    'Chi ',
    'Piao ',
    'Bi ',
    'Mo ',
    'Ji ',
    'Xu ',
    'Chou ',
    'Yan ',
    'Zhan ',
    'Yu ',
    'Dao ',
    'Ren ',
    'Ji ',
    'Eri ',
    'Gong ',
    'Tuo ',
    'Diao ',
    'Ji ',
    'Xu ',
    'E ',
    'E ',
    'Sha ',
    'Hang ',
    'Tun ',
    'Mo ',
    'Jie ',
    'Shen ',
    'Fan ',
    'Yuan ',
    'Bi ',
    'Lu ',
    'Wen ',
    'Hu ',
    'Lu ',
    'Za ',
    'Fang ',
    'Fen ',
    'Na ',
    'You ',
    'Namazu ',
    'Todo ',
    'He ',
    'Xia ',
    'Qu ',
    'Han ',
    'Pi ',
    'Ling ',
    'Tuo ',
    'Bo ',
    'Qiu ',
    'Ping ',
    'Fu ',
    'Bi ',
    'Ji ',
    'Wei ',
    'Ju ',
    'Diao ',
    'Bo ',
    'You ',
    'Gun ',
    'Pi ',
    'Nian ',
    'Xing ',
    'Tai ',
    'Bao ',
    'Fu ',
    'Zha ',
    'Ju ',
    'Gu ',
    'Kajika ',
    'Tong ',
    "[?] ",
    'Ta ',
    'Jie ',
    'Shu ',
    'Hou ',
    'Xiang ',
    'Er ',
    'An ',
    'Wei ',
    'Tiao ',
    'Zhu ',
    'Yin ',
    'Lie ',
    'Luo ',
    'Tong ',
    'Yi ',
    'Qi ',
    'Bing ',
    'Wei ',
    'Jiao ',
    'Bu ',
    'Gui ',
    'Xian ',
    'Ge ',
    'Hui ',
    'Bora ',
    'Mate ',
    'Kao ',
    'Gori ',
    'Duo ',
    'Jun ',
    'Ti ',
    'Man ',
    'Xiao ',
    'Za ',
    'Sha ',
    'Qin ',
    'Yu ',
    'Nei ',
    'Zhe ',
    'Gun ',
    'Geng ',
    'Su ',
    'Wu ',
    'Qiu ',
    'Ting ',
    'Fu ',
    'Wan ',
    'You ',
    'Li ',
    'Sha ',
    'Sha ',
    'Gao ',
    'Meng ',
    'Ugui ',
    'Asari ',
    'Subashiri ',
    'Kazunoko ',
    'Yong ',
    'Ni ',
    'Zi ',
    'Qi ',
    'Qing ',
    'Xiang ',
    'Nei ',
    'Chun ',
    'Ji ',
    'Diao ',
    'Qie ',
    'Gu ',
    'Zhou ',
    'Dong ',
    'Lai ',
    'Fei ',
    'Ni ',
    'Yi ',
    'Kun ',
    'Lu ',
    'Jiu ',
    'Chang ',
    'Jing ',
    'Lun ',
    'Ling ',
    'Zou ',
    'Li ',
    'Meng ',
    'Zong ',
    'Zhi ',
    'Nian ',
    'Shachi ',
    'Dojou ',
    'Sukesou ',
    'Shi ',
    'Shen ',
    'Hun ',
    'Shi ',
    'Hou ',
    'Xing ',
    'Zhu ',
    'La ',
    'Zong ',
    'Ji ',
    'Bian ',
    'Bian '
];

},{}],"l7Oxx":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:36 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Huan ',
    'Quan ',
    'Ze ',
    'Wei ',
    'Wei ',
    'Yu ',
    'Qun ',
    'Rou ',
    'Die ',
    'Huang ',
    'Lian ',
    'Yan ',
    'Qiu ',
    'Qiu ',
    'Jian ',
    'Bi ',
    'E ',
    'Yang ',
    'Fu ',
    'Sai ',
    'Jian ',
    'Xia ',
    'Tuo ',
    'Hu ',
    'Muroaji ',
    'Ruo ',
    'Haraka ',
    'Wen ',
    'Jian ',
    'Hao ',
    'Wu ',
    'Fang ',
    'Sao ',
    'Liu ',
    'Ma ',
    'Shi ',
    'Shi ',
    'Yin ',
    'Z ',
    'Teng ',
    'Ta ',
    'Yao ',
    'Ge ',
    'Rong ',
    'Qian ',
    'Qi ',
    'Wen ',
    'Ruo ',
    'Hatahata ',
    'Lian ',
    'Ao ',
    'Le ',
    'Hui ',
    'Min ',
    'Ji ',
    'Tiao ',
    'Qu ',
    'Jian ',
    'Sao ',
    'Man ',
    'Xi ',
    'Qiu ',
    'Biao ',
    'Ji ',
    'Ji ',
    'Zhu ',
    'Jiang ',
    'Qiu ',
    'Zhuan ',
    'Yong ',
    'Zhang ',
    'Kang ',
    'Xue ',
    'Bie ',
    'Jue ',
    'Qu ',
    'Xiang ',
    'Bo ',
    'Jiao ',
    'Xun ',
    'Su ',
    'Huang ',
    'Zun ',
    'Shan ',
    'Shan ',
    'Fan ',
    'Jue ',
    'Lin ',
    'Xun ',
    'Miao ',
    'Xi ',
    'Eso ',
    'Kyou ',
    'Fen ',
    'Guan ',
    'Hou ',
    'Kuai ',
    'Zei ',
    'Sao ',
    'Zhan ',
    'Gan ',
    'Gui ',
    'Sheng ',
    'Li ',
    'Chang ',
    'Hatahata ',
    'Shiira ',
    'Mutsu ',
    'Ru ',
    'Ji ',
    'Xu ',
    'Huo ',
    'Shiira ',
    'Li ',
    'Lie ',
    'Li ',
    'Mie ',
    'Zhen ',
    'Xiang ',
    'E ',
    'Lu ',
    'Guan ',
    'Li ',
    'Xian ',
    'Yu ',
    'Dao ',
    'Ji ',
    'You ',
    'Tun ',
    'Lu ',
    'Fang ',
    'Ba ',
    'He ',
    'Bo ',
    'Ping ',
    'Nian ',
    'Lu ',
    'You ',
    'Zha ',
    'Fu ',
    'Bo ',
    'Bao ',
    'Hou ',
    'Pi ',
    'Tai ',
    'Gui ',
    'Jie ',
    'Kao ',
    'Wei ',
    'Er ',
    'Tong ',
    'Ze ',
    'Hou ',
    'Kuai ',
    'Ji ',
    'Jiao ',
    'Xian ',
    'Za ',
    'Xiang ',
    'Xun ',
    'Geng ',
    'Li ',
    'Lian ',
    'Jian ',
    'Li ',
    'Shi ',
    'Tiao ',
    'Gun ',
    'Sha ',
    'Wan ',
    'Jun ',
    'Ji ',
    'Yong ',
    'Qing ',
    'Ling ',
    'Qi ',
    'Zou ',
    'Fei ',
    'Kun ',
    'Chang ',
    'Gu ',
    'Ni ',
    'Nian ',
    'Diao ',
    'Jing ',
    'Shen ',
    'Shi ',
    'Zi ',
    'Fen ',
    'Die ',
    'Bi ',
    'Chang ',
    'Shi ',
    'Wen ',
    'Wei ',
    'Sai ',
    'E ',
    'Qiu ',
    'Fu ',
    'Huang ',
    'Quan ',
    'Jiang ',
    'Bian ',
    'Sao ',
    'Ao ',
    'Qi ',
    'Ta ',
    'Yin ',
    'Yao ',
    'Fang ',
    'Jian ',
    'Le ',
    'Biao ',
    'Xue ',
    'Bie ',
    'Man ',
    'Min ',
    'Yong ',
    'Wei ',
    'Xi ',
    'Jue ',
    'Shan ',
    'Lin ',
    'Zun ',
    'Huo ',
    'Gan ',
    'Li ',
    'Zhan ',
    'Guan ',
    'Niao ',
    'Yi ',
    'Fu ',
    'Li ',
    'Jiu ',
    'Bu ',
    'Yan ',
    'Fu ',
    'Diao ',
    'Ji ',
    'Feng ',
    'Nio ',
    'Gan ',
    'Shi ',
    'Feng ',
    'Ming ',
    'Bao ',
    'Yuan ',
    'Zhi ',
    'Hu ',
    'Qin ',
    'Fu ',
    'Fen ',
    'Wen ',
    'Jian ',
    'Shi ',
    'Yu '
];

},{}],"2Gf1t":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:36 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Fou ',
    'Yiao ',
    'Jue ',
    'Jue ',
    'Pi ',
    'Huan ',
    'Zhen ',
    'Bao ',
    'Yan ',
    'Ya ',
    'Zheng ',
    'Fang ',
    'Feng ',
    'Wen ',
    'Ou ',
    'Te ',
    'Jia ',
    'Nu ',
    'Ling ',
    'Mie ',
    'Fu ',
    'Tuo ',
    'Wen ',
    'Li ',
    'Bian ',
    'Zhi ',
    'Ge ',
    'Yuan ',
    'Zi ',
    'Qu ',
    'Xiao ',
    'Zhi ',
    'Dan ',
    'Ju ',
    'You ',
    'Gu ',
    'Zhong ',
    'Yu ',
    'Yang ',
    'Rong ',
    'Ya ',
    'Tie ',
    'Yu ',
    'Shigi ',
    'Ying ',
    'Zhui ',
    'Wu ',
    'Er ',
    'Gua ',
    'Ai ',
    'Zhi ',
    'Yan ',
    'Heng ',
    'Jiao ',
    'Ji ',
    'Lie ',
    'Zhu ',
    'Ren ',
    'Yi ',
    'Hong ',
    'Luo ',
    'Ru ',
    'Mou ',
    'Ge ',
    'Ren ',
    'Jiao ',
    'Xiu ',
    'Zhou ',
    'Zhi ',
    'Luo ',
    'Chidori ',
    'Toki ',
    'Ten ',
    'Luan ',
    'Jia ',
    'Ji ',
    'Yu ',
    'Huan ',
    'Tuo ',
    'Bu ',
    'Wu ',
    'Juan ',
    'Yu ',
    'Bo ',
    'Xun ',
    'Xun ',
    'Bi ',
    'Xi ',
    'Jun ',
    'Ju ',
    'Tu ',
    'Jing ',
    'Ti ',
    'E ',
    'E ',
    'Kuang ',
    'Hu ',
    'Wu ',
    'Shen ',
    'Lai ',
    'Ikaruga ',
    'Kakesu ',
    'Lu ',
    'Ping ',
    'Shu ',
    'Fu ',
    'An ',
    'Zhao ',
    'Peng ',
    'Qin ',
    'Qian ',
    'Bei ',
    'Diao ',
    'Lu ',
    'Que ',
    'Jian ',
    'Ju ',
    'Tu ',
    'Ya ',
    'Yuan ',
    'Qi ',
    'Li ',
    'Ye ',
    'Zhui ',
    'Kong ',
    'Zhui ',
    'Kun ',
    'Sheng ',
    'Qi ',
    'Jing ',
    'Yi ',
    'Yi ',
    'Jing ',
    'Zi ',
    'Lai ',
    'Dong ',
    'Qi ',
    'Chun ',
    'Geng ',
    'Ju ',
    'Qu ',
    'Isuka ',
    'Kikuitadaki ',
    'Ji ',
    'Shu ',
    "[?] ",
    'Chi ',
    'Miao ',
    'Rou ',
    'An ',
    'Qiu ',
    'Ti ',
    'Hu ',
    'Ti ',
    'E ',
    'Jie ',
    'Mao ',
    'Fu ',
    'Chun ',
    'Tu ',
    'Yan ',
    'He ',
    'Yuan ',
    'Pian ',
    'Yun ',
    'Mei ',
    'Hu ',
    'Ying ',
    'Dun ',
    'Mu ',
    'Ju ',
    'Tsugumi ',
    'Cang ',
    'Fang ',
    'Gu ',
    'Ying ',
    'Yuan ',
    'Xuan ',
    'Weng ',
    'Shi ',
    'He ',
    'Chu ',
    'Tang ',
    'Xia ',
    'Ruo ',
    'Liu ',
    'Ji ',
    'Gu ',
    'Jian ',
    'Zhun ',
    'Han ',
    'Zi ',
    'Zi ',
    'Ni ',
    'Yao ',
    'Yan ',
    'Ji ',
    'Li ',
    'Tian ',
    'Kou ',
    'Ti ',
    'Ti ',
    'Ni ',
    'Tu ',
    'Ma ',
    'Jiao ',
    'Gao ',
    'Tian ',
    'Chen ',
    'Li ',
    'Zhuan ',
    'Zhe ',
    'Ao ',
    'Yao ',
    'Yi ',
    'Ou ',
    'Chi ',
    'Zhi ',
    'Liao ',
    'Rong ',
    'Lou ',
    'Bi ',
    'Shuang ',
    'Zhuo ',
    'Yu ',
    'Wu ',
    'Jue ',
    'Yin ',
    'Quan ',
    'Si ',
    'Jiao ',
    'Yi ',
    'Hua ',
    'Bi ',
    'Ying ',
    'Su ',
    'Huang ',
    'Fan ',
    'Jiao ',
    'Liao ',
    'Yan ',
    'Kao ',
    'Jiu ',
    'Xian ',
    'Xian ',
    'Tu ',
    'Mai ',
    'Zun ',
    'Yu ',
    'Ying ',
    'Lu ',
    'Tuan ',
    'Xian ',
    'Xue ',
    'Yi ',
    'Pi '
];

},{}],"ivYZQ":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:36 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Shu ',
    'Luo ',
    'Qi ',
    'Yi ',
    'Ji ',
    'Zhe ',
    'Yu ',
    'Zhan ',
    'Ye ',
    'Yang ',
    'Pi ',
    'Ning ',
    'Huo ',
    'Mi ',
    'Ying ',
    'Meng ',
    'Di ',
    'Yue ',
    'Yu ',
    'Lei ',
    'Bao ',
    'Lu ',
    'He ',
    'Long ',
    'Shuang ',
    'Yue ',
    'Ying ',
    'Guan ',
    'Qu ',
    'Li ',
    'Luan ',
    'Niao ',
    'Jiu ',
    'Ji ',
    'Yuan ',
    'Ming ',
    'Shi ',
    'Ou ',
    'Ya ',
    'Cang ',
    'Bao ',
    'Zhen ',
    'Gu ',
    'Dong ',
    'Lu ',
    'Ya ',
    'Xiao ',
    'Yang ',
    'Ling ',
    'Zhi ',
    'Qu ',
    'Yuan ',
    'Xue ',
    'Tuo ',
    'Si ',
    'Zhi ',
    'Er ',
    'Gua ',
    'Xiu ',
    'Heng ',
    'Zhou ',
    'Ge ',
    'Luan ',
    'Hong ',
    'Wu ',
    'Bo ',
    'Li ',
    'Juan ',
    'Hu ',
    'E ',
    'Yu ',
    'Xian ',
    'Ti ',
    'Wu ',
    'Que ',
    'Miao ',
    'An ',
    'Kun ',
    'Bei ',
    'Peng ',
    'Qian ',
    'Chun ',
    'Geng ',
    'Yuan ',
    'Su ',
    'Hu ',
    'He ',
    'E ',
    'Gu ',
    'Qiu ',
    'Zi ',
    'Mei ',
    'Mu ',
    'Ni ',
    'Yao ',
    'Weng ',
    'Liu ',
    'Ji ',
    'Ni ',
    'Jian ',
    'He ',
    'Yi ',
    'Ying ',
    'Zhe ',
    'Liao ',
    'Liao ',
    'Jiao ',
    'Jiu ',
    'Yu ',
    'Lu ',
    'Xuan ',
    'Zhan ',
    'Ying ',
    'Huo ',
    'Meng ',
    'Guan ',
    'Shuang ',
    'Lu ',
    'Jin ',
    'Ling ',
    'Jian ',
    'Xian ',
    'Cuo ',
    'Jian ',
    'Jian ',
    'Yan ',
    'Cuo ',
    'Lu ',
    'You ',
    'Cu ',
    'Ji ',
    'Biao ',
    'Cu ',
    'Biao ',
    'Zhu ',
    'Jun ',
    'Zhu ',
    'Jian ',
    'Mi ',
    'Mi ',
    'Wu ',
    'Liu ',
    'Chen ',
    'Jun ',
    'Lin ',
    'Ni ',
    'Qi ',
    'Lu ',
    'Jiu ',
    'Jun ',
    'Jing ',
    'Li ',
    'Xiang ',
    'Yan ',
    'Jia ',
    'Mi ',
    'Li ',
    'She ',
    'Zhang ',
    'Lin ',
    'Jing ',
    'Ji ',
    'Ling ',
    'Yan ',
    'Cu ',
    'Mai ',
    'Mai ',
    'Ge ',
    'Chao ',
    'Fu ',
    'Mian ',
    'Mian ',
    'Fu ',
    'Pao ',
    'Qu ',
    'Qu ',
    'Mou ',
    'Fu ',
    'Xian ',
    'Lai ',
    'Qu ',
    'Mian ',
    "[?] ",
    'Feng ',
    'Fu ',
    'Qu ',
    'Mian ',
    'Ma ',
    'Mo ',
    'Mo ',
    'Hui ',
    'Ma ',
    'Zou ',
    'Nen ',
    'Fen ',
    'Huang ',
    'Huang ',
    'Jin ',
    'Guang ',
    'Tian ',
    'Tou ',
    'Heng ',
    'Xi ',
    'Kuang ',
    'Heng ',
    'Shu ',
    'Li ',
    'Nian ',
    'Chi ',
    'Hei ',
    'Hei ',
    'Yi ',
    'Qian ',
    'Dan ',
    'Xi ',
    'Tuan ',
    'Mo ',
    'Mo ',
    'Qian ',
    'Dai ',
    'Chu ',
    'You ',
    'Dian ',
    'Yi ',
    'Xia ',
    'Yan ',
    'Qu ',
    'Mei ',
    'Yan ',
    'Jing ',
    'Yu ',
    'Li ',
    'Dang ',
    'Du ',
    'Can ',
    'Yin ',
    'An ',
    'Yan ',
    'Tan ',
    'An ',
    'Zhen ',
    'Dai ',
    'Can ',
    'Yi ',
    'Mei ',
    'Dan ',
    'Yan ',
    'Du ',
    'Lu ',
    'Zhi ',
    'Fen ',
    'Fu ',
    'Fu ',
    'Min ',
    'Min ',
    'Yuan '
];

},{}],"kW7Dj":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:12:47 MDT"
module.exports = [
    'Cu ',
    'Qu ',
    'Chao ',
    'Wa ',
    'Zhu ',
    'Zhi ',
    'Mang ',
    'Ao ',
    'Bie ',
    'Tuo ',
    'Bi ',
    'Yuan ',
    'Chao ',
    'Tuo ',
    'Ding ',
    'Mi ',
    'Nai ',
    'Ding ',
    'Zi ',
    'Gu ',
    'Gu ',
    'Dong ',
    'Fen ',
    'Tao ',
    'Yuan ',
    'Pi ',
    'Chang ',
    'Gao ',
    'Qi ',
    'Yuan ',
    'Tang ',
    'Teng ',
    'Shu ',
    'Shu ',
    'Fen ',
    'Fei ',
    'Wen ',
    'Ba ',
    'Diao ',
    'Tuo ',
    'Tong ',
    'Qu ',
    'Sheng ',
    'Shi ',
    'You ',
    'Shi ',
    'Ting ',
    'Wu ',
    'Nian ',
    'Jing ',
    'Hun ',
    'Ju ',
    'Yan ',
    'Tu ',
    'Ti ',
    'Xi ',
    'Xian ',
    'Yan ',
    'Lei ',
    'Bi ',
    'Yao ',
    'Qiu ',
    'Han ',
    'Wu ',
    'Wu ',
    'Hou ',
    'Xi ',
    'Ge ',
    'Zha ',
    'Xiu ',
    'Weng ',
    'Zha ',
    'Nong ',
    'Nang ',
    'Qi ',
    'Zhai ',
    'Ji ',
    'Zi ',
    'Ji ',
    'Ji ',
    'Qi ',
    'Ji ',
    'Chi ',
    'Chen ',
    'Chen ',
    'He ',
    'Ya ',
    'Ken ',
    'Xie ',
    'Pao ',
    'Cuo ',
    'Shi ',
    'Zi ',
    'Chi ',
    'Nian ',
    'Ju ',
    'Tiao ',
    'Ling ',
    'Ling ',
    'Chu ',
    'Quan ',
    'Xie ',
    'Ken ',
    'Nie ',
    'Jiu ',
    'Yao ',
    'Chuo ',
    'Kun ',
    'Yu ',
    'Chu ',
    'Yi ',
    'Ni ',
    'Cuo ',
    'Zou ',
    'Qu ',
    'Nen ',
    'Xian ',
    'Ou ',
    'E ',
    'Wo ',
    'Yi ',
    'Chuo ',
    'Zou ',
    'Dian ',
    'Chu ',
    'Jin ',
    'Ya ',
    'Chi ',
    'Chen ',
    'He ',
    'Ken ',
    'Ju ',
    'Ling ',
    'Pao ',
    'Tiao ',
    'Zi ',
    'Ken ',
    'Yu ',
    'Chuo ',
    'Qu ',
    'Wo ',
    'Long ',
    'Pang ',
    'Gong ',
    'Pang ',
    'Yan ',
    'Long ',
    'Long ',
    'Gong ',
    'Kan ',
    'Ta ',
    'Ling ',
    'Ta ',
    'Long ',
    'Gong ',
    'Kan ',
    'Gui ',
    'Qiu ',
    'Bie ',
    'Gui ',
    'Yue ',
    'Chui ',
    'He ',
    'Jue ',
    'Xie ',
    'Yu ',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"lqoxc":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:36 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'it',
    'ix',
    'i',
    'ip',
    'iet',
    'iex',
    'ie',
    'iep',
    'at',
    'ax',
    'a',
    'ap',
    'uox',
    'uo',
    'uop',
    'ot',
    'ox',
    'o',
    'op',
    'ex',
    'e',
    'wu',
    'bit',
    'bix',
    'bi',
    'bip',
    'biet',
    'biex',
    'bie',
    'biep',
    'bat',
    'bax',
    'ba',
    'bap',
    'buox',
    'buo',
    'buop',
    'bot',
    'box',
    'bo',
    'bop',
    'bex',
    'be',
    'bep',
    'but',
    'bux',
    'bu',
    'bup',
    'burx',
    'bur',
    'byt',
    'byx',
    'by',
    'byp',
    'byrx',
    'byr',
    'pit',
    'pix',
    'pi',
    'pip',
    'piex',
    'pie',
    'piep',
    'pat',
    'pax',
    'pa',
    'pap',
    'puox',
    'puo',
    'puop',
    'pot',
    'pox',
    'po',
    'pop',
    'put',
    'pux',
    'pu',
    'pup',
    'purx',
    'pur',
    'pyt',
    'pyx',
    'py',
    'pyp',
    'pyrx',
    'pyr',
    'bbit',
    'bbix',
    'bbi',
    'bbip',
    'bbiet',
    'bbiex',
    'bbie',
    'bbiep',
    'bbat',
    'bbax',
    'bba',
    'bbap',
    'bbuox',
    'bbuo',
    'bbuop',
    'bbot',
    'bbox',
    'bbo',
    'bbop',
    'bbex',
    'bbe',
    'bbep',
    'bbut',
    'bbux',
    'bbu',
    'bbup',
    'bburx',
    'bbur',
    'bbyt',
    'bbyx',
    'bby',
    'bbyp',
    'nbit',
    'nbix',
    'nbi',
    'nbip',
    'nbiex',
    'nbie',
    'nbiep',
    'nbat',
    'nbax',
    'nba',
    'nbap',
    'nbot',
    'nbox',
    'nbo',
    'nbop',
    'nbut',
    'nbux',
    'nbu',
    'nbup',
    'nburx',
    'nbur',
    'nbyt',
    'nbyx',
    'nby',
    'nbyp',
    'nbyrx',
    'nbyr',
    'hmit',
    'hmix',
    'hmi',
    'hmip',
    'hmiex',
    'hmie',
    'hmiep',
    'hmat',
    'hmax',
    'hma',
    'hmap',
    'hmuox',
    'hmuo',
    'hmuop',
    'hmot',
    'hmox',
    'hmo',
    'hmop',
    'hmut',
    'hmux',
    'hmu',
    'hmup',
    'hmurx',
    'hmur',
    'hmyx',
    'hmy',
    'hmyp',
    'hmyrx',
    'hmyr',
    'mit',
    'mix',
    'mi',
    'mip',
    'miex',
    'mie',
    'miep',
    'mat',
    'max',
    'ma',
    'map',
    'muot',
    'muox',
    'muo',
    'muop',
    'mot',
    'mox',
    'mo',
    'mop',
    'mex',
    'me',
    'mut',
    'mux',
    'mu',
    'mup',
    'murx',
    'mur',
    'myt',
    'myx',
    'my',
    'myp',
    'fit',
    'fix',
    'fi',
    'fip',
    'fat',
    'fax',
    'fa',
    'fap',
    'fox',
    'fo',
    'fop',
    'fut',
    'fux',
    'fu',
    'fup',
    'furx',
    'fur',
    'fyt',
    'fyx',
    'fy',
    'fyp',
    'vit',
    'vix',
    'vi',
    'vip',
    'viet',
    'viex',
    'vie',
    'viep',
    'vat',
    'vax',
    'va',
    'vap',
    'vot',
    'vox',
    'vo',
    'vop',
    'vex',
    'vep',
    'vut',
    'vux',
    'vu',
    'vup',
    'vurx',
    'vur',
    'vyt',
    'vyx',
    'vy',
    'vyp',
    'vyrx',
    'vyr'
];

},{}],"4Fc4G":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:36 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'dit',
    'dix',
    'di',
    'dip',
    'diex',
    'die',
    'diep',
    'dat',
    'dax',
    'da',
    'dap',
    'duox',
    'duo',
    'dot',
    'dox',
    'do',
    'dop',
    'dex',
    'de',
    'dep',
    'dut',
    'dux',
    'du',
    'dup',
    'durx',
    'dur',
    'tit',
    'tix',
    'ti',
    'tip',
    'tiex',
    'tie',
    'tiep',
    'tat',
    'tax',
    'ta',
    'tap',
    'tuot',
    'tuox',
    'tuo',
    'tuop',
    'tot',
    'tox',
    'to',
    'top',
    'tex',
    'te',
    'tep',
    'tut',
    'tux',
    'tu',
    'tup',
    'turx',
    'tur',
    'ddit',
    'ddix',
    'ddi',
    'ddip',
    'ddiex',
    'ddie',
    'ddiep',
    'ddat',
    'ddax',
    'dda',
    'ddap',
    'dduox',
    'dduo',
    'dduop',
    'ddot',
    'ddox',
    'ddo',
    'ddop',
    'ddex',
    'dde',
    'ddep',
    'ddut',
    'ddux',
    'ddu',
    'ddup',
    'ddurx',
    'ddur',
    'ndit',
    'ndix',
    'ndi',
    'ndip',
    'ndiex',
    'ndie',
    'ndat',
    'ndax',
    'nda',
    'ndap',
    'ndot',
    'ndox',
    'ndo',
    'ndop',
    'ndex',
    'nde',
    'ndep',
    'ndut',
    'ndux',
    'ndu',
    'ndup',
    'ndurx',
    'ndur',
    'hnit',
    'hnix',
    'hni',
    'hnip',
    'hniet',
    'hniex',
    'hnie',
    'hniep',
    'hnat',
    'hnax',
    'hna',
    'hnap',
    'hnuox',
    'hnuo',
    'hnot',
    'hnox',
    'hnop',
    'hnex',
    'hne',
    'hnep',
    'hnut',
    'nit',
    'nix',
    'ni',
    'nip',
    'niex',
    'nie',
    'niep',
    'nax',
    'na',
    'nap',
    'nuox',
    'nuo',
    'nuop',
    'not',
    'nox',
    'no',
    'nop',
    'nex',
    'ne',
    'nep',
    'nut',
    'nux',
    'nu',
    'nup',
    'nurx',
    'nur',
    'hlit',
    'hlix',
    'hli',
    'hlip',
    'hliex',
    'hlie',
    'hliep',
    'hlat',
    'hlax',
    'hla',
    'hlap',
    'hluox',
    'hluo',
    'hluop',
    'hlox',
    'hlo',
    'hlop',
    'hlex',
    'hle',
    'hlep',
    'hlut',
    'hlux',
    'hlu',
    'hlup',
    'hlurx',
    'hlur',
    'hlyt',
    'hlyx',
    'hly',
    'hlyp',
    'hlyrx',
    'hlyr',
    'lit',
    'lix',
    'li',
    'lip',
    'liet',
    'liex',
    'lie',
    'liep',
    'lat',
    'lax',
    'la',
    'lap',
    'luot',
    'luox',
    'luo',
    'luop',
    'lot',
    'lox',
    'lo',
    'lop',
    'lex',
    'le',
    'lep',
    'lut',
    'lux',
    'lu',
    'lup',
    'lurx',
    'lur',
    'lyt',
    'lyx',
    'ly',
    'lyp',
    'lyrx',
    'lyr',
    'git',
    'gix',
    'gi',
    'gip',
    'giet',
    'giex',
    'gie',
    'giep',
    'gat',
    'gax',
    'ga',
    'gap',
    'guot',
    'guox',
    'guo',
    'guop',
    'got',
    'gox',
    'go',
    'gop',
    'get',
    'gex',
    'ge',
    'gep',
    'gut',
    'gux',
    'gu',
    'gup',
    'gurx',
    'gur',
    'kit',
    'kix',
    'ki',
    'kip',
    'kiex',
    'kie',
    'kiep',
    'kat'
];

},{}],"auYF9":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:36 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'kax',
    'ka',
    'kap',
    'kuox',
    'kuo',
    'kuop',
    'kot',
    'kox',
    'ko',
    'kop',
    'ket',
    'kex',
    'ke',
    'kep',
    'kut',
    'kux',
    'ku',
    'kup',
    'kurx',
    'kur',
    'ggit',
    'ggix',
    'ggi',
    'ggiex',
    'ggie',
    'ggiep',
    'ggat',
    'ggax',
    'gga',
    'ggap',
    'gguot',
    'gguox',
    'gguo',
    'gguop',
    'ggot',
    'ggox',
    'ggo',
    'ggop',
    'gget',
    'ggex',
    'gge',
    'ggep',
    'ggut',
    'ggux',
    'ggu',
    'ggup',
    'ggurx',
    'ggur',
    'mgiex',
    'mgie',
    'mgat',
    'mgax',
    'mga',
    'mgap',
    'mguox',
    'mguo',
    'mguop',
    'mgot',
    'mgox',
    'mgo',
    'mgop',
    'mgex',
    'mge',
    'mgep',
    'mgut',
    'mgux',
    'mgu',
    'mgup',
    'mgurx',
    'mgur',
    'hxit',
    'hxix',
    'hxi',
    'hxip',
    'hxiet',
    'hxiex',
    'hxie',
    'hxiep',
    'hxat',
    'hxax',
    'hxa',
    'hxap',
    'hxuot',
    'hxuox',
    'hxuo',
    'hxuop',
    'hxot',
    'hxox',
    'hxo',
    'hxop',
    'hxex',
    'hxe',
    'hxep',
    'ngiex',
    'ngie',
    'ngiep',
    'ngat',
    'ngax',
    'nga',
    'ngap',
    'nguot',
    'nguox',
    'nguo',
    'ngot',
    'ngox',
    'ngo',
    'ngop',
    'ngex',
    'nge',
    'ngep',
    'hit',
    'hiex',
    'hie',
    'hat',
    'hax',
    'ha',
    'hap',
    'huot',
    'huox',
    'huo',
    'huop',
    'hot',
    'hox',
    'ho',
    'hop',
    'hex',
    'he',
    'hep',
    'wat',
    'wax',
    'wa',
    'wap',
    'wuox',
    'wuo',
    'wuop',
    'wox',
    'wo',
    'wop',
    'wex',
    'we',
    'wep',
    'zit',
    'zix',
    'zi',
    'zip',
    'ziex',
    'zie',
    'ziep',
    'zat',
    'zax',
    'za',
    'zap',
    'zuox',
    'zuo',
    'zuop',
    'zot',
    'zox',
    'zo',
    'zop',
    'zex',
    'ze',
    'zep',
    'zut',
    'zux',
    'zu',
    'zup',
    'zurx',
    'zur',
    'zyt',
    'zyx',
    'zy',
    'zyp',
    'zyrx',
    'zyr',
    'cit',
    'cix',
    'ci',
    'cip',
    'ciet',
    'ciex',
    'cie',
    'ciep',
    'cat',
    'cax',
    'ca',
    'cap',
    'cuox',
    'cuo',
    'cuop',
    'cot',
    'cox',
    'co',
    'cop',
    'cex',
    'ce',
    'cep',
    'cut',
    'cux',
    'cu',
    'cup',
    'curx',
    'cur',
    'cyt',
    'cyx',
    'cy',
    'cyp',
    'cyrx',
    'cyr',
    'zzit',
    'zzix',
    'zzi',
    'zzip',
    'zziet',
    'zziex',
    'zzie',
    'zziep',
    'zzat',
    'zzax',
    'zza',
    'zzap',
    'zzox',
    'zzo',
    'zzop',
    'zzex',
    'zze',
    'zzep',
    'zzux',
    'zzu',
    'zzup',
    'zzurx',
    'zzur',
    'zzyt',
    'zzyx',
    'zzy',
    'zzyp',
    'zzyrx',
    'zzyr',
    'nzit',
    'nzix',
    'nzi',
    'nzip',
    'nziex',
    'nzie',
    'nziep',
    'nzat',
    'nzax',
    'nza',
    'nzap',
    'nzuox',
    'nzuo',
    'nzox',
    'nzop',
    'nzex',
    'nze',
    'nzux',
    'nzu'
];

},{}],"7NtEF":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:36 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'nzup',
    'nzurx',
    'nzur',
    'nzyt',
    'nzyx',
    'nzy',
    'nzyp',
    'nzyrx',
    'nzyr',
    'sit',
    'six',
    'si',
    'sip',
    'siex',
    'sie',
    'siep',
    'sat',
    'sax',
    'sa',
    'sap',
    'suox',
    'suo',
    'suop',
    'sot',
    'sox',
    'so',
    'sop',
    'sex',
    'se',
    'sep',
    'sut',
    'sux',
    'su',
    'sup',
    'surx',
    'sur',
    'syt',
    'syx',
    'sy',
    'syp',
    'syrx',
    'syr',
    'ssit',
    'ssix',
    'ssi',
    'ssip',
    'ssiex',
    'ssie',
    'ssiep',
    'ssat',
    'ssax',
    'ssa',
    'ssap',
    'ssot',
    'ssox',
    'sso',
    'ssop',
    'ssex',
    'sse',
    'ssep',
    'ssut',
    'ssux',
    'ssu',
    'ssup',
    'ssyt',
    'ssyx',
    'ssy',
    'ssyp',
    'ssyrx',
    'ssyr',
    'zhat',
    'zhax',
    'zha',
    'zhap',
    'zhuox',
    'zhuo',
    'zhuop',
    'zhot',
    'zhox',
    'zho',
    'zhop',
    'zhet',
    'zhex',
    'zhe',
    'zhep',
    'zhut',
    'zhux',
    'zhu',
    'zhup',
    'zhurx',
    'zhur',
    'zhyt',
    'zhyx',
    'zhy',
    'zhyp',
    'zhyrx',
    'zhyr',
    'chat',
    'chax',
    'cha',
    'chap',
    'chuot',
    'chuox',
    'chuo',
    'chuop',
    'chot',
    'chox',
    'cho',
    'chop',
    'chet',
    'chex',
    'che',
    'chep',
    'chux',
    'chu',
    'chup',
    'churx',
    'chur',
    'chyt',
    'chyx',
    'chy',
    'chyp',
    'chyrx',
    'chyr',
    'rrax',
    'rra',
    'rruox',
    'rruo',
    'rrot',
    'rrox',
    'rro',
    'rrop',
    'rret',
    'rrex',
    'rre',
    'rrep',
    'rrut',
    'rrux',
    'rru',
    'rrup',
    'rrurx',
    'rrur',
    'rryt',
    'rryx',
    'rry',
    'rryp',
    'rryrx',
    'rryr',
    'nrat',
    'nrax',
    'nra',
    'nrap',
    'nrox',
    'nro',
    'nrop',
    'nret',
    'nrex',
    'nre',
    'nrep',
    'nrut',
    'nrux',
    'nru',
    'nrup',
    'nrurx',
    'nrur',
    'nryt',
    'nryx',
    'nry',
    'nryp',
    'nryrx',
    'nryr',
    'shat',
    'shax',
    'sha',
    'shap',
    'shuox',
    'shuo',
    'shuop',
    'shot',
    'shox',
    'sho',
    'shop',
    'shet',
    'shex',
    'she',
    'shep',
    'shut',
    'shux',
    'shu',
    'shup',
    'shurx',
    'shur',
    'shyt',
    'shyx',
    'shy',
    'shyp',
    'shyrx',
    'shyr',
    'rat',
    'rax',
    'ra',
    'rap',
    'ruox',
    'ruo',
    'ruop',
    'rot',
    'rox',
    'ro',
    'rop',
    'rex',
    're',
    'rep',
    'rut',
    'rux',
    'ru',
    'rup',
    'rurx',
    'rur',
    'ryt',
    'ryx',
    'ry',
    'ryp',
    'ryrx',
    'ryr',
    'jit',
    'jix',
    'ji',
    'jip',
    'jiet',
    'jiex',
    'jie',
    'jiep',
    'juot',
    'juox',
    'juo',
    'juop',
    'jot',
    'jox',
    'jo',
    'jop',
    'jut',
    'jux',
    'ju',
    'jup',
    'jurx',
    'jur',
    'jyt',
    'jyx',
    'jy',
    'jyp',
    'jyrx',
    'jyr',
    'qit',
    'qix',
    'qi',
    'qip'
];

},{}],"cRM5y":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:13:29 MDT"
module.exports = [
    'qiet',
    'qiex',
    'qie',
    'qiep',
    'quot',
    'quox',
    'quo',
    'quop',
    'qot',
    'qox',
    'qo',
    'qop',
    'qut',
    'qux',
    'qu',
    'qup',
    'qurx',
    'qur',
    'qyt',
    'qyx',
    'qy',
    'qyp',
    'qyrx',
    'qyr',
    'jjit',
    'jjix',
    'jji',
    'jjip',
    'jjiet',
    'jjiex',
    'jjie',
    'jjiep',
    'jjuox',
    'jjuo',
    'jjuop',
    'jjot',
    'jjox',
    'jjo',
    'jjop',
    'jjut',
    'jjux',
    'jju',
    'jjup',
    'jjurx',
    'jjur',
    'jjyt',
    'jjyx',
    'jjy',
    'jjyp',
    'njit',
    'njix',
    'nji',
    'njip',
    'njiet',
    'njiex',
    'njie',
    'njiep',
    'njuox',
    'njuo',
    'njot',
    'njox',
    'njo',
    'njop',
    'njux',
    'nju',
    'njup',
    'njurx',
    'njur',
    'njyt',
    'njyx',
    'njy',
    'njyp',
    'njyrx',
    'njyr',
    'nyit',
    'nyix',
    'nyi',
    'nyip',
    'nyiet',
    'nyiex',
    'nyie',
    'nyiep',
    'nyuox',
    'nyuo',
    'nyuop',
    'nyot',
    'nyox',
    'nyo',
    'nyop',
    'nyut',
    'nyux',
    'nyu',
    'nyup',
    'xit',
    'xix',
    'xi',
    'xip',
    'xiet',
    'xiex',
    'xie',
    'xiep',
    'xuox',
    'xuo',
    'xot',
    'xox',
    'xo',
    'xop',
    'xyt',
    'xyx',
    'xy',
    'xyp',
    'xyrx',
    'xyr',
    'yit',
    'yix',
    'yi',
    'yip',
    'yiet',
    'yiex',
    'yie',
    'yiep',
    'yuot',
    'yuox',
    'yuo',
    'yuop',
    'yot',
    'yox',
    'yo',
    'yop',
    'yut',
    'yux',
    'yu',
    'yup',
    'yurx',
    'yur',
    'yyt',
    'yyx',
    'yy',
    'yyp',
    'yyrx',
    'yyr',
    '[?]',
    '[?]',
    '[?]',
    'Qot',
    'Li',
    'Kit',
    'Nyip',
    'Cyp',
    'Ssi',
    'Ggop',
    'Gep',
    'Mi',
    'Hxit',
    'Lyr',
    'Bbut',
    'Mop',
    'Yo',
    'Put',
    'Hxuo',
    'Tat',
    'Ga',
    '[?]',
    '[?]',
    'Ddur',
    'Bur',
    'Gguo',
    'Nyop',
    'Tu',
    'Op',
    'Jjut',
    'Zot',
    'Pyt',
    'Hmo',
    'Yit',
    'Vur',
    'Shy',
    'Vep',
    'Za',
    'Jo',
    '[?]',
    'Jjy',
    'Got',
    'Jjie',
    'Wo',
    'Du',
    'Shur',
    'Lie',
    'Cy',
    'Cuop',
    'Cip',
    'Hxop',
    'Shat',
    '[?]',
    'Shop',
    'Che',
    'Zziet',
    '[?]',
    'Ke',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"fz5Db":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:37 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'ga',
    'gag',
    'gagg',
    'gags',
    'gan',
    'ganj',
    'ganh',
    'gad',
    'gal',
    'galg',
    'galm',
    'galb',
    'gals',
    'galt',
    'galp',
    'galh',
    'gam',
    'gab',
    'gabs',
    'gas',
    'gass',
    'gang',
    'gaj',
    'gac',
    'gak',
    'gat',
    'gap',
    'gah',
    'gae',
    'gaeg',
    'gaegg',
    'gaegs',
    'gaen',
    'gaenj',
    'gaenh',
    'gaed',
    'gael',
    'gaelg',
    'gaelm',
    'gaelb',
    'gaels',
    'gaelt',
    'gaelp',
    'gaelh',
    'gaem',
    'gaeb',
    'gaebs',
    'gaes',
    'gaess',
    'gaeng',
    'gaej',
    'gaec',
    'gaek',
    'gaet',
    'gaep',
    'gaeh',
    'gya',
    'gyag',
    'gyagg',
    'gyags',
    'gyan',
    'gyanj',
    'gyanh',
    'gyad',
    'gyal',
    'gyalg',
    'gyalm',
    'gyalb',
    'gyals',
    'gyalt',
    'gyalp',
    'gyalh',
    'gyam',
    'gyab',
    'gyabs',
    'gyas',
    'gyass',
    'gyang',
    'gyaj',
    'gyac',
    'gyak',
    'gyat',
    'gyap',
    'gyah',
    'gyae',
    'gyaeg',
    'gyaegg',
    'gyaegs',
    'gyaen',
    'gyaenj',
    'gyaenh',
    'gyaed',
    'gyael',
    'gyaelg',
    'gyaelm',
    'gyaelb',
    'gyaels',
    'gyaelt',
    'gyaelp',
    'gyaelh',
    'gyaem',
    'gyaeb',
    'gyaebs',
    'gyaes',
    'gyaess',
    'gyaeng',
    'gyaej',
    'gyaec',
    'gyaek',
    'gyaet',
    'gyaep',
    'gyaeh',
    'geo',
    'geog',
    'geogg',
    'geogs',
    'geon',
    'geonj',
    'geonh',
    'geod',
    'geol',
    'geolg',
    'geolm',
    'geolb',
    'geols',
    'geolt',
    'geolp',
    'geolh',
    'geom',
    'geob',
    'geobs',
    'geos',
    'geoss',
    'geong',
    'geoj',
    'geoc',
    'geok',
    'geot',
    'geop',
    'geoh',
    'ge',
    'geg',
    'gegg',
    'gegs',
    'gen',
    'genj',
    'genh',
    'ged',
    'gel',
    'gelg',
    'gelm',
    'gelb',
    'gels',
    'gelt',
    'gelp',
    'gelh',
    'gem',
    'geb',
    'gebs',
    'ges',
    'gess',
    'geng',
    'gej',
    'gec',
    'gek',
    'get',
    'gep',
    'geh',
    'gyeo',
    'gyeog',
    'gyeogg',
    'gyeogs',
    'gyeon',
    'gyeonj',
    'gyeonh',
    'gyeod',
    'gyeol',
    'gyeolg',
    'gyeolm',
    'gyeolb',
    'gyeols',
    'gyeolt',
    'gyeolp',
    'gyeolh',
    'gyeom',
    'gyeob',
    'gyeobs',
    'gyeos',
    'gyeoss',
    'gyeong',
    'gyeoj',
    'gyeoc',
    'gyeok',
    'gyeot',
    'gyeop',
    'gyeoh',
    'gye',
    'gyeg',
    'gyegg',
    'gyegs',
    'gyen',
    'gyenj',
    'gyenh',
    'gyed',
    'gyel',
    'gyelg',
    'gyelm',
    'gyelb',
    'gyels',
    'gyelt',
    'gyelp',
    'gyelh',
    'gyem',
    'gyeb',
    'gyebs',
    'gyes',
    'gyess',
    'gyeng',
    'gyej',
    'gyec',
    'gyek',
    'gyet',
    'gyep',
    'gyeh',
    'go',
    'gog',
    'gogg',
    'gogs',
    'gon',
    'gonj',
    'gonh',
    'god',
    'gol',
    'golg',
    'golm',
    'golb',
    'gols',
    'golt',
    'golp',
    'golh',
    'gom',
    'gob',
    'gobs',
    'gos',
    'goss',
    'gong',
    'goj',
    'goc',
    'gok',
    'got',
    'gop',
    'goh',
    'gwa',
    'gwag',
    'gwagg',
    'gwags'
];

},{}],"fZy3P":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:37 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'gwan',
    'gwanj',
    'gwanh',
    'gwad',
    'gwal',
    'gwalg',
    'gwalm',
    'gwalb',
    'gwals',
    'gwalt',
    'gwalp',
    'gwalh',
    'gwam',
    'gwab',
    'gwabs',
    'gwas',
    'gwass',
    'gwang',
    'gwaj',
    'gwac',
    'gwak',
    'gwat',
    'gwap',
    'gwah',
    'gwae',
    'gwaeg',
    'gwaegg',
    'gwaegs',
    'gwaen',
    'gwaenj',
    'gwaenh',
    'gwaed',
    'gwael',
    'gwaelg',
    'gwaelm',
    'gwaelb',
    'gwaels',
    'gwaelt',
    'gwaelp',
    'gwaelh',
    'gwaem',
    'gwaeb',
    'gwaebs',
    'gwaes',
    'gwaess',
    'gwaeng',
    'gwaej',
    'gwaec',
    'gwaek',
    'gwaet',
    'gwaep',
    'gwaeh',
    'goe',
    'goeg',
    'goegg',
    'goegs',
    'goen',
    'goenj',
    'goenh',
    'goed',
    'goel',
    'goelg',
    'goelm',
    'goelb',
    'goels',
    'goelt',
    'goelp',
    'goelh',
    'goem',
    'goeb',
    'goebs',
    'goes',
    'goess',
    'goeng',
    'goej',
    'goec',
    'goek',
    'goet',
    'goep',
    'goeh',
    'gyo',
    'gyog',
    'gyogg',
    'gyogs',
    'gyon',
    'gyonj',
    'gyonh',
    'gyod',
    'gyol',
    'gyolg',
    'gyolm',
    'gyolb',
    'gyols',
    'gyolt',
    'gyolp',
    'gyolh',
    'gyom',
    'gyob',
    'gyobs',
    'gyos',
    'gyoss',
    'gyong',
    'gyoj',
    'gyoc',
    'gyok',
    'gyot',
    'gyop',
    'gyoh',
    'gu',
    'gug',
    'gugg',
    'gugs',
    'gun',
    'gunj',
    'gunh',
    'gud',
    'gul',
    'gulg',
    'gulm',
    'gulb',
    'guls',
    'gult',
    'gulp',
    'gulh',
    'gum',
    'gub',
    'gubs',
    'gus',
    'guss',
    'gung',
    'guj',
    'guc',
    'guk',
    'gut',
    'gup',
    'guh',
    'gweo',
    'gweog',
    'gweogg',
    'gweogs',
    'gweon',
    'gweonj',
    'gweonh',
    'gweod',
    'gweol',
    'gweolg',
    'gweolm',
    'gweolb',
    'gweols',
    'gweolt',
    'gweolp',
    'gweolh',
    'gweom',
    'gweob',
    'gweobs',
    'gweos',
    'gweoss',
    'gweong',
    'gweoj',
    'gweoc',
    'gweok',
    'gweot',
    'gweop',
    'gweoh',
    'gwe',
    'gweg',
    'gwegg',
    'gwegs',
    'gwen',
    'gwenj',
    'gwenh',
    'gwed',
    'gwel',
    'gwelg',
    'gwelm',
    'gwelb',
    'gwels',
    'gwelt',
    'gwelp',
    'gwelh',
    'gwem',
    'gweb',
    'gwebs',
    'gwes',
    'gwess',
    'gweng',
    'gwej',
    'gwec',
    'gwek',
    'gwet',
    'gwep',
    'gweh',
    'gwi',
    'gwig',
    'gwigg',
    'gwigs',
    'gwin',
    'gwinj',
    'gwinh',
    'gwid',
    'gwil',
    'gwilg',
    'gwilm',
    'gwilb',
    'gwils',
    'gwilt',
    'gwilp',
    'gwilh',
    'gwim',
    'gwib',
    'gwibs',
    'gwis',
    'gwiss',
    'gwing',
    'gwij',
    'gwic',
    'gwik',
    'gwit',
    'gwip',
    'gwih',
    'gyu',
    'gyug',
    'gyugg',
    'gyugs',
    'gyun',
    'gyunj',
    'gyunh',
    'gyud',
    'gyul',
    'gyulg',
    'gyulm',
    'gyulb',
    'gyuls',
    'gyult',
    'gyulp',
    'gyulh',
    'gyum',
    'gyub',
    'gyubs',
    'gyus',
    'gyuss',
    'gyung',
    'gyuj',
    'gyuc',
    'gyuk',
    'gyut',
    'gyup',
    'gyuh',
    'geu',
    'geug',
    'geugg',
    'geugs',
    'geun',
    'geunj',
    'geunh',
    'geud'
];

},{}],"bgAFb":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:37 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'geul',
    'geulg',
    'geulm',
    'geulb',
    'geuls',
    'geult',
    'geulp',
    'geulh',
    'geum',
    'geub',
    'geubs',
    'geus',
    'geuss',
    'geung',
    'geuj',
    'geuc',
    'geuk',
    'geut',
    'geup',
    'geuh',
    'gyi',
    'gyig',
    'gyigg',
    'gyigs',
    'gyin',
    'gyinj',
    'gyinh',
    'gyid',
    'gyil',
    'gyilg',
    'gyilm',
    'gyilb',
    'gyils',
    'gyilt',
    'gyilp',
    'gyilh',
    'gyim',
    'gyib',
    'gyibs',
    'gyis',
    'gyiss',
    'gying',
    'gyij',
    'gyic',
    'gyik',
    'gyit',
    'gyip',
    'gyih',
    'gi',
    'gig',
    'gigg',
    'gigs',
    'gin',
    'ginj',
    'ginh',
    'gid',
    'gil',
    'gilg',
    'gilm',
    'gilb',
    'gils',
    'gilt',
    'gilp',
    'gilh',
    'gim',
    'gib',
    'gibs',
    'gis',
    'giss',
    'ging',
    'gij',
    'gic',
    'gik',
    'git',
    'gip',
    'gih',
    'gga',
    'ggag',
    'ggagg',
    'ggags',
    'ggan',
    'gganj',
    'gganh',
    'ggad',
    'ggal',
    'ggalg',
    'ggalm',
    'ggalb',
    'ggals',
    'ggalt',
    'ggalp',
    'ggalh',
    'ggam',
    'ggab',
    'ggabs',
    'ggas',
    'ggass',
    'ggang',
    'ggaj',
    'ggac',
    'ggak',
    'ggat',
    'ggap',
    'ggah',
    'ggae',
    'ggaeg',
    'ggaegg',
    'ggaegs',
    'ggaen',
    'ggaenj',
    'ggaenh',
    'ggaed',
    'ggael',
    'ggaelg',
    'ggaelm',
    'ggaelb',
    'ggaels',
    'ggaelt',
    'ggaelp',
    'ggaelh',
    'ggaem',
    'ggaeb',
    'ggaebs',
    'ggaes',
    'ggaess',
    'ggaeng',
    'ggaej',
    'ggaec',
    'ggaek',
    'ggaet',
    'ggaep',
    'ggaeh',
    'ggya',
    'ggyag',
    'ggyagg',
    'ggyags',
    'ggyan',
    'ggyanj',
    'ggyanh',
    'ggyad',
    'ggyal',
    'ggyalg',
    'ggyalm',
    'ggyalb',
    'ggyals',
    'ggyalt',
    'ggyalp',
    'ggyalh',
    'ggyam',
    'ggyab',
    'ggyabs',
    'ggyas',
    'ggyass',
    'ggyang',
    'ggyaj',
    'ggyac',
    'ggyak',
    'ggyat',
    'ggyap',
    'ggyah',
    'ggyae',
    'ggyaeg',
    'ggyaegg',
    'ggyaegs',
    'ggyaen',
    'ggyaenj',
    'ggyaenh',
    'ggyaed',
    'ggyael',
    'ggyaelg',
    'ggyaelm',
    'ggyaelb',
    'ggyaels',
    'ggyaelt',
    'ggyaelp',
    'ggyaelh',
    'ggyaem',
    'ggyaeb',
    'ggyaebs',
    'ggyaes',
    'ggyaess',
    'ggyaeng',
    'ggyaej',
    'ggyaec',
    'ggyaek',
    'ggyaet',
    'ggyaep',
    'ggyaeh',
    'ggeo',
    'ggeog',
    'ggeogg',
    'ggeogs',
    'ggeon',
    'ggeonj',
    'ggeonh',
    'ggeod',
    'ggeol',
    'ggeolg',
    'ggeolm',
    'ggeolb',
    'ggeols',
    'ggeolt',
    'ggeolp',
    'ggeolh',
    'ggeom',
    'ggeob',
    'ggeobs',
    'ggeos',
    'ggeoss',
    'ggeong',
    'ggeoj',
    'ggeoc',
    'ggeok',
    'ggeot',
    'ggeop',
    'ggeoh',
    'gge',
    'ggeg',
    'ggegg',
    'ggegs',
    'ggen',
    'ggenj',
    'ggenh',
    'gged',
    'ggel',
    'ggelg',
    'ggelm',
    'ggelb',
    'ggels',
    'ggelt',
    'ggelp',
    'ggelh',
    'ggem',
    'ggeb',
    'ggebs',
    'gges',
    'ggess',
    'ggeng',
    'ggej',
    'ggec',
    'ggek',
    'gget',
    'ggep',
    'ggeh',
    'ggyeo',
    'ggyeog',
    'ggyeogg',
    'ggyeogs',
    'ggyeon',
    'ggyeonj',
    'ggyeonh',
    'ggyeod',
    'ggyeol',
    'ggyeolg',
    'ggyeolm',
    'ggyeolb'
];

},{}],"50dyF":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:37 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'ggyeols',
    'ggyeolt',
    'ggyeolp',
    'ggyeolh',
    'ggyeom',
    'ggyeob',
    'ggyeobs',
    'ggyeos',
    'ggyeoss',
    'ggyeong',
    'ggyeoj',
    'ggyeoc',
    'ggyeok',
    'ggyeot',
    'ggyeop',
    'ggyeoh',
    'ggye',
    'ggyeg',
    'ggyegg',
    'ggyegs',
    'ggyen',
    'ggyenj',
    'ggyenh',
    'ggyed',
    'ggyel',
    'ggyelg',
    'ggyelm',
    'ggyelb',
    'ggyels',
    'ggyelt',
    'ggyelp',
    'ggyelh',
    'ggyem',
    'ggyeb',
    'ggyebs',
    'ggyes',
    'ggyess',
    'ggyeng',
    'ggyej',
    'ggyec',
    'ggyek',
    'ggyet',
    'ggyep',
    'ggyeh',
    'ggo',
    'ggog',
    'ggogg',
    'ggogs',
    'ggon',
    'ggonj',
    'ggonh',
    'ggod',
    'ggol',
    'ggolg',
    'ggolm',
    'ggolb',
    'ggols',
    'ggolt',
    'ggolp',
    'ggolh',
    'ggom',
    'ggob',
    'ggobs',
    'ggos',
    'ggoss',
    'ggong',
    'ggoj',
    'ggoc',
    'ggok',
    'ggot',
    'ggop',
    'ggoh',
    'ggwa',
    'ggwag',
    'ggwagg',
    'ggwags',
    'ggwan',
    'ggwanj',
    'ggwanh',
    'ggwad',
    'ggwal',
    'ggwalg',
    'ggwalm',
    'ggwalb',
    'ggwals',
    'ggwalt',
    'ggwalp',
    'ggwalh',
    'ggwam',
    'ggwab',
    'ggwabs',
    'ggwas',
    'ggwass',
    'ggwang',
    'ggwaj',
    'ggwac',
    'ggwak',
    'ggwat',
    'ggwap',
    'ggwah',
    'ggwae',
    'ggwaeg',
    'ggwaegg',
    'ggwaegs',
    'ggwaen',
    'ggwaenj',
    'ggwaenh',
    'ggwaed',
    'ggwael',
    'ggwaelg',
    'ggwaelm',
    'ggwaelb',
    'ggwaels',
    'ggwaelt',
    'ggwaelp',
    'ggwaelh',
    'ggwaem',
    'ggwaeb',
    'ggwaebs',
    'ggwaes',
    'ggwaess',
    'ggwaeng',
    'ggwaej',
    'ggwaec',
    'ggwaek',
    'ggwaet',
    'ggwaep',
    'ggwaeh',
    'ggoe',
    'ggoeg',
    'ggoegg',
    'ggoegs',
    'ggoen',
    'ggoenj',
    'ggoenh',
    'ggoed',
    'ggoel',
    'ggoelg',
    'ggoelm',
    'ggoelb',
    'ggoels',
    'ggoelt',
    'ggoelp',
    'ggoelh',
    'ggoem',
    'ggoeb',
    'ggoebs',
    'ggoes',
    'ggoess',
    'ggoeng',
    'ggoej',
    'ggoec',
    'ggoek',
    'ggoet',
    'ggoep',
    'ggoeh',
    'ggyo',
    'ggyog',
    'ggyogg',
    'ggyogs',
    'ggyon',
    'ggyonj',
    'ggyonh',
    'ggyod',
    'ggyol',
    'ggyolg',
    'ggyolm',
    'ggyolb',
    'ggyols',
    'ggyolt',
    'ggyolp',
    'ggyolh',
    'ggyom',
    'ggyob',
    'ggyobs',
    'ggyos',
    'ggyoss',
    'ggyong',
    'ggyoj',
    'ggyoc',
    'ggyok',
    'ggyot',
    'ggyop',
    'ggyoh',
    'ggu',
    'ggug',
    'ggugg',
    'ggugs',
    'ggun',
    'ggunj',
    'ggunh',
    'ggud',
    'ggul',
    'ggulg',
    'ggulm',
    'ggulb',
    'gguls',
    'ggult',
    'ggulp',
    'ggulh',
    'ggum',
    'ggub',
    'ggubs',
    'ggus',
    'gguss',
    'ggung',
    'gguj',
    'gguc',
    'gguk',
    'ggut',
    'ggup',
    'gguh',
    'ggweo',
    'ggweog',
    'ggweogg',
    'ggweogs',
    'ggweon',
    'ggweonj',
    'ggweonh',
    'ggweod',
    'ggweol',
    'ggweolg',
    'ggweolm',
    'ggweolb',
    'ggweols',
    'ggweolt',
    'ggweolp',
    'ggweolh',
    'ggweom',
    'ggweob',
    'ggweobs',
    'ggweos',
    'ggweoss',
    'ggweong',
    'ggweoj',
    'ggweoc',
    'ggweok',
    'ggweot',
    'ggweop',
    'ggweoh',
    'ggwe',
    'ggweg',
    'ggwegg',
    'ggwegs',
    'ggwen',
    'ggwenj',
    'ggwenh',
    'ggwed',
    'ggwel',
    'ggwelg',
    'ggwelm',
    'ggwelb',
    'ggwels',
    'ggwelt',
    'ggwelp',
    'ggwelh'
];

},{}],"2HADJ":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:37 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'ggwem',
    'ggweb',
    'ggwebs',
    'ggwes',
    'ggwess',
    'ggweng',
    'ggwej',
    'ggwec',
    'ggwek',
    'ggwet',
    'ggwep',
    'ggweh',
    'ggwi',
    'ggwig',
    'ggwigg',
    'ggwigs',
    'ggwin',
    'ggwinj',
    'ggwinh',
    'ggwid',
    'ggwil',
    'ggwilg',
    'ggwilm',
    'ggwilb',
    'ggwils',
    'ggwilt',
    'ggwilp',
    'ggwilh',
    'ggwim',
    'ggwib',
    'ggwibs',
    'ggwis',
    'ggwiss',
    'ggwing',
    'ggwij',
    'ggwic',
    'ggwik',
    'ggwit',
    'ggwip',
    'ggwih',
    'ggyu',
    'ggyug',
    'ggyugg',
    'ggyugs',
    'ggyun',
    'ggyunj',
    'ggyunh',
    'ggyud',
    'ggyul',
    'ggyulg',
    'ggyulm',
    'ggyulb',
    'ggyuls',
    'ggyult',
    'ggyulp',
    'ggyulh',
    'ggyum',
    'ggyub',
    'ggyubs',
    'ggyus',
    'ggyuss',
    'ggyung',
    'ggyuj',
    'ggyuc',
    'ggyuk',
    'ggyut',
    'ggyup',
    'ggyuh',
    'ggeu',
    'ggeug',
    'ggeugg',
    'ggeugs',
    'ggeun',
    'ggeunj',
    'ggeunh',
    'ggeud',
    'ggeul',
    'ggeulg',
    'ggeulm',
    'ggeulb',
    'ggeuls',
    'ggeult',
    'ggeulp',
    'ggeulh',
    'ggeum',
    'ggeub',
    'ggeubs',
    'ggeus',
    'ggeuss',
    'ggeung',
    'ggeuj',
    'ggeuc',
    'ggeuk',
    'ggeut',
    'ggeup',
    'ggeuh',
    'ggyi',
    'ggyig',
    'ggyigg',
    'ggyigs',
    'ggyin',
    'ggyinj',
    'ggyinh',
    'ggyid',
    'ggyil',
    'ggyilg',
    'ggyilm',
    'ggyilb',
    'ggyils',
    'ggyilt',
    'ggyilp',
    'ggyilh',
    'ggyim',
    'ggyib',
    'ggyibs',
    'ggyis',
    'ggyiss',
    'ggying',
    'ggyij',
    'ggyic',
    'ggyik',
    'ggyit',
    'ggyip',
    'ggyih',
    'ggi',
    'ggig',
    'ggigg',
    'ggigs',
    'ggin',
    'gginj',
    'gginh',
    'ggid',
    'ggil',
    'ggilg',
    'ggilm',
    'ggilb',
    'ggils',
    'ggilt',
    'ggilp',
    'ggilh',
    'ggim',
    'ggib',
    'ggibs',
    'ggis',
    'ggiss',
    'gging',
    'ggij',
    'ggic',
    'ggik',
    'ggit',
    'ggip',
    'ggih',
    'na',
    'nag',
    'nagg',
    'nags',
    'nan',
    'nanj',
    'nanh',
    'nad',
    'nal',
    'nalg',
    'nalm',
    'nalb',
    'nals',
    'nalt',
    'nalp',
    'nalh',
    'nam',
    'nab',
    'nabs',
    'nas',
    'nass',
    'nang',
    'naj',
    'nac',
    'nak',
    'nat',
    'nap',
    'nah',
    'nae',
    'naeg',
    'naegg',
    'naegs',
    'naen',
    'naenj',
    'naenh',
    'naed',
    'nael',
    'naelg',
    'naelm',
    'naelb',
    'naels',
    'naelt',
    'naelp',
    'naelh',
    'naem',
    'naeb',
    'naebs',
    'naes',
    'naess',
    'naeng',
    'naej',
    'naec',
    'naek',
    'naet',
    'naep',
    'naeh',
    'nya',
    'nyag',
    'nyagg',
    'nyags',
    'nyan',
    'nyanj',
    'nyanh',
    'nyad',
    'nyal',
    'nyalg',
    'nyalm',
    'nyalb',
    'nyals',
    'nyalt',
    'nyalp',
    'nyalh',
    'nyam',
    'nyab',
    'nyabs',
    'nyas',
    'nyass',
    'nyang',
    'nyaj',
    'nyac',
    'nyak',
    'nyat',
    'nyap',
    'nyah',
    'nyae',
    'nyaeg',
    'nyaegg',
    'nyaegs',
    'nyaen',
    'nyaenj',
    'nyaenh',
    'nyaed',
    'nyael',
    'nyaelg',
    'nyaelm',
    'nyaelb',
    'nyaels',
    'nyaelt',
    'nyaelp',
    'nyaelh',
    'nyaem',
    'nyaeb',
    'nyaebs',
    'nyaes'
];

},{}],"4y3Id":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:37 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'nyaess',
    'nyaeng',
    'nyaej',
    'nyaec',
    'nyaek',
    'nyaet',
    'nyaep',
    'nyaeh',
    'neo',
    'neog',
    'neogg',
    'neogs',
    'neon',
    'neonj',
    'neonh',
    'neod',
    'neol',
    'neolg',
    'neolm',
    'neolb',
    'neols',
    'neolt',
    'neolp',
    'neolh',
    'neom',
    'neob',
    'neobs',
    'neos',
    'neoss',
    'neong',
    'neoj',
    'neoc',
    'neok',
    'neot',
    'neop',
    'neoh',
    'ne',
    'neg',
    'negg',
    'negs',
    'nen',
    'nenj',
    'nenh',
    'ned',
    'nel',
    'nelg',
    'nelm',
    'nelb',
    'nels',
    'nelt',
    'nelp',
    'nelh',
    'nem',
    'neb',
    'nebs',
    'nes',
    'ness',
    'neng',
    'nej',
    'nec',
    'nek',
    'net',
    'nep',
    'neh',
    'nyeo',
    'nyeog',
    'nyeogg',
    'nyeogs',
    'nyeon',
    'nyeonj',
    'nyeonh',
    'nyeod',
    'nyeol',
    'nyeolg',
    'nyeolm',
    'nyeolb',
    'nyeols',
    'nyeolt',
    'nyeolp',
    'nyeolh',
    'nyeom',
    'nyeob',
    'nyeobs',
    'nyeos',
    'nyeoss',
    'nyeong',
    'nyeoj',
    'nyeoc',
    'nyeok',
    'nyeot',
    'nyeop',
    'nyeoh',
    'nye',
    'nyeg',
    'nyegg',
    'nyegs',
    'nyen',
    'nyenj',
    'nyenh',
    'nyed',
    'nyel',
    'nyelg',
    'nyelm',
    'nyelb',
    'nyels',
    'nyelt',
    'nyelp',
    'nyelh',
    'nyem',
    'nyeb',
    'nyebs',
    'nyes',
    'nyess',
    'nyeng',
    'nyej',
    'nyec',
    'nyek',
    'nyet',
    'nyep',
    'nyeh',
    'no',
    'nog',
    'nogg',
    'nogs',
    'non',
    'nonj',
    'nonh',
    'nod',
    'nol',
    'nolg',
    'nolm',
    'nolb',
    'nols',
    'nolt',
    'nolp',
    'nolh',
    'nom',
    'nob',
    'nobs',
    'nos',
    'noss',
    'nong',
    'noj',
    'noc',
    'nok',
    'not',
    'nop',
    'noh',
    'nwa',
    'nwag',
    'nwagg',
    'nwags',
    'nwan',
    'nwanj',
    'nwanh',
    'nwad',
    'nwal',
    'nwalg',
    'nwalm',
    'nwalb',
    'nwals',
    'nwalt',
    'nwalp',
    'nwalh',
    'nwam',
    'nwab',
    'nwabs',
    'nwas',
    'nwass',
    'nwang',
    'nwaj',
    'nwac',
    'nwak',
    'nwat',
    'nwap',
    'nwah',
    'nwae',
    'nwaeg',
    'nwaegg',
    'nwaegs',
    'nwaen',
    'nwaenj',
    'nwaenh',
    'nwaed',
    'nwael',
    'nwaelg',
    'nwaelm',
    'nwaelb',
    'nwaels',
    'nwaelt',
    'nwaelp',
    'nwaelh',
    'nwaem',
    'nwaeb',
    'nwaebs',
    'nwaes',
    'nwaess',
    'nwaeng',
    'nwaej',
    'nwaec',
    'nwaek',
    'nwaet',
    'nwaep',
    'nwaeh',
    'noe',
    'noeg',
    'noegg',
    'noegs',
    'noen',
    'noenj',
    'noenh',
    'noed',
    'noel',
    'noelg',
    'noelm',
    'noelb',
    'noels',
    'noelt',
    'noelp',
    'noelh',
    'noem',
    'noeb',
    'noebs',
    'noes',
    'noess',
    'noeng',
    'noej',
    'noec',
    'noek',
    'noet',
    'noep',
    'noeh',
    'nyo',
    'nyog',
    'nyogg',
    'nyogs',
    'nyon',
    'nyonj',
    'nyonh',
    'nyod',
    'nyol',
    'nyolg',
    'nyolm',
    'nyolb',
    'nyols',
    'nyolt',
    'nyolp',
    'nyolh',
    'nyom',
    'nyob',
    'nyobs',
    'nyos',
    'nyoss',
    'nyong',
    'nyoj',
    'nyoc'
];

},{}],"yiPge":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:37 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'nyok',
    'nyot',
    'nyop',
    'nyoh',
    'nu',
    'nug',
    'nugg',
    'nugs',
    'nun',
    'nunj',
    'nunh',
    'nud',
    'nul',
    'nulg',
    'nulm',
    'nulb',
    'nuls',
    'nult',
    'nulp',
    'nulh',
    'num',
    'nub',
    'nubs',
    'nus',
    'nuss',
    'nung',
    'nuj',
    'nuc',
    'nuk',
    'nut',
    'nup',
    'nuh',
    'nweo',
    'nweog',
    'nweogg',
    'nweogs',
    'nweon',
    'nweonj',
    'nweonh',
    'nweod',
    'nweol',
    'nweolg',
    'nweolm',
    'nweolb',
    'nweols',
    'nweolt',
    'nweolp',
    'nweolh',
    'nweom',
    'nweob',
    'nweobs',
    'nweos',
    'nweoss',
    'nweong',
    'nweoj',
    'nweoc',
    'nweok',
    'nweot',
    'nweop',
    'nweoh',
    'nwe',
    'nweg',
    'nwegg',
    'nwegs',
    'nwen',
    'nwenj',
    'nwenh',
    'nwed',
    'nwel',
    'nwelg',
    'nwelm',
    'nwelb',
    'nwels',
    'nwelt',
    'nwelp',
    'nwelh',
    'nwem',
    'nweb',
    'nwebs',
    'nwes',
    'nwess',
    'nweng',
    'nwej',
    'nwec',
    'nwek',
    'nwet',
    'nwep',
    'nweh',
    'nwi',
    'nwig',
    'nwigg',
    'nwigs',
    'nwin',
    'nwinj',
    'nwinh',
    'nwid',
    'nwil',
    'nwilg',
    'nwilm',
    'nwilb',
    'nwils',
    'nwilt',
    'nwilp',
    'nwilh',
    'nwim',
    'nwib',
    'nwibs',
    'nwis',
    'nwiss',
    'nwing',
    'nwij',
    'nwic',
    'nwik',
    'nwit',
    'nwip',
    'nwih',
    'nyu',
    'nyug',
    'nyugg',
    'nyugs',
    'nyun',
    'nyunj',
    'nyunh',
    'nyud',
    'nyul',
    'nyulg',
    'nyulm',
    'nyulb',
    'nyuls',
    'nyult',
    'nyulp',
    'nyulh',
    'nyum',
    'nyub',
    'nyubs',
    'nyus',
    'nyuss',
    'nyung',
    'nyuj',
    'nyuc',
    'nyuk',
    'nyut',
    'nyup',
    'nyuh',
    'neu',
    'neug',
    'neugg',
    'neugs',
    'neun',
    'neunj',
    'neunh',
    'neud',
    'neul',
    'neulg',
    'neulm',
    'neulb',
    'neuls',
    'neult',
    'neulp',
    'neulh',
    'neum',
    'neub',
    'neubs',
    'neus',
    'neuss',
    'neung',
    'neuj',
    'neuc',
    'neuk',
    'neut',
    'neup',
    'neuh',
    'nyi',
    'nyig',
    'nyigg',
    'nyigs',
    'nyin',
    'nyinj',
    'nyinh',
    'nyid',
    'nyil',
    'nyilg',
    'nyilm',
    'nyilb',
    'nyils',
    'nyilt',
    'nyilp',
    'nyilh',
    'nyim',
    'nyib',
    'nyibs',
    'nyis',
    'nyiss',
    'nying',
    'nyij',
    'nyic',
    'nyik',
    'nyit',
    'nyip',
    'nyih',
    'ni',
    'nig',
    'nigg',
    'nigs',
    'nin',
    'ninj',
    'ninh',
    'nid',
    'nil',
    'nilg',
    'nilm',
    'nilb',
    'nils',
    'nilt',
    'nilp',
    'nilh',
    'nim',
    'nib',
    'nibs',
    'nis',
    'niss',
    'ning',
    'nij',
    'nic',
    'nik',
    'nit',
    'nip',
    'nih',
    'da',
    'dag',
    'dagg',
    'dags',
    'dan',
    'danj',
    'danh',
    'dad',
    'dal',
    'dalg',
    'dalm',
    'dalb',
    'dals',
    'dalt',
    'dalp',
    'dalh',
    'dam',
    'dab',
    'dabs',
    'das',
    'dass',
    'dang',
    'daj',
    'dac',
    'dak',
    'dat',
    'dap',
    'dah'
];

},{}],"iFAdB":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:37 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'dae',
    'daeg',
    'daegg',
    'daegs',
    'daen',
    'daenj',
    'daenh',
    'daed',
    'dael',
    'daelg',
    'daelm',
    'daelb',
    'daels',
    'daelt',
    'daelp',
    'daelh',
    'daem',
    'daeb',
    'daebs',
    'daes',
    'daess',
    'daeng',
    'daej',
    'daec',
    'daek',
    'daet',
    'daep',
    'daeh',
    'dya',
    'dyag',
    'dyagg',
    'dyags',
    'dyan',
    'dyanj',
    'dyanh',
    'dyad',
    'dyal',
    'dyalg',
    'dyalm',
    'dyalb',
    'dyals',
    'dyalt',
    'dyalp',
    'dyalh',
    'dyam',
    'dyab',
    'dyabs',
    'dyas',
    'dyass',
    'dyang',
    'dyaj',
    'dyac',
    'dyak',
    'dyat',
    'dyap',
    'dyah',
    'dyae',
    'dyaeg',
    'dyaegg',
    'dyaegs',
    'dyaen',
    'dyaenj',
    'dyaenh',
    'dyaed',
    'dyael',
    'dyaelg',
    'dyaelm',
    'dyaelb',
    'dyaels',
    'dyaelt',
    'dyaelp',
    'dyaelh',
    'dyaem',
    'dyaeb',
    'dyaebs',
    'dyaes',
    'dyaess',
    'dyaeng',
    'dyaej',
    'dyaec',
    'dyaek',
    'dyaet',
    'dyaep',
    'dyaeh',
    'deo',
    'deog',
    'deogg',
    'deogs',
    'deon',
    'deonj',
    'deonh',
    'deod',
    'deol',
    'deolg',
    'deolm',
    'deolb',
    'deols',
    'deolt',
    'deolp',
    'deolh',
    'deom',
    'deob',
    'deobs',
    'deos',
    'deoss',
    'deong',
    'deoj',
    'deoc',
    'deok',
    'deot',
    'deop',
    'deoh',
    'de',
    'deg',
    'degg',
    'degs',
    'den',
    'denj',
    'denh',
    'ded',
    'del',
    'delg',
    'delm',
    'delb',
    'dels',
    'delt',
    'delp',
    'delh',
    'dem',
    'deb',
    'debs',
    'des',
    'dess',
    'deng',
    'dej',
    'dec',
    'dek',
    'det',
    'dep',
    'deh',
    'dyeo',
    'dyeog',
    'dyeogg',
    'dyeogs',
    'dyeon',
    'dyeonj',
    'dyeonh',
    'dyeod',
    'dyeol',
    'dyeolg',
    'dyeolm',
    'dyeolb',
    'dyeols',
    'dyeolt',
    'dyeolp',
    'dyeolh',
    'dyeom',
    'dyeob',
    'dyeobs',
    'dyeos',
    'dyeoss',
    'dyeong',
    'dyeoj',
    'dyeoc',
    'dyeok',
    'dyeot',
    'dyeop',
    'dyeoh',
    'dye',
    'dyeg',
    'dyegg',
    'dyegs',
    'dyen',
    'dyenj',
    'dyenh',
    'dyed',
    'dyel',
    'dyelg',
    'dyelm',
    'dyelb',
    'dyels',
    'dyelt',
    'dyelp',
    'dyelh',
    'dyem',
    'dyeb',
    'dyebs',
    'dyes',
    'dyess',
    'dyeng',
    'dyej',
    'dyec',
    'dyek',
    'dyet',
    'dyep',
    'dyeh',
    'do',
    'dog',
    'dogg',
    'dogs',
    'don',
    'donj',
    'donh',
    'dod',
    'dol',
    'dolg',
    'dolm',
    'dolb',
    'dols',
    'dolt',
    'dolp',
    'dolh',
    'dom',
    'dob',
    'dobs',
    'dos',
    'doss',
    'dong',
    'doj',
    'doc',
    'dok',
    'dot',
    'dop',
    'doh',
    'dwa',
    'dwag',
    'dwagg',
    'dwags',
    'dwan',
    'dwanj',
    'dwanh',
    'dwad',
    'dwal',
    'dwalg',
    'dwalm',
    'dwalb',
    'dwals',
    'dwalt',
    'dwalp',
    'dwalh',
    'dwam',
    'dwab',
    'dwabs',
    'dwas',
    'dwass',
    'dwang',
    'dwaj',
    'dwac',
    'dwak',
    'dwat',
    'dwap',
    'dwah',
    'dwae',
    'dwaeg',
    'dwaegg',
    'dwaegs'
];

},{}],"c3Tpj":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:37 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'dwaen',
    'dwaenj',
    'dwaenh',
    'dwaed',
    'dwael',
    'dwaelg',
    'dwaelm',
    'dwaelb',
    'dwaels',
    'dwaelt',
    'dwaelp',
    'dwaelh',
    'dwaem',
    'dwaeb',
    'dwaebs',
    'dwaes',
    'dwaess',
    'dwaeng',
    'dwaej',
    'dwaec',
    'dwaek',
    'dwaet',
    'dwaep',
    'dwaeh',
    'doe',
    'doeg',
    'doegg',
    'doegs',
    'doen',
    'doenj',
    'doenh',
    'doed',
    'doel',
    'doelg',
    'doelm',
    'doelb',
    'doels',
    'doelt',
    'doelp',
    'doelh',
    'doem',
    'doeb',
    'doebs',
    'does',
    'doess',
    'doeng',
    'doej',
    'doec',
    'doek',
    'doet',
    'doep',
    'doeh',
    'dyo',
    'dyog',
    'dyogg',
    'dyogs',
    'dyon',
    'dyonj',
    'dyonh',
    'dyod',
    'dyol',
    'dyolg',
    'dyolm',
    'dyolb',
    'dyols',
    'dyolt',
    'dyolp',
    'dyolh',
    'dyom',
    'dyob',
    'dyobs',
    'dyos',
    'dyoss',
    'dyong',
    'dyoj',
    'dyoc',
    'dyok',
    'dyot',
    'dyop',
    'dyoh',
    'du',
    'dug',
    'dugg',
    'dugs',
    'dun',
    'dunj',
    'dunh',
    'dud',
    'dul',
    'dulg',
    'dulm',
    'dulb',
    'duls',
    'dult',
    'dulp',
    'dulh',
    'dum',
    'dub',
    'dubs',
    'dus',
    'duss',
    'dung',
    'duj',
    'duc',
    'duk',
    'dut',
    'dup',
    'duh',
    'dweo',
    'dweog',
    'dweogg',
    'dweogs',
    'dweon',
    'dweonj',
    'dweonh',
    'dweod',
    'dweol',
    'dweolg',
    'dweolm',
    'dweolb',
    'dweols',
    'dweolt',
    'dweolp',
    'dweolh',
    'dweom',
    'dweob',
    'dweobs',
    'dweos',
    'dweoss',
    'dweong',
    'dweoj',
    'dweoc',
    'dweok',
    'dweot',
    'dweop',
    'dweoh',
    'dwe',
    'dweg',
    'dwegg',
    'dwegs',
    'dwen',
    'dwenj',
    'dwenh',
    'dwed',
    'dwel',
    'dwelg',
    'dwelm',
    'dwelb',
    'dwels',
    'dwelt',
    'dwelp',
    'dwelh',
    'dwem',
    'dweb',
    'dwebs',
    'dwes',
    'dwess',
    'dweng',
    'dwej',
    'dwec',
    'dwek',
    'dwet',
    'dwep',
    'dweh',
    'dwi',
    'dwig',
    'dwigg',
    'dwigs',
    'dwin',
    'dwinj',
    'dwinh',
    'dwid',
    'dwil',
    'dwilg',
    'dwilm',
    'dwilb',
    'dwils',
    'dwilt',
    'dwilp',
    'dwilh',
    'dwim',
    'dwib',
    'dwibs',
    'dwis',
    'dwiss',
    'dwing',
    'dwij',
    'dwic',
    'dwik',
    'dwit',
    'dwip',
    'dwih',
    'dyu',
    'dyug',
    'dyugg',
    'dyugs',
    'dyun',
    'dyunj',
    'dyunh',
    'dyud',
    'dyul',
    'dyulg',
    'dyulm',
    'dyulb',
    'dyuls',
    'dyult',
    'dyulp',
    'dyulh',
    'dyum',
    'dyub',
    'dyubs',
    'dyus',
    'dyuss',
    'dyung',
    'dyuj',
    'dyuc',
    'dyuk',
    'dyut',
    'dyup',
    'dyuh',
    'deu',
    'deug',
    'deugg',
    'deugs',
    'deun',
    'deunj',
    'deunh',
    'deud',
    'deul',
    'deulg',
    'deulm',
    'deulb',
    'deuls',
    'deult',
    'deulp',
    'deulh',
    'deum',
    'deub',
    'deubs',
    'deus',
    'deuss',
    'deung',
    'deuj',
    'deuc',
    'deuk',
    'deut',
    'deup',
    'deuh',
    'dyi',
    'dyig',
    'dyigg',
    'dyigs',
    'dyin',
    'dyinj',
    'dyinh',
    'dyid'
];

},{}],"7Etd8":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:38 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'dyil',
    'dyilg',
    'dyilm',
    'dyilb',
    'dyils',
    'dyilt',
    'dyilp',
    'dyilh',
    'dyim',
    'dyib',
    'dyibs',
    'dyis',
    'dyiss',
    'dying',
    'dyij',
    'dyic',
    'dyik',
    'dyit',
    'dyip',
    'dyih',
    'di',
    'dig',
    'digg',
    'digs',
    'din',
    'dinj',
    'dinh',
    'did',
    'dil',
    'dilg',
    'dilm',
    'dilb',
    'dils',
    'dilt',
    'dilp',
    'dilh',
    'dim',
    'dib',
    'dibs',
    'dis',
    'diss',
    'ding',
    'dij',
    'dic',
    'dik',
    'dit',
    'dip',
    'dih',
    'dda',
    'ddag',
    'ddagg',
    'ddags',
    'ddan',
    'ddanj',
    'ddanh',
    'ddad',
    'ddal',
    'ddalg',
    'ddalm',
    'ddalb',
    'ddals',
    'ddalt',
    'ddalp',
    'ddalh',
    'ddam',
    'ddab',
    'ddabs',
    'ddas',
    'ddass',
    'ddang',
    'ddaj',
    'ddac',
    'ddak',
    'ddat',
    'ddap',
    'ddah',
    'ddae',
    'ddaeg',
    'ddaegg',
    'ddaegs',
    'ddaen',
    'ddaenj',
    'ddaenh',
    'ddaed',
    'ddael',
    'ddaelg',
    'ddaelm',
    'ddaelb',
    'ddaels',
    'ddaelt',
    'ddaelp',
    'ddaelh',
    'ddaem',
    'ddaeb',
    'ddaebs',
    'ddaes',
    'ddaess',
    'ddaeng',
    'ddaej',
    'ddaec',
    'ddaek',
    'ddaet',
    'ddaep',
    'ddaeh',
    'ddya',
    'ddyag',
    'ddyagg',
    'ddyags',
    'ddyan',
    'ddyanj',
    'ddyanh',
    'ddyad',
    'ddyal',
    'ddyalg',
    'ddyalm',
    'ddyalb',
    'ddyals',
    'ddyalt',
    'ddyalp',
    'ddyalh',
    'ddyam',
    'ddyab',
    'ddyabs',
    'ddyas',
    'ddyass',
    'ddyang',
    'ddyaj',
    'ddyac',
    'ddyak',
    'ddyat',
    'ddyap',
    'ddyah',
    'ddyae',
    'ddyaeg',
    'ddyaegg',
    'ddyaegs',
    'ddyaen',
    'ddyaenj',
    'ddyaenh',
    'ddyaed',
    'ddyael',
    'ddyaelg',
    'ddyaelm',
    'ddyaelb',
    'ddyaels',
    'ddyaelt',
    'ddyaelp',
    'ddyaelh',
    'ddyaem',
    'ddyaeb',
    'ddyaebs',
    'ddyaes',
    'ddyaess',
    'ddyaeng',
    'ddyaej',
    'ddyaec',
    'ddyaek',
    'ddyaet',
    'ddyaep',
    'ddyaeh',
    'ddeo',
    'ddeog',
    'ddeogg',
    'ddeogs',
    'ddeon',
    'ddeonj',
    'ddeonh',
    'ddeod',
    'ddeol',
    'ddeolg',
    'ddeolm',
    'ddeolb',
    'ddeols',
    'ddeolt',
    'ddeolp',
    'ddeolh',
    'ddeom',
    'ddeob',
    'ddeobs',
    'ddeos',
    'ddeoss',
    'ddeong',
    'ddeoj',
    'ddeoc',
    'ddeok',
    'ddeot',
    'ddeop',
    'ddeoh',
    'dde',
    'ddeg',
    'ddegg',
    'ddegs',
    'dden',
    'ddenj',
    'ddenh',
    'dded',
    'ddel',
    'ddelg',
    'ddelm',
    'ddelb',
    'ddels',
    'ddelt',
    'ddelp',
    'ddelh',
    'ddem',
    'ddeb',
    'ddebs',
    'ddes',
    'ddess',
    'ddeng',
    'ddej',
    'ddec',
    'ddek',
    'ddet',
    'ddep',
    'ddeh',
    'ddyeo',
    'ddyeog',
    'ddyeogg',
    'ddyeogs',
    'ddyeon',
    'ddyeonj',
    'ddyeonh',
    'ddyeod',
    'ddyeol',
    'ddyeolg',
    'ddyeolm',
    'ddyeolb',
    'ddyeols',
    'ddyeolt',
    'ddyeolp',
    'ddyeolh',
    'ddyeom',
    'ddyeob',
    'ddyeobs',
    'ddyeos',
    'ddyeoss',
    'ddyeong',
    'ddyeoj',
    'ddyeoc',
    'ddyeok',
    'ddyeot',
    'ddyeop',
    'ddyeoh',
    'ddye',
    'ddyeg',
    'ddyegg',
    'ddyegs',
    'ddyen',
    'ddyenj',
    'ddyenh',
    'ddyed',
    'ddyel',
    'ddyelg',
    'ddyelm',
    'ddyelb'
];

},{}],"8dUzb":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:38 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'ddyels',
    'ddyelt',
    'ddyelp',
    'ddyelh',
    'ddyem',
    'ddyeb',
    'ddyebs',
    'ddyes',
    'ddyess',
    'ddyeng',
    'ddyej',
    'ddyec',
    'ddyek',
    'ddyet',
    'ddyep',
    'ddyeh',
    'ddo',
    'ddog',
    'ddogg',
    'ddogs',
    'ddon',
    'ddonj',
    'ddonh',
    'ddod',
    'ddol',
    'ddolg',
    'ddolm',
    'ddolb',
    'ddols',
    'ddolt',
    'ddolp',
    'ddolh',
    'ddom',
    'ddob',
    'ddobs',
    'ddos',
    'ddoss',
    'ddong',
    'ddoj',
    'ddoc',
    'ddok',
    'ddot',
    'ddop',
    'ddoh',
    'ddwa',
    'ddwag',
    'ddwagg',
    'ddwags',
    'ddwan',
    'ddwanj',
    'ddwanh',
    'ddwad',
    'ddwal',
    'ddwalg',
    'ddwalm',
    'ddwalb',
    'ddwals',
    'ddwalt',
    'ddwalp',
    'ddwalh',
    'ddwam',
    'ddwab',
    'ddwabs',
    'ddwas',
    'ddwass',
    'ddwang',
    'ddwaj',
    'ddwac',
    'ddwak',
    'ddwat',
    'ddwap',
    'ddwah',
    'ddwae',
    'ddwaeg',
    'ddwaegg',
    'ddwaegs',
    'ddwaen',
    'ddwaenj',
    'ddwaenh',
    'ddwaed',
    'ddwael',
    'ddwaelg',
    'ddwaelm',
    'ddwaelb',
    'ddwaels',
    'ddwaelt',
    'ddwaelp',
    'ddwaelh',
    'ddwaem',
    'ddwaeb',
    'ddwaebs',
    'ddwaes',
    'ddwaess',
    'ddwaeng',
    'ddwaej',
    'ddwaec',
    'ddwaek',
    'ddwaet',
    'ddwaep',
    'ddwaeh',
    'ddoe',
    'ddoeg',
    'ddoegg',
    'ddoegs',
    'ddoen',
    'ddoenj',
    'ddoenh',
    'ddoed',
    'ddoel',
    'ddoelg',
    'ddoelm',
    'ddoelb',
    'ddoels',
    'ddoelt',
    'ddoelp',
    'ddoelh',
    'ddoem',
    'ddoeb',
    'ddoebs',
    'ddoes',
    'ddoess',
    'ddoeng',
    'ddoej',
    'ddoec',
    'ddoek',
    'ddoet',
    'ddoep',
    'ddoeh',
    'ddyo',
    'ddyog',
    'ddyogg',
    'ddyogs',
    'ddyon',
    'ddyonj',
    'ddyonh',
    'ddyod',
    'ddyol',
    'ddyolg',
    'ddyolm',
    'ddyolb',
    'ddyols',
    'ddyolt',
    'ddyolp',
    'ddyolh',
    'ddyom',
    'ddyob',
    'ddyobs',
    'ddyos',
    'ddyoss',
    'ddyong',
    'ddyoj',
    'ddyoc',
    'ddyok',
    'ddyot',
    'ddyop',
    'ddyoh',
    'ddu',
    'ddug',
    'ddugg',
    'ddugs',
    'ddun',
    'ddunj',
    'ddunh',
    'ddud',
    'ddul',
    'ddulg',
    'ddulm',
    'ddulb',
    'dduls',
    'ddult',
    'ddulp',
    'ddulh',
    'ddum',
    'ddub',
    'ddubs',
    'ddus',
    'dduss',
    'ddung',
    'dduj',
    'dduc',
    'dduk',
    'ddut',
    'ddup',
    'dduh',
    'ddweo',
    'ddweog',
    'ddweogg',
    'ddweogs',
    'ddweon',
    'ddweonj',
    'ddweonh',
    'ddweod',
    'ddweol',
    'ddweolg',
    'ddweolm',
    'ddweolb',
    'ddweols',
    'ddweolt',
    'ddweolp',
    'ddweolh',
    'ddweom',
    'ddweob',
    'ddweobs',
    'ddweos',
    'ddweoss',
    'ddweong',
    'ddweoj',
    'ddweoc',
    'ddweok',
    'ddweot',
    'ddweop',
    'ddweoh',
    'ddwe',
    'ddweg',
    'ddwegg',
    'ddwegs',
    'ddwen',
    'ddwenj',
    'ddwenh',
    'ddwed',
    'ddwel',
    'ddwelg',
    'ddwelm',
    'ddwelb',
    'ddwels',
    'ddwelt',
    'ddwelp',
    'ddwelh',
    'ddwem',
    'ddweb',
    'ddwebs',
    'ddwes',
    'ddwess',
    'ddweng',
    'ddwej',
    'ddwec',
    'ddwek',
    'ddwet',
    'ddwep',
    'ddweh',
    'ddwi',
    'ddwig',
    'ddwigg',
    'ddwigs',
    'ddwin',
    'ddwinj',
    'ddwinh',
    'ddwid',
    'ddwil',
    'ddwilg',
    'ddwilm',
    'ddwilb',
    'ddwils',
    'ddwilt',
    'ddwilp',
    'ddwilh'
];

},{}],"3i1Ke":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:39 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'ddwim',
    'ddwib',
    'ddwibs',
    'ddwis',
    'ddwiss',
    'ddwing',
    'ddwij',
    'ddwic',
    'ddwik',
    'ddwit',
    'ddwip',
    'ddwih',
    'ddyu',
    'ddyug',
    'ddyugg',
    'ddyugs',
    'ddyun',
    'ddyunj',
    'ddyunh',
    'ddyud',
    'ddyul',
    'ddyulg',
    'ddyulm',
    'ddyulb',
    'ddyuls',
    'ddyult',
    'ddyulp',
    'ddyulh',
    'ddyum',
    'ddyub',
    'ddyubs',
    'ddyus',
    'ddyuss',
    'ddyung',
    'ddyuj',
    'ddyuc',
    'ddyuk',
    'ddyut',
    'ddyup',
    'ddyuh',
    'ddeu',
    'ddeug',
    'ddeugg',
    'ddeugs',
    'ddeun',
    'ddeunj',
    'ddeunh',
    'ddeud',
    'ddeul',
    'ddeulg',
    'ddeulm',
    'ddeulb',
    'ddeuls',
    'ddeult',
    'ddeulp',
    'ddeulh',
    'ddeum',
    'ddeub',
    'ddeubs',
    'ddeus',
    'ddeuss',
    'ddeung',
    'ddeuj',
    'ddeuc',
    'ddeuk',
    'ddeut',
    'ddeup',
    'ddeuh',
    'ddyi',
    'ddyig',
    'ddyigg',
    'ddyigs',
    'ddyin',
    'ddyinj',
    'ddyinh',
    'ddyid',
    'ddyil',
    'ddyilg',
    'ddyilm',
    'ddyilb',
    'ddyils',
    'ddyilt',
    'ddyilp',
    'ddyilh',
    'ddyim',
    'ddyib',
    'ddyibs',
    'ddyis',
    'ddyiss',
    'ddying',
    'ddyij',
    'ddyic',
    'ddyik',
    'ddyit',
    'ddyip',
    'ddyih',
    'ddi',
    'ddig',
    'ddigg',
    'ddigs',
    'ddin',
    'ddinj',
    'ddinh',
    'ddid',
    'ddil',
    'ddilg',
    'ddilm',
    'ddilb',
    'ddils',
    'ddilt',
    'ddilp',
    'ddilh',
    'ddim',
    'ddib',
    'ddibs',
    'ddis',
    'ddiss',
    'dding',
    'ddij',
    'ddic',
    'ddik',
    'ddit',
    'ddip',
    'ddih',
    'ra',
    'rag',
    'ragg',
    'rags',
    'ran',
    'ranj',
    'ranh',
    'rad',
    'ral',
    'ralg',
    'ralm',
    'ralb',
    'rals',
    'ralt',
    'ralp',
    'ralh',
    'ram',
    'rab',
    'rabs',
    'ras',
    'rass',
    'rang',
    'raj',
    'rac',
    'rak',
    'rat',
    'rap',
    'rah',
    'rae',
    'raeg',
    'raegg',
    'raegs',
    'raen',
    'raenj',
    'raenh',
    'raed',
    'rael',
    'raelg',
    'raelm',
    'raelb',
    'raels',
    'raelt',
    'raelp',
    'raelh',
    'raem',
    'raeb',
    'raebs',
    'raes',
    'raess',
    'raeng',
    'raej',
    'raec',
    'raek',
    'raet',
    'raep',
    'raeh',
    'rya',
    'ryag',
    'ryagg',
    'ryags',
    'ryan',
    'ryanj',
    'ryanh',
    'ryad',
    'ryal',
    'ryalg',
    'ryalm',
    'ryalb',
    'ryals',
    'ryalt',
    'ryalp',
    'ryalh',
    'ryam',
    'ryab',
    'ryabs',
    'ryas',
    'ryass',
    'ryang',
    'ryaj',
    'ryac',
    'ryak',
    'ryat',
    'ryap',
    'ryah',
    'ryae',
    'ryaeg',
    'ryaegg',
    'ryaegs',
    'ryaen',
    'ryaenj',
    'ryaenh',
    'ryaed',
    'ryael',
    'ryaelg',
    'ryaelm',
    'ryaelb',
    'ryaels',
    'ryaelt',
    'ryaelp',
    'ryaelh',
    'ryaem',
    'ryaeb',
    'ryaebs',
    'ryaes',
    'ryaess',
    'ryaeng',
    'ryaej',
    'ryaec',
    'ryaek',
    'ryaet',
    'ryaep',
    'ryaeh',
    'reo',
    'reog',
    'reogg',
    'reogs',
    'reon',
    'reonj',
    'reonh',
    'reod',
    'reol',
    'reolg',
    'reolm',
    'reolb',
    'reols',
    'reolt',
    'reolp',
    'reolh',
    'reom',
    'reob',
    'reobs',
    'reos'
];

},{}],"8d7nq":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:39 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'reoss',
    'reong',
    'reoj',
    'reoc',
    'reok',
    'reot',
    'reop',
    'reoh',
    're',
    'reg',
    'regg',
    'regs',
    'ren',
    'renj',
    'renh',
    'red',
    'rel',
    'relg',
    'relm',
    'relb',
    'rels',
    'relt',
    'relp',
    'relh',
    'rem',
    'reb',
    'rebs',
    'res',
    'ress',
    'reng',
    'rej',
    'rec',
    'rek',
    'ret',
    'rep',
    'reh',
    'ryeo',
    'ryeog',
    'ryeogg',
    'ryeogs',
    'ryeon',
    'ryeonj',
    'ryeonh',
    'ryeod',
    'ryeol',
    'ryeolg',
    'ryeolm',
    'ryeolb',
    'ryeols',
    'ryeolt',
    'ryeolp',
    'ryeolh',
    'ryeom',
    'ryeob',
    'ryeobs',
    'ryeos',
    'ryeoss',
    'ryeong',
    'ryeoj',
    'ryeoc',
    'ryeok',
    'ryeot',
    'ryeop',
    'ryeoh',
    'rye',
    'ryeg',
    'ryegg',
    'ryegs',
    'ryen',
    'ryenj',
    'ryenh',
    'ryed',
    'ryel',
    'ryelg',
    'ryelm',
    'ryelb',
    'ryels',
    'ryelt',
    'ryelp',
    'ryelh',
    'ryem',
    'ryeb',
    'ryebs',
    'ryes',
    'ryess',
    'ryeng',
    'ryej',
    'ryec',
    'ryek',
    'ryet',
    'ryep',
    'ryeh',
    'ro',
    'rog',
    'rogg',
    'rogs',
    'ron',
    'ronj',
    'ronh',
    'rod',
    'rol',
    'rolg',
    'rolm',
    'rolb',
    'rols',
    'rolt',
    'rolp',
    'rolh',
    'rom',
    'rob',
    'robs',
    'ros',
    'ross',
    'rong',
    'roj',
    'roc',
    'rok',
    'rot',
    'rop',
    'roh',
    'rwa',
    'rwag',
    'rwagg',
    'rwags',
    'rwan',
    'rwanj',
    'rwanh',
    'rwad',
    'rwal',
    'rwalg',
    'rwalm',
    'rwalb',
    'rwals',
    'rwalt',
    'rwalp',
    'rwalh',
    'rwam',
    'rwab',
    'rwabs',
    'rwas',
    'rwass',
    'rwang',
    'rwaj',
    'rwac',
    'rwak',
    'rwat',
    'rwap',
    'rwah',
    'rwae',
    'rwaeg',
    'rwaegg',
    'rwaegs',
    'rwaen',
    'rwaenj',
    'rwaenh',
    'rwaed',
    'rwael',
    'rwaelg',
    'rwaelm',
    'rwaelb',
    'rwaels',
    'rwaelt',
    'rwaelp',
    'rwaelh',
    'rwaem',
    'rwaeb',
    'rwaebs',
    'rwaes',
    'rwaess',
    'rwaeng',
    'rwaej',
    'rwaec',
    'rwaek',
    'rwaet',
    'rwaep',
    'rwaeh',
    'roe',
    'roeg',
    'roegg',
    'roegs',
    'roen',
    'roenj',
    'roenh',
    'roed',
    'roel',
    'roelg',
    'roelm',
    'roelb',
    'roels',
    'roelt',
    'roelp',
    'roelh',
    'roem',
    'roeb',
    'roebs',
    'roes',
    'roess',
    'roeng',
    'roej',
    'roec',
    'roek',
    'roet',
    'roep',
    'roeh',
    'ryo',
    'ryog',
    'ryogg',
    'ryogs',
    'ryon',
    'ryonj',
    'ryonh',
    'ryod',
    'ryol',
    'ryolg',
    'ryolm',
    'ryolb',
    'ryols',
    'ryolt',
    'ryolp',
    'ryolh',
    'ryom',
    'ryob',
    'ryobs',
    'ryos',
    'ryoss',
    'ryong',
    'ryoj',
    'ryoc',
    'ryok',
    'ryot',
    'ryop',
    'ryoh',
    'ru',
    'rug',
    'rugg',
    'rugs',
    'run',
    'runj',
    'runh',
    'rud',
    'rul',
    'rulg',
    'rulm',
    'rulb',
    'ruls',
    'rult',
    'rulp',
    'rulh',
    'rum',
    'rub',
    'rubs',
    'rus',
    'russ',
    'rung',
    'ruj',
    'ruc'
];

},{}],"iugBR":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:39 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'ruk',
    'rut',
    'rup',
    'ruh',
    'rweo',
    'rweog',
    'rweogg',
    'rweogs',
    'rweon',
    'rweonj',
    'rweonh',
    'rweod',
    'rweol',
    'rweolg',
    'rweolm',
    'rweolb',
    'rweols',
    'rweolt',
    'rweolp',
    'rweolh',
    'rweom',
    'rweob',
    'rweobs',
    'rweos',
    'rweoss',
    'rweong',
    'rweoj',
    'rweoc',
    'rweok',
    'rweot',
    'rweop',
    'rweoh',
    'rwe',
    'rweg',
    'rwegg',
    'rwegs',
    'rwen',
    'rwenj',
    'rwenh',
    'rwed',
    'rwel',
    'rwelg',
    'rwelm',
    'rwelb',
    'rwels',
    'rwelt',
    'rwelp',
    'rwelh',
    'rwem',
    'rweb',
    'rwebs',
    'rwes',
    'rwess',
    'rweng',
    'rwej',
    'rwec',
    'rwek',
    'rwet',
    'rwep',
    'rweh',
    'rwi',
    'rwig',
    'rwigg',
    'rwigs',
    'rwin',
    'rwinj',
    'rwinh',
    'rwid',
    'rwil',
    'rwilg',
    'rwilm',
    'rwilb',
    'rwils',
    'rwilt',
    'rwilp',
    'rwilh',
    'rwim',
    'rwib',
    'rwibs',
    'rwis',
    'rwiss',
    'rwing',
    'rwij',
    'rwic',
    'rwik',
    'rwit',
    'rwip',
    'rwih',
    'ryu',
    'ryug',
    'ryugg',
    'ryugs',
    'ryun',
    'ryunj',
    'ryunh',
    'ryud',
    'ryul',
    'ryulg',
    'ryulm',
    'ryulb',
    'ryuls',
    'ryult',
    'ryulp',
    'ryulh',
    'ryum',
    'ryub',
    'ryubs',
    'ryus',
    'ryuss',
    'ryung',
    'ryuj',
    'ryuc',
    'ryuk',
    'ryut',
    'ryup',
    'ryuh',
    'reu',
    'reug',
    'reugg',
    'reugs',
    'reun',
    'reunj',
    'reunh',
    'reud',
    'reul',
    'reulg',
    'reulm',
    'reulb',
    'reuls',
    'reult',
    'reulp',
    'reulh',
    'reum',
    'reub',
    'reubs',
    'reus',
    'reuss',
    'reung',
    'reuj',
    'reuc',
    'reuk',
    'reut',
    'reup',
    'reuh',
    'ryi',
    'ryig',
    'ryigg',
    'ryigs',
    'ryin',
    'ryinj',
    'ryinh',
    'ryid',
    'ryil',
    'ryilg',
    'ryilm',
    'ryilb',
    'ryils',
    'ryilt',
    'ryilp',
    'ryilh',
    'ryim',
    'ryib',
    'ryibs',
    'ryis',
    'ryiss',
    'rying',
    'ryij',
    'ryic',
    'ryik',
    'ryit',
    'ryip',
    'ryih',
    'ri',
    'rig',
    'rigg',
    'rigs',
    'rin',
    'rinj',
    'rinh',
    'rid',
    'ril',
    'rilg',
    'rilm',
    'rilb',
    'rils',
    'rilt',
    'rilp',
    'rilh',
    'rim',
    'rib',
    'ribs',
    'ris',
    'riss',
    'ring',
    'rij',
    'ric',
    'rik',
    'rit',
    'rip',
    'rih',
    'ma',
    'mag',
    'magg',
    'mags',
    'man',
    'manj',
    'manh',
    'mad',
    'mal',
    'malg',
    'malm',
    'malb',
    'mals',
    'malt',
    'malp',
    'malh',
    'mam',
    'mab',
    'mabs',
    'mas',
    'mass',
    'mang',
    'maj',
    'mac',
    'mak',
    'mat',
    'map',
    'mah',
    'mae',
    'maeg',
    'maegg',
    'maegs',
    'maen',
    'maenj',
    'maenh',
    'maed',
    'mael',
    'maelg',
    'maelm',
    'maelb',
    'maels',
    'maelt',
    'maelp',
    'maelh',
    'maem',
    'maeb',
    'maebs',
    'maes',
    'maess',
    'maeng',
    'maej',
    'maec',
    'maek',
    'maet',
    'maep',
    'maeh'
];

},{}],"a0grS":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:39 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'mya',
    'myag',
    'myagg',
    'myags',
    'myan',
    'myanj',
    'myanh',
    'myad',
    'myal',
    'myalg',
    'myalm',
    'myalb',
    'myals',
    'myalt',
    'myalp',
    'myalh',
    'myam',
    'myab',
    'myabs',
    'myas',
    'myass',
    'myang',
    'myaj',
    'myac',
    'myak',
    'myat',
    'myap',
    'myah',
    'myae',
    'myaeg',
    'myaegg',
    'myaegs',
    'myaen',
    'myaenj',
    'myaenh',
    'myaed',
    'myael',
    'myaelg',
    'myaelm',
    'myaelb',
    'myaels',
    'myaelt',
    'myaelp',
    'myaelh',
    'myaem',
    'myaeb',
    'myaebs',
    'myaes',
    'myaess',
    'myaeng',
    'myaej',
    'myaec',
    'myaek',
    'myaet',
    'myaep',
    'myaeh',
    'meo',
    'meog',
    'meogg',
    'meogs',
    'meon',
    'meonj',
    'meonh',
    'meod',
    'meol',
    'meolg',
    'meolm',
    'meolb',
    'meols',
    'meolt',
    'meolp',
    'meolh',
    'meom',
    'meob',
    'meobs',
    'meos',
    'meoss',
    'meong',
    'meoj',
    'meoc',
    'meok',
    'meot',
    'meop',
    'meoh',
    'me',
    'meg',
    'megg',
    'megs',
    'men',
    'menj',
    'menh',
    'med',
    'mel',
    'melg',
    'melm',
    'melb',
    'mels',
    'melt',
    'melp',
    'melh',
    'mem',
    'meb',
    'mebs',
    'mes',
    'mess',
    'meng',
    'mej',
    'mec',
    'mek',
    'met',
    'mep',
    'meh',
    'myeo',
    'myeog',
    'myeogg',
    'myeogs',
    'myeon',
    'myeonj',
    'myeonh',
    'myeod',
    'myeol',
    'myeolg',
    'myeolm',
    'myeolb',
    'myeols',
    'myeolt',
    'myeolp',
    'myeolh',
    'myeom',
    'myeob',
    'myeobs',
    'myeos',
    'myeoss',
    'myeong',
    'myeoj',
    'myeoc',
    'myeok',
    'myeot',
    'myeop',
    'myeoh',
    'mye',
    'myeg',
    'myegg',
    'myegs',
    'myen',
    'myenj',
    'myenh',
    'myed',
    'myel',
    'myelg',
    'myelm',
    'myelb',
    'myels',
    'myelt',
    'myelp',
    'myelh',
    'myem',
    'myeb',
    'myebs',
    'myes',
    'myess',
    'myeng',
    'myej',
    'myec',
    'myek',
    'myet',
    'myep',
    'myeh',
    'mo',
    'mog',
    'mogg',
    'mogs',
    'mon',
    'monj',
    'monh',
    'mod',
    'mol',
    'molg',
    'molm',
    'molb',
    'mols',
    'molt',
    'molp',
    'molh',
    'mom',
    'mob',
    'mobs',
    'mos',
    'moss',
    'mong',
    'moj',
    'moc',
    'mok',
    'mot',
    'mop',
    'moh',
    'mwa',
    'mwag',
    'mwagg',
    'mwags',
    'mwan',
    'mwanj',
    'mwanh',
    'mwad',
    'mwal',
    'mwalg',
    'mwalm',
    'mwalb',
    'mwals',
    'mwalt',
    'mwalp',
    'mwalh',
    'mwam',
    'mwab',
    'mwabs',
    'mwas',
    'mwass',
    'mwang',
    'mwaj',
    'mwac',
    'mwak',
    'mwat',
    'mwap',
    'mwah',
    'mwae',
    'mwaeg',
    'mwaegg',
    'mwaegs',
    'mwaen',
    'mwaenj',
    'mwaenh',
    'mwaed',
    'mwael',
    'mwaelg',
    'mwaelm',
    'mwaelb',
    'mwaels',
    'mwaelt',
    'mwaelp',
    'mwaelh',
    'mwaem',
    'mwaeb',
    'mwaebs',
    'mwaes',
    'mwaess',
    'mwaeng',
    'mwaej',
    'mwaec',
    'mwaek',
    'mwaet',
    'mwaep',
    'mwaeh',
    'moe',
    'moeg',
    'moegg',
    'moegs'
];

},{}],"eGbnx":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:39 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'moen',
    'moenj',
    'moenh',
    'moed',
    'moel',
    'moelg',
    'moelm',
    'moelb',
    'moels',
    'moelt',
    'moelp',
    'moelh',
    'moem',
    'moeb',
    'moebs',
    'moes',
    'moess',
    'moeng',
    'moej',
    'moec',
    'moek',
    'moet',
    'moep',
    'moeh',
    'myo',
    'myog',
    'myogg',
    'myogs',
    'myon',
    'myonj',
    'myonh',
    'myod',
    'myol',
    'myolg',
    'myolm',
    'myolb',
    'myols',
    'myolt',
    'myolp',
    'myolh',
    'myom',
    'myob',
    'myobs',
    'myos',
    'myoss',
    'myong',
    'myoj',
    'myoc',
    'myok',
    'myot',
    'myop',
    'myoh',
    'mu',
    'mug',
    'mugg',
    'mugs',
    'mun',
    'munj',
    'munh',
    'mud',
    'mul',
    'mulg',
    'mulm',
    'mulb',
    'muls',
    'mult',
    'mulp',
    'mulh',
    'mum',
    'mub',
    'mubs',
    'mus',
    'muss',
    'mung',
    'muj',
    'muc',
    'muk',
    'mut',
    'mup',
    'muh',
    'mweo',
    'mweog',
    'mweogg',
    'mweogs',
    'mweon',
    'mweonj',
    'mweonh',
    'mweod',
    'mweol',
    'mweolg',
    'mweolm',
    'mweolb',
    'mweols',
    'mweolt',
    'mweolp',
    'mweolh',
    'mweom',
    'mweob',
    'mweobs',
    'mweos',
    'mweoss',
    'mweong',
    'mweoj',
    'mweoc',
    'mweok',
    'mweot',
    'mweop',
    'mweoh',
    'mwe',
    'mweg',
    'mwegg',
    'mwegs',
    'mwen',
    'mwenj',
    'mwenh',
    'mwed',
    'mwel',
    'mwelg',
    'mwelm',
    'mwelb',
    'mwels',
    'mwelt',
    'mwelp',
    'mwelh',
    'mwem',
    'mweb',
    'mwebs',
    'mwes',
    'mwess',
    'mweng',
    'mwej',
    'mwec',
    'mwek',
    'mwet',
    'mwep',
    'mweh',
    'mwi',
    'mwig',
    'mwigg',
    'mwigs',
    'mwin',
    'mwinj',
    'mwinh',
    'mwid',
    'mwil',
    'mwilg',
    'mwilm',
    'mwilb',
    'mwils',
    'mwilt',
    'mwilp',
    'mwilh',
    'mwim',
    'mwib',
    'mwibs',
    'mwis',
    'mwiss',
    'mwing',
    'mwij',
    'mwic',
    'mwik',
    'mwit',
    'mwip',
    'mwih',
    'myu',
    'myug',
    'myugg',
    'myugs',
    'myun',
    'myunj',
    'myunh',
    'myud',
    'myul',
    'myulg',
    'myulm',
    'myulb',
    'myuls',
    'myult',
    'myulp',
    'myulh',
    'myum',
    'myub',
    'myubs',
    'myus',
    'myuss',
    'myung',
    'myuj',
    'myuc',
    'myuk',
    'myut',
    'myup',
    'myuh',
    'meu',
    'meug',
    'meugg',
    'meugs',
    'meun',
    'meunj',
    'meunh',
    'meud',
    'meul',
    'meulg',
    'meulm',
    'meulb',
    'meuls',
    'meult',
    'meulp',
    'meulh',
    'meum',
    'meub',
    'meubs',
    'meus',
    'meuss',
    'meung',
    'meuj',
    'meuc',
    'meuk',
    'meut',
    'meup',
    'meuh',
    'myi',
    'myig',
    'myigg',
    'myigs',
    'myin',
    'myinj',
    'myinh',
    'myid',
    'myil',
    'myilg',
    'myilm',
    'myilb',
    'myils',
    'myilt',
    'myilp',
    'myilh',
    'myim',
    'myib',
    'myibs',
    'myis',
    'myiss',
    'mying',
    'myij',
    'myic',
    'myik',
    'myit',
    'myip',
    'myih',
    'mi',
    'mig',
    'migg',
    'migs',
    'min',
    'minj',
    'minh',
    'mid'
];

},{}],"3pzbL":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:39 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'mil',
    'milg',
    'milm',
    'milb',
    'mils',
    'milt',
    'milp',
    'milh',
    'mim',
    'mib',
    'mibs',
    'mis',
    'miss',
    'ming',
    'mij',
    'mic',
    'mik',
    'mit',
    'mip',
    'mih',
    'ba',
    'bag',
    'bagg',
    'bags',
    'ban',
    'banj',
    'banh',
    'bad',
    'bal',
    'balg',
    'balm',
    'balb',
    'bals',
    'balt',
    'balp',
    'balh',
    'bam',
    'bab',
    'babs',
    'bas',
    'bass',
    'bang',
    'baj',
    'bac',
    'bak',
    'bat',
    'bap',
    'bah',
    'bae',
    'baeg',
    'baegg',
    'baegs',
    'baen',
    'baenj',
    'baenh',
    'baed',
    'bael',
    'baelg',
    'baelm',
    'baelb',
    'baels',
    'baelt',
    'baelp',
    'baelh',
    'baem',
    'baeb',
    'baebs',
    'baes',
    'baess',
    'baeng',
    'baej',
    'baec',
    'baek',
    'baet',
    'baep',
    'baeh',
    'bya',
    'byag',
    'byagg',
    'byags',
    'byan',
    'byanj',
    'byanh',
    'byad',
    'byal',
    'byalg',
    'byalm',
    'byalb',
    'byals',
    'byalt',
    'byalp',
    'byalh',
    'byam',
    'byab',
    'byabs',
    'byas',
    'byass',
    'byang',
    'byaj',
    'byac',
    'byak',
    'byat',
    'byap',
    'byah',
    'byae',
    'byaeg',
    'byaegg',
    'byaegs',
    'byaen',
    'byaenj',
    'byaenh',
    'byaed',
    'byael',
    'byaelg',
    'byaelm',
    'byaelb',
    'byaels',
    'byaelt',
    'byaelp',
    'byaelh',
    'byaem',
    'byaeb',
    'byaebs',
    'byaes',
    'byaess',
    'byaeng',
    'byaej',
    'byaec',
    'byaek',
    'byaet',
    'byaep',
    'byaeh',
    'beo',
    'beog',
    'beogg',
    'beogs',
    'beon',
    'beonj',
    'beonh',
    'beod',
    'beol',
    'beolg',
    'beolm',
    'beolb',
    'beols',
    'beolt',
    'beolp',
    'beolh',
    'beom',
    'beob',
    'beobs',
    'beos',
    'beoss',
    'beong',
    'beoj',
    'beoc',
    'beok',
    'beot',
    'beop',
    'beoh',
    'be',
    'beg',
    'begg',
    'begs',
    'ben',
    'benj',
    'benh',
    'bed',
    'bel',
    'belg',
    'belm',
    'belb',
    'bels',
    'belt',
    'belp',
    'belh',
    'bem',
    'beb',
    'bebs',
    'bes',
    'bess',
    'beng',
    'bej',
    'bec',
    'bek',
    'bet',
    'bep',
    'beh',
    'byeo',
    'byeog',
    'byeogg',
    'byeogs',
    'byeon',
    'byeonj',
    'byeonh',
    'byeod',
    'byeol',
    'byeolg',
    'byeolm',
    'byeolb',
    'byeols',
    'byeolt',
    'byeolp',
    'byeolh',
    'byeom',
    'byeob',
    'byeobs',
    'byeos',
    'byeoss',
    'byeong',
    'byeoj',
    'byeoc',
    'byeok',
    'byeot',
    'byeop',
    'byeoh',
    'bye',
    'byeg',
    'byegg',
    'byegs',
    'byen',
    'byenj',
    'byenh',
    'byed',
    'byel',
    'byelg',
    'byelm',
    'byelb',
    'byels',
    'byelt',
    'byelp',
    'byelh',
    'byem',
    'byeb',
    'byebs',
    'byes',
    'byess',
    'byeng',
    'byej',
    'byec',
    'byek',
    'byet',
    'byep',
    'byeh',
    'bo',
    'bog',
    'bogg',
    'bogs',
    'bon',
    'bonj',
    'bonh',
    'bod',
    'bol',
    'bolg',
    'bolm',
    'bolb'
];

},{}],"9n03R":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:39 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'bols',
    'bolt',
    'bolp',
    'bolh',
    'bom',
    'bob',
    'bobs',
    'bos',
    'boss',
    'bong',
    'boj',
    'boc',
    'bok',
    'bot',
    'bop',
    'boh',
    'bwa',
    'bwag',
    'bwagg',
    'bwags',
    'bwan',
    'bwanj',
    'bwanh',
    'bwad',
    'bwal',
    'bwalg',
    'bwalm',
    'bwalb',
    'bwals',
    'bwalt',
    'bwalp',
    'bwalh',
    'bwam',
    'bwab',
    'bwabs',
    'bwas',
    'bwass',
    'bwang',
    'bwaj',
    'bwac',
    'bwak',
    'bwat',
    'bwap',
    'bwah',
    'bwae',
    'bwaeg',
    'bwaegg',
    'bwaegs',
    'bwaen',
    'bwaenj',
    'bwaenh',
    'bwaed',
    'bwael',
    'bwaelg',
    'bwaelm',
    'bwaelb',
    'bwaels',
    'bwaelt',
    'bwaelp',
    'bwaelh',
    'bwaem',
    'bwaeb',
    'bwaebs',
    'bwaes',
    'bwaess',
    'bwaeng',
    'bwaej',
    'bwaec',
    'bwaek',
    'bwaet',
    'bwaep',
    'bwaeh',
    'boe',
    'boeg',
    'boegg',
    'boegs',
    'boen',
    'boenj',
    'boenh',
    'boed',
    'boel',
    'boelg',
    'boelm',
    'boelb',
    'boels',
    'boelt',
    'boelp',
    'boelh',
    'boem',
    'boeb',
    'boebs',
    'boes',
    'boess',
    'boeng',
    'boej',
    'boec',
    'boek',
    'boet',
    'boep',
    'boeh',
    'byo',
    'byog',
    'byogg',
    'byogs',
    'byon',
    'byonj',
    'byonh',
    'byod',
    'byol',
    'byolg',
    'byolm',
    'byolb',
    'byols',
    'byolt',
    'byolp',
    'byolh',
    'byom',
    'byob',
    'byobs',
    'byos',
    'byoss',
    'byong',
    'byoj',
    'byoc',
    'byok',
    'byot',
    'byop',
    'byoh',
    'bu',
    'bug',
    'bugg',
    'bugs',
    'bun',
    'bunj',
    'bunh',
    'bud',
    'bul',
    'bulg',
    'bulm',
    'bulb',
    'buls',
    'bult',
    'bulp',
    'bulh',
    'bum',
    'bub',
    'bubs',
    'bus',
    'buss',
    'bung',
    'buj',
    'buc',
    'buk',
    'but',
    'bup',
    'buh',
    'bweo',
    'bweog',
    'bweogg',
    'bweogs',
    'bweon',
    'bweonj',
    'bweonh',
    'bweod',
    'bweol',
    'bweolg',
    'bweolm',
    'bweolb',
    'bweols',
    'bweolt',
    'bweolp',
    'bweolh',
    'bweom',
    'bweob',
    'bweobs',
    'bweos',
    'bweoss',
    'bweong',
    'bweoj',
    'bweoc',
    'bweok',
    'bweot',
    'bweop',
    'bweoh',
    'bwe',
    'bweg',
    'bwegg',
    'bwegs',
    'bwen',
    'bwenj',
    'bwenh',
    'bwed',
    'bwel',
    'bwelg',
    'bwelm',
    'bwelb',
    'bwels',
    'bwelt',
    'bwelp',
    'bwelh',
    'bwem',
    'bweb',
    'bwebs',
    'bwes',
    'bwess',
    'bweng',
    'bwej',
    'bwec',
    'bwek',
    'bwet',
    'bwep',
    'bweh',
    'bwi',
    'bwig',
    'bwigg',
    'bwigs',
    'bwin',
    'bwinj',
    'bwinh',
    'bwid',
    'bwil',
    'bwilg',
    'bwilm',
    'bwilb',
    'bwils',
    'bwilt',
    'bwilp',
    'bwilh',
    'bwim',
    'bwib',
    'bwibs',
    'bwis',
    'bwiss',
    'bwing',
    'bwij',
    'bwic',
    'bwik',
    'bwit',
    'bwip',
    'bwih',
    'byu',
    'byug',
    'byugg',
    'byugs',
    'byun',
    'byunj',
    'byunh',
    'byud',
    'byul',
    'byulg',
    'byulm',
    'byulb',
    'byuls',
    'byult',
    'byulp',
    'byulh'
];

},{}],"f1grB":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:39 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'byum',
    'byub',
    'byubs',
    'byus',
    'byuss',
    'byung',
    'byuj',
    'byuc',
    'byuk',
    'byut',
    'byup',
    'byuh',
    'beu',
    'beug',
    'beugg',
    'beugs',
    'beun',
    'beunj',
    'beunh',
    'beud',
    'beul',
    'beulg',
    'beulm',
    'beulb',
    'beuls',
    'beult',
    'beulp',
    'beulh',
    'beum',
    'beub',
    'beubs',
    'beus',
    'beuss',
    'beung',
    'beuj',
    'beuc',
    'beuk',
    'beut',
    'beup',
    'beuh',
    'byi',
    'byig',
    'byigg',
    'byigs',
    'byin',
    'byinj',
    'byinh',
    'byid',
    'byil',
    'byilg',
    'byilm',
    'byilb',
    'byils',
    'byilt',
    'byilp',
    'byilh',
    'byim',
    'byib',
    'byibs',
    'byis',
    'byiss',
    'bying',
    'byij',
    'byic',
    'byik',
    'byit',
    'byip',
    'byih',
    'bi',
    'big',
    'bigg',
    'bigs',
    'bin',
    'binj',
    'binh',
    'bid',
    'bil',
    'bilg',
    'bilm',
    'bilb',
    'bils',
    'bilt',
    'bilp',
    'bilh',
    'bim',
    'bib',
    'bibs',
    'bis',
    'biss',
    'bing',
    'bij',
    'bic',
    'bik',
    'bit',
    'bip',
    'bih',
    'bba',
    'bbag',
    'bbagg',
    'bbags',
    'bban',
    'bbanj',
    'bbanh',
    'bbad',
    'bbal',
    'bbalg',
    'bbalm',
    'bbalb',
    'bbals',
    'bbalt',
    'bbalp',
    'bbalh',
    'bbam',
    'bbab',
    'bbabs',
    'bbas',
    'bbass',
    'bbang',
    'bbaj',
    'bbac',
    'bbak',
    'bbat',
    'bbap',
    'bbah',
    'bbae',
    'bbaeg',
    'bbaegg',
    'bbaegs',
    'bbaen',
    'bbaenj',
    'bbaenh',
    'bbaed',
    'bbael',
    'bbaelg',
    'bbaelm',
    'bbaelb',
    'bbaels',
    'bbaelt',
    'bbaelp',
    'bbaelh',
    'bbaem',
    'bbaeb',
    'bbaebs',
    'bbaes',
    'bbaess',
    'bbaeng',
    'bbaej',
    'bbaec',
    'bbaek',
    'bbaet',
    'bbaep',
    'bbaeh',
    'bbya',
    'bbyag',
    'bbyagg',
    'bbyags',
    'bbyan',
    'bbyanj',
    'bbyanh',
    'bbyad',
    'bbyal',
    'bbyalg',
    'bbyalm',
    'bbyalb',
    'bbyals',
    'bbyalt',
    'bbyalp',
    'bbyalh',
    'bbyam',
    'bbyab',
    'bbyabs',
    'bbyas',
    'bbyass',
    'bbyang',
    'bbyaj',
    'bbyac',
    'bbyak',
    'bbyat',
    'bbyap',
    'bbyah',
    'bbyae',
    'bbyaeg',
    'bbyaegg',
    'bbyaegs',
    'bbyaen',
    'bbyaenj',
    'bbyaenh',
    'bbyaed',
    'bbyael',
    'bbyaelg',
    'bbyaelm',
    'bbyaelb',
    'bbyaels',
    'bbyaelt',
    'bbyaelp',
    'bbyaelh',
    'bbyaem',
    'bbyaeb',
    'bbyaebs',
    'bbyaes',
    'bbyaess',
    'bbyaeng',
    'bbyaej',
    'bbyaec',
    'bbyaek',
    'bbyaet',
    'bbyaep',
    'bbyaeh',
    'bbeo',
    'bbeog',
    'bbeogg',
    'bbeogs',
    'bbeon',
    'bbeonj',
    'bbeonh',
    'bbeod',
    'bbeol',
    'bbeolg',
    'bbeolm',
    'bbeolb',
    'bbeols',
    'bbeolt',
    'bbeolp',
    'bbeolh',
    'bbeom',
    'bbeob',
    'bbeobs',
    'bbeos',
    'bbeoss',
    'bbeong',
    'bbeoj',
    'bbeoc',
    'bbeok',
    'bbeot',
    'bbeop',
    'bbeoh',
    'bbe',
    'bbeg',
    'bbegg',
    'bbegs',
    'bben',
    'bbenj',
    'bbenh',
    'bbed',
    'bbel',
    'bbelg',
    'bbelm',
    'bbelb',
    'bbels',
    'bbelt',
    'bbelp',
    'bbelh',
    'bbem',
    'bbeb',
    'bbebs',
    'bbes'
];

},{}],"fdd2h":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:39 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'bbess',
    'bbeng',
    'bbej',
    'bbec',
    'bbek',
    'bbet',
    'bbep',
    'bbeh',
    'bbyeo',
    'bbyeog',
    'bbyeogg',
    'bbyeogs',
    'bbyeon',
    'bbyeonj',
    'bbyeonh',
    'bbyeod',
    'bbyeol',
    'bbyeolg',
    'bbyeolm',
    'bbyeolb',
    'bbyeols',
    'bbyeolt',
    'bbyeolp',
    'bbyeolh',
    'bbyeom',
    'bbyeob',
    'bbyeobs',
    'bbyeos',
    'bbyeoss',
    'bbyeong',
    'bbyeoj',
    'bbyeoc',
    'bbyeok',
    'bbyeot',
    'bbyeop',
    'bbyeoh',
    'bbye',
    'bbyeg',
    'bbyegg',
    'bbyegs',
    'bbyen',
    'bbyenj',
    'bbyenh',
    'bbyed',
    'bbyel',
    'bbyelg',
    'bbyelm',
    'bbyelb',
    'bbyels',
    'bbyelt',
    'bbyelp',
    'bbyelh',
    'bbyem',
    'bbyeb',
    'bbyebs',
    'bbyes',
    'bbyess',
    'bbyeng',
    'bbyej',
    'bbyec',
    'bbyek',
    'bbyet',
    'bbyep',
    'bbyeh',
    'bbo',
    'bbog',
    'bbogg',
    'bbogs',
    'bbon',
    'bbonj',
    'bbonh',
    'bbod',
    'bbol',
    'bbolg',
    'bbolm',
    'bbolb',
    'bbols',
    'bbolt',
    'bbolp',
    'bbolh',
    'bbom',
    'bbob',
    'bbobs',
    'bbos',
    'bboss',
    'bbong',
    'bboj',
    'bboc',
    'bbok',
    'bbot',
    'bbop',
    'bboh',
    'bbwa',
    'bbwag',
    'bbwagg',
    'bbwags',
    'bbwan',
    'bbwanj',
    'bbwanh',
    'bbwad',
    'bbwal',
    'bbwalg',
    'bbwalm',
    'bbwalb',
    'bbwals',
    'bbwalt',
    'bbwalp',
    'bbwalh',
    'bbwam',
    'bbwab',
    'bbwabs',
    'bbwas',
    'bbwass',
    'bbwang',
    'bbwaj',
    'bbwac',
    'bbwak',
    'bbwat',
    'bbwap',
    'bbwah',
    'bbwae',
    'bbwaeg',
    'bbwaegg',
    'bbwaegs',
    'bbwaen',
    'bbwaenj',
    'bbwaenh',
    'bbwaed',
    'bbwael',
    'bbwaelg',
    'bbwaelm',
    'bbwaelb',
    'bbwaels',
    'bbwaelt',
    'bbwaelp',
    'bbwaelh',
    'bbwaem',
    'bbwaeb',
    'bbwaebs',
    'bbwaes',
    'bbwaess',
    'bbwaeng',
    'bbwaej',
    'bbwaec',
    'bbwaek',
    'bbwaet',
    'bbwaep',
    'bbwaeh',
    'bboe',
    'bboeg',
    'bboegg',
    'bboegs',
    'bboen',
    'bboenj',
    'bboenh',
    'bboed',
    'bboel',
    'bboelg',
    'bboelm',
    'bboelb',
    'bboels',
    'bboelt',
    'bboelp',
    'bboelh',
    'bboem',
    'bboeb',
    'bboebs',
    'bboes',
    'bboess',
    'bboeng',
    'bboej',
    'bboec',
    'bboek',
    'bboet',
    'bboep',
    'bboeh',
    'bbyo',
    'bbyog',
    'bbyogg',
    'bbyogs',
    'bbyon',
    'bbyonj',
    'bbyonh',
    'bbyod',
    'bbyol',
    'bbyolg',
    'bbyolm',
    'bbyolb',
    'bbyols',
    'bbyolt',
    'bbyolp',
    'bbyolh',
    'bbyom',
    'bbyob',
    'bbyobs',
    'bbyos',
    'bbyoss',
    'bbyong',
    'bbyoj',
    'bbyoc',
    'bbyok',
    'bbyot',
    'bbyop',
    'bbyoh',
    'bbu',
    'bbug',
    'bbugg',
    'bbugs',
    'bbun',
    'bbunj',
    'bbunh',
    'bbud',
    'bbul',
    'bbulg',
    'bbulm',
    'bbulb',
    'bbuls',
    'bbult',
    'bbulp',
    'bbulh',
    'bbum',
    'bbub',
    'bbubs',
    'bbus',
    'bbuss',
    'bbung',
    'bbuj',
    'bbuc',
    'bbuk',
    'bbut',
    'bbup',
    'bbuh',
    'bbweo',
    'bbweog',
    'bbweogg',
    'bbweogs',
    'bbweon',
    'bbweonj',
    'bbweonh',
    'bbweod',
    'bbweol',
    'bbweolg',
    'bbweolm',
    'bbweolb',
    'bbweols',
    'bbweolt',
    'bbweolp',
    'bbweolh',
    'bbweom',
    'bbweob',
    'bbweobs',
    'bbweos',
    'bbweoss',
    'bbweong',
    'bbweoj',
    'bbweoc'
];

},{}],"js4IM":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:39 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'bbweok',
    'bbweot',
    'bbweop',
    'bbweoh',
    'bbwe',
    'bbweg',
    'bbwegg',
    'bbwegs',
    'bbwen',
    'bbwenj',
    'bbwenh',
    'bbwed',
    'bbwel',
    'bbwelg',
    'bbwelm',
    'bbwelb',
    'bbwels',
    'bbwelt',
    'bbwelp',
    'bbwelh',
    'bbwem',
    'bbweb',
    'bbwebs',
    'bbwes',
    'bbwess',
    'bbweng',
    'bbwej',
    'bbwec',
    'bbwek',
    'bbwet',
    'bbwep',
    'bbweh',
    'bbwi',
    'bbwig',
    'bbwigg',
    'bbwigs',
    'bbwin',
    'bbwinj',
    'bbwinh',
    'bbwid',
    'bbwil',
    'bbwilg',
    'bbwilm',
    'bbwilb',
    'bbwils',
    'bbwilt',
    'bbwilp',
    'bbwilh',
    'bbwim',
    'bbwib',
    'bbwibs',
    'bbwis',
    'bbwiss',
    'bbwing',
    'bbwij',
    'bbwic',
    'bbwik',
    'bbwit',
    'bbwip',
    'bbwih',
    'bbyu',
    'bbyug',
    'bbyugg',
    'bbyugs',
    'bbyun',
    'bbyunj',
    'bbyunh',
    'bbyud',
    'bbyul',
    'bbyulg',
    'bbyulm',
    'bbyulb',
    'bbyuls',
    'bbyult',
    'bbyulp',
    'bbyulh',
    'bbyum',
    'bbyub',
    'bbyubs',
    'bbyus',
    'bbyuss',
    'bbyung',
    'bbyuj',
    'bbyuc',
    'bbyuk',
    'bbyut',
    'bbyup',
    'bbyuh',
    'bbeu',
    'bbeug',
    'bbeugg',
    'bbeugs',
    'bbeun',
    'bbeunj',
    'bbeunh',
    'bbeud',
    'bbeul',
    'bbeulg',
    'bbeulm',
    'bbeulb',
    'bbeuls',
    'bbeult',
    'bbeulp',
    'bbeulh',
    'bbeum',
    'bbeub',
    'bbeubs',
    'bbeus',
    'bbeuss',
    'bbeung',
    'bbeuj',
    'bbeuc',
    'bbeuk',
    'bbeut',
    'bbeup',
    'bbeuh',
    'bbyi',
    'bbyig',
    'bbyigg',
    'bbyigs',
    'bbyin',
    'bbyinj',
    'bbyinh',
    'bbyid',
    'bbyil',
    'bbyilg',
    'bbyilm',
    'bbyilb',
    'bbyils',
    'bbyilt',
    'bbyilp',
    'bbyilh',
    'bbyim',
    'bbyib',
    'bbyibs',
    'bbyis',
    'bbyiss',
    'bbying',
    'bbyij',
    'bbyic',
    'bbyik',
    'bbyit',
    'bbyip',
    'bbyih',
    'bbi',
    'bbig',
    'bbigg',
    'bbigs',
    'bbin',
    'bbinj',
    'bbinh',
    'bbid',
    'bbil',
    'bbilg',
    'bbilm',
    'bbilb',
    'bbils',
    'bbilt',
    'bbilp',
    'bbilh',
    'bbim',
    'bbib',
    'bbibs',
    'bbis',
    'bbiss',
    'bbing',
    'bbij',
    'bbic',
    'bbik',
    'bbit',
    'bbip',
    'bbih',
    'sa',
    'sag',
    'sagg',
    'sags',
    'san',
    'sanj',
    'sanh',
    'sad',
    'sal',
    'salg',
    'salm',
    'salb',
    'sals',
    'salt',
    'salp',
    'salh',
    'sam',
    'sab',
    'sabs',
    'sas',
    'sass',
    'sang',
    'saj',
    'sac',
    'sak',
    'sat',
    'sap',
    'sah',
    'sae',
    'saeg',
    'saegg',
    'saegs',
    'saen',
    'saenj',
    'saenh',
    'saed',
    'sael',
    'saelg',
    'saelm',
    'saelb',
    'saels',
    'saelt',
    'saelp',
    'saelh',
    'saem',
    'saeb',
    'saebs',
    'saes',
    'saess',
    'saeng',
    'saej',
    'saec',
    'saek',
    'saet',
    'saep',
    'saeh',
    'sya',
    'syag',
    'syagg',
    'syags',
    'syan',
    'syanj',
    'syanh',
    'syad',
    'syal',
    'syalg',
    'syalm',
    'syalb',
    'syals',
    'syalt',
    'syalp',
    'syalh',
    'syam',
    'syab',
    'syabs',
    'syas',
    'syass',
    'syang',
    'syaj',
    'syac',
    'syak',
    'syat',
    'syap',
    'syah'
];

},{}],"dun76":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:40 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'syae',
    'syaeg',
    'syaegg',
    'syaegs',
    'syaen',
    'syaenj',
    'syaenh',
    'syaed',
    'syael',
    'syaelg',
    'syaelm',
    'syaelb',
    'syaels',
    'syaelt',
    'syaelp',
    'syaelh',
    'syaem',
    'syaeb',
    'syaebs',
    'syaes',
    'syaess',
    'syaeng',
    'syaej',
    'syaec',
    'syaek',
    'syaet',
    'syaep',
    'syaeh',
    'seo',
    'seog',
    'seogg',
    'seogs',
    'seon',
    'seonj',
    'seonh',
    'seod',
    'seol',
    'seolg',
    'seolm',
    'seolb',
    'seols',
    'seolt',
    'seolp',
    'seolh',
    'seom',
    'seob',
    'seobs',
    'seos',
    'seoss',
    'seong',
    'seoj',
    'seoc',
    'seok',
    'seot',
    'seop',
    'seoh',
    'se',
    'seg',
    'segg',
    'segs',
    'sen',
    'senj',
    'senh',
    'sed',
    'sel',
    'selg',
    'selm',
    'selb',
    'sels',
    'selt',
    'selp',
    'selh',
    'sem',
    'seb',
    'sebs',
    'ses',
    'sess',
    'seng',
    'sej',
    'sec',
    'sek',
    'set',
    'sep',
    'seh',
    'syeo',
    'syeog',
    'syeogg',
    'syeogs',
    'syeon',
    'syeonj',
    'syeonh',
    'syeod',
    'syeol',
    'syeolg',
    'syeolm',
    'syeolb',
    'syeols',
    'syeolt',
    'syeolp',
    'syeolh',
    'syeom',
    'syeob',
    'syeobs',
    'syeos',
    'syeoss',
    'syeong',
    'syeoj',
    'syeoc',
    'syeok',
    'syeot',
    'syeop',
    'syeoh',
    'sye',
    'syeg',
    'syegg',
    'syegs',
    'syen',
    'syenj',
    'syenh',
    'syed',
    'syel',
    'syelg',
    'syelm',
    'syelb',
    'syels',
    'syelt',
    'syelp',
    'syelh',
    'syem',
    'syeb',
    'syebs',
    'syes',
    'syess',
    'syeng',
    'syej',
    'syec',
    'syek',
    'syet',
    'syep',
    'syeh',
    'so',
    'sog',
    'sogg',
    'sogs',
    'son',
    'sonj',
    'sonh',
    'sod',
    'sol',
    'solg',
    'solm',
    'solb',
    'sols',
    'solt',
    'solp',
    'solh',
    'som',
    'sob',
    'sobs',
    'sos',
    'soss',
    'song',
    'soj',
    'soc',
    'sok',
    'sot',
    'sop',
    'soh',
    'swa',
    'swag',
    'swagg',
    'swags',
    'swan',
    'swanj',
    'swanh',
    'swad',
    'swal',
    'swalg',
    'swalm',
    'swalb',
    'swals',
    'swalt',
    'swalp',
    'swalh',
    'swam',
    'swab',
    'swabs',
    'swas',
    'swass',
    'swang',
    'swaj',
    'swac',
    'swak',
    'swat',
    'swap',
    'swah',
    'swae',
    'swaeg',
    'swaegg',
    'swaegs',
    'swaen',
    'swaenj',
    'swaenh',
    'swaed',
    'swael',
    'swaelg',
    'swaelm',
    'swaelb',
    'swaels',
    'swaelt',
    'swaelp',
    'swaelh',
    'swaem',
    'swaeb',
    'swaebs',
    'swaes',
    'swaess',
    'swaeng',
    'swaej',
    'swaec',
    'swaek',
    'swaet',
    'swaep',
    'swaeh',
    'soe',
    'soeg',
    'soegg',
    'soegs',
    'soen',
    'soenj',
    'soenh',
    'soed',
    'soel',
    'soelg',
    'soelm',
    'soelb',
    'soels',
    'soelt',
    'soelp',
    'soelh',
    'soem',
    'soeb',
    'soebs',
    'soes',
    'soess',
    'soeng',
    'soej',
    'soec',
    'soek',
    'soet',
    'soep',
    'soeh',
    'syo',
    'syog',
    'syogg',
    'syogs'
];

},{}],"7kVjE":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:40 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'syon',
    'syonj',
    'syonh',
    'syod',
    'syol',
    'syolg',
    'syolm',
    'syolb',
    'syols',
    'syolt',
    'syolp',
    'syolh',
    'syom',
    'syob',
    'syobs',
    'syos',
    'syoss',
    'syong',
    'syoj',
    'syoc',
    'syok',
    'syot',
    'syop',
    'syoh',
    'su',
    'sug',
    'sugg',
    'sugs',
    'sun',
    'sunj',
    'sunh',
    'sud',
    'sul',
    'sulg',
    'sulm',
    'sulb',
    'suls',
    'sult',
    'sulp',
    'sulh',
    'sum',
    'sub',
    'subs',
    'sus',
    'suss',
    'sung',
    'suj',
    'suc',
    'suk',
    'sut',
    'sup',
    'suh',
    'sweo',
    'sweog',
    'sweogg',
    'sweogs',
    'sweon',
    'sweonj',
    'sweonh',
    'sweod',
    'sweol',
    'sweolg',
    'sweolm',
    'sweolb',
    'sweols',
    'sweolt',
    'sweolp',
    'sweolh',
    'sweom',
    'sweob',
    'sweobs',
    'sweos',
    'sweoss',
    'sweong',
    'sweoj',
    'sweoc',
    'sweok',
    'sweot',
    'sweop',
    'sweoh',
    'swe',
    'sweg',
    'swegg',
    'swegs',
    'swen',
    'swenj',
    'swenh',
    'swed',
    'swel',
    'swelg',
    'swelm',
    'swelb',
    'swels',
    'swelt',
    'swelp',
    'swelh',
    'swem',
    'sweb',
    'swebs',
    'swes',
    'swess',
    'sweng',
    'swej',
    'swec',
    'swek',
    'swet',
    'swep',
    'sweh',
    'swi',
    'swig',
    'swigg',
    'swigs',
    'swin',
    'swinj',
    'swinh',
    'swid',
    'swil',
    'swilg',
    'swilm',
    'swilb',
    'swils',
    'swilt',
    'swilp',
    'swilh',
    'swim',
    'swib',
    'swibs',
    'swis',
    'swiss',
    'swing',
    'swij',
    'swic',
    'swik',
    'swit',
    'swip',
    'swih',
    'syu',
    'syug',
    'syugg',
    'syugs',
    'syun',
    'syunj',
    'syunh',
    'syud',
    'syul',
    'syulg',
    'syulm',
    'syulb',
    'syuls',
    'syult',
    'syulp',
    'syulh',
    'syum',
    'syub',
    'syubs',
    'syus',
    'syuss',
    'syung',
    'syuj',
    'syuc',
    'syuk',
    'syut',
    'syup',
    'syuh',
    'seu',
    'seug',
    'seugg',
    'seugs',
    'seun',
    'seunj',
    'seunh',
    'seud',
    'seul',
    'seulg',
    'seulm',
    'seulb',
    'seuls',
    'seult',
    'seulp',
    'seulh',
    'seum',
    'seub',
    'seubs',
    'seus',
    'seuss',
    'seung',
    'seuj',
    'seuc',
    'seuk',
    'seut',
    'seup',
    'seuh',
    'syi',
    'syig',
    'syigg',
    'syigs',
    'syin',
    'syinj',
    'syinh',
    'syid',
    'syil',
    'syilg',
    'syilm',
    'syilb',
    'syils',
    'syilt',
    'syilp',
    'syilh',
    'syim',
    'syib',
    'syibs',
    'syis',
    'syiss',
    'sying',
    'syij',
    'syic',
    'syik',
    'syit',
    'syip',
    'syih',
    'si',
    'sig',
    'sigg',
    'sigs',
    'sin',
    'sinj',
    'sinh',
    'sid',
    'sil',
    'silg',
    'silm',
    'silb',
    'sils',
    'silt',
    'silp',
    'silh',
    'sim',
    'sib',
    'sibs',
    'sis',
    'siss',
    'sing',
    'sij',
    'sic',
    'sik',
    'sit',
    'sip',
    'sih',
    'ssa',
    'ssag',
    'ssagg',
    'ssags',
    'ssan',
    'ssanj',
    'ssanh',
    'ssad'
];

},{}],"bLHI7":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:40 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'ssal',
    'ssalg',
    'ssalm',
    'ssalb',
    'ssals',
    'ssalt',
    'ssalp',
    'ssalh',
    'ssam',
    'ssab',
    'ssabs',
    'ssas',
    'ssass',
    'ssang',
    'ssaj',
    'ssac',
    'ssak',
    'ssat',
    'ssap',
    'ssah',
    'ssae',
    'ssaeg',
    'ssaegg',
    'ssaegs',
    'ssaen',
    'ssaenj',
    'ssaenh',
    'ssaed',
    'ssael',
    'ssaelg',
    'ssaelm',
    'ssaelb',
    'ssaels',
    'ssaelt',
    'ssaelp',
    'ssaelh',
    'ssaem',
    'ssaeb',
    'ssaebs',
    'ssaes',
    'ssaess',
    'ssaeng',
    'ssaej',
    'ssaec',
    'ssaek',
    'ssaet',
    'ssaep',
    'ssaeh',
    'ssya',
    'ssyag',
    'ssyagg',
    'ssyags',
    'ssyan',
    'ssyanj',
    'ssyanh',
    'ssyad',
    'ssyal',
    'ssyalg',
    'ssyalm',
    'ssyalb',
    'ssyals',
    'ssyalt',
    'ssyalp',
    'ssyalh',
    'ssyam',
    'ssyab',
    'ssyabs',
    'ssyas',
    'ssyass',
    'ssyang',
    'ssyaj',
    'ssyac',
    'ssyak',
    'ssyat',
    'ssyap',
    'ssyah',
    'ssyae',
    'ssyaeg',
    'ssyaegg',
    'ssyaegs',
    'ssyaen',
    'ssyaenj',
    'ssyaenh',
    'ssyaed',
    'ssyael',
    'ssyaelg',
    'ssyaelm',
    'ssyaelb',
    'ssyaels',
    'ssyaelt',
    'ssyaelp',
    'ssyaelh',
    'ssyaem',
    'ssyaeb',
    'ssyaebs',
    'ssyaes',
    'ssyaess',
    'ssyaeng',
    'ssyaej',
    'ssyaec',
    'ssyaek',
    'ssyaet',
    'ssyaep',
    'ssyaeh',
    'sseo',
    'sseog',
    'sseogg',
    'sseogs',
    'sseon',
    'sseonj',
    'sseonh',
    'sseod',
    'sseol',
    'sseolg',
    'sseolm',
    'sseolb',
    'sseols',
    'sseolt',
    'sseolp',
    'sseolh',
    'sseom',
    'sseob',
    'sseobs',
    'sseos',
    'sseoss',
    'sseong',
    'sseoj',
    'sseoc',
    'sseok',
    'sseot',
    'sseop',
    'sseoh',
    'sse',
    'sseg',
    'ssegg',
    'ssegs',
    'ssen',
    'ssenj',
    'ssenh',
    'ssed',
    'ssel',
    'sselg',
    'sselm',
    'sselb',
    'ssels',
    'sselt',
    'sselp',
    'sselh',
    'ssem',
    'sseb',
    'ssebs',
    'sses',
    'ssess',
    'sseng',
    'ssej',
    'ssec',
    'ssek',
    'sset',
    'ssep',
    'sseh',
    'ssyeo',
    'ssyeog',
    'ssyeogg',
    'ssyeogs',
    'ssyeon',
    'ssyeonj',
    'ssyeonh',
    'ssyeod',
    'ssyeol',
    'ssyeolg',
    'ssyeolm',
    'ssyeolb',
    'ssyeols',
    'ssyeolt',
    'ssyeolp',
    'ssyeolh',
    'ssyeom',
    'ssyeob',
    'ssyeobs',
    'ssyeos',
    'ssyeoss',
    'ssyeong',
    'ssyeoj',
    'ssyeoc',
    'ssyeok',
    'ssyeot',
    'ssyeop',
    'ssyeoh',
    'ssye',
    'ssyeg',
    'ssyegg',
    'ssyegs',
    'ssyen',
    'ssyenj',
    'ssyenh',
    'ssyed',
    'ssyel',
    'ssyelg',
    'ssyelm',
    'ssyelb',
    'ssyels',
    'ssyelt',
    'ssyelp',
    'ssyelh',
    'ssyem',
    'ssyeb',
    'ssyebs',
    'ssyes',
    'ssyess',
    'ssyeng',
    'ssyej',
    'ssyec',
    'ssyek',
    'ssyet',
    'ssyep',
    'ssyeh',
    'sso',
    'ssog',
    'ssogg',
    'ssogs',
    'sson',
    'ssonj',
    'ssonh',
    'ssod',
    'ssol',
    'ssolg',
    'ssolm',
    'ssolb',
    'ssols',
    'ssolt',
    'ssolp',
    'ssolh',
    'ssom',
    'ssob',
    'ssobs',
    'ssos',
    'ssoss',
    'ssong',
    'ssoj',
    'ssoc',
    'ssok',
    'ssot',
    'ssop',
    'ssoh',
    'sswa',
    'sswag',
    'sswagg',
    'sswags',
    'sswan',
    'sswanj',
    'sswanh',
    'sswad',
    'sswal',
    'sswalg',
    'sswalm',
    'sswalb'
];

},{}],"9aE1x":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:40 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'sswals',
    'sswalt',
    'sswalp',
    'sswalh',
    'sswam',
    'sswab',
    'sswabs',
    'sswas',
    'sswass',
    'sswang',
    'sswaj',
    'sswac',
    'sswak',
    'sswat',
    'sswap',
    'sswah',
    'sswae',
    'sswaeg',
    'sswaegg',
    'sswaegs',
    'sswaen',
    'sswaenj',
    'sswaenh',
    'sswaed',
    'sswael',
    'sswaelg',
    'sswaelm',
    'sswaelb',
    'sswaels',
    'sswaelt',
    'sswaelp',
    'sswaelh',
    'sswaem',
    'sswaeb',
    'sswaebs',
    'sswaes',
    'sswaess',
    'sswaeng',
    'sswaej',
    'sswaec',
    'sswaek',
    'sswaet',
    'sswaep',
    'sswaeh',
    'ssoe',
    'ssoeg',
    'ssoegg',
    'ssoegs',
    'ssoen',
    'ssoenj',
    'ssoenh',
    'ssoed',
    'ssoel',
    'ssoelg',
    'ssoelm',
    'ssoelb',
    'ssoels',
    'ssoelt',
    'ssoelp',
    'ssoelh',
    'ssoem',
    'ssoeb',
    'ssoebs',
    'ssoes',
    'ssoess',
    'ssoeng',
    'ssoej',
    'ssoec',
    'ssoek',
    'ssoet',
    'ssoep',
    'ssoeh',
    'ssyo',
    'ssyog',
    'ssyogg',
    'ssyogs',
    'ssyon',
    'ssyonj',
    'ssyonh',
    'ssyod',
    'ssyol',
    'ssyolg',
    'ssyolm',
    'ssyolb',
    'ssyols',
    'ssyolt',
    'ssyolp',
    'ssyolh',
    'ssyom',
    'ssyob',
    'ssyobs',
    'ssyos',
    'ssyoss',
    'ssyong',
    'ssyoj',
    'ssyoc',
    'ssyok',
    'ssyot',
    'ssyop',
    'ssyoh',
    'ssu',
    'ssug',
    'ssugg',
    'ssugs',
    'ssun',
    'ssunj',
    'ssunh',
    'ssud',
    'ssul',
    'ssulg',
    'ssulm',
    'ssulb',
    'ssuls',
    'ssult',
    'ssulp',
    'ssulh',
    'ssum',
    'ssub',
    'ssubs',
    'ssus',
    'ssuss',
    'ssung',
    'ssuj',
    'ssuc',
    'ssuk',
    'ssut',
    'ssup',
    'ssuh',
    'ssweo',
    'ssweog',
    'ssweogg',
    'ssweogs',
    'ssweon',
    'ssweonj',
    'ssweonh',
    'ssweod',
    'ssweol',
    'ssweolg',
    'ssweolm',
    'ssweolb',
    'ssweols',
    'ssweolt',
    'ssweolp',
    'ssweolh',
    'ssweom',
    'ssweob',
    'ssweobs',
    'ssweos',
    'ssweoss',
    'ssweong',
    'ssweoj',
    'ssweoc',
    'ssweok',
    'ssweot',
    'ssweop',
    'ssweoh',
    'sswe',
    'ssweg',
    'sswegg',
    'sswegs',
    'sswen',
    'sswenj',
    'sswenh',
    'sswed',
    'sswel',
    'sswelg',
    'sswelm',
    'sswelb',
    'sswels',
    'sswelt',
    'sswelp',
    'sswelh',
    'sswem',
    'ssweb',
    'sswebs',
    'sswes',
    'sswess',
    'ssweng',
    'sswej',
    'sswec',
    'sswek',
    'sswet',
    'sswep',
    'ssweh',
    'sswi',
    'sswig',
    'sswigg',
    'sswigs',
    'sswin',
    'sswinj',
    'sswinh',
    'sswid',
    'sswil',
    'sswilg',
    'sswilm',
    'sswilb',
    'sswils',
    'sswilt',
    'sswilp',
    'sswilh',
    'sswim',
    'sswib',
    'sswibs',
    'sswis',
    'sswiss',
    'sswing',
    'sswij',
    'sswic',
    'sswik',
    'sswit',
    'sswip',
    'sswih',
    'ssyu',
    'ssyug',
    'ssyugg',
    'ssyugs',
    'ssyun',
    'ssyunj',
    'ssyunh',
    'ssyud',
    'ssyul',
    'ssyulg',
    'ssyulm',
    'ssyulb',
    'ssyuls',
    'ssyult',
    'ssyulp',
    'ssyulh',
    'ssyum',
    'ssyub',
    'ssyubs',
    'ssyus',
    'ssyuss',
    'ssyung',
    'ssyuj',
    'ssyuc',
    'ssyuk',
    'ssyut',
    'ssyup',
    'ssyuh',
    'sseu',
    'sseug',
    'sseugg',
    'sseugs',
    'sseun',
    'sseunj',
    'sseunh',
    'sseud',
    'sseul',
    'sseulg',
    'sseulm',
    'sseulb',
    'sseuls',
    'sseult',
    'sseulp',
    'sseulh'
];

},{}],"7pzXW":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:40 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'sseum',
    'sseub',
    'sseubs',
    'sseus',
    'sseuss',
    'sseung',
    'sseuj',
    'sseuc',
    'sseuk',
    'sseut',
    'sseup',
    'sseuh',
    'ssyi',
    'ssyig',
    'ssyigg',
    'ssyigs',
    'ssyin',
    'ssyinj',
    'ssyinh',
    'ssyid',
    'ssyil',
    'ssyilg',
    'ssyilm',
    'ssyilb',
    'ssyils',
    'ssyilt',
    'ssyilp',
    'ssyilh',
    'ssyim',
    'ssyib',
    'ssyibs',
    'ssyis',
    'ssyiss',
    'ssying',
    'ssyij',
    'ssyic',
    'ssyik',
    'ssyit',
    'ssyip',
    'ssyih',
    'ssi',
    'ssig',
    'ssigg',
    'ssigs',
    'ssin',
    'ssinj',
    'ssinh',
    'ssid',
    'ssil',
    'ssilg',
    'ssilm',
    'ssilb',
    'ssils',
    'ssilt',
    'ssilp',
    'ssilh',
    'ssim',
    'ssib',
    'ssibs',
    'ssis',
    'ssiss',
    'ssing',
    'ssij',
    'ssic',
    'ssik',
    'ssit',
    'ssip',
    'ssih',
    'a',
    'ag',
    'agg',
    'ags',
    'an',
    'anj',
    'anh',
    'ad',
    'al',
    'alg',
    'alm',
    'alb',
    'als',
    'alt',
    'alp',
    'alh',
    'am',
    'ab',
    'abs',
    'as',
    'ass',
    'ang',
    'aj',
    'ac',
    'ak',
    'at',
    'ap',
    'ah',
    'ae',
    'aeg',
    'aegg',
    'aegs',
    'aen',
    'aenj',
    'aenh',
    'aed',
    'ael',
    'aelg',
    'aelm',
    'aelb',
    'aels',
    'aelt',
    'aelp',
    'aelh',
    'aem',
    'aeb',
    'aebs',
    'aes',
    'aess',
    'aeng',
    'aej',
    'aec',
    'aek',
    'aet',
    'aep',
    'aeh',
    'ya',
    'yag',
    'yagg',
    'yags',
    'yan',
    'yanj',
    'yanh',
    'yad',
    'yal',
    'yalg',
    'yalm',
    'yalb',
    'yals',
    'yalt',
    'yalp',
    'yalh',
    'yam',
    'yab',
    'yabs',
    'yas',
    'yass',
    'yang',
    'yaj',
    'yac',
    'yak',
    'yat',
    'yap',
    'yah',
    'yae',
    'yaeg',
    'yaegg',
    'yaegs',
    'yaen',
    'yaenj',
    'yaenh',
    'yaed',
    'yael',
    'yaelg',
    'yaelm',
    'yaelb',
    'yaels',
    'yaelt',
    'yaelp',
    'yaelh',
    'yaem',
    'yaeb',
    'yaebs',
    'yaes',
    'yaess',
    'yaeng',
    'yaej',
    'yaec',
    'yaek',
    'yaet',
    'yaep',
    'yaeh',
    'eo',
    'eog',
    'eogg',
    'eogs',
    'eon',
    'eonj',
    'eonh',
    'eod',
    'eol',
    'eolg',
    'eolm',
    'eolb',
    'eols',
    'eolt',
    'eolp',
    'eolh',
    'eom',
    'eob',
    'eobs',
    'eos',
    'eoss',
    'eong',
    'eoj',
    'eoc',
    'eok',
    'eot',
    'eop',
    'eoh',
    'e',
    'eg',
    'egg',
    'egs',
    'en',
    'enj',
    'enh',
    'ed',
    'el',
    'elg',
    'elm',
    'elb',
    'els',
    'elt',
    'elp',
    'elh',
    'em',
    'eb',
    'ebs',
    'es',
    'ess',
    'eng',
    'ej',
    'ec',
    'ek',
    'et',
    'ep',
    'eh',
    'yeo',
    'yeog',
    'yeogg',
    'yeogs',
    'yeon',
    'yeonj',
    'yeonh',
    'yeod',
    'yeol',
    'yeolg',
    'yeolm',
    'yeolb',
    'yeols',
    'yeolt',
    'yeolp',
    'yeolh',
    'yeom',
    'yeob',
    'yeobs',
    'yeos'
];

},{}],"b95vI":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:40 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'yeoss',
    'yeong',
    'yeoj',
    'yeoc',
    'yeok',
    'yeot',
    'yeop',
    'yeoh',
    'ye',
    'yeg',
    'yegg',
    'yegs',
    'yen',
    'yenj',
    'yenh',
    'yed',
    'yel',
    'yelg',
    'yelm',
    'yelb',
    'yels',
    'yelt',
    'yelp',
    'yelh',
    'yem',
    'yeb',
    'yebs',
    'yes',
    'yess',
    'yeng',
    'yej',
    'yec',
    'yek',
    'yet',
    'yep',
    'yeh',
    'o',
    'og',
    'ogg',
    'ogs',
    'on',
    'onj',
    'onh',
    'od',
    'ol',
    'olg',
    'olm',
    'olb',
    'ols',
    'olt',
    'olp',
    'olh',
    'om',
    'ob',
    'obs',
    'os',
    'oss',
    'ong',
    'oj',
    'oc',
    'ok',
    'ot',
    'op',
    'oh',
    'wa',
    'wag',
    'wagg',
    'wags',
    'wan',
    'wanj',
    'wanh',
    'wad',
    'wal',
    'walg',
    'walm',
    'walb',
    'wals',
    'walt',
    'walp',
    'walh',
    'wam',
    'wab',
    'wabs',
    'was',
    'wass',
    'wang',
    'waj',
    'wac',
    'wak',
    'wat',
    'wap',
    'wah',
    'wae',
    'waeg',
    'waegg',
    'waegs',
    'waen',
    'waenj',
    'waenh',
    'waed',
    'wael',
    'waelg',
    'waelm',
    'waelb',
    'waels',
    'waelt',
    'waelp',
    'waelh',
    'waem',
    'waeb',
    'waebs',
    'waes',
    'waess',
    'waeng',
    'waej',
    'waec',
    'waek',
    'waet',
    'waep',
    'waeh',
    'oe',
    'oeg',
    'oegg',
    'oegs',
    'oen',
    'oenj',
    'oenh',
    'oed',
    'oel',
    'oelg',
    'oelm',
    'oelb',
    'oels',
    'oelt',
    'oelp',
    'oelh',
    'oem',
    'oeb',
    'oebs',
    'oes',
    'oess',
    'oeng',
    'oej',
    'oec',
    'oek',
    'oet',
    'oep',
    'oeh',
    'yo',
    'yog',
    'yogg',
    'yogs',
    'yon',
    'yonj',
    'yonh',
    'yod',
    'yol',
    'yolg',
    'yolm',
    'yolb',
    'yols',
    'yolt',
    'yolp',
    'yolh',
    'yom',
    'yob',
    'yobs',
    'yos',
    'yoss',
    'yong',
    'yoj',
    'yoc',
    'yok',
    'yot',
    'yop',
    'yoh',
    'u',
    'ug',
    'ugg',
    'ugs',
    'un',
    'unj',
    'unh',
    'ud',
    'ul',
    'ulg',
    'ulm',
    'ulb',
    'uls',
    'ult',
    'ulp',
    'ulh',
    'um',
    'ub',
    'ubs',
    'us',
    'uss',
    'ung',
    'uj',
    'uc',
    'uk',
    'ut',
    'up',
    'uh',
    'weo',
    'weog',
    'weogg',
    'weogs',
    'weon',
    'weonj',
    'weonh',
    'weod',
    'weol',
    'weolg',
    'weolm',
    'weolb',
    'weols',
    'weolt',
    'weolp',
    'weolh',
    'weom',
    'weob',
    'weobs',
    'weos',
    'weoss',
    'weong',
    'weoj',
    'weoc',
    'weok',
    'weot',
    'weop',
    'weoh',
    'we',
    'weg',
    'wegg',
    'wegs',
    'wen',
    'wenj',
    'wenh',
    'wed',
    'wel',
    'welg',
    'welm',
    'welb',
    'wels',
    'welt',
    'welp',
    'welh',
    'wem',
    'web',
    'webs',
    'wes',
    'wess',
    'weng',
    'wej',
    'wec'
];

},{}],"LJSEa":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:41 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'wek',
    'wet',
    'wep',
    'weh',
    'wi',
    'wig',
    'wigg',
    'wigs',
    'win',
    'winj',
    'winh',
    'wid',
    'wil',
    'wilg',
    'wilm',
    'wilb',
    'wils',
    'wilt',
    'wilp',
    'wilh',
    'wim',
    'wib',
    'wibs',
    'wis',
    'wiss',
    'wing',
    'wij',
    'wic',
    'wik',
    'wit',
    'wip',
    'wih',
    'yu',
    'yug',
    'yugg',
    'yugs',
    'yun',
    'yunj',
    'yunh',
    'yud',
    'yul',
    'yulg',
    'yulm',
    'yulb',
    'yuls',
    'yult',
    'yulp',
    'yulh',
    'yum',
    'yub',
    'yubs',
    'yus',
    'yuss',
    'yung',
    'yuj',
    'yuc',
    'yuk',
    'yut',
    'yup',
    'yuh',
    'eu',
    'eug',
    'eugg',
    'eugs',
    'eun',
    'eunj',
    'eunh',
    'eud',
    'eul',
    'eulg',
    'eulm',
    'eulb',
    'euls',
    'eult',
    'eulp',
    'eulh',
    'eum',
    'eub',
    'eubs',
    'eus',
    'euss',
    'eung',
    'euj',
    'euc',
    'euk',
    'eut',
    'eup',
    'euh',
    'yi',
    'yig',
    'yigg',
    'yigs',
    'yin',
    'yinj',
    'yinh',
    'yid',
    'yil',
    'yilg',
    'yilm',
    'yilb',
    'yils',
    'yilt',
    'yilp',
    'yilh',
    'yim',
    'yib',
    'yibs',
    'yis',
    'yiss',
    'ying',
    'yij',
    'yic',
    'yik',
    'yit',
    'yip',
    'yih',
    'i',
    'ig',
    'igg',
    'igs',
    'in',
    'inj',
    'inh',
    'id',
    'il',
    'ilg',
    'ilm',
    'ilb',
    'ils',
    'ilt',
    'ilp',
    'ilh',
    'im',
    'ib',
    'ibs',
    'is',
    'iss',
    'ing',
    'ij',
    'ic',
    'ik',
    'it',
    'ip',
    'ih',
    'ja',
    'jag',
    'jagg',
    'jags',
    'jan',
    'janj',
    'janh',
    'jad',
    'jal',
    'jalg',
    'jalm',
    'jalb',
    'jals',
    'jalt',
    'jalp',
    'jalh',
    'jam',
    'jab',
    'jabs',
    'jas',
    'jass',
    'jang',
    'jaj',
    'jac',
    'jak',
    'jat',
    'jap',
    'jah',
    'jae',
    'jaeg',
    'jaegg',
    'jaegs',
    'jaen',
    'jaenj',
    'jaenh',
    'jaed',
    'jael',
    'jaelg',
    'jaelm',
    'jaelb',
    'jaels',
    'jaelt',
    'jaelp',
    'jaelh',
    'jaem',
    'jaeb',
    'jaebs',
    'jaes',
    'jaess',
    'jaeng',
    'jaej',
    'jaec',
    'jaek',
    'jaet',
    'jaep',
    'jaeh',
    'jya',
    'jyag',
    'jyagg',
    'jyags',
    'jyan',
    'jyanj',
    'jyanh',
    'jyad',
    'jyal',
    'jyalg',
    'jyalm',
    'jyalb',
    'jyals',
    'jyalt',
    'jyalp',
    'jyalh',
    'jyam',
    'jyab',
    'jyabs',
    'jyas',
    'jyass',
    'jyang',
    'jyaj',
    'jyac',
    'jyak',
    'jyat',
    'jyap',
    'jyah',
    'jyae',
    'jyaeg',
    'jyaegg',
    'jyaegs',
    'jyaen',
    'jyaenj',
    'jyaenh',
    'jyaed',
    'jyael',
    'jyaelg',
    'jyaelm',
    'jyaelb',
    'jyaels',
    'jyaelt',
    'jyaelp',
    'jyaelh',
    'jyaem',
    'jyaeb',
    'jyaebs',
    'jyaes',
    'jyaess',
    'jyaeng',
    'jyaej',
    'jyaec',
    'jyaek',
    'jyaet',
    'jyaep',
    'jyaeh'
];

},{}],"XytEM":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:41 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'jeo',
    'jeog',
    'jeogg',
    'jeogs',
    'jeon',
    'jeonj',
    'jeonh',
    'jeod',
    'jeol',
    'jeolg',
    'jeolm',
    'jeolb',
    'jeols',
    'jeolt',
    'jeolp',
    'jeolh',
    'jeom',
    'jeob',
    'jeobs',
    'jeos',
    'jeoss',
    'jeong',
    'jeoj',
    'jeoc',
    'jeok',
    'jeot',
    'jeop',
    'jeoh',
    'je',
    'jeg',
    'jegg',
    'jegs',
    'jen',
    'jenj',
    'jenh',
    'jed',
    'jel',
    'jelg',
    'jelm',
    'jelb',
    'jels',
    'jelt',
    'jelp',
    'jelh',
    'jem',
    'jeb',
    'jebs',
    'jes',
    'jess',
    'jeng',
    'jej',
    'jec',
    'jek',
    'jet',
    'jep',
    'jeh',
    'jyeo',
    'jyeog',
    'jyeogg',
    'jyeogs',
    'jyeon',
    'jyeonj',
    'jyeonh',
    'jyeod',
    'jyeol',
    'jyeolg',
    'jyeolm',
    'jyeolb',
    'jyeols',
    'jyeolt',
    'jyeolp',
    'jyeolh',
    'jyeom',
    'jyeob',
    'jyeobs',
    'jyeos',
    'jyeoss',
    'jyeong',
    'jyeoj',
    'jyeoc',
    'jyeok',
    'jyeot',
    'jyeop',
    'jyeoh',
    'jye',
    'jyeg',
    'jyegg',
    'jyegs',
    'jyen',
    'jyenj',
    'jyenh',
    'jyed',
    'jyel',
    'jyelg',
    'jyelm',
    'jyelb',
    'jyels',
    'jyelt',
    'jyelp',
    'jyelh',
    'jyem',
    'jyeb',
    'jyebs',
    'jyes',
    'jyess',
    'jyeng',
    'jyej',
    'jyec',
    'jyek',
    'jyet',
    'jyep',
    'jyeh',
    'jo',
    'jog',
    'jogg',
    'jogs',
    'jon',
    'jonj',
    'jonh',
    'jod',
    'jol',
    'jolg',
    'jolm',
    'jolb',
    'jols',
    'jolt',
    'jolp',
    'jolh',
    'jom',
    'job',
    'jobs',
    'jos',
    'joss',
    'jong',
    'joj',
    'joc',
    'jok',
    'jot',
    'jop',
    'joh',
    'jwa',
    'jwag',
    'jwagg',
    'jwags',
    'jwan',
    'jwanj',
    'jwanh',
    'jwad',
    'jwal',
    'jwalg',
    'jwalm',
    'jwalb',
    'jwals',
    'jwalt',
    'jwalp',
    'jwalh',
    'jwam',
    'jwab',
    'jwabs',
    'jwas',
    'jwass',
    'jwang',
    'jwaj',
    'jwac',
    'jwak',
    'jwat',
    'jwap',
    'jwah',
    'jwae',
    'jwaeg',
    'jwaegg',
    'jwaegs',
    'jwaen',
    'jwaenj',
    'jwaenh',
    'jwaed',
    'jwael',
    'jwaelg',
    'jwaelm',
    'jwaelb',
    'jwaels',
    'jwaelt',
    'jwaelp',
    'jwaelh',
    'jwaem',
    'jwaeb',
    'jwaebs',
    'jwaes',
    'jwaess',
    'jwaeng',
    'jwaej',
    'jwaec',
    'jwaek',
    'jwaet',
    'jwaep',
    'jwaeh',
    'joe',
    'joeg',
    'joegg',
    'joegs',
    'joen',
    'joenj',
    'joenh',
    'joed',
    'joel',
    'joelg',
    'joelm',
    'joelb',
    'joels',
    'joelt',
    'joelp',
    'joelh',
    'joem',
    'joeb',
    'joebs',
    'joes',
    'joess',
    'joeng',
    'joej',
    'joec',
    'joek',
    'joet',
    'joep',
    'joeh',
    'jyo',
    'jyog',
    'jyogg',
    'jyogs',
    'jyon',
    'jyonj',
    'jyonh',
    'jyod',
    'jyol',
    'jyolg',
    'jyolm',
    'jyolb',
    'jyols',
    'jyolt',
    'jyolp',
    'jyolh',
    'jyom',
    'jyob',
    'jyobs',
    'jyos',
    'jyoss',
    'jyong',
    'jyoj',
    'jyoc',
    'jyok',
    'jyot',
    'jyop',
    'jyoh',
    'ju',
    'jug',
    'jugg',
    'jugs'
];

},{}],"4FKys":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:41 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'jun',
    'junj',
    'junh',
    'jud',
    'jul',
    'julg',
    'julm',
    'julb',
    'juls',
    'jult',
    'julp',
    'julh',
    'jum',
    'jub',
    'jubs',
    'jus',
    'juss',
    'jung',
    'juj',
    'juc',
    'juk',
    'jut',
    'jup',
    'juh',
    'jweo',
    'jweog',
    'jweogg',
    'jweogs',
    'jweon',
    'jweonj',
    'jweonh',
    'jweod',
    'jweol',
    'jweolg',
    'jweolm',
    'jweolb',
    'jweols',
    'jweolt',
    'jweolp',
    'jweolh',
    'jweom',
    'jweob',
    'jweobs',
    'jweos',
    'jweoss',
    'jweong',
    'jweoj',
    'jweoc',
    'jweok',
    'jweot',
    'jweop',
    'jweoh',
    'jwe',
    'jweg',
    'jwegg',
    'jwegs',
    'jwen',
    'jwenj',
    'jwenh',
    'jwed',
    'jwel',
    'jwelg',
    'jwelm',
    'jwelb',
    'jwels',
    'jwelt',
    'jwelp',
    'jwelh',
    'jwem',
    'jweb',
    'jwebs',
    'jwes',
    'jwess',
    'jweng',
    'jwej',
    'jwec',
    'jwek',
    'jwet',
    'jwep',
    'jweh',
    'jwi',
    'jwig',
    'jwigg',
    'jwigs',
    'jwin',
    'jwinj',
    'jwinh',
    'jwid',
    'jwil',
    'jwilg',
    'jwilm',
    'jwilb',
    'jwils',
    'jwilt',
    'jwilp',
    'jwilh',
    'jwim',
    'jwib',
    'jwibs',
    'jwis',
    'jwiss',
    'jwing',
    'jwij',
    'jwic',
    'jwik',
    'jwit',
    'jwip',
    'jwih',
    'jyu',
    'jyug',
    'jyugg',
    'jyugs',
    'jyun',
    'jyunj',
    'jyunh',
    'jyud',
    'jyul',
    'jyulg',
    'jyulm',
    'jyulb',
    'jyuls',
    'jyult',
    'jyulp',
    'jyulh',
    'jyum',
    'jyub',
    'jyubs',
    'jyus',
    'jyuss',
    'jyung',
    'jyuj',
    'jyuc',
    'jyuk',
    'jyut',
    'jyup',
    'jyuh',
    'jeu',
    'jeug',
    'jeugg',
    'jeugs',
    'jeun',
    'jeunj',
    'jeunh',
    'jeud',
    'jeul',
    'jeulg',
    'jeulm',
    'jeulb',
    'jeuls',
    'jeult',
    'jeulp',
    'jeulh',
    'jeum',
    'jeub',
    'jeubs',
    'jeus',
    'jeuss',
    'jeung',
    'jeuj',
    'jeuc',
    'jeuk',
    'jeut',
    'jeup',
    'jeuh',
    'jyi',
    'jyig',
    'jyigg',
    'jyigs',
    'jyin',
    'jyinj',
    'jyinh',
    'jyid',
    'jyil',
    'jyilg',
    'jyilm',
    'jyilb',
    'jyils',
    'jyilt',
    'jyilp',
    'jyilh',
    'jyim',
    'jyib',
    'jyibs',
    'jyis',
    'jyiss',
    'jying',
    'jyij',
    'jyic',
    'jyik',
    'jyit',
    'jyip',
    'jyih',
    'ji',
    'jig',
    'jigg',
    'jigs',
    'jin',
    'jinj',
    'jinh',
    'jid',
    'jil',
    'jilg',
    'jilm',
    'jilb',
    'jils',
    'jilt',
    'jilp',
    'jilh',
    'jim',
    'jib',
    'jibs',
    'jis',
    'jiss',
    'jing',
    'jij',
    'jic',
    'jik',
    'jit',
    'jip',
    'jih',
    'jja',
    'jjag',
    'jjagg',
    'jjags',
    'jjan',
    'jjanj',
    'jjanh',
    'jjad',
    'jjal',
    'jjalg',
    'jjalm',
    'jjalb',
    'jjals',
    'jjalt',
    'jjalp',
    'jjalh',
    'jjam',
    'jjab',
    'jjabs',
    'jjas',
    'jjass',
    'jjang',
    'jjaj',
    'jjac',
    'jjak',
    'jjat',
    'jjap',
    'jjah',
    'jjae',
    'jjaeg',
    'jjaegg',
    'jjaegs',
    'jjaen',
    'jjaenj',
    'jjaenh',
    'jjaed'
];

},{}],"giIp0":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:41 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'jjael',
    'jjaelg',
    'jjaelm',
    'jjaelb',
    'jjaels',
    'jjaelt',
    'jjaelp',
    'jjaelh',
    'jjaem',
    'jjaeb',
    'jjaebs',
    'jjaes',
    'jjaess',
    'jjaeng',
    'jjaej',
    'jjaec',
    'jjaek',
    'jjaet',
    'jjaep',
    'jjaeh',
    'jjya',
    'jjyag',
    'jjyagg',
    'jjyags',
    'jjyan',
    'jjyanj',
    'jjyanh',
    'jjyad',
    'jjyal',
    'jjyalg',
    'jjyalm',
    'jjyalb',
    'jjyals',
    'jjyalt',
    'jjyalp',
    'jjyalh',
    'jjyam',
    'jjyab',
    'jjyabs',
    'jjyas',
    'jjyass',
    'jjyang',
    'jjyaj',
    'jjyac',
    'jjyak',
    'jjyat',
    'jjyap',
    'jjyah',
    'jjyae',
    'jjyaeg',
    'jjyaegg',
    'jjyaegs',
    'jjyaen',
    'jjyaenj',
    'jjyaenh',
    'jjyaed',
    'jjyael',
    'jjyaelg',
    'jjyaelm',
    'jjyaelb',
    'jjyaels',
    'jjyaelt',
    'jjyaelp',
    'jjyaelh',
    'jjyaem',
    'jjyaeb',
    'jjyaebs',
    'jjyaes',
    'jjyaess',
    'jjyaeng',
    'jjyaej',
    'jjyaec',
    'jjyaek',
    'jjyaet',
    'jjyaep',
    'jjyaeh',
    'jjeo',
    'jjeog',
    'jjeogg',
    'jjeogs',
    'jjeon',
    'jjeonj',
    'jjeonh',
    'jjeod',
    'jjeol',
    'jjeolg',
    'jjeolm',
    'jjeolb',
    'jjeols',
    'jjeolt',
    'jjeolp',
    'jjeolh',
    'jjeom',
    'jjeob',
    'jjeobs',
    'jjeos',
    'jjeoss',
    'jjeong',
    'jjeoj',
    'jjeoc',
    'jjeok',
    'jjeot',
    'jjeop',
    'jjeoh',
    'jje',
    'jjeg',
    'jjegg',
    'jjegs',
    'jjen',
    'jjenj',
    'jjenh',
    'jjed',
    'jjel',
    'jjelg',
    'jjelm',
    'jjelb',
    'jjels',
    'jjelt',
    'jjelp',
    'jjelh',
    'jjem',
    'jjeb',
    'jjebs',
    'jjes',
    'jjess',
    'jjeng',
    'jjej',
    'jjec',
    'jjek',
    'jjet',
    'jjep',
    'jjeh',
    'jjyeo',
    'jjyeog',
    'jjyeogg',
    'jjyeogs',
    'jjyeon',
    'jjyeonj',
    'jjyeonh',
    'jjyeod',
    'jjyeol',
    'jjyeolg',
    'jjyeolm',
    'jjyeolb',
    'jjyeols',
    'jjyeolt',
    'jjyeolp',
    'jjyeolh',
    'jjyeom',
    'jjyeob',
    'jjyeobs',
    'jjyeos',
    'jjyeoss',
    'jjyeong',
    'jjyeoj',
    'jjyeoc',
    'jjyeok',
    'jjyeot',
    'jjyeop',
    'jjyeoh',
    'jjye',
    'jjyeg',
    'jjyegg',
    'jjyegs',
    'jjyen',
    'jjyenj',
    'jjyenh',
    'jjyed',
    'jjyel',
    'jjyelg',
    'jjyelm',
    'jjyelb',
    'jjyels',
    'jjyelt',
    'jjyelp',
    'jjyelh',
    'jjyem',
    'jjyeb',
    'jjyebs',
    'jjyes',
    'jjyess',
    'jjyeng',
    'jjyej',
    'jjyec',
    'jjyek',
    'jjyet',
    'jjyep',
    'jjyeh',
    'jjo',
    'jjog',
    'jjogg',
    'jjogs',
    'jjon',
    'jjonj',
    'jjonh',
    'jjod',
    'jjol',
    'jjolg',
    'jjolm',
    'jjolb',
    'jjols',
    'jjolt',
    'jjolp',
    'jjolh',
    'jjom',
    'jjob',
    'jjobs',
    'jjos',
    'jjoss',
    'jjong',
    'jjoj',
    'jjoc',
    'jjok',
    'jjot',
    'jjop',
    'jjoh',
    'jjwa',
    'jjwag',
    'jjwagg',
    'jjwags',
    'jjwan',
    'jjwanj',
    'jjwanh',
    'jjwad',
    'jjwal',
    'jjwalg',
    'jjwalm',
    'jjwalb',
    'jjwals',
    'jjwalt',
    'jjwalp',
    'jjwalh',
    'jjwam',
    'jjwab',
    'jjwabs',
    'jjwas',
    'jjwass',
    'jjwang',
    'jjwaj',
    'jjwac',
    'jjwak',
    'jjwat',
    'jjwap',
    'jjwah',
    'jjwae',
    'jjwaeg',
    'jjwaegg',
    'jjwaegs',
    'jjwaen',
    'jjwaenj',
    'jjwaenh',
    'jjwaed',
    'jjwael',
    'jjwaelg',
    'jjwaelm',
    'jjwaelb'
];

},{}],"gN4OR":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:42 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'jjwaels',
    'jjwaelt',
    'jjwaelp',
    'jjwaelh',
    'jjwaem',
    'jjwaeb',
    'jjwaebs',
    'jjwaes',
    'jjwaess',
    'jjwaeng',
    'jjwaej',
    'jjwaec',
    'jjwaek',
    'jjwaet',
    'jjwaep',
    'jjwaeh',
    'jjoe',
    'jjoeg',
    'jjoegg',
    'jjoegs',
    'jjoen',
    'jjoenj',
    'jjoenh',
    'jjoed',
    'jjoel',
    'jjoelg',
    'jjoelm',
    'jjoelb',
    'jjoels',
    'jjoelt',
    'jjoelp',
    'jjoelh',
    'jjoem',
    'jjoeb',
    'jjoebs',
    'jjoes',
    'jjoess',
    'jjoeng',
    'jjoej',
    'jjoec',
    'jjoek',
    'jjoet',
    'jjoep',
    'jjoeh',
    'jjyo',
    'jjyog',
    'jjyogg',
    'jjyogs',
    'jjyon',
    'jjyonj',
    'jjyonh',
    'jjyod',
    'jjyol',
    'jjyolg',
    'jjyolm',
    'jjyolb',
    'jjyols',
    'jjyolt',
    'jjyolp',
    'jjyolh',
    'jjyom',
    'jjyob',
    'jjyobs',
    'jjyos',
    'jjyoss',
    'jjyong',
    'jjyoj',
    'jjyoc',
    'jjyok',
    'jjyot',
    'jjyop',
    'jjyoh',
    'jju',
    'jjug',
    'jjugg',
    'jjugs',
    'jjun',
    'jjunj',
    'jjunh',
    'jjud',
    'jjul',
    'jjulg',
    'jjulm',
    'jjulb',
    'jjuls',
    'jjult',
    'jjulp',
    'jjulh',
    'jjum',
    'jjub',
    'jjubs',
    'jjus',
    'jjuss',
    'jjung',
    'jjuj',
    'jjuc',
    'jjuk',
    'jjut',
    'jjup',
    'jjuh',
    'jjweo',
    'jjweog',
    'jjweogg',
    'jjweogs',
    'jjweon',
    'jjweonj',
    'jjweonh',
    'jjweod',
    'jjweol',
    'jjweolg',
    'jjweolm',
    'jjweolb',
    'jjweols',
    'jjweolt',
    'jjweolp',
    'jjweolh',
    'jjweom',
    'jjweob',
    'jjweobs',
    'jjweos',
    'jjweoss',
    'jjweong',
    'jjweoj',
    'jjweoc',
    'jjweok',
    'jjweot',
    'jjweop',
    'jjweoh',
    'jjwe',
    'jjweg',
    'jjwegg',
    'jjwegs',
    'jjwen',
    'jjwenj',
    'jjwenh',
    'jjwed',
    'jjwel',
    'jjwelg',
    'jjwelm',
    'jjwelb',
    'jjwels',
    'jjwelt',
    'jjwelp',
    'jjwelh',
    'jjwem',
    'jjweb',
    'jjwebs',
    'jjwes',
    'jjwess',
    'jjweng',
    'jjwej',
    'jjwec',
    'jjwek',
    'jjwet',
    'jjwep',
    'jjweh',
    'jjwi',
    'jjwig',
    'jjwigg',
    'jjwigs',
    'jjwin',
    'jjwinj',
    'jjwinh',
    'jjwid',
    'jjwil',
    'jjwilg',
    'jjwilm',
    'jjwilb',
    'jjwils',
    'jjwilt',
    'jjwilp',
    'jjwilh',
    'jjwim',
    'jjwib',
    'jjwibs',
    'jjwis',
    'jjwiss',
    'jjwing',
    'jjwij',
    'jjwic',
    'jjwik',
    'jjwit',
    'jjwip',
    'jjwih',
    'jjyu',
    'jjyug',
    'jjyugg',
    'jjyugs',
    'jjyun',
    'jjyunj',
    'jjyunh',
    'jjyud',
    'jjyul',
    'jjyulg',
    'jjyulm',
    'jjyulb',
    'jjyuls',
    'jjyult',
    'jjyulp',
    'jjyulh',
    'jjyum',
    'jjyub',
    'jjyubs',
    'jjyus',
    'jjyuss',
    'jjyung',
    'jjyuj',
    'jjyuc',
    'jjyuk',
    'jjyut',
    'jjyup',
    'jjyuh',
    'jjeu',
    'jjeug',
    'jjeugg',
    'jjeugs',
    'jjeun',
    'jjeunj',
    'jjeunh',
    'jjeud',
    'jjeul',
    'jjeulg',
    'jjeulm',
    'jjeulb',
    'jjeuls',
    'jjeult',
    'jjeulp',
    'jjeulh',
    'jjeum',
    'jjeub',
    'jjeubs',
    'jjeus',
    'jjeuss',
    'jjeung',
    'jjeuj',
    'jjeuc',
    'jjeuk',
    'jjeut',
    'jjeup',
    'jjeuh',
    'jjyi',
    'jjyig',
    'jjyigg',
    'jjyigs',
    'jjyin',
    'jjyinj',
    'jjyinh',
    'jjyid',
    'jjyil',
    'jjyilg',
    'jjyilm',
    'jjyilb',
    'jjyils',
    'jjyilt',
    'jjyilp',
    'jjyilh'
];

},{}],"6cDvC":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:42 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'jjyim',
    'jjyib',
    'jjyibs',
    'jjyis',
    'jjyiss',
    'jjying',
    'jjyij',
    'jjyic',
    'jjyik',
    'jjyit',
    'jjyip',
    'jjyih',
    'jji',
    'jjig',
    'jjigg',
    'jjigs',
    'jjin',
    'jjinj',
    'jjinh',
    'jjid',
    'jjil',
    'jjilg',
    'jjilm',
    'jjilb',
    'jjils',
    'jjilt',
    'jjilp',
    'jjilh',
    'jjim',
    'jjib',
    'jjibs',
    'jjis',
    'jjiss',
    'jjing',
    'jjij',
    'jjic',
    'jjik',
    'jjit',
    'jjip',
    'jjih',
    'ca',
    'cag',
    'cagg',
    'cags',
    'can',
    'canj',
    'canh',
    'cad',
    'cal',
    'calg',
    'calm',
    'calb',
    'cals',
    'calt',
    'calp',
    'calh',
    'cam',
    'cab',
    'cabs',
    'cas',
    'cass',
    'cang',
    'caj',
    'cac',
    'cak',
    'cat',
    'cap',
    'cah',
    'cae',
    'caeg',
    'caegg',
    'caegs',
    'caen',
    'caenj',
    'caenh',
    'caed',
    'cael',
    'caelg',
    'caelm',
    'caelb',
    'caels',
    'caelt',
    'caelp',
    'caelh',
    'caem',
    'caeb',
    'caebs',
    'caes',
    'caess',
    'caeng',
    'caej',
    'caec',
    'caek',
    'caet',
    'caep',
    'caeh',
    'cya',
    'cyag',
    'cyagg',
    'cyags',
    'cyan',
    'cyanj',
    'cyanh',
    'cyad',
    'cyal',
    'cyalg',
    'cyalm',
    'cyalb',
    'cyals',
    'cyalt',
    'cyalp',
    'cyalh',
    'cyam',
    'cyab',
    'cyabs',
    'cyas',
    'cyass',
    'cyang',
    'cyaj',
    'cyac',
    'cyak',
    'cyat',
    'cyap',
    'cyah',
    'cyae',
    'cyaeg',
    'cyaegg',
    'cyaegs',
    'cyaen',
    'cyaenj',
    'cyaenh',
    'cyaed',
    'cyael',
    'cyaelg',
    'cyaelm',
    'cyaelb',
    'cyaels',
    'cyaelt',
    'cyaelp',
    'cyaelh',
    'cyaem',
    'cyaeb',
    'cyaebs',
    'cyaes',
    'cyaess',
    'cyaeng',
    'cyaej',
    'cyaec',
    'cyaek',
    'cyaet',
    'cyaep',
    'cyaeh',
    'ceo',
    'ceog',
    'ceogg',
    'ceogs',
    'ceon',
    'ceonj',
    'ceonh',
    'ceod',
    'ceol',
    'ceolg',
    'ceolm',
    'ceolb',
    'ceols',
    'ceolt',
    'ceolp',
    'ceolh',
    'ceom',
    'ceob',
    'ceobs',
    'ceos',
    'ceoss',
    'ceong',
    'ceoj',
    'ceoc',
    'ceok',
    'ceot',
    'ceop',
    'ceoh',
    'ce',
    'ceg',
    'cegg',
    'cegs',
    'cen',
    'cenj',
    'cenh',
    'ced',
    'cel',
    'celg',
    'celm',
    'celb',
    'cels',
    'celt',
    'celp',
    'celh',
    'cem',
    'ceb',
    'cebs',
    'ces',
    'cess',
    'ceng',
    'cej',
    'cec',
    'cek',
    'cet',
    'cep',
    'ceh',
    'cyeo',
    'cyeog',
    'cyeogg',
    'cyeogs',
    'cyeon',
    'cyeonj',
    'cyeonh',
    'cyeod',
    'cyeol',
    'cyeolg',
    'cyeolm',
    'cyeolb',
    'cyeols',
    'cyeolt',
    'cyeolp',
    'cyeolh',
    'cyeom',
    'cyeob',
    'cyeobs',
    'cyeos',
    'cyeoss',
    'cyeong',
    'cyeoj',
    'cyeoc',
    'cyeok',
    'cyeot',
    'cyeop',
    'cyeoh',
    'cye',
    'cyeg',
    'cyegg',
    'cyegs',
    'cyen',
    'cyenj',
    'cyenh',
    'cyed',
    'cyel',
    'cyelg',
    'cyelm',
    'cyelb',
    'cyels',
    'cyelt',
    'cyelp',
    'cyelh',
    'cyem',
    'cyeb',
    'cyebs',
    'cyes'
];

},{}],"9fuxi":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:42 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'cyess',
    'cyeng',
    'cyej',
    'cyec',
    'cyek',
    'cyet',
    'cyep',
    'cyeh',
    'co',
    'cog',
    'cogg',
    'cogs',
    'con',
    'conj',
    'conh',
    'cod',
    'col',
    'colg',
    'colm',
    'colb',
    'cols',
    'colt',
    'colp',
    'colh',
    'com',
    'cob',
    'cobs',
    'cos',
    'coss',
    'cong',
    'coj',
    'coc',
    'cok',
    'cot',
    'cop',
    'coh',
    'cwa',
    'cwag',
    'cwagg',
    'cwags',
    'cwan',
    'cwanj',
    'cwanh',
    'cwad',
    'cwal',
    'cwalg',
    'cwalm',
    'cwalb',
    'cwals',
    'cwalt',
    'cwalp',
    'cwalh',
    'cwam',
    'cwab',
    'cwabs',
    'cwas',
    'cwass',
    'cwang',
    'cwaj',
    'cwac',
    'cwak',
    'cwat',
    'cwap',
    'cwah',
    'cwae',
    'cwaeg',
    'cwaegg',
    'cwaegs',
    'cwaen',
    'cwaenj',
    'cwaenh',
    'cwaed',
    'cwael',
    'cwaelg',
    'cwaelm',
    'cwaelb',
    'cwaels',
    'cwaelt',
    'cwaelp',
    'cwaelh',
    'cwaem',
    'cwaeb',
    'cwaebs',
    'cwaes',
    'cwaess',
    'cwaeng',
    'cwaej',
    'cwaec',
    'cwaek',
    'cwaet',
    'cwaep',
    'cwaeh',
    'coe',
    'coeg',
    'coegg',
    'coegs',
    'coen',
    'coenj',
    'coenh',
    'coed',
    'coel',
    'coelg',
    'coelm',
    'coelb',
    'coels',
    'coelt',
    'coelp',
    'coelh',
    'coem',
    'coeb',
    'coebs',
    'coes',
    'coess',
    'coeng',
    'coej',
    'coec',
    'coek',
    'coet',
    'coep',
    'coeh',
    'cyo',
    'cyog',
    'cyogg',
    'cyogs',
    'cyon',
    'cyonj',
    'cyonh',
    'cyod',
    'cyol',
    'cyolg',
    'cyolm',
    'cyolb',
    'cyols',
    'cyolt',
    'cyolp',
    'cyolh',
    'cyom',
    'cyob',
    'cyobs',
    'cyos',
    'cyoss',
    'cyong',
    'cyoj',
    'cyoc',
    'cyok',
    'cyot',
    'cyop',
    'cyoh',
    'cu',
    'cug',
    'cugg',
    'cugs',
    'cun',
    'cunj',
    'cunh',
    'cud',
    'cul',
    'culg',
    'culm',
    'culb',
    'culs',
    'cult',
    'culp',
    'culh',
    'cum',
    'cub',
    'cubs',
    'cus',
    'cuss',
    'cung',
    'cuj',
    'cuc',
    'cuk',
    'cut',
    'cup',
    'cuh',
    'cweo',
    'cweog',
    'cweogg',
    'cweogs',
    'cweon',
    'cweonj',
    'cweonh',
    'cweod',
    'cweol',
    'cweolg',
    'cweolm',
    'cweolb',
    'cweols',
    'cweolt',
    'cweolp',
    'cweolh',
    'cweom',
    'cweob',
    'cweobs',
    'cweos',
    'cweoss',
    'cweong',
    'cweoj',
    'cweoc',
    'cweok',
    'cweot',
    'cweop',
    'cweoh',
    'cwe',
    'cweg',
    'cwegg',
    'cwegs',
    'cwen',
    'cwenj',
    'cwenh',
    'cwed',
    'cwel',
    'cwelg',
    'cwelm',
    'cwelb',
    'cwels',
    'cwelt',
    'cwelp',
    'cwelh',
    'cwem',
    'cweb',
    'cwebs',
    'cwes',
    'cwess',
    'cweng',
    'cwej',
    'cwec',
    'cwek',
    'cwet',
    'cwep',
    'cweh',
    'cwi',
    'cwig',
    'cwigg',
    'cwigs',
    'cwin',
    'cwinj',
    'cwinh',
    'cwid',
    'cwil',
    'cwilg',
    'cwilm',
    'cwilb',
    'cwils',
    'cwilt',
    'cwilp',
    'cwilh',
    'cwim',
    'cwib',
    'cwibs',
    'cwis',
    'cwiss',
    'cwing',
    'cwij',
    'cwic'
];

},{}],"ctqoC":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:42 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'cwik',
    'cwit',
    'cwip',
    'cwih',
    'cyu',
    'cyug',
    'cyugg',
    'cyugs',
    'cyun',
    'cyunj',
    'cyunh',
    'cyud',
    'cyul',
    'cyulg',
    'cyulm',
    'cyulb',
    'cyuls',
    'cyult',
    'cyulp',
    'cyulh',
    'cyum',
    'cyub',
    'cyubs',
    'cyus',
    'cyuss',
    'cyung',
    'cyuj',
    'cyuc',
    'cyuk',
    'cyut',
    'cyup',
    'cyuh',
    'ceu',
    'ceug',
    'ceugg',
    'ceugs',
    'ceun',
    'ceunj',
    'ceunh',
    'ceud',
    'ceul',
    'ceulg',
    'ceulm',
    'ceulb',
    'ceuls',
    'ceult',
    'ceulp',
    'ceulh',
    'ceum',
    'ceub',
    'ceubs',
    'ceus',
    'ceuss',
    'ceung',
    'ceuj',
    'ceuc',
    'ceuk',
    'ceut',
    'ceup',
    'ceuh',
    'cyi',
    'cyig',
    'cyigg',
    'cyigs',
    'cyin',
    'cyinj',
    'cyinh',
    'cyid',
    'cyil',
    'cyilg',
    'cyilm',
    'cyilb',
    'cyils',
    'cyilt',
    'cyilp',
    'cyilh',
    'cyim',
    'cyib',
    'cyibs',
    'cyis',
    'cyiss',
    'cying',
    'cyij',
    'cyic',
    'cyik',
    'cyit',
    'cyip',
    'cyih',
    'ci',
    'cig',
    'cigg',
    'cigs',
    'cin',
    'cinj',
    'cinh',
    'cid',
    'cil',
    'cilg',
    'cilm',
    'cilb',
    'cils',
    'cilt',
    'cilp',
    'cilh',
    'cim',
    'cib',
    'cibs',
    'cis',
    'ciss',
    'cing',
    'cij',
    'cic',
    'cik',
    'cit',
    'cip',
    'cih',
    'ka',
    'kag',
    'kagg',
    'kags',
    'kan',
    'kanj',
    'kanh',
    'kad',
    'kal',
    'kalg',
    'kalm',
    'kalb',
    'kals',
    'kalt',
    'kalp',
    'kalh',
    'kam',
    'kab',
    'kabs',
    'kas',
    'kass',
    'kang',
    'kaj',
    'kac',
    'kak',
    'kat',
    'kap',
    'kah',
    'kae',
    'kaeg',
    'kaegg',
    'kaegs',
    'kaen',
    'kaenj',
    'kaenh',
    'kaed',
    'kael',
    'kaelg',
    'kaelm',
    'kaelb',
    'kaels',
    'kaelt',
    'kaelp',
    'kaelh',
    'kaem',
    'kaeb',
    'kaebs',
    'kaes',
    'kaess',
    'kaeng',
    'kaej',
    'kaec',
    'kaek',
    'kaet',
    'kaep',
    'kaeh',
    'kya',
    'kyag',
    'kyagg',
    'kyags',
    'kyan',
    'kyanj',
    'kyanh',
    'kyad',
    'kyal',
    'kyalg',
    'kyalm',
    'kyalb',
    'kyals',
    'kyalt',
    'kyalp',
    'kyalh',
    'kyam',
    'kyab',
    'kyabs',
    'kyas',
    'kyass',
    'kyang',
    'kyaj',
    'kyac',
    'kyak',
    'kyat',
    'kyap',
    'kyah',
    'kyae',
    'kyaeg',
    'kyaegg',
    'kyaegs',
    'kyaen',
    'kyaenj',
    'kyaenh',
    'kyaed',
    'kyael',
    'kyaelg',
    'kyaelm',
    'kyaelb',
    'kyaels',
    'kyaelt',
    'kyaelp',
    'kyaelh',
    'kyaem',
    'kyaeb',
    'kyaebs',
    'kyaes',
    'kyaess',
    'kyaeng',
    'kyaej',
    'kyaec',
    'kyaek',
    'kyaet',
    'kyaep',
    'kyaeh',
    'keo',
    'keog',
    'keogg',
    'keogs',
    'keon',
    'keonj',
    'keonh',
    'keod',
    'keol',
    'keolg',
    'keolm',
    'keolb',
    'keols',
    'keolt',
    'keolp',
    'keolh',
    'keom',
    'keob',
    'keobs',
    'keos',
    'keoss',
    'keong',
    'keoj',
    'keoc',
    'keok',
    'keot',
    'keop',
    'keoh'
];

},{}],"aNYIL":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:42 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'ke',
    'keg',
    'kegg',
    'kegs',
    'ken',
    'kenj',
    'kenh',
    'ked',
    'kel',
    'kelg',
    'kelm',
    'kelb',
    'kels',
    'kelt',
    'kelp',
    'kelh',
    'kem',
    'keb',
    'kebs',
    'kes',
    'kess',
    'keng',
    'kej',
    'kec',
    'kek',
    'ket',
    'kep',
    'keh',
    'kyeo',
    'kyeog',
    'kyeogg',
    'kyeogs',
    'kyeon',
    'kyeonj',
    'kyeonh',
    'kyeod',
    'kyeol',
    'kyeolg',
    'kyeolm',
    'kyeolb',
    'kyeols',
    'kyeolt',
    'kyeolp',
    'kyeolh',
    'kyeom',
    'kyeob',
    'kyeobs',
    'kyeos',
    'kyeoss',
    'kyeong',
    'kyeoj',
    'kyeoc',
    'kyeok',
    'kyeot',
    'kyeop',
    'kyeoh',
    'kye',
    'kyeg',
    'kyegg',
    'kyegs',
    'kyen',
    'kyenj',
    'kyenh',
    'kyed',
    'kyel',
    'kyelg',
    'kyelm',
    'kyelb',
    'kyels',
    'kyelt',
    'kyelp',
    'kyelh',
    'kyem',
    'kyeb',
    'kyebs',
    'kyes',
    'kyess',
    'kyeng',
    'kyej',
    'kyec',
    'kyek',
    'kyet',
    'kyep',
    'kyeh',
    'ko',
    'kog',
    'kogg',
    'kogs',
    'kon',
    'konj',
    'konh',
    'kod',
    'kol',
    'kolg',
    'kolm',
    'kolb',
    'kols',
    'kolt',
    'kolp',
    'kolh',
    'kom',
    'kob',
    'kobs',
    'kos',
    'koss',
    'kong',
    'koj',
    'koc',
    'kok',
    'kot',
    'kop',
    'koh',
    'kwa',
    'kwag',
    'kwagg',
    'kwags',
    'kwan',
    'kwanj',
    'kwanh',
    'kwad',
    'kwal',
    'kwalg',
    'kwalm',
    'kwalb',
    'kwals',
    'kwalt',
    'kwalp',
    'kwalh',
    'kwam',
    'kwab',
    'kwabs',
    'kwas',
    'kwass',
    'kwang',
    'kwaj',
    'kwac',
    'kwak',
    'kwat',
    'kwap',
    'kwah',
    'kwae',
    'kwaeg',
    'kwaegg',
    'kwaegs',
    'kwaen',
    'kwaenj',
    'kwaenh',
    'kwaed',
    'kwael',
    'kwaelg',
    'kwaelm',
    'kwaelb',
    'kwaels',
    'kwaelt',
    'kwaelp',
    'kwaelh',
    'kwaem',
    'kwaeb',
    'kwaebs',
    'kwaes',
    'kwaess',
    'kwaeng',
    'kwaej',
    'kwaec',
    'kwaek',
    'kwaet',
    'kwaep',
    'kwaeh',
    'koe',
    'koeg',
    'koegg',
    'koegs',
    'koen',
    'koenj',
    'koenh',
    'koed',
    'koel',
    'koelg',
    'koelm',
    'koelb',
    'koels',
    'koelt',
    'koelp',
    'koelh',
    'koem',
    'koeb',
    'koebs',
    'koes',
    'koess',
    'koeng',
    'koej',
    'koec',
    'koek',
    'koet',
    'koep',
    'koeh',
    'kyo',
    'kyog',
    'kyogg',
    'kyogs',
    'kyon',
    'kyonj',
    'kyonh',
    'kyod',
    'kyol',
    'kyolg',
    'kyolm',
    'kyolb',
    'kyols',
    'kyolt',
    'kyolp',
    'kyolh',
    'kyom',
    'kyob',
    'kyobs',
    'kyos',
    'kyoss',
    'kyong',
    'kyoj',
    'kyoc',
    'kyok',
    'kyot',
    'kyop',
    'kyoh',
    'ku',
    'kug',
    'kugg',
    'kugs',
    'kun',
    'kunj',
    'kunh',
    'kud',
    'kul',
    'kulg',
    'kulm',
    'kulb',
    'kuls',
    'kult',
    'kulp',
    'kulh',
    'kum',
    'kub',
    'kubs',
    'kus',
    'kuss',
    'kung',
    'kuj',
    'kuc',
    'kuk',
    'kut',
    'kup',
    'kuh',
    'kweo',
    'kweog',
    'kweogg',
    'kweogs'
];

},{}],"ewKNn":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:42 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'kweon',
    'kweonj',
    'kweonh',
    'kweod',
    'kweol',
    'kweolg',
    'kweolm',
    'kweolb',
    'kweols',
    'kweolt',
    'kweolp',
    'kweolh',
    'kweom',
    'kweob',
    'kweobs',
    'kweos',
    'kweoss',
    'kweong',
    'kweoj',
    'kweoc',
    'kweok',
    'kweot',
    'kweop',
    'kweoh',
    'kwe',
    'kweg',
    'kwegg',
    'kwegs',
    'kwen',
    'kwenj',
    'kwenh',
    'kwed',
    'kwel',
    'kwelg',
    'kwelm',
    'kwelb',
    'kwels',
    'kwelt',
    'kwelp',
    'kwelh',
    'kwem',
    'kweb',
    'kwebs',
    'kwes',
    'kwess',
    'kweng',
    'kwej',
    'kwec',
    'kwek',
    'kwet',
    'kwep',
    'kweh',
    'kwi',
    'kwig',
    'kwigg',
    'kwigs',
    'kwin',
    'kwinj',
    'kwinh',
    'kwid',
    'kwil',
    'kwilg',
    'kwilm',
    'kwilb',
    'kwils',
    'kwilt',
    'kwilp',
    'kwilh',
    'kwim',
    'kwib',
    'kwibs',
    'kwis',
    'kwiss',
    'kwing',
    'kwij',
    'kwic',
    'kwik',
    'kwit',
    'kwip',
    'kwih',
    'kyu',
    'kyug',
    'kyugg',
    'kyugs',
    'kyun',
    'kyunj',
    'kyunh',
    'kyud',
    'kyul',
    'kyulg',
    'kyulm',
    'kyulb',
    'kyuls',
    'kyult',
    'kyulp',
    'kyulh',
    'kyum',
    'kyub',
    'kyubs',
    'kyus',
    'kyuss',
    'kyung',
    'kyuj',
    'kyuc',
    'kyuk',
    'kyut',
    'kyup',
    'kyuh',
    'keu',
    'keug',
    'keugg',
    'keugs',
    'keun',
    'keunj',
    'keunh',
    'keud',
    'keul',
    'keulg',
    'keulm',
    'keulb',
    'keuls',
    'keult',
    'keulp',
    'keulh',
    'keum',
    'keub',
    'keubs',
    'keus',
    'keuss',
    'keung',
    'keuj',
    'keuc',
    'keuk',
    'keut',
    'keup',
    'keuh',
    'kyi',
    'kyig',
    'kyigg',
    'kyigs',
    'kyin',
    'kyinj',
    'kyinh',
    'kyid',
    'kyil',
    'kyilg',
    'kyilm',
    'kyilb',
    'kyils',
    'kyilt',
    'kyilp',
    'kyilh',
    'kyim',
    'kyib',
    'kyibs',
    'kyis',
    'kyiss',
    'kying',
    'kyij',
    'kyic',
    'kyik',
    'kyit',
    'kyip',
    'kyih',
    'ki',
    'kig',
    'kigg',
    'kigs',
    'kin',
    'kinj',
    'kinh',
    'kid',
    'kil',
    'kilg',
    'kilm',
    'kilb',
    'kils',
    'kilt',
    'kilp',
    'kilh',
    'kim',
    'kib',
    'kibs',
    'kis',
    'kiss',
    'king',
    'kij',
    'kic',
    'kik',
    'kit',
    'kip',
    'kih',
    'ta',
    'tag',
    'tagg',
    'tags',
    'tan',
    'tanj',
    'tanh',
    'tad',
    'tal',
    'talg',
    'talm',
    'talb',
    'tals',
    'talt',
    'talp',
    'talh',
    'tam',
    'tab',
    'tabs',
    'tas',
    'tass',
    'tang',
    'taj',
    'tac',
    'tak',
    'tat',
    'tap',
    'tah',
    'tae',
    'taeg',
    'taegg',
    'taegs',
    'taen',
    'taenj',
    'taenh',
    'taed',
    'tael',
    'taelg',
    'taelm',
    'taelb',
    'taels',
    'taelt',
    'taelp',
    'taelh',
    'taem',
    'taeb',
    'taebs',
    'taes',
    'taess',
    'taeng',
    'taej',
    'taec',
    'taek',
    'taet',
    'taep',
    'taeh',
    'tya',
    'tyag',
    'tyagg',
    'tyags',
    'tyan',
    'tyanj',
    'tyanh',
    'tyad'
];

},{}],"gUVJK":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:42 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'tyal',
    'tyalg',
    'tyalm',
    'tyalb',
    'tyals',
    'tyalt',
    'tyalp',
    'tyalh',
    'tyam',
    'tyab',
    'tyabs',
    'tyas',
    'tyass',
    'tyang',
    'tyaj',
    'tyac',
    'tyak',
    'tyat',
    'tyap',
    'tyah',
    'tyae',
    'tyaeg',
    'tyaegg',
    'tyaegs',
    'tyaen',
    'tyaenj',
    'tyaenh',
    'tyaed',
    'tyael',
    'tyaelg',
    'tyaelm',
    'tyaelb',
    'tyaels',
    'tyaelt',
    'tyaelp',
    'tyaelh',
    'tyaem',
    'tyaeb',
    'tyaebs',
    'tyaes',
    'tyaess',
    'tyaeng',
    'tyaej',
    'tyaec',
    'tyaek',
    'tyaet',
    'tyaep',
    'tyaeh',
    'teo',
    'teog',
    'teogg',
    'teogs',
    'teon',
    'teonj',
    'teonh',
    'teod',
    'teol',
    'teolg',
    'teolm',
    'teolb',
    'teols',
    'teolt',
    'teolp',
    'teolh',
    'teom',
    'teob',
    'teobs',
    'teos',
    'teoss',
    'teong',
    'teoj',
    'teoc',
    'teok',
    'teot',
    'teop',
    'teoh',
    'te',
    'teg',
    'tegg',
    'tegs',
    'ten',
    'tenj',
    'tenh',
    'ted',
    'tel',
    'telg',
    'telm',
    'telb',
    'tels',
    'telt',
    'telp',
    'telh',
    'tem',
    'teb',
    'tebs',
    'tes',
    'tess',
    'teng',
    'tej',
    'tec',
    'tek',
    'tet',
    'tep',
    'teh',
    'tyeo',
    'tyeog',
    'tyeogg',
    'tyeogs',
    'tyeon',
    'tyeonj',
    'tyeonh',
    'tyeod',
    'tyeol',
    'tyeolg',
    'tyeolm',
    'tyeolb',
    'tyeols',
    'tyeolt',
    'tyeolp',
    'tyeolh',
    'tyeom',
    'tyeob',
    'tyeobs',
    'tyeos',
    'tyeoss',
    'tyeong',
    'tyeoj',
    'tyeoc',
    'tyeok',
    'tyeot',
    'tyeop',
    'tyeoh',
    'tye',
    'tyeg',
    'tyegg',
    'tyegs',
    'tyen',
    'tyenj',
    'tyenh',
    'tyed',
    'tyel',
    'tyelg',
    'tyelm',
    'tyelb',
    'tyels',
    'tyelt',
    'tyelp',
    'tyelh',
    'tyem',
    'tyeb',
    'tyebs',
    'tyes',
    'tyess',
    'tyeng',
    'tyej',
    'tyec',
    'tyek',
    'tyet',
    'tyep',
    'tyeh',
    'to',
    'tog',
    'togg',
    'togs',
    'ton',
    'tonj',
    'tonh',
    'tod',
    'tol',
    'tolg',
    'tolm',
    'tolb',
    'tols',
    'tolt',
    'tolp',
    'tolh',
    'tom',
    'tob',
    'tobs',
    'tos',
    'toss',
    'tong',
    'toj',
    'toc',
    'tok',
    'tot',
    'top',
    'toh',
    'twa',
    'twag',
    'twagg',
    'twags',
    'twan',
    'twanj',
    'twanh',
    'twad',
    'twal',
    'twalg',
    'twalm',
    'twalb',
    'twals',
    'twalt',
    'twalp',
    'twalh',
    'twam',
    'twab',
    'twabs',
    'twas',
    'twass',
    'twang',
    'twaj',
    'twac',
    'twak',
    'twat',
    'twap',
    'twah',
    'twae',
    'twaeg',
    'twaegg',
    'twaegs',
    'twaen',
    'twaenj',
    'twaenh',
    'twaed',
    'twael',
    'twaelg',
    'twaelm',
    'twaelb',
    'twaels',
    'twaelt',
    'twaelp',
    'twaelh',
    'twaem',
    'twaeb',
    'twaebs',
    'twaes',
    'twaess',
    'twaeng',
    'twaej',
    'twaec',
    'twaek',
    'twaet',
    'twaep',
    'twaeh',
    'toe',
    'toeg',
    'toegg',
    'toegs',
    'toen',
    'toenj',
    'toenh',
    'toed',
    'toel',
    'toelg',
    'toelm',
    'toelb'
];

},{}],"kYr5R":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:42 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'toels',
    'toelt',
    'toelp',
    'toelh',
    'toem',
    'toeb',
    'toebs',
    'toes',
    'toess',
    'toeng',
    'toej',
    'toec',
    'toek',
    'toet',
    'toep',
    'toeh',
    'tyo',
    'tyog',
    'tyogg',
    'tyogs',
    'tyon',
    'tyonj',
    'tyonh',
    'tyod',
    'tyol',
    'tyolg',
    'tyolm',
    'tyolb',
    'tyols',
    'tyolt',
    'tyolp',
    'tyolh',
    'tyom',
    'tyob',
    'tyobs',
    'tyos',
    'tyoss',
    'tyong',
    'tyoj',
    'tyoc',
    'tyok',
    'tyot',
    'tyop',
    'tyoh',
    'tu',
    'tug',
    'tugg',
    'tugs',
    'tun',
    'tunj',
    'tunh',
    'tud',
    'tul',
    'tulg',
    'tulm',
    'tulb',
    'tuls',
    'tult',
    'tulp',
    'tulh',
    'tum',
    'tub',
    'tubs',
    'tus',
    'tuss',
    'tung',
    'tuj',
    'tuc',
    'tuk',
    'tut',
    'tup',
    'tuh',
    'tweo',
    'tweog',
    'tweogg',
    'tweogs',
    'tweon',
    'tweonj',
    'tweonh',
    'tweod',
    'tweol',
    'tweolg',
    'tweolm',
    'tweolb',
    'tweols',
    'tweolt',
    'tweolp',
    'tweolh',
    'tweom',
    'tweob',
    'tweobs',
    'tweos',
    'tweoss',
    'tweong',
    'tweoj',
    'tweoc',
    'tweok',
    'tweot',
    'tweop',
    'tweoh',
    'twe',
    'tweg',
    'twegg',
    'twegs',
    'twen',
    'twenj',
    'twenh',
    'twed',
    'twel',
    'twelg',
    'twelm',
    'twelb',
    'twels',
    'twelt',
    'twelp',
    'twelh',
    'twem',
    'tweb',
    'twebs',
    'twes',
    'twess',
    'tweng',
    'twej',
    'twec',
    'twek',
    'twet',
    'twep',
    'tweh',
    'twi',
    'twig',
    'twigg',
    'twigs',
    'twin',
    'twinj',
    'twinh',
    'twid',
    'twil',
    'twilg',
    'twilm',
    'twilb',
    'twils',
    'twilt',
    'twilp',
    'twilh',
    'twim',
    'twib',
    'twibs',
    'twis',
    'twiss',
    'twing',
    'twij',
    'twic',
    'twik',
    'twit',
    'twip',
    'twih',
    'tyu',
    'tyug',
    'tyugg',
    'tyugs',
    'tyun',
    'tyunj',
    'tyunh',
    'tyud',
    'tyul',
    'tyulg',
    'tyulm',
    'tyulb',
    'tyuls',
    'tyult',
    'tyulp',
    'tyulh',
    'tyum',
    'tyub',
    'tyubs',
    'tyus',
    'tyuss',
    'tyung',
    'tyuj',
    'tyuc',
    'tyuk',
    'tyut',
    'tyup',
    'tyuh',
    'teu',
    'teug',
    'teugg',
    'teugs',
    'teun',
    'teunj',
    'teunh',
    'teud',
    'teul',
    'teulg',
    'teulm',
    'teulb',
    'teuls',
    'teult',
    'teulp',
    'teulh',
    'teum',
    'teub',
    'teubs',
    'teus',
    'teuss',
    'teung',
    'teuj',
    'teuc',
    'teuk',
    'teut',
    'teup',
    'teuh',
    'tyi',
    'tyig',
    'tyigg',
    'tyigs',
    'tyin',
    'tyinj',
    'tyinh',
    'tyid',
    'tyil',
    'tyilg',
    'tyilm',
    'tyilb',
    'tyils',
    'tyilt',
    'tyilp',
    'tyilh',
    'tyim',
    'tyib',
    'tyibs',
    'tyis',
    'tyiss',
    'tying',
    'tyij',
    'tyic',
    'tyik',
    'tyit',
    'tyip',
    'tyih',
    'ti',
    'tig',
    'tigg',
    'tigs',
    'tin',
    'tinj',
    'tinh',
    'tid',
    'til',
    'tilg',
    'tilm',
    'tilb',
    'tils',
    'tilt',
    'tilp',
    'tilh'
];

},{}],"9nQiO":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:42 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'tim',
    'tib',
    'tibs',
    'tis',
    'tiss',
    'ting',
    'tij',
    'tic',
    'tik',
    'tit',
    'tip',
    'tih',
    'pa',
    'pag',
    'pagg',
    'pags',
    'pan',
    'panj',
    'panh',
    'pad',
    'pal',
    'palg',
    'palm',
    'palb',
    'pals',
    'palt',
    'palp',
    'palh',
    'pam',
    'pab',
    'pabs',
    'pas',
    'pass',
    'pang',
    'paj',
    'pac',
    'pak',
    'pat',
    'pap',
    'pah',
    'pae',
    'paeg',
    'paegg',
    'paegs',
    'paen',
    'paenj',
    'paenh',
    'paed',
    'pael',
    'paelg',
    'paelm',
    'paelb',
    'paels',
    'paelt',
    'paelp',
    'paelh',
    'paem',
    'paeb',
    'paebs',
    'paes',
    'paess',
    'paeng',
    'paej',
    'paec',
    'paek',
    'paet',
    'paep',
    'paeh',
    'pya',
    'pyag',
    'pyagg',
    'pyags',
    'pyan',
    'pyanj',
    'pyanh',
    'pyad',
    'pyal',
    'pyalg',
    'pyalm',
    'pyalb',
    'pyals',
    'pyalt',
    'pyalp',
    'pyalh',
    'pyam',
    'pyab',
    'pyabs',
    'pyas',
    'pyass',
    'pyang',
    'pyaj',
    'pyac',
    'pyak',
    'pyat',
    'pyap',
    'pyah',
    'pyae',
    'pyaeg',
    'pyaegg',
    'pyaegs',
    'pyaen',
    'pyaenj',
    'pyaenh',
    'pyaed',
    'pyael',
    'pyaelg',
    'pyaelm',
    'pyaelb',
    'pyaels',
    'pyaelt',
    'pyaelp',
    'pyaelh',
    'pyaem',
    'pyaeb',
    'pyaebs',
    'pyaes',
    'pyaess',
    'pyaeng',
    'pyaej',
    'pyaec',
    'pyaek',
    'pyaet',
    'pyaep',
    'pyaeh',
    'peo',
    'peog',
    'peogg',
    'peogs',
    'peon',
    'peonj',
    'peonh',
    'peod',
    'peol',
    'peolg',
    'peolm',
    'peolb',
    'peols',
    'peolt',
    'peolp',
    'peolh',
    'peom',
    'peob',
    'peobs',
    'peos',
    'peoss',
    'peong',
    'peoj',
    'peoc',
    'peok',
    'peot',
    'peop',
    'peoh',
    'pe',
    'peg',
    'pegg',
    'pegs',
    'pen',
    'penj',
    'penh',
    'ped',
    'pel',
    'pelg',
    'pelm',
    'pelb',
    'pels',
    'pelt',
    'pelp',
    'pelh',
    'pem',
    'peb',
    'pebs',
    'pes',
    'pess',
    'peng',
    'pej',
    'pec',
    'pek',
    'pet',
    'pep',
    'peh',
    'pyeo',
    'pyeog',
    'pyeogg',
    'pyeogs',
    'pyeon',
    'pyeonj',
    'pyeonh',
    'pyeod',
    'pyeol',
    'pyeolg',
    'pyeolm',
    'pyeolb',
    'pyeols',
    'pyeolt',
    'pyeolp',
    'pyeolh',
    'pyeom',
    'pyeob',
    'pyeobs',
    'pyeos',
    'pyeoss',
    'pyeong',
    'pyeoj',
    'pyeoc',
    'pyeok',
    'pyeot',
    'pyeop',
    'pyeoh',
    'pye',
    'pyeg',
    'pyegg',
    'pyegs',
    'pyen',
    'pyenj',
    'pyenh',
    'pyed',
    'pyel',
    'pyelg',
    'pyelm',
    'pyelb',
    'pyels',
    'pyelt',
    'pyelp',
    'pyelh',
    'pyem',
    'pyeb',
    'pyebs',
    'pyes',
    'pyess',
    'pyeng',
    'pyej',
    'pyec',
    'pyek',
    'pyet',
    'pyep',
    'pyeh',
    'po',
    'pog',
    'pogg',
    'pogs',
    'pon',
    'ponj',
    'ponh',
    'pod',
    'pol',
    'polg',
    'polm',
    'polb',
    'pols',
    'polt',
    'polp',
    'polh',
    'pom',
    'pob',
    'pobs',
    'pos'
];

},{}],"aCyhY":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:42 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'poss',
    'pong',
    'poj',
    'poc',
    'pok',
    'pot',
    'pop',
    'poh',
    'pwa',
    'pwag',
    'pwagg',
    'pwags',
    'pwan',
    'pwanj',
    'pwanh',
    'pwad',
    'pwal',
    'pwalg',
    'pwalm',
    'pwalb',
    'pwals',
    'pwalt',
    'pwalp',
    'pwalh',
    'pwam',
    'pwab',
    'pwabs',
    'pwas',
    'pwass',
    'pwang',
    'pwaj',
    'pwac',
    'pwak',
    'pwat',
    'pwap',
    'pwah',
    'pwae',
    'pwaeg',
    'pwaegg',
    'pwaegs',
    'pwaen',
    'pwaenj',
    'pwaenh',
    'pwaed',
    'pwael',
    'pwaelg',
    'pwaelm',
    'pwaelb',
    'pwaels',
    'pwaelt',
    'pwaelp',
    'pwaelh',
    'pwaem',
    'pwaeb',
    'pwaebs',
    'pwaes',
    'pwaess',
    'pwaeng',
    'pwaej',
    'pwaec',
    'pwaek',
    'pwaet',
    'pwaep',
    'pwaeh',
    'poe',
    'poeg',
    'poegg',
    'poegs',
    'poen',
    'poenj',
    'poenh',
    'poed',
    'poel',
    'poelg',
    'poelm',
    'poelb',
    'poels',
    'poelt',
    'poelp',
    'poelh',
    'poem',
    'poeb',
    'poebs',
    'poes',
    'poess',
    'poeng',
    'poej',
    'poec',
    'poek',
    'poet',
    'poep',
    'poeh',
    'pyo',
    'pyog',
    'pyogg',
    'pyogs',
    'pyon',
    'pyonj',
    'pyonh',
    'pyod',
    'pyol',
    'pyolg',
    'pyolm',
    'pyolb',
    'pyols',
    'pyolt',
    'pyolp',
    'pyolh',
    'pyom',
    'pyob',
    'pyobs',
    'pyos',
    'pyoss',
    'pyong',
    'pyoj',
    'pyoc',
    'pyok',
    'pyot',
    'pyop',
    'pyoh',
    'pu',
    'pug',
    'pugg',
    'pugs',
    'pun',
    'punj',
    'punh',
    'pud',
    'pul',
    'pulg',
    'pulm',
    'pulb',
    'puls',
    'pult',
    'pulp',
    'pulh',
    'pum',
    'pub',
    'pubs',
    'pus',
    'puss',
    'pung',
    'puj',
    'puc',
    'puk',
    'put',
    'pup',
    'puh',
    'pweo',
    'pweog',
    'pweogg',
    'pweogs',
    'pweon',
    'pweonj',
    'pweonh',
    'pweod',
    'pweol',
    'pweolg',
    'pweolm',
    'pweolb',
    'pweols',
    'pweolt',
    'pweolp',
    'pweolh',
    'pweom',
    'pweob',
    'pweobs',
    'pweos',
    'pweoss',
    'pweong',
    'pweoj',
    'pweoc',
    'pweok',
    'pweot',
    'pweop',
    'pweoh',
    'pwe',
    'pweg',
    'pwegg',
    'pwegs',
    'pwen',
    'pwenj',
    'pwenh',
    'pwed',
    'pwel',
    'pwelg',
    'pwelm',
    'pwelb',
    'pwels',
    'pwelt',
    'pwelp',
    'pwelh',
    'pwem',
    'pweb',
    'pwebs',
    'pwes',
    'pwess',
    'pweng',
    'pwej',
    'pwec',
    'pwek',
    'pwet',
    'pwep',
    'pweh',
    'pwi',
    'pwig',
    'pwigg',
    'pwigs',
    'pwin',
    'pwinj',
    'pwinh',
    'pwid',
    'pwil',
    'pwilg',
    'pwilm',
    'pwilb',
    'pwils',
    'pwilt',
    'pwilp',
    'pwilh',
    'pwim',
    'pwib',
    'pwibs',
    'pwis',
    'pwiss',
    'pwing',
    'pwij',
    'pwic',
    'pwik',
    'pwit',
    'pwip',
    'pwih',
    'pyu',
    'pyug',
    'pyugg',
    'pyugs',
    'pyun',
    'pyunj',
    'pyunh',
    'pyud',
    'pyul',
    'pyulg',
    'pyulm',
    'pyulb',
    'pyuls',
    'pyult',
    'pyulp',
    'pyulh',
    'pyum',
    'pyub',
    'pyubs',
    'pyus',
    'pyuss',
    'pyung',
    'pyuj',
    'pyuc'
];

},{}],"7iF1m":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:43 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'pyuk',
    'pyut',
    'pyup',
    'pyuh',
    'peu',
    'peug',
    'peugg',
    'peugs',
    'peun',
    'peunj',
    'peunh',
    'peud',
    'peul',
    'peulg',
    'peulm',
    'peulb',
    'peuls',
    'peult',
    'peulp',
    'peulh',
    'peum',
    'peub',
    'peubs',
    'peus',
    'peuss',
    'peung',
    'peuj',
    'peuc',
    'peuk',
    'peut',
    'peup',
    'peuh',
    'pyi',
    'pyig',
    'pyigg',
    'pyigs',
    'pyin',
    'pyinj',
    'pyinh',
    'pyid',
    'pyil',
    'pyilg',
    'pyilm',
    'pyilb',
    'pyils',
    'pyilt',
    'pyilp',
    'pyilh',
    'pyim',
    'pyib',
    'pyibs',
    'pyis',
    'pyiss',
    'pying',
    'pyij',
    'pyic',
    'pyik',
    'pyit',
    'pyip',
    'pyih',
    'pi',
    'pig',
    'pigg',
    'pigs',
    'pin',
    'pinj',
    'pinh',
    'pid',
    'pil',
    'pilg',
    'pilm',
    'pilb',
    'pils',
    'pilt',
    'pilp',
    'pilh',
    'pim',
    'pib',
    'pibs',
    'pis',
    'piss',
    'ping',
    'pij',
    'pic',
    'pik',
    'pit',
    'pip',
    'pih',
    'ha',
    'hag',
    'hagg',
    'hags',
    'han',
    'hanj',
    'hanh',
    'had',
    'hal',
    'halg',
    'halm',
    'halb',
    'hals',
    'halt',
    'halp',
    'halh',
    'ham',
    'hab',
    'habs',
    'has',
    'hass',
    'hang',
    'haj',
    'hac',
    'hak',
    'hat',
    'hap',
    'hah',
    'hae',
    'haeg',
    'haegg',
    'haegs',
    'haen',
    'haenj',
    'haenh',
    'haed',
    'hael',
    'haelg',
    'haelm',
    'haelb',
    'haels',
    'haelt',
    'haelp',
    'haelh',
    'haem',
    'haeb',
    'haebs',
    'haes',
    'haess',
    'haeng',
    'haej',
    'haec',
    'haek',
    'haet',
    'haep',
    'haeh',
    'hya',
    'hyag',
    'hyagg',
    'hyags',
    'hyan',
    'hyanj',
    'hyanh',
    'hyad',
    'hyal',
    'hyalg',
    'hyalm',
    'hyalb',
    'hyals',
    'hyalt',
    'hyalp',
    'hyalh',
    'hyam',
    'hyab',
    'hyabs',
    'hyas',
    'hyass',
    'hyang',
    'hyaj',
    'hyac',
    'hyak',
    'hyat',
    'hyap',
    'hyah',
    'hyae',
    'hyaeg',
    'hyaegg',
    'hyaegs',
    'hyaen',
    'hyaenj',
    'hyaenh',
    'hyaed',
    'hyael',
    'hyaelg',
    'hyaelm',
    'hyaelb',
    'hyaels',
    'hyaelt',
    'hyaelp',
    'hyaelh',
    'hyaem',
    'hyaeb',
    'hyaebs',
    'hyaes',
    'hyaess',
    'hyaeng',
    'hyaej',
    'hyaec',
    'hyaek',
    'hyaet',
    'hyaep',
    'hyaeh',
    'heo',
    'heog',
    'heogg',
    'heogs',
    'heon',
    'heonj',
    'heonh',
    'heod',
    'heol',
    'heolg',
    'heolm',
    'heolb',
    'heols',
    'heolt',
    'heolp',
    'heolh',
    'heom',
    'heob',
    'heobs',
    'heos',
    'heoss',
    'heong',
    'heoj',
    'heoc',
    'heok',
    'heot',
    'heop',
    'heoh',
    'he',
    'heg',
    'hegg',
    'hegs',
    'hen',
    'henj',
    'henh',
    'hed',
    'hel',
    'helg',
    'helm',
    'helb',
    'hels',
    'helt',
    'help',
    'helh',
    'hem',
    'heb',
    'hebs',
    'hes',
    'hess',
    'heng',
    'hej',
    'hec',
    'hek',
    'het',
    'hep',
    'heh'
];

},{}],"kzuEK":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:43 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'hyeo',
    'hyeog',
    'hyeogg',
    'hyeogs',
    'hyeon',
    'hyeonj',
    'hyeonh',
    'hyeod',
    'hyeol',
    'hyeolg',
    'hyeolm',
    'hyeolb',
    'hyeols',
    'hyeolt',
    'hyeolp',
    'hyeolh',
    'hyeom',
    'hyeob',
    'hyeobs',
    'hyeos',
    'hyeoss',
    'hyeong',
    'hyeoj',
    'hyeoc',
    'hyeok',
    'hyeot',
    'hyeop',
    'hyeoh',
    'hye',
    'hyeg',
    'hyegg',
    'hyegs',
    'hyen',
    'hyenj',
    'hyenh',
    'hyed',
    'hyel',
    'hyelg',
    'hyelm',
    'hyelb',
    'hyels',
    'hyelt',
    'hyelp',
    'hyelh',
    'hyem',
    'hyeb',
    'hyebs',
    'hyes',
    'hyess',
    'hyeng',
    'hyej',
    'hyec',
    'hyek',
    'hyet',
    'hyep',
    'hyeh',
    'ho',
    'hog',
    'hogg',
    'hogs',
    'hon',
    'honj',
    'honh',
    'hod',
    'hol',
    'holg',
    'holm',
    'holb',
    'hols',
    'holt',
    'holp',
    'holh',
    'hom',
    'hob',
    'hobs',
    'hos',
    'hoss',
    'hong',
    'hoj',
    'hoc',
    'hok',
    'hot',
    'hop',
    'hoh',
    'hwa',
    'hwag',
    'hwagg',
    'hwags',
    'hwan',
    'hwanj',
    'hwanh',
    'hwad',
    'hwal',
    'hwalg',
    'hwalm',
    'hwalb',
    'hwals',
    'hwalt',
    'hwalp',
    'hwalh',
    'hwam',
    'hwab',
    'hwabs',
    'hwas',
    'hwass',
    'hwang',
    'hwaj',
    'hwac',
    'hwak',
    'hwat',
    'hwap',
    'hwah',
    'hwae',
    'hwaeg',
    'hwaegg',
    'hwaegs',
    'hwaen',
    'hwaenj',
    'hwaenh',
    'hwaed',
    'hwael',
    'hwaelg',
    'hwaelm',
    'hwaelb',
    'hwaels',
    'hwaelt',
    'hwaelp',
    'hwaelh',
    'hwaem',
    'hwaeb',
    'hwaebs',
    'hwaes',
    'hwaess',
    'hwaeng',
    'hwaej',
    'hwaec',
    'hwaek',
    'hwaet',
    'hwaep',
    'hwaeh',
    'hoe',
    'hoeg',
    'hoegg',
    'hoegs',
    'hoen',
    'hoenj',
    'hoenh',
    'hoed',
    'hoel',
    'hoelg',
    'hoelm',
    'hoelb',
    'hoels',
    'hoelt',
    'hoelp',
    'hoelh',
    'hoem',
    'hoeb',
    'hoebs',
    'hoes',
    'hoess',
    'hoeng',
    'hoej',
    'hoec',
    'hoek',
    'hoet',
    'hoep',
    'hoeh',
    'hyo',
    'hyog',
    'hyogg',
    'hyogs',
    'hyon',
    'hyonj',
    'hyonh',
    'hyod',
    'hyol',
    'hyolg',
    'hyolm',
    'hyolb',
    'hyols',
    'hyolt',
    'hyolp',
    'hyolh',
    'hyom',
    'hyob',
    'hyobs',
    'hyos',
    'hyoss',
    'hyong',
    'hyoj',
    'hyoc',
    'hyok',
    'hyot',
    'hyop',
    'hyoh',
    'hu',
    'hug',
    'hugg',
    'hugs',
    'hun',
    'hunj',
    'hunh',
    'hud',
    'hul',
    'hulg',
    'hulm',
    'hulb',
    'huls',
    'hult',
    'hulp',
    'hulh',
    'hum',
    'hub',
    'hubs',
    'hus',
    'huss',
    'hung',
    'huj',
    'huc',
    'huk',
    'hut',
    'hup',
    'huh',
    'hweo',
    'hweog',
    'hweogg',
    'hweogs',
    'hweon',
    'hweonj',
    'hweonh',
    'hweod',
    'hweol',
    'hweolg',
    'hweolm',
    'hweolb',
    'hweols',
    'hweolt',
    'hweolp',
    'hweolh',
    'hweom',
    'hweob',
    'hweobs',
    'hweos',
    'hweoss',
    'hweong',
    'hweoj',
    'hweoc',
    'hweok',
    'hweot',
    'hweop',
    'hweoh',
    'hwe',
    'hweg',
    'hwegg',
    'hwegs'
];

},{}],"3QEib":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:13:56 MDT"
module.exports = [
    'hwen',
    'hwenj',
    'hwenh',
    'hwed',
    'hwel',
    'hwelg',
    'hwelm',
    'hwelb',
    'hwels',
    'hwelt',
    'hwelp',
    'hwelh',
    'hwem',
    'hweb',
    'hwebs',
    'hwes',
    'hwess',
    'hweng',
    'hwej',
    'hwec',
    'hwek',
    'hwet',
    'hwep',
    'hweh',
    'hwi',
    'hwig',
    'hwigg',
    'hwigs',
    'hwin',
    'hwinj',
    'hwinh',
    'hwid',
    'hwil',
    'hwilg',
    'hwilm',
    'hwilb',
    'hwils',
    'hwilt',
    'hwilp',
    'hwilh',
    'hwim',
    'hwib',
    'hwibs',
    'hwis',
    'hwiss',
    'hwing',
    'hwij',
    'hwic',
    'hwik',
    'hwit',
    'hwip',
    'hwih',
    'hyu',
    'hyug',
    'hyugg',
    'hyugs',
    'hyun',
    'hyunj',
    'hyunh',
    'hyud',
    'hyul',
    'hyulg',
    'hyulm',
    'hyulb',
    'hyuls',
    'hyult',
    'hyulp',
    'hyulh',
    'hyum',
    'hyub',
    'hyubs',
    'hyus',
    'hyuss',
    'hyung',
    'hyuj',
    'hyuc',
    'hyuk',
    'hyut',
    'hyup',
    'hyuh',
    'heu',
    'heug',
    'heugg',
    'heugs',
    'heun',
    'heunj',
    'heunh',
    'heud',
    'heul',
    'heulg',
    'heulm',
    'heulb',
    'heuls',
    'heult',
    'heulp',
    'heulh',
    'heum',
    'heub',
    'heubs',
    'heus',
    'heuss',
    'heung',
    'heuj',
    'heuc',
    'heuk',
    'heut',
    'heup',
    'heuh',
    'hyi',
    'hyig',
    'hyigg',
    'hyigs',
    'hyin',
    'hyinj',
    'hyinh',
    'hyid',
    'hyil',
    'hyilg',
    'hyilm',
    'hyilb',
    'hyils',
    'hyilt',
    'hyilp',
    'hyilh',
    'hyim',
    'hyib',
    'hyibs',
    'hyis',
    'hyiss',
    'hying',
    'hyij',
    'hyic',
    'hyik',
    'hyit',
    'hyip',
    'hyih',
    'hi',
    'hig',
    'higg',
    'higs',
    'hin',
    'hinj',
    'hinh',
    'hid',
    'hil',
    'hilg',
    'hilm',
    'hilb',
    'hils',
    'hilt',
    'hilp',
    'hilh',
    'him',
    'hib',
    'hibs',
    'his',
    'hiss',
    'hing',
    'hij',
    'hic',
    'hik',
    'hit',
    'hip',
    'hih',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"7bjJ6":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:43 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'Kay ',
    'Kayng ',
    'Ke ',
    'Ko ',
    'Kol ',
    'Koc ',
    'Kwi ',
    'Kwi ',
    'Kyun ',
    'Kul ',
    'Kum ',
    'Na ',
    'Na ',
    'Na ',
    'La ',
    'Na ',
    'Na ',
    'Na ',
    'Na ',
    'Na ',
    'Nak ',
    'Nak ',
    'Nak ',
    'Nak ',
    'Nak ',
    'Nak ',
    'Nak ',
    'Nan ',
    'Nan ',
    'Nan ',
    'Nan ',
    'Nan ',
    'Nan ',
    'Nam ',
    'Nam ',
    'Nam ',
    'Nam ',
    'Nap ',
    'Nap ',
    'Nap ',
    'Nang ',
    'Nang ',
    'Nang ',
    'Nang ',
    'Nang ',
    'Nay ',
    'Nayng ',
    'No ',
    'No ',
    'No ',
    'No ',
    'No ',
    'No ',
    'No ',
    'No ',
    'No ',
    'No ',
    'No ',
    'No ',
    'Nok ',
    'Nok ',
    'Nok ',
    'Nok ',
    'Nok ',
    'Nok ',
    'Non ',
    'Nong ',
    'Nong ',
    'Nong ',
    'Nong ',
    'Noy ',
    'Noy ',
    'Noy ',
    'Noy ',
    'Nwu ',
    'Nwu ',
    'Nwu ',
    'Nwu ',
    'Nwu ',
    'Nwu ',
    'Nwu ',
    'Nwu ',
    'Nuk ',
    'Nuk ',
    'Num ',
    'Nung ',
    'Nung ',
    'Nung ',
    'Nung ',
    'Nung ',
    'Twu ',
    'La ',
    'Lak ',
    'Lak ',
    'Lan ',
    'Lyeng ',
    'Lo ',
    'Lyul ',
    'Li ',
    'Pey ',
    'Pen ',
    'Pyen ',
    'Pwu ',
    'Pwul ',
    'Pi ',
    'Sak ',
    'Sak ',
    'Sam ',
    'Sayk ',
    'Sayng ',
    'Sep ',
    'Sey ',
    'Sway ',
    'Sin ',
    'Sim ',
    'Sip ',
    'Ya ',
    'Yak ',
    'Yak ',
    'Yang ',
    'Yang ',
    'Yang ',
    'Yang ',
    'Yang ',
    'Yang ',
    'Yang ',
    'Yang ',
    'Ye ',
    'Ye ',
    'Ye ',
    'Ye ',
    'Ye ',
    'Ye ',
    'Ye ',
    'Ye ',
    'Ye ',
    'Ye ',
    'Ye ',
    'Yek ',
    'Yek ',
    'Yek ',
    'Yek ',
    'Yen ',
    'Yen ',
    'Yen ',
    'Yen ',
    'Yen ',
    'Yen ',
    'Yen ',
    'Yen ',
    'Yen ',
    'Yen ',
    'Yen ',
    'Yen ',
    'Yen ',
    'Yen ',
    'Yel ',
    'Yel ',
    'Yel ',
    'Yel ',
    'Yel ',
    'Yel ',
    'Yem ',
    'Yem ',
    'Yem ',
    'Yem ',
    'Yem ',
    'Yep ',
    'Yeng ',
    'Yeng ',
    'Yeng ',
    'Yeng ',
    'Yeng ',
    'Yeng ',
    'Yeng ',
    'Yeng ',
    'Yeng ',
    'Yeng ',
    'Yeng ',
    'Yeng ',
    'Yeng ',
    'Yey ',
    'Yey ',
    'Yey ',
    'Yey ',
    'O ',
    'Yo ',
    'Yo ',
    'Yo ',
    'Yo ',
    'Yo ',
    'Yo ',
    'Yo ',
    'Yo ',
    'Yo ',
    'Yo ',
    'Yong ',
    'Wun ',
    'Wen ',
    'Yu ',
    'Yu ',
    'Yu ',
    'Yu ',
    'Yu ',
    'Yu ',
    'Yu ',
    'Yu ',
    'Yu ',
    'Yu ',
    'Yuk ',
    'Yuk ',
    'Yuk ',
    'Yun ',
    'Yun ',
    'Yun ',
    'Yun ',
    'Yul ',
    'Yul ',
    'Yul ',
    'Yul ',
    'Yung ',
    'I ',
    'I ',
    'I ',
    'I ',
    'I ',
    'I ',
    'I ',
    'I ',
    'I ',
    'I ',
    'I ',
    'I ',
    'I ',
    'I ',
    'Ik ',
    'Ik ',
    'In ',
    'In ',
    'In ',
    'In ',
    'In ',
    'In ',
    'In ',
    'Im ',
    'Im ',
    'Im ',
    'Ip ',
    'Ip ',
    'Ip ',
    'Cang ',
    'Cek ',
    'Ci ',
    'Cip ',
    'Cha ',
    'Chek '
];

},{}],"29Yyq":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-07-25 07:14:29 MDT"
module.exports = [
    'Chey ',
    'Thak ',
    'Thak ',
    'Thang ',
    'Thayk ',
    'Thong ',
    'Pho ',
    'Phok ',
    'Hang ',
    'Hang ',
    'Hyen ',
    'Hwak ',
    'Wu ',
    'Huo ',
    "[?] ",
    "[?] ",
    'Zhong ',
    "[?] ",
    'Qing ',
    "[?] ",
    "[?] ",
    'Xi ',
    'Zhu ',
    'Yi ',
    'Li ',
    'Shen ',
    'Xiang ',
    'Fu ',
    'Jing ',
    'Jing ',
    'Yu ',
    "[?] ",
    'Hagi ',
    "[?] ",
    'Zhu ',
    "[?] ",
    "[?] ",
    'Yi ',
    'Du ',
    "[?] ",
    "[?] ",
    "[?] ",
    'Fan ',
    'Si ',
    'Guan ',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]'
];

},{}],"g0cOw":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:43 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    'ff',
    'fi',
    'fl',
    'ffi',
    'ffl',
    'st',
    'st',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'mn',
    'me',
    'mi',
    'vn',
    'mkh',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    'yi',
    "",
    'ay',
    "`",
    "",
    'd',
    'h',
    'k',
    'l',
    'm',
    'm',
    't',
    "+",
    'sh',
    's',
    'sh',
    's',
    'a',
    'a',
    "",
    'b',
    'g',
    'd',
    'h',
    'v',
    'z',
    '[?]',
    't',
    'y',
    'k',
    'k',
    'l',
    '[?]',
    'l',
    '[?]',
    'n',
    'n',
    '[?]',
    'p',
    'p',
    '[?]',
    'ts',
    'ts',
    'r',
    'sh',
    't',
    'vo',
    'b',
    'k',
    'p',
    'l',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    ""
];

},{}],"5jNy7":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:43 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    ""
];

},{}],"akxgZ":[function(require,module,exports,__globalThis) {
//  Time-stamp: "2016-08-06 22:03:39 MDT"
module.exports = [
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    // ======================================================================
    //  FFD0 to FFEF = "Not A Character..."
    // FDD0
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    // FDE0
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    // ======================================================================
    // ======================================================================
    // perl -CO -e 'for( 0xFDF0 .. 0xFDFD) { printf "\"\",//  %04X p%cq\n", $_, $_; }'
    "{Salla}",
    //   FDF0	ARABIC LIGATURE SALLA USED AS KORANIC STOP SIGN ISOLATED FORM
    "{Qala}",
    //   FDF1	ARABIC LIGATURE QALA USED AS KORANIC STOP SIGN ISOLATED FORM
    "Allah",
    //   FDF2	ARABIC LIGATURE ALLAH ISOLATED FORM
    "Akbar",
    //   FDF3	ARABIC LIGATURE AKBAR ISOLATED FORM
    "Mohammed",
    //   FDF4	ARABIC LIGATURE MOHAMMAD ISOLATED FORM
    "SL`M",
    //   FDF5	ARABIC LIGATURE SALAM ISOLATED FORM
    "Rasul",
    //   FDF6	ARABIC LIGATURE RASOUL ISOLATED FORM
    "{Alayhi}",
    //   FDF7	ARABIC LIGATURE ALAYHE ISOLATED FORM
    "{WaSallam}",
    //   FDF8	ARABIC LIGATURE WASALLAM ISOLATED FORM
    "{Salla}",
    //   FDF9	ARABIC LIGATURE SALLA ISOLATED FORM
    "{Salla Llahu Alayhi WaSallam}",
    //   FDFA	ARABIC LIGATURE SALLALLAHOU ALAYHE WASALLAM
    "{Jalla Jalalahu}",
    //   FDFB	ARABIC LIGATURE JALLAJALALOUHOU
    "Rial ",
    //   FDFC	RIAL SIGN
    "{Bismillah Ar-Rahman Ar-Rahimi}",
    //   FDFD	ARABIC LIGATURE BISMILLAH AR-RAHMAN AR-RAHEEM
    //  And unassigned:
    "[?]",
    "[?]"
];

},{}],"emLzZ":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:44 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    "~",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "..",
    "--",
    "-",
    "_",
    "_",
    "(",
    ") ",
    "\\{",
    "\\} ",
    "[",
    "] ",
    "[(",
    ")] ",
    "<<",
    ">> ",
    "<",
    "> ",
    "[",
    "] ",
    "\\{",
    "\\}",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    ",",
    ",",
    ".",
    "",
    ";",
    ":",
    "?",
    "!",
    "-",
    "(",
    ")",
    "\\{",
    "\\}",
    "\\{",
    "\\}",
    "#",
    "&",
    "*",
    "+",
    "-",
    "<",
    ">",
    "=",
    "",
    "\\\\",
    "\\$",
    "%",
    "\\@",
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "",
    "",
    "",
    '[?]',
    "",
    '[?]',
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    '[?]',
    '[?]',
    ""
];

},{}],"gXDZe":[function(require,module,exports,__globalThis) {
//  Time-stamp: "Sat Jul 14 00:27:44 2001 by Automatic Bizooty (__blocks2pm.plx)"
module.exports = [
    '[?]',
    "!",
    "\"",
    "#",
    "\\$",
    "%",
    "&",
    "'",
    "(",
    ")",
    "*",
    "+",
    ",",
    "-",
    ".",
    "/",
    '0',
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    '7',
    '8',
    '9',
    ":",
    ";",
    "<",
    "=",
    ">",
    "?",
    "\\@",
    'A',
    'B',
    'C',
    'D',
    'E',
    'F',
    'G',
    'H',
    'I',
    'J',
    'K',
    'L',
    'M',
    'N',
    'O',
    'P',
    'Q',
    'R',
    'S',
    'T',
    'U',
    'V',
    'W',
    'X',
    'Y',
    'Z',
    "[",
    "\\\\",
    "]",
    "^",
    "_",
    "`",
    'a',
    'b',
    'c',
    'd',
    'e',
    'f',
    'g',
    'h',
    'i',
    'j',
    'k',
    'l',
    'm',
    'n',
    'o',
    'p',
    'q',
    'r',
    's',
    't',
    'u',
    'v',
    'w',
    'x',
    'y',
    'z',
    "\\{",
    "|",
    "\\}",
    "~",
    '[?]',
    '[?]',
    ".",
    "[",
    "]",
    ",",
    "*",
    'wo',
    'a',
    'i',
    'u',
    'e',
    'o',
    'ya',
    'yu',
    'yo',
    'tu',
    "+",
    'a',
    'i',
    'u',
    'e',
    'o',
    'ka',
    'ki',
    'ku',
    'ke',
    'ko',
    'sa',
    'si',
    'su',
    'se',
    'so',
    'ta',
    'ti',
    'tu',
    'te',
    'to',
    'na',
    'ni',
    'nu',
    'ne',
    'no',
    'ha',
    'hi',
    'hu',
    'he',
    'ho',
    'ma',
    'mi',
    'mu',
    'me',
    'mo',
    'ya',
    'yu',
    'yo',
    'ra',
    'ri',
    'ru',
    're',
    'ro',
    'wa',
    'n',
    ":",
    ";",
    "",
    'g',
    'gg',
    'gs',
    'n',
    'nj',
    'nh',
    'd',
    'dd',
    'r',
    'lg',
    'lm',
    'lb',
    'ls',
    'lt',
    'lp',
    'rh',
    'm',
    'b',
    'bb',
    'bs',
    's',
    'ss',
    "",
    'j',
    'jj',
    'c',
    'k',
    't',
    'p',
    'h',
    '[?]',
    '[?]',
    '[?]',
    'a',
    'ae',
    'ya',
    'yae',
    'eo',
    'e',
    '[?]',
    '[?]',
    'yeo',
    'ye',
    'o',
    'wa',
    'wae',
    'oe',
    '[?]',
    '[?]',
    'yo',
    'u',
    'weo',
    'we',
    'wi',
    'yu',
    '[?]',
    '[?]',
    'eu',
    'yi',
    'i',
    '[?]',
    '[?]',
    '[?]',
    "/C",
    'PS',
    "!",
    "-",
    "|",
    "Y=",
    "W=",
    '[?]',
    "|",
    "-",
    "|",
    "-",
    "|",
    "#",
    'O',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    '[?]',
    "\\{",
    "|",
    "\\}",
    "",
    "",
    "",
    ""
];

},{}],"53ndf":[function(require,module,exports,__globalThis) {
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "EventType", ()=>EventType);
parcelHelpers.export(exports, "SanctionLevel", ()=>SanctionLevel);
parcelHelpers.export(exports, "SanctionCategory", ()=>SanctionCategory);
var EventType = /*#__PURE__*/ function(EventType) {
    EventType["REGISTER"] = "REGISTER";
    EventType["OPEN_REGISTRATION"] = "OPEN_REGISTRATION";
    EventType["CLOSE_REGISTRATION"] = "CLOSE_REGISTRATION";
    EventType["OPEN_CHECKIN"] = "OPEN_CHECKIN";
    EventType["CANCEL_CHECKIN"] = "CANCEL_CHECKIN";
    EventType["CHECK_IN"] = "CHECK_IN";
    EventType["CHECK_EVERYONE_IN"] = "CHECK_EVERYONE_IN";
    EventType["CHECK_OUT"] = "CHECK_OUT";
    EventType["ROUND_START"] = "ROUND_START";
    EventType["ROUND_ALTER"] = "ROUND_ALTER";
    EventType["ROUND_FINISH"] = "ROUND_FINISH";
    EventType["ROUND_CANCEL"] = "ROUND_CANCEL";
    EventType["SET_RESULT"] = "SET_RESULT";
    EventType["SET_DECK"] = "SET_DECK";
    EventType["DROP"] = "DROP";
    EventType["SANCTION"] = "SANCTION";
    EventType["UNSANCTION"] = "UNSANCTION";
    EventType["OVERRIDE"] = "OVERRIDE";
    EventType["UNOVERRIDE"] = "UNOVERRIDE";
    EventType["SEED_FINALS"] = "SEED_FINALS";
    EventType["SEAT_FINALS"] = "SEAT_FINALS";
    EventType["FINISH_TOURNAMENT"] = "FINISH_TOURNAMENT";
    return EventType;
}({});
var SanctionLevel = /*#__PURE__*/ function(SanctionLevel) {
    SanctionLevel["CAUTION"] = "Caution";
    SanctionLevel["WARNING"] = "Warning";
    SanctionLevel["DISQUALIFICATION"] = "Disqualification";
    SanctionLevel["BAN"] = "Ban";
    return SanctionLevel;
}({});
var SanctionCategory = /*#__PURE__*/ function(SanctionCategory) {
    SanctionCategory["NONE"] = "";
    SanctionCategory["DECK_PROBLEM"] = "Deck Problem";
    SanctionCategory["PROCEDURAL_ERROR"] = "Procedural Error";
    SanctionCategory["CARD_DRAWING"] = "Card drawing";
    SanctionCategory["MARKED_CARDS"] = "Marked Cards";
    SanctionCategory["SLOW_PLAY"] = "Slow Play";
    SanctionCategory["UNSPORTSMANLIKE_CONDUCT"] = "Unsportsmanlike Conduct";
    SanctionCategory["CHEATING"] = "Cheating";
    SanctionCategory["ETHICS"] = "Ethics";
    return SanctionCategory;
}({});

},{"@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"1fFGC":[function(require,module,exports,__globalThis) {
// Some common display utilities
// badges, acronyms, score, etc.
var parcelHelpers = require("@parcel/transformer-js/src/esmodule-helpers.js");
parcelHelpers.defineInteropFlag(exports);
parcelHelpers.export(exports, "tournament_rank_badge", ()=>tournament_rank_badge);
parcelHelpers.export(exports, "format_badge", ()=>format_badge);
parcelHelpers.export(exports, "score_string", ()=>score_string);
parcelHelpers.export(exports, "score_string_with_tp_badge", ()=>score_string_with_tp_badge);
parcelHelpers.export(exports, "full_score_string", ()=>full_score_string);
parcelHelpers.export(exports, "tournament_result_string", ()=>tournament_result_string);
parcelHelpers.export(exports, "ranking_category", ()=>ranking_category);
parcelHelpers.export(exports, "DATETIME_UNAMBIGUOUS", ()=>DATETIME_UNAMBIGUOUS);
parcelHelpers.export(exports, "datetime", ()=>datetime);
parcelHelpers.export(exports, "datetime_finish", ()=>datetime_finish);
parcelHelpers.export(exports, "overlap", ()=>overlap);
parcelHelpers.export(exports, "datetime_string", ()=>datetime_string);
parcelHelpers.export(exports, "datetime_string_finish", ()=>datetime_string_finish);
parcelHelpers.export(exports, "date_string", ()=>date_string);
parcelHelpers.export(exports, "date_string_finish", ()=>date_string_finish);
parcelHelpers.export(exports, "standings", ()=>standings);
parcelHelpers.export(exports, "ranked_players", ()=>ranked_players);
parcelHelpers.export(exports, "ordinal", ()=>ordinal);
parcelHelpers.export(exports, "constrain_string", ()=>constrain_string);
var _d = require("./d");
var _luxon = require("luxon");
function tournament_rank_badge(tournament) {
    var cls;
    var txt;
    switch(tournament.rank){
        case _d.TournamentRank.NC:
            txt = "NC";
            cls = "text-bg-primary";
            break;
        case _d.TournamentRank.GP:
            txt = "GP";
            cls = "text-bg-warning";
            break;
        case _d.TournamentRank.CC:
            txt = "CC";
            cls = "text-bg-danger";
            break;
    }
    if (cls && txt) return `<span class="badge ${cls} align-text-top text-nowrap">${txt}</span>`;
    else return "";
}
function format_badge(event) {
    var cls;
    const txt = event.format;
    switch(event.format){
        case _d.TournamentFormat.Standard:
            cls = "text-bg-secondary";
            break;
        case _d.TournamentFormat.V5:
            cls = "text-bg-warning";
            break;
        case _d.TournamentFormat.Limited:
            cls = "text-bg-warning";
            break;
        case _d.TournamentFormat.Draft:
            cls = "text-bg-primary";
            break;
    }
    if (cls && txt) return `<span class="badge ${cls} align-text-top text-nowrap">${txt}</span>`;
    else return "";
}
function score_string(score) {
    if (score.gw) return `${score.gw}GW${score.vp}`;
    if (score.vp > 1) return `${score.vp}VPs`;
    return `${score.vp}VP`;
}
function score_string_with_tp_badge(score) {
    var ret;
    if (score.gw) ret = `${score.gw}GW${score.vp}`;
    else if (score.vp > 1) ret = `${score.vp}VPs`;
    else ret = `${score.vp}VP`;
    ret += ` <span class="badge text-bg-secondary align-text-top">${score.tp}TPs</span>`;
    return ret;
}
function full_score_string(player, rank) {
    const score = score_string(player.result);
    if (player.toss && player.toss > 0) return `<strong>${rank ?? player.seed}.</strong> ` + `${score} ` + `<span class="badge text-bg-secondary align-text-top">${player.result.tp}TPs, T: ${player.toss}</span>`;
    else return `<strong>${rank ?? player.seed}.</strong> ` + `${score} ` + `<span class="badge text-bg-secondary align-text-top">${player.result.tp}TPs</span>`;
}
function tournament_result_string(result) {
    return `<strong>${result.rank}.</strong> ${score_string(result.result)}`;
}
function ranking_category(tournament) {
    if (tournament.format == _d.TournamentFormat.Standard) {
        if (tournament?.online) return _d.RankingCategoy.CONSTRUCTED_ONLINE;
        return _d.RankingCategoy.CONSTRUCTED_ONSITE;
    }
    if (tournament?.online) return _d.RankingCategoy.LIMITED_ONLINE;
    return _d.RankingCategoy.LIMITED_ONSITE;
}
const DATETIME_UNAMBIGUOUS = {
    hour12: false,
    year: "numeric",
    month: "long",
    day: "numeric",
    timeZoneName: "short",
    hour: "2-digit",
    minute: "2-digit"
};
function _datetime(date, timezone) {
    const ret = (0, _luxon.DateTime).fromFormat(`${date} ${timezone}`, "yyyy-MM-dd'T'HH:mm:ss z", {
        setZone: true
    });
    if (ret.isValid) return ret;
    return undefined;
}
function datetime(tournament) {
    return _datetime(tournament.start, tournament.timezone);
}
function datetime_finish(tournament) {
    if (tournament.finish && tournament.finish.length > 0) return _datetime(tournament.finish, tournament.timezone);
    return undefined;
}
function overlap(lhs, start, finish, timezone) {
    const lhs_start = datetime(lhs);
    const rhs_start = _datetime(start, timezone) ?? lhs_start;
    const lhs_finish = datetime_finish(lhs) ?? rhs_start;
    const rhs_finish = _datetime(finish, timezone) ?? lhs_start;
    // use a one-day tolerance to avoid timezone fumbles
    return lhs_start <= rhs_finish.plus({
        days: 1
    }) && rhs_start <= lhs_finish.plus({
        days: 1
    });
}
function datetime_string(tournament) {
    if (!tournament) return "";
    const dt = datetime(tournament);
    if (!tournament.country || tournament.country.length < 1) return dt.toLocal().toLocaleString(DATETIME_UNAMBIGUOUS);
    else return dt.toLocaleString(DATETIME_UNAMBIGUOUS);
}
function datetime_string_finish(tournament) {
    if (!tournament || !tournament.finish) return "";
    const dt = _datetime(tournament.finish, tournament.timezone);
    if (!tournament.country || tournament.country.length < 1) return dt.toLocal().toLocaleString(DATETIME_UNAMBIGUOUS);
    else return dt.toLocaleString(DATETIME_UNAMBIGUOUS);
}
function date_string(tournament) {
    if (!tournament) return "";
    const dt = datetime(tournament);
    if (!tournament.country || tournament.country.length < 1) return dt.toLocal().toISODate();
    else return dt.toISODate();
}
function date_string_finish(tournament) {
    if (!tournament || !tournament.finish || tournament.finish === "") return "";
    const dt = _datetime(tournament.finish, tournament.timezone);
    if (!tournament.country || tournament.country.length < 1) return dt.toLocal().toISODate();
    else return dt.toISODate();
}
// ----------------------------------------------------------------------------------------------------------- Standings
function compare_arrays(lhs, rhs) {
    for(let i = 0; i < lhs.length; i++){
        if (lhs[i] < rhs[i]) return -1;
        if (lhs[i] > rhs[i]) return 1;
    }
    return 0;
}
function compare_players_standings(lhs, rhs) {
    const ret = compare_arrays(lhs[0], rhs[0]);
    if (ret != 0) return ret;
    return lhs[1].name.localeCompare(rhs[1].name);
}
function _calculate_rankings(tournament, players, ignore_toss = false) {
    function standings_array(p) {
        return [
            // dropouts go last (only matters when tournament in progress)
            +(p.state == _d.PlayerState.FINISHED),
            // winner always first if not DQ
            -(p.uid == tournament.winner),
            // then finalists (higher score can have dropped out)
            -tournament.finals_seeds.includes(p.uid),
            -p.result.gw,
            -p.result.vp,
            -p.result.tp,
            -(p.rating_points || 0),
            ignore_toss ? 0 : p.toss
        ];
    }
    const sorted_players = Object.values(players).map((p)=>[
            standings_array(p),
            p
        ]);
    sorted_players.sort(compare_players_standings);
    if (sorted_players.length < 1) return [];
    var rank = 1;
    var next_rank = 0;
    const res = [];
    var finalists = 5;
    if (tournament.state == _d.TournamentState.FINISHED) finalists = 0;
    var last_standings = sorted_players[0][0];
    for (const [standings_array, player] of sorted_players){
        if (finalists < 5) {
            finalists++;
            if (finalists == 1) rank = 1;
            else {
                next_rank++;
                rank = 2;
            }
        } else if (compare_arrays(last_standings, standings_array) < 0) {
            rank += next_rank;
            next_rank = 1;
            last_standings = standings_array;
        } else next_rank++;
        res.push([
            rank,
            player
        ]);
    }
    return res;
}
function standings(tournament, players, ignore_toss = false) {
    const players_list = Object.values(players ?? tournament.players).filter((p)=>p.rounds_played > 0);
    return _calculate_rankings(tournament, players_list, ignore_toss);
}
function ranked_players(tournament, players, ignore_toss = false) {
    const players_list = Object.values(players ?? tournament.players);
    return _calculate_rankings(tournament, players_list, ignore_toss);
}
function ordinal(n) {
    if (!n) return "";
    if (n <= 0) return n.toString();
    const suffix = n.toString().slice(-1);
    if (suffix == "1") return `${n}<sup>st</sup>`;
    if (suffix == "2") return `${n}<sup>nd</sup>`;
    if (suffix == "3") return `${n}<sup>rd</sup>`;
    return `${n}<sup>th</sup>`;
}
function constrain_string(str, max_length) {
    if (str.length <= max_length) return str;
    return str.slice(0, max_length - 1) + "\u2026";
}

},{"./d":"8rVEj","luxon":"dpK6X","@parcel/transformer-js/src/esmodule-helpers.js":"gkKU3"}],"dpK6X":[function(require,module,exports,__globalThis) {
'use strict';
Object.defineProperty(exports, '__esModule', {
    value: true
});
function _defineProperties(target, props) {
    for(var i = 0; i < props.length; i++){
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) descriptor.writable = true;
        Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor);
    }
}
function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);
    if (staticProps) _defineProperties(Constructor, staticProps);
    Object.defineProperty(Constructor, "prototype", {
        writable: false
    });
    return Constructor;
}
function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for(var i = 1; i < arguments.length; i++){
            var source = arguments[i];
            for(var key in source)if (Object.prototype.hasOwnProperty.call(source, key)) target[key] = source[key];
        }
        return target;
    };
    return _extends.apply(this, arguments);
}
function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass);
}
function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) {
        return o.__proto__ || Object.getPrototypeOf(o);
    };
    return _getPrototypeOf(o);
}
function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) {
        o.__proto__ = p;
        return o;
    };
    return _setPrototypeOf(o, p);
}
function _isNativeReflectConstruct() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;
    if (Reflect.construct.sham) return false;
    if (typeof Proxy === "function") return true;
    try {
        Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function() {}));
        return true;
    } catch (e) {
        return false;
    }
}
function _construct(Parent, args, Class) {
    if (_isNativeReflectConstruct()) _construct = Reflect.construct.bind();
    else _construct = function _construct(Parent, args, Class) {
        var a = [
            null
        ];
        a.push.apply(a, args);
        var Constructor = Function.bind.apply(Parent, a);
        var instance = new Constructor();
        if (Class) _setPrototypeOf(instance, Class.prototype);
        return instance;
    };
    return _construct.apply(null, arguments);
}
function _isNativeFunction(fn) {
    return Function.toString.call(fn).indexOf("[native code]") !== -1;
}
function _wrapNativeSuper(Class) {
    var _cache = typeof Map === "function" ? new Map() : undefined;
    _wrapNativeSuper = function _wrapNativeSuper(Class) {
        if (Class === null || !_isNativeFunction(Class)) return Class;
        if (typeof Class !== "function") throw new TypeError("Super expression must either be null or a function");
        if (typeof _cache !== "undefined") {
            if (_cache.has(Class)) return _cache.get(Class);
            _cache.set(Class, Wrapper);
        }
        function Wrapper() {
            return _construct(Class, arguments, _getPrototypeOf(this).constructor);
        }
        Wrapper.prototype = Object.create(Class.prototype, {
            constructor: {
                value: Wrapper,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        return _setPrototypeOf(Wrapper, Class);
    };
    return _wrapNativeSuper(Class);
}
function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;
    for(i = 0; i < sourceKeys.length; i++){
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        target[key] = source[key];
    }
    return target;
}
function _unsupportedIterableToArray(o, minLen) {
    if (!o) return;
    if (typeof o === "string") return _arrayLikeToArray(o, minLen);
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if (n === "Object" && o.constructor) n = o.constructor.name;
    if (n === "Map" || n === "Set") return Array.from(o);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}
function _arrayLikeToArray(arr, len) {
    if (len == null || len > arr.length) len = arr.length;
    for(var i = 0, arr2 = new Array(len); i < len; i++)arr2[i] = arr[i];
    return arr2;
}
function _createForOfIteratorHelperLoose(o, allowArrayLike) {
    var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
    if (it) return (it = it.call(o)).next.bind(it);
    if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
        if (it) o = it;
        var i = 0;
        return function() {
            if (i >= o.length) return {
                done: true
            };
            return {
                done: false,
                value: o[i++]
            };
        };
    }
    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
function _toPrimitive(input, hint) {
    if (typeof input !== "object" || input === null) return input;
    var prim = input[Symbol.toPrimitive];
    if (prim !== undefined) {
        var res = prim.call(input, hint || "default");
        if (typeof res !== "object") return res;
        throw new TypeError("@@toPrimitive must return a primitive value.");
    }
    return (hint === "string" ? String : Number)(input);
}
function _toPropertyKey(arg) {
    var key = _toPrimitive(arg, "string");
    return typeof key === "symbol" ? key : String(key);
}
// these aren't really private, but nor are they really useful to document
/**
 * @private
 */ var LuxonError = /*#__PURE__*/ function(_Error) {
    _inheritsLoose(LuxonError, _Error);
    function LuxonError() {
        return _Error.apply(this, arguments) || this;
    }
    return LuxonError;
}(/*#__PURE__*/ _wrapNativeSuper(Error));
/**
 * @private
 */ var InvalidDateTimeError = /*#__PURE__*/ function(_LuxonError) {
    _inheritsLoose(InvalidDateTimeError, _LuxonError);
    function InvalidDateTimeError(reason) {
        return _LuxonError.call(this, "Invalid DateTime: " + reason.toMessage()) || this;
    }
    return InvalidDateTimeError;
}(LuxonError);
/**
 * @private
 */ var InvalidIntervalError = /*#__PURE__*/ function(_LuxonError2) {
    _inheritsLoose(InvalidIntervalError, _LuxonError2);
    function InvalidIntervalError(reason) {
        return _LuxonError2.call(this, "Invalid Interval: " + reason.toMessage()) || this;
    }
    return InvalidIntervalError;
}(LuxonError);
/**
 * @private
 */ var InvalidDurationError = /*#__PURE__*/ function(_LuxonError3) {
    _inheritsLoose(InvalidDurationError, _LuxonError3);
    function InvalidDurationError(reason) {
        return _LuxonError3.call(this, "Invalid Duration: " + reason.toMessage()) || this;
    }
    return InvalidDurationError;
}(LuxonError);
/**
 * @private
 */ var ConflictingSpecificationError = /*#__PURE__*/ function(_LuxonError4) {
    _inheritsLoose(ConflictingSpecificationError, _LuxonError4);
    function ConflictingSpecificationError() {
        return _LuxonError4.apply(this, arguments) || this;
    }
    return ConflictingSpecificationError;
}(LuxonError);
/**
 * @private
 */ var InvalidUnitError = /*#__PURE__*/ function(_LuxonError5) {
    _inheritsLoose(InvalidUnitError, _LuxonError5);
    function InvalidUnitError(unit) {
        return _LuxonError5.call(this, "Invalid unit " + unit) || this;
    }
    return InvalidUnitError;
}(LuxonError);
/**
 * @private
 */ var InvalidArgumentError = /*#__PURE__*/ function(_LuxonError6) {
    _inheritsLoose(InvalidArgumentError, _LuxonError6);
    function InvalidArgumentError() {
        return _LuxonError6.apply(this, arguments) || this;
    }
    return InvalidArgumentError;
}(LuxonError);
/**
 * @private
 */ var ZoneIsAbstractError = /*#__PURE__*/ function(_LuxonError7) {
    _inheritsLoose(ZoneIsAbstractError, _LuxonError7);
    function ZoneIsAbstractError() {
        return _LuxonError7.call(this, "Zone is an abstract class") || this;
    }
    return ZoneIsAbstractError;
}(LuxonError);
/**
 * @private
 */ var n = "numeric", s = "short", l = "long";
var DATE_SHORT = {
    year: n,
    month: n,
    day: n
};
var DATE_MED = {
    year: n,
    month: s,
    day: n
};
var DATE_MED_WITH_WEEKDAY = {
    year: n,
    month: s,
    day: n,
    weekday: s
};
var DATE_FULL = {
    year: n,
    month: l,
    day: n
};
var DATE_HUGE = {
    year: n,
    month: l,
    day: n,
    weekday: l
};
var TIME_SIMPLE = {
    hour: n,
    minute: n
};
var TIME_WITH_SECONDS = {
    hour: n,
    minute: n,
    second: n
};
var TIME_WITH_SHORT_OFFSET = {
    hour: n,
    minute: n,
    second: n,
    timeZoneName: s
};
var TIME_WITH_LONG_OFFSET = {
    hour: n,
    minute: n,
    second: n,
    timeZoneName: l
};
var TIME_24_SIMPLE = {
    hour: n,
    minute: n,
    hourCycle: "h23"
};
var TIME_24_WITH_SECONDS = {
    hour: n,
    minute: n,
    second: n,
    hourCycle: "h23"
};
var TIME_24_WITH_SHORT_OFFSET = {
    hour: n,
    minute: n,
    second: n,
    hourCycle: "h23",
    timeZoneName: s
};
var TIME_24_WITH_LONG_OFFSET = {
    hour: n,
    minute: n,
    second: n,
    hourCycle: "h23",
    timeZoneName: l
};
var DATETIME_SHORT = {
    year: n,
    month: n,
    day: n,
    hour: n,
    minute: n
};
var DATETIME_SHORT_WITH_SECONDS = {
    year: n,
    month: n,
    day: n,
    hour: n,
    minute: n,
    second: n
};
var DATETIME_MED = {
    year: n,
    month: s,
    day: n,
    hour: n,
    minute: n
};
var DATETIME_MED_WITH_SECONDS = {
    year: n,
    month: s,
    day: n,
    hour: n,
    minute: n,
    second: n
};
var DATETIME_MED_WITH_WEEKDAY = {
    year: n,
    month: s,
    day: n,
    weekday: s,
    hour: n,
    minute: n
};
var DATETIME_FULL = {
    year: n,
    month: l,
    day: n,
    hour: n,
    minute: n,
    timeZoneName: s
};
var DATETIME_FULL_WITH_SECONDS = {
    year: n,
    month: l,
    day: n,
    hour: n,
    minute: n,
    second: n,
    timeZoneName: s
};
var DATETIME_HUGE = {
    year: n,
    month: l,
    day: n,
    weekday: l,
    hour: n,
    minute: n,
    timeZoneName: l
};
var DATETIME_HUGE_WITH_SECONDS = {
    year: n,
    month: l,
    day: n,
    weekday: l,
    hour: n,
    minute: n,
    second: n,
    timeZoneName: l
};
/**
 * @interface
 */ var Zone = /*#__PURE__*/ function() {
    function Zone() {}
    var _proto = Zone.prototype;
    /**
   * Returns the offset's common name (such as EST) at the specified timestamp
   * @abstract
   * @param {number} ts - Epoch milliseconds for which to get the name
   * @param {Object} opts - Options to affect the format
   * @param {string} opts.format - What style of offset to return. Accepts 'long' or 'short'.
   * @param {string} opts.locale - What locale to return the offset name in.
   * @return {string}
   */ _proto.offsetName = function offsetName(ts, opts) {
        throw new ZoneIsAbstractError();
    };
    _proto.formatOffset = function formatOffset(ts, format) {
        throw new ZoneIsAbstractError();
    };
    _proto.offset = function offset(ts) {
        throw new ZoneIsAbstractError();
    };
    _proto.equals = function equals(otherZone) {
        throw new ZoneIsAbstractError();
    };
    _createClass(Zone, [
        {
            key: "type",
            get: /**
     * The type of zone
     * @abstract
     * @type {string}
     */ function get() {
                throw new ZoneIsAbstractError();
            }
        },
        {
            key: "name",
            get: function get() {
                throw new ZoneIsAbstractError();
            }
        },
        {
            key: "ianaName",
            get: function get() {
                return this.name;
            }
        },
        {
            key: "isUniversal",
            get: function get() {
                throw new ZoneIsAbstractError();
            }
        },
        {
            key: "isValid",
            get: function get() {
                throw new ZoneIsAbstractError();
            }
        }
    ]);
    return Zone;
}();
var singleton$1 = null;
/**
 * Represents the local zone for this JavaScript environment.
 * @implements {Zone}
 */ var SystemZone = /*#__PURE__*/ function(_Zone) {
    _inheritsLoose(SystemZone, _Zone);
    function SystemZone() {
        return _Zone.apply(this, arguments) || this;
    }
    var _proto = SystemZone.prototype;
    /** @override **/ _proto.offsetName = function offsetName(ts, _ref) {
        var format = _ref.format, locale = _ref.locale;
        return parseZoneInfo(ts, format, locale);
    };
    _proto.formatOffset = function formatOffset$1(ts, format) {
        return formatOffset(this.offset(ts), format);
    };
    _proto.offset = function offset(ts) {
        return -new Date(ts).getTimezoneOffset();
    };
    _proto.equals = function equals(otherZone) {
        return otherZone.type === "system";
    };
    _createClass(SystemZone, [
        {
            key: "type",
            get: /** @override **/ function get() {
                return "system";
            }
        },
        {
            key: "name",
            get: function get() {
                return new Intl.DateTimeFormat().resolvedOptions().timeZone;
            }
        },
        {
            key: "isUniversal",
            get: function get() {
                return false;
            }
        },
        {
            key: "isValid",
            get: function get() {
                return true;
            }
        }
    ], [
        {
            key: "instance",
            get: /**
     * Get a singleton instance of the local zone
     * @return {SystemZone}
     */ function get() {
                if (singleton$1 === null) singleton$1 = new SystemZone();
                return singleton$1;
            }
        }
    ]);
    return SystemZone;
}(Zone);
var dtfCache = new Map();
function makeDTF(zoneName) {
    var dtf = dtfCache.get(zoneName);
    if (dtf === undefined) {
        dtf = new Intl.DateTimeFormat("en-US", {
            hour12: false,
            timeZone: zoneName,
            year: "numeric",
            month: "2-digit",
            day: "2-digit",
            hour: "2-digit",
            minute: "2-digit",
            second: "2-digit",
            era: "short"
        });
        dtfCache.set(zoneName, dtf);
    }
    return dtf;
}
var typeToPos = {
    year: 0,
    month: 1,
    day: 2,
    era: 3,
    hour: 4,
    minute: 5,
    second: 6
};
function hackyOffset(dtf, date) {
    var formatted = dtf.format(date).replace(/\u200E/g, ""), parsed = /(\d+)\/(\d+)\/(\d+) (AD|BC),? (\d+):(\d+):(\d+)/.exec(formatted), fMonth = parsed[1], fDay = parsed[2], fYear = parsed[3], fadOrBc = parsed[4], fHour = parsed[5], fMinute = parsed[6], fSecond = parsed[7];
    return [
        fYear,
        fMonth,
        fDay,
        fadOrBc,
        fHour,
        fMinute,
        fSecond
    ];
}
function partsOffset(dtf, date) {
    var formatted = dtf.formatToParts(date);
    var filled = [];
    for(var i = 0; i < formatted.length; i++){
        var _formatted$i = formatted[i], type = _formatted$i.type, value = _formatted$i.value;
        var pos = typeToPos[type];
        if (type === "era") filled[pos] = value;
        else if (!isUndefined(pos)) filled[pos] = parseInt(value, 10);
    }
    return filled;
}
var ianaZoneCache = new Map();
/**
 * A zone identified by an IANA identifier, like America/New_York
 * @implements {Zone}
 */ var IANAZone = /*#__PURE__*/ function(_Zone) {
    _inheritsLoose(IANAZone, _Zone);
    /**
   * @param {string} name - Zone name
   * @return {IANAZone}
   */ IANAZone.create = function create(name) {
        var zone = ianaZoneCache.get(name);
        if (zone === undefined) ianaZoneCache.set(name, zone = new IANAZone(name));
        return zone;
    };
    IANAZone.resetCache = function resetCache() {
        ianaZoneCache.clear();
        dtfCache.clear();
    };
    IANAZone.isValidSpecifier = function isValidSpecifier(s) {
        return this.isValidZone(s);
    };
    IANAZone.isValidZone = function isValidZone(zone) {
        if (!zone) return false;
        try {
            new Intl.DateTimeFormat("en-US", {
                timeZone: zone
            }).format();
            return true;
        } catch (e) {
            return false;
        }
    };
    function IANAZone(name) {
        var _this;
        _this = _Zone.call(this) || this;
        /** @private **/ _this.zoneName = name;
        /** @private **/ _this.valid = IANAZone.isValidZone(name);
        return _this;
    }
    /**
   * The type of zone. `iana` for all instances of `IANAZone`.
   * @override
   * @type {string}
   */ var _proto = IANAZone.prototype;
    /**
   * Returns the offset's common name (such as EST) at the specified timestamp
   * @override
   * @param {number} ts - Epoch milliseconds for which to get the name
   * @param {Object} opts - Options to affect the format
   * @param {string} opts.format - What style of offset to return. Accepts 'long' or 'short'.
   * @param {string} opts.locale - What locale to return the offset name in.
   * @return {string}
   */ _proto.offsetName = function offsetName(ts, _ref) {
        var format = _ref.format, locale = _ref.locale;
        return parseZoneInfo(ts, format, locale, this.name);
    };
    _proto.formatOffset = function formatOffset$1(ts, format) {
        return formatOffset(this.offset(ts), format);
    };
    _proto.offset = function offset(ts) {
        if (!this.valid) return NaN;
        var date = new Date(ts);
        if (isNaN(date)) return NaN;
        var dtf = makeDTF(this.name);
        var _ref2 = dtf.formatToParts ? partsOffset(dtf, date) : hackyOffset(dtf, date), year = _ref2[0], month = _ref2[1], day = _ref2[2], adOrBc = _ref2[3], hour = _ref2[4], minute = _ref2[5], second = _ref2[6];
        if (adOrBc === "BC") year = -Math.abs(year) + 1;
        // because we're using hour12 and https://bugs.chromium.org/p/chromium/issues/detail?id=1025564&can=2&q=%2224%3A00%22%20datetimeformat
        var adjustedHour = hour === 24 ? 0 : hour;
        var asUTC = objToLocalTS({
            year: year,
            month: month,
            day: day,
            hour: adjustedHour,
            minute: minute,
            second: second,
            millisecond: 0
        });
        var asTS = +date;
        var over = asTS % 1000;
        asTS -= over >= 0 ? over : 1000 + over;
        return (asUTC - asTS) / 60000;
    };
    _proto.equals = function equals(otherZone) {
        return otherZone.type === "iana" && otherZone.name === this.name;
    };
    _createClass(IANAZone, [
        {
            key: "type",
            get: function get() {
                return "iana";
            }
        },
        {
            key: "name",
            get: function get() {
                return this.zoneName;
            }
        },
        {
            key: "isUniversal",
            get: function get() {
                return false;
            }
        },
        {
            key: "isValid",
            get: function get() {
                return this.valid;
            }
        }
    ]);
    return IANAZone;
}(Zone);
var _excluded = [
    "base"
], _excluded2 = [
    "padTo",
    "floor"
];
// todo - remap caching
var intlLFCache = {};
function getCachedLF(locString, opts) {
    if (opts === void 0) opts = {};
    var key = JSON.stringify([
        locString,
        opts
    ]);
    var dtf = intlLFCache[key];
    if (!dtf) {
        dtf = new Intl.ListFormat(locString, opts);
        intlLFCache[key] = dtf;
    }
    return dtf;
}
var intlDTCache = new Map();
function getCachedDTF(locString, opts) {
    if (opts === void 0) opts = {};
    var key = JSON.stringify([
        locString,
        opts
    ]);
    var dtf = intlDTCache.get(key);
    if (dtf === undefined) {
        dtf = new Intl.DateTimeFormat(locString, opts);
        intlDTCache.set(key, dtf);
    }
    return dtf;
}
var intlNumCache = new Map();
function getCachedINF(locString, opts) {
    if (opts === void 0) opts = {};
    var key = JSON.stringify([
        locString,
        opts
    ]);
    var inf = intlNumCache.get(key);
    if (inf === undefined) {
        inf = new Intl.NumberFormat(locString, opts);
        intlNumCache.set(key, inf);
    }
    return inf;
}
var intlRelCache = new Map();
function getCachedRTF(locString, opts) {
    if (opts === void 0) opts = {};
    var _opts = opts;
    _opts.base;
    var cacheKeyOpts = _objectWithoutPropertiesLoose(_opts, _excluded); // exclude `base` from the options
    var key = JSON.stringify([
        locString,
        cacheKeyOpts
    ]);
    var inf = intlRelCache.get(key);
    if (inf === undefined) {
        inf = new Intl.RelativeTimeFormat(locString, opts);
        intlRelCache.set(key, inf);
    }
    return inf;
}
var sysLocaleCache = null;
function systemLocale() {
    if (sysLocaleCache) return sysLocaleCache;
    else {
        sysLocaleCache = new Intl.DateTimeFormat().resolvedOptions().locale;
        return sysLocaleCache;
    }
}
var intlResolvedOptionsCache = new Map();
function getCachedIntResolvedOptions(locString) {
    var opts = intlResolvedOptionsCache.get(locString);
    if (opts === undefined) {
        opts = new Intl.DateTimeFormat(locString).resolvedOptions();
        intlResolvedOptionsCache.set(locString, opts);
    }
    return opts;
}
var weekInfoCache = new Map();
function getCachedWeekInfo(locString) {
    var data = weekInfoCache.get(locString);
    if (!data) {
        var locale = new Intl.Locale(locString);
        // browsers currently implement this as a property, but spec says it should be a getter function
        data = "getWeekInfo" in locale ? locale.getWeekInfo() : locale.weekInfo;
        // minimalDays was removed from WeekInfo: https://github.com/tc39/proposal-intl-locale-info/issues/86
        if (!("minimalDays" in data)) data = _extends({}, fallbackWeekSettings, data);
        weekInfoCache.set(locString, data);
    }
    return data;
}
function parseLocaleString(localeStr) {
    // I really want to avoid writing a BCP 47 parser
    // see, e.g. https://github.com/wooorm/bcp-47
    // Instead, we'll do this:
    // a) if the string has no -u extensions, just leave it alone
    // b) if it does, use Intl to resolve everything
    // c) if Intl fails, try again without the -u
    // private subtags and unicode subtags have ordering requirements,
    // and we're not properly parsing this, so just strip out the
    // private ones if they exist.
    var xIndex = localeStr.indexOf("-x-");
    if (xIndex !== -1) localeStr = localeStr.substring(0, xIndex);
    var uIndex = localeStr.indexOf("-u-");
    if (uIndex === -1) return [
        localeStr
    ];
    else {
        var options;
        var selectedStr;
        try {
            options = getCachedDTF(localeStr).resolvedOptions();
            selectedStr = localeStr;
        } catch (e) {
            var smaller = localeStr.substring(0, uIndex);
            options = getCachedDTF(smaller).resolvedOptions();
            selectedStr = smaller;
        }
        var _options = options, numberingSystem = _options.numberingSystem, calendar = _options.calendar;
        return [
            selectedStr,
            numberingSystem,
            calendar
        ];
    }
}
function intlConfigString(localeStr, numberingSystem, outputCalendar) {
    if (outputCalendar || numberingSystem) {
        if (!localeStr.includes("-u-")) localeStr += "-u";
        if (outputCalendar) localeStr += "-ca-" + outputCalendar;
        if (numberingSystem) localeStr += "-nu-" + numberingSystem;
        return localeStr;
    } else return localeStr;
}
function mapMonths(f) {
    var ms = [];
    for(var i = 1; i <= 12; i++){
        var dt = DateTime.utc(2009, i, 1);
        ms.push(f(dt));
    }
    return ms;
}
function mapWeekdays(f) {
    var ms = [];
    for(var i = 1; i <= 7; i++){
        var dt = DateTime.utc(2016, 11, 13 + i);
        ms.push(f(dt));
    }
    return ms;
}
function listStuff(loc, length, englishFn, intlFn) {
    var mode = loc.listingMode();
    if (mode === "error") return null;
    else if (mode === "en") return englishFn(length);
    else return intlFn(length);
}
function supportsFastNumbers(loc) {
    if (loc.numberingSystem && loc.numberingSystem !== "latn") return false;
    else return loc.numberingSystem === "latn" || !loc.locale || loc.locale.startsWith("en") || getCachedIntResolvedOptions(loc.locale).numberingSystem === "latn";
}
/**
 * @private
 */ var PolyNumberFormatter = /*#__PURE__*/ function() {
    function PolyNumberFormatter(intl, forceSimple, opts) {
        this.padTo = opts.padTo || 0;
        this.floor = opts.floor || false;
        opts.padTo;
        opts.floor;
        var otherOpts = _objectWithoutPropertiesLoose(opts, _excluded2);
        if (!forceSimple || Object.keys(otherOpts).length > 0) {
            var intlOpts = _extends({
                useGrouping: false
            }, opts);
            if (opts.padTo > 0) intlOpts.minimumIntegerDigits = opts.padTo;
            this.inf = getCachedINF(intl, intlOpts);
        }
    }
    var _proto = PolyNumberFormatter.prototype;
    _proto.format = function format(i) {
        if (this.inf) {
            var fixed = this.floor ? Math.floor(i) : i;
            return this.inf.format(fixed);
        } else {
            // to match the browser's numberformatter defaults
            var _fixed = this.floor ? Math.floor(i) : roundTo(i, 3);
            return padStart(_fixed, this.padTo);
        }
    };
    return PolyNumberFormatter;
}();
/**
 * @private
 */ var PolyDateFormatter = /*#__PURE__*/ function() {
    function PolyDateFormatter(dt, intl, opts) {
        this.opts = opts;
        this.originalZone = undefined;
        var z = undefined;
        if (this.opts.timeZone) // Don't apply any workarounds if a timeZone is explicitly provided in opts
        this.dt = dt;
        else if (dt.zone.type === "fixed") {
            // UTC-8 or Etc/UTC-8 are not part of tzdata, only Etc/GMT+8 and the like.
            // That is why fixed-offset TZ is set to that unless it is:
            // 1. Representing offset 0 when UTC is used to maintain previous behavior and does not become GMT.
            // 2. Unsupported by the browser:
            //    - some do not support Etc/
            //    - < Etc/GMT-14, > Etc/GMT+12, and 30-minute or 45-minute offsets are not part of tzdata
            var gmtOffset = -1 * (dt.offset / 60);
            var offsetZ = gmtOffset >= 0 ? "Etc/GMT+" + gmtOffset : "Etc/GMT" + gmtOffset;
            if (dt.offset !== 0 && IANAZone.create(offsetZ).valid) {
                z = offsetZ;
                this.dt = dt;
            } else {
                // Not all fixed-offset zones like Etc/+4:30 are present in tzdata so
                // we manually apply the offset and substitute the zone as needed.
                z = "UTC";
                this.dt = dt.offset === 0 ? dt : dt.setZone("UTC").plus({
                    minutes: dt.offset
                });
                this.originalZone = dt.zone;
            }
        } else if (dt.zone.type === "system") this.dt = dt;
        else if (dt.zone.type === "iana") {
            this.dt = dt;
            z = dt.zone.name;
        } else {
            // Custom zones can have any offset / offsetName so we just manually
            // apply the offset and substitute the zone as needed.
            z = "UTC";
            this.dt = dt.setZone("UTC").plus({
                minutes: dt.offset
            });
            this.originalZone = dt.zone;
        }
        var intlOpts = _extends({}, this.opts);
        intlOpts.timeZone = intlOpts.timeZone || z;
        this.dtf = getCachedDTF(intl, intlOpts);
    }
    var _proto2 = PolyDateFormatter.prototype;
    _proto2.format = function format() {
        if (this.originalZone) // If we have to substitute in the actual zone name, we have to use
        // formatToParts so that the timezone can be replaced.
        return this.formatToParts().map(function(_ref) {
            var value = _ref.value;
            return value;
        }).join("");
        return this.dtf.format(this.dt.toJSDate());
    };
    _proto2.formatToParts = function formatToParts() {
        var _this = this;
        var parts = this.dtf.formatToParts(this.dt.toJSDate());
        if (this.originalZone) return parts.map(function(part) {
            if (part.type === "timeZoneName") {
                var offsetName = _this.originalZone.offsetName(_this.dt.ts, {
                    locale: _this.dt.locale,
                    format: _this.opts.timeZoneName
                });
                return _extends({}, part, {
                    value: offsetName
                });
            } else return part;
        });
        return parts;
    };
    _proto2.resolvedOptions = function resolvedOptions() {
        return this.dtf.resolvedOptions();
    };
    return PolyDateFormatter;
}();
/**
 * @private
 */ var PolyRelFormatter = /*#__PURE__*/ function() {
    function PolyRelFormatter(intl, isEnglish, opts) {
        this.opts = _extends({
            style: "long"
        }, opts);
        if (!isEnglish && hasRelative()) this.rtf = getCachedRTF(intl, opts);
    }
    var _proto3 = PolyRelFormatter.prototype;
    _proto3.format = function format(count, unit) {
        if (this.rtf) return this.rtf.format(count, unit);
        else return formatRelativeTime(unit, count, this.opts.numeric, this.opts.style !== "long");
    };
    _proto3.formatToParts = function formatToParts(count, unit) {
        if (this.rtf) return this.rtf.formatToParts(count, unit);
        else return [];
    };
    return PolyRelFormatter;
}();
var fallbackWeekSettings = {
    firstDay: 1,
    minimalDays: 4,
    weekend: [
        6,
        7
    ]
};
/**
 * @private
 */ var Locale = /*#__PURE__*/ function() {
    Locale.fromOpts = function fromOpts(opts) {
        return Locale.create(opts.locale, opts.numberingSystem, opts.outputCalendar, opts.weekSettings, opts.defaultToEN);
    };
    Locale.create = function create(locale, numberingSystem, outputCalendar, weekSettings, defaultToEN) {
        if (defaultToEN === void 0) defaultToEN = false;
        var specifiedLocale = locale || Settings.defaultLocale;
        // the system locale is useful for human-readable strings but annoying for parsing/formatting known formats
        var localeR = specifiedLocale || (defaultToEN ? "en-US" : systemLocale());
        var numberingSystemR = numberingSystem || Settings.defaultNumberingSystem;
        var outputCalendarR = outputCalendar || Settings.defaultOutputCalendar;
        var weekSettingsR = validateWeekSettings(weekSettings) || Settings.defaultWeekSettings;
        return new Locale(localeR, numberingSystemR, outputCalendarR, weekSettingsR, specifiedLocale);
    };
    Locale.resetCache = function resetCache() {
        sysLocaleCache = null;
        intlDTCache.clear();
        intlNumCache.clear();
        intlRelCache.clear();
        intlResolvedOptionsCache.clear();
        weekInfoCache.clear();
    };
    Locale.fromObject = function fromObject(_temp) {
        var _ref2 = _temp === void 0 ? {} : _temp, locale = _ref2.locale, numberingSystem = _ref2.numberingSystem, outputCalendar = _ref2.outputCalendar, weekSettings = _ref2.weekSettings;
        return Locale.create(locale, numberingSystem, outputCalendar, weekSettings);
    };
    function Locale(locale, numbering, outputCalendar, weekSettings, specifiedLocale) {
        var _parseLocaleString = parseLocaleString(locale), parsedLocale = _parseLocaleString[0], parsedNumberingSystem = _parseLocaleString[1], parsedOutputCalendar = _parseLocaleString[2];
        this.locale = parsedLocale;
        this.numberingSystem = numbering || parsedNumberingSystem || null;
        this.outputCalendar = outputCalendar || parsedOutputCalendar || null;
        this.weekSettings = weekSettings;
        this.intl = intlConfigString(this.locale, this.numberingSystem, this.outputCalendar);
        this.weekdaysCache = {
            format: {},
            standalone: {}
        };
        this.monthsCache = {
            format: {},
            standalone: {}
        };
        this.meridiemCache = null;
        this.eraCache = {};
        this.specifiedLocale = specifiedLocale;
        this.fastNumbersCached = null;
    }
    var _proto4 = Locale.prototype;
    _proto4.listingMode = function listingMode() {
        var isActuallyEn = this.isEnglish();
        var hasNoWeirdness = (this.numberingSystem === null || this.numberingSystem === "latn") && (this.outputCalendar === null || this.outputCalendar === "gregory");
        return isActuallyEn && hasNoWeirdness ? "en" : "intl";
    };
    _proto4.clone = function clone(alts) {
        if (!alts || Object.getOwnPropertyNames(alts).length === 0) return this;
        else return Locale.create(alts.locale || this.specifiedLocale, alts.numberingSystem || this.numberingSystem, alts.outputCalendar || this.outputCalendar, validateWeekSettings(alts.weekSettings) || this.weekSettings, alts.defaultToEN || false);
    };
    _proto4.redefaultToEN = function redefaultToEN(alts) {
        if (alts === void 0) alts = {};
        return this.clone(_extends({}, alts, {
            defaultToEN: true
        }));
    };
    _proto4.redefaultToSystem = function redefaultToSystem(alts) {
        if (alts === void 0) alts = {};
        return this.clone(_extends({}, alts, {
            defaultToEN: false
        }));
    };
    _proto4.months = function months$1(length, format) {
        var _this2 = this;
        if (format === void 0) format = false;
        return listStuff(this, length, months, function() {
            // Workaround for "ja" locale: formatToParts does not label all parts of the month
            // as "month" and for this locale there is no difference between "format" and "non-format".
            // As such, just use format() instead of formatToParts() and take the whole string
            var monthSpecialCase = _this2.intl === "ja" || _this2.intl.startsWith("ja-");
            format &= !monthSpecialCase;
            var intl = format ? {
                month: length,
                day: "numeric"
            } : {
                month: length
            }, formatStr = format ? "format" : "standalone";
            if (!_this2.monthsCache[formatStr][length]) {
                var mapper = !monthSpecialCase ? function(dt) {
                    return _this2.extract(dt, intl, "month");
                } : function(dt) {
                    return _this2.dtFormatter(dt, intl).format();
                };
                _this2.monthsCache[formatStr][length] = mapMonths(mapper);
            }
            return _this2.monthsCache[formatStr][length];
        });
    };
    _proto4.weekdays = function weekdays$1(length, format) {
        var _this3 = this;
        if (format === void 0) format = false;
        return listStuff(this, length, weekdays, function() {
            var intl = format ? {
                weekday: length,
                year: "numeric",
                month: "long",
                day: "numeric"
            } : {
                weekday: length
            }, formatStr = format ? "format" : "standalone";
            if (!_this3.weekdaysCache[formatStr][length]) _this3.weekdaysCache[formatStr][length] = mapWeekdays(function(dt) {
                return _this3.extract(dt, intl, "weekday");
            });
            return _this3.weekdaysCache[formatStr][length];
        });
    };
    _proto4.meridiems = function meridiems$1() {
        var _this4 = this;
        return listStuff(this, undefined, function() {
            return meridiems;
        }, function() {
            // In theory there could be aribitrary day periods. We're gonna assume there are exactly two
            // for AM and PM. This is probably wrong, but it's makes parsing way easier.
            if (!_this4.meridiemCache) {
                var intl = {
                    hour: "numeric",
                    hourCycle: "h12"
                };
                _this4.meridiemCache = [
                    DateTime.utc(2016, 11, 13, 9),
                    DateTime.utc(2016, 11, 13, 19)
                ].map(function(dt) {
                    return _this4.extract(dt, intl, "dayperiod");
                });
            }
            return _this4.meridiemCache;
        });
    };
    _proto4.eras = function eras$1(length) {
        var _this5 = this;
        return listStuff(this, length, eras, function() {
            var intl = {
                era: length
            };
            // This is problematic. Different calendars are going to define eras totally differently. What I need is the minimum set of dates
            // to definitely enumerate them.
            if (!_this5.eraCache[length]) _this5.eraCache[length] = [
                DateTime.utc(-40, 1, 1),
                DateTime.utc(2017, 1, 1)
            ].map(function(dt) {
                return _this5.extract(dt, intl, "era");
            });
            return _this5.eraCache[length];
        });
    };
    _proto4.extract = function extract(dt, intlOpts, field) {
        var df = this.dtFormatter(dt, intlOpts), results = df.formatToParts(), matching = results.find(function(m) {
            return m.type.toLowerCase() === field;
        });
        return matching ? matching.value : null;
    };
    _proto4.numberFormatter = function numberFormatter(opts) {
        if (opts === void 0) opts = {};
        // this forcesimple option is never used (the only caller short-circuits on it, but it seems safer to leave)
        // (in contrast, the rest of the condition is used heavily)
        return new PolyNumberFormatter(this.intl, opts.forceSimple || this.fastNumbers, opts);
    };
    _proto4.dtFormatter = function dtFormatter(dt, intlOpts) {
        if (intlOpts === void 0) intlOpts = {};
        return new PolyDateFormatter(dt, this.intl, intlOpts);
    };
    _proto4.relFormatter = function relFormatter(opts) {
        if (opts === void 0) opts = {};
        return new PolyRelFormatter(this.intl, this.isEnglish(), opts);
    };
    _proto4.listFormatter = function listFormatter(opts) {
        if (opts === void 0) opts = {};
        return getCachedLF(this.intl, opts);
    };
    _proto4.isEnglish = function isEnglish() {
        return this.locale === "en" || this.locale.toLowerCase() === "en-us" || getCachedIntResolvedOptions(this.intl).locale.startsWith("en-us");
    };
    _proto4.getWeekSettings = function getWeekSettings() {
        if (this.weekSettings) return this.weekSettings;
        else if (!hasLocaleWeekInfo()) return fallbackWeekSettings;
        else return getCachedWeekInfo(this.locale);
    };
    _proto4.getStartOfWeek = function getStartOfWeek() {
        return this.getWeekSettings().firstDay;
    };
    _proto4.getMinDaysInFirstWeek = function getMinDaysInFirstWeek() {
        return this.getWeekSettings().minimalDays;
    };
    _proto4.getWeekendDays = function getWeekendDays() {
        return this.getWeekSettings().weekend;
    };
    _proto4.equals = function equals(other) {
        return this.locale === other.locale && this.numberingSystem === other.numberingSystem && this.outputCalendar === other.outputCalendar;
    };
    _proto4.toString = function toString() {
        return "Locale(" + this.locale + ", " + this.numberingSystem + ", " + this.outputCalendar + ")";
    };
    _createClass(Locale, [
        {
            key: "fastNumbers",
            get: function get() {
                if (this.fastNumbersCached == null) this.fastNumbersCached = supportsFastNumbers(this);
                return this.fastNumbersCached;
            }
        }
    ]);
    return Locale;
}();
var singleton = null;
/**
 * A zone with a fixed offset (meaning no DST)
 * @implements {Zone}
 */ var FixedOffsetZone = /*#__PURE__*/ function(_Zone) {
    _inheritsLoose(FixedOffsetZone, _Zone);
    /**
   * Get an instance with a specified offset
   * @param {number} offset - The offset in minutes
   * @return {FixedOffsetZone}
   */ FixedOffsetZone.instance = function instance(offset) {
        return offset === 0 ? FixedOffsetZone.utcInstance : new FixedOffsetZone(offset);
    };
    FixedOffsetZone.parseSpecifier = function parseSpecifier(s) {
        if (s) {
            var r = s.match(/^utc(?:([+-]\d{1,2})(?::(\d{2}))?)?$/i);
            if (r) return new FixedOffsetZone(signedOffset(r[1], r[2]));
        }
        return null;
    };
    function FixedOffsetZone(offset) {
        var _this;
        _this = _Zone.call(this) || this;
        /** @private **/ _this.fixed = offset;
        return _this;
    }
    /**
   * The type of zone. `fixed` for all instances of `FixedOffsetZone`.
   * @override
   * @type {string}
   */ var _proto = FixedOffsetZone.prototype;
    /**
   * Returns the offset's common name at the specified timestamp.
   *
   * For fixed offset zones this equals to the zone name.
   * @override
   */ _proto.offsetName = function offsetName() {
        return this.name;
    };
    _proto.formatOffset = function formatOffset$1(ts, format) {
        return formatOffset(this.fixed, format);
    };
    /**
   * Return the offset in minutes for this zone at the specified timestamp.
   *
   * For fixed offset zones, this is constant and does not depend on a timestamp.
   * @override
   * @return {number}
   */ _proto.offset = function offset() {
        return this.fixed;
    };
    _proto.equals = function equals(otherZone) {
        return otherZone.type === "fixed" && otherZone.fixed === this.fixed;
    };
    _createClass(FixedOffsetZone, [
        {
            key: "type",
            get: function get() {
                return "fixed";
            }
        },
        {
            key: "name",
            get: function get() {
                return this.fixed === 0 ? "UTC" : "UTC" + formatOffset(this.fixed, "narrow");
            }
        },
        {
            key: "ianaName",
            get: function get() {
                if (this.fixed === 0) return "Etc/UTC";
                else return "Etc/GMT" + formatOffset(-this.fixed, "narrow");
            }
        },
        {
            key: "isUniversal",
            get: function get() {
                return true;
            }
        },
        {
            key: "isValid",
            get: function get() {
                return true;
            }
        }
    ], [
        {
            key: "utcInstance",
            get: /**
     * Get a singleton instance of UTC
     * @return {FixedOffsetZone}
     */ function get() {
                if (singleton === null) singleton = new FixedOffsetZone(0);
                return singleton;
            }
        }
    ]);
    return FixedOffsetZone;
}(Zone);
/**
 * A zone that failed to parse. You should never need to instantiate this.
 * @implements {Zone}
 */ var InvalidZone = /*#__PURE__*/ function(_Zone) {
    _inheritsLoose(InvalidZone, _Zone);
    function InvalidZone(zoneName) {
        var _this;
        _this = _Zone.call(this) || this;
        /**  @private */ _this.zoneName = zoneName;
        return _this;
    }
    /** @override **/ var _proto = InvalidZone.prototype;
    /** @override **/ _proto.offsetName = function offsetName() {
        return null;
    };
    _proto.formatOffset = function formatOffset() {
        return "";
    };
    _proto.offset = function offset() {
        return NaN;
    };
    _proto.equals = function equals() {
        return false;
    };
    _createClass(InvalidZone, [
        {
            key: "type",
            get: function get() {
                return "invalid";
            }
        },
        {
            key: "name",
            get: function get() {
                return this.zoneName;
            }
        },
        {
            key: "isUniversal",
            get: function get() {
                return false;
            }
        },
        {
            key: "isValid",
            get: function get() {
                return false;
            }
        }
    ]);
    return InvalidZone;
}(Zone);
/**
 * @private
 */ function normalizeZone(input, defaultZone) {
    if (isUndefined(input) || input === null) return defaultZone;
    else if (input instanceof Zone) return input;
    else if (isString(input)) {
        var lowered = input.toLowerCase();
        if (lowered === "default") return defaultZone;
        else if (lowered === "local" || lowered === "system") return SystemZone.instance;
        else if (lowered === "utc" || lowered === "gmt") return FixedOffsetZone.utcInstance;
        else return FixedOffsetZone.parseSpecifier(lowered) || IANAZone.create(input);
    } else if (isNumber(input)) return FixedOffsetZone.instance(input);
    else if (typeof input === "object" && "offset" in input && typeof input.offset === "function") // This is dumb, but the instanceof check above doesn't seem to really work
    // so we're duck checking it
    return input;
    else return new InvalidZone(input);
}
var numberingSystems = {
    arab: "[\u0660-\u0669]",
    arabext: "[\u06F0-\u06F9]",
    bali: "[\u1B50-\u1B59]",
    beng: "[\u09E6-\u09EF]",
    deva: "[\u0966-\u096F]",
    fullwide: "[\uFF10-\uFF19]",
    gujr: "[\u0AE6-\u0AEF]",
    hanidec: "[\u3007|\u4E00|\u4E8C|\u4E09|\u56DB|\u4E94|\u516D|\u4E03|\u516B|\u4E5D]",
    khmr: "[\u17E0-\u17E9]",
    knda: "[\u0CE6-\u0CEF]",
    laoo: "[\u0ED0-\u0ED9]",
    limb: "[\u1946-\u194F]",
    mlym: "[\u0D66-\u0D6F]",
    mong: "[\u1810-\u1819]",
    mymr: "[\u1040-\u1049]",
    orya: "[\u0B66-\u0B6F]",
    tamldec: "[\u0BE6-\u0BEF]",
    telu: "[\u0C66-\u0C6F]",
    thai: "[\u0E50-\u0E59]",
    tibt: "[\u0F20-\u0F29]",
    latn: "\\d"
};
var numberingSystemsUTF16 = {
    arab: [
        1632,
        1641
    ],
    arabext: [
        1776,
        1785
    ],
    bali: [
        6992,
        7001
    ],
    beng: [
        2534,
        2543
    ],
    deva: [
        2406,
        2415
    ],
    fullwide: [
        65296,
        65303
    ],
    gujr: [
        2790,
        2799
    ],
    khmr: [
        6112,
        6121
    ],
    knda: [
        3302,
        3311
    ],
    laoo: [
        3792,
        3801
    ],
    limb: [
        6470,
        6479
    ],
    mlym: [
        3430,
        3439
    ],
    mong: [
        6160,
        6169
    ],
    mymr: [
        4160,
        4169
    ],
    orya: [
        2918,
        2927
    ],
    tamldec: [
        3046,
        3055
    ],
    telu: [
        3174,
        3183
    ],
    thai: [
        3664,
        3673
    ],
    tibt: [
        3872,
        3881
    ]
};
var hanidecChars = numberingSystems.hanidec.replace(/[\[|\]]/g, "").split("");
function parseDigits(str) {
    var value = parseInt(str, 10);
    if (isNaN(value)) {
        value = "";
        for(var i = 0; i < str.length; i++){
            var code = str.charCodeAt(i);
            if (str[i].search(numberingSystems.hanidec) !== -1) value += hanidecChars.indexOf(str[i]);
            else for(var key in numberingSystemsUTF16){
                var _numberingSystemsUTF = numberingSystemsUTF16[key], min = _numberingSystemsUTF[0], max = _numberingSystemsUTF[1];
                if (code >= min && code <= max) value += code - min;
            }
        }
        return parseInt(value, 10);
    } else return value;
}
// cache of {numberingSystem: {append: regex}}
var digitRegexCache = new Map();
function resetDigitRegexCache() {
    digitRegexCache.clear();
}
function digitRegex(_ref, append) {
    var numberingSystem = _ref.numberingSystem;
    if (append === void 0) append = "";
    var ns = numberingSystem || "latn";
    var appendCache = digitRegexCache.get(ns);
    if (appendCache === undefined) {
        appendCache = new Map();
        digitRegexCache.set(ns, appendCache);
    }
    var regex = appendCache.get(append);
    if (regex === undefined) {
        regex = new RegExp("" + numberingSystems[ns] + append);
        appendCache.set(append, regex);
    }
    return regex;
}
var now = function now() {
    return Date.now();
}, defaultZone = "system", defaultLocale = null, defaultNumberingSystem = null, defaultOutputCalendar = null, twoDigitCutoffYear = 60, throwOnInvalid, defaultWeekSettings = null;
/**
 * Settings contains static getters and setters that control Luxon's overall behavior. Luxon is a simple library with few options, but the ones it does have live here.
 */ var Settings = /*#__PURE__*/ function() {
    function Settings() {}
    /**
   * Reset Luxon's global caches. Should only be necessary in testing scenarios.
   * @return {void}
   */ Settings.resetCaches = function resetCaches() {
        Locale.resetCache();
        IANAZone.resetCache();
        DateTime.resetCache();
        resetDigitRegexCache();
    };
    _createClass(Settings, null, [
        {
            key: "now",
            get: /**
     * Get the callback for returning the current timestamp.
     * @type {function}
     */ function get() {
                return now;
            },
            set: function set(n) {
                now = n;
            }
        },
        {
            key: "defaultZone",
            get: /**
     * Get the default time zone object currently used to create DateTimes. Does not affect existing instances.
     * The default value is the system's time zone (the one set on the machine that runs this code).
     * @type {Zone}
     */ function get() {
                return normalizeZone(defaultZone, SystemZone.instance);
            },
            set: function set(zone) {
                defaultZone = zone;
            }
        },
        {
            key: "defaultLocale",
            get: function get() {
                return defaultLocale;
            },
            set: function set(locale) {
                defaultLocale = locale;
            }
        },
        {
            key: "defaultNumberingSystem",
            get: function get() {
                return defaultNumberingSystem;
            },
            set: function set(numberingSystem) {
                defaultNumberingSystem = numberingSystem;
            }
        },
        {
            key: "defaultOutputCalendar",
            get: function get() {
                return defaultOutputCalendar;
            },
            set: function set(outputCalendar) {
                defaultOutputCalendar = outputCalendar;
            }
        },
        {
            key: "defaultWeekSettings",
            get: function get() {
                return defaultWeekSettings;
            },
            set: function set(weekSettings) {
                defaultWeekSettings = validateWeekSettings(weekSettings);
            }
        },
        {
            key: "twoDigitCutoffYear",
            get: function get() {
                return twoDigitCutoffYear;
            },
            set: function set(cutoffYear) {
                twoDigitCutoffYear = cutoffYear % 100;
            }
        },
        {
            key: "throwOnInvalid",
            get: function get() {
                return throwOnInvalid;
            },
            set: function set(t) {
                throwOnInvalid = t;
            }
        }
    ]);
    return Settings;
}();
var Invalid = /*#__PURE__*/ function() {
    function Invalid(reason, explanation) {
        this.reason = reason;
        this.explanation = explanation;
    }
    var _proto = Invalid.prototype;
    _proto.toMessage = function toMessage() {
        if (this.explanation) return this.reason + ": " + this.explanation;
        else return this.reason;
    };
    return Invalid;
}();
var nonLeapLadder = [
    0,
    31,
    59,
    90,
    120,
    151,
    181,
    212,
    243,
    273,
    304,
    334
], leapLadder = [
    0,
    31,
    60,
    91,
    121,
    152,
    182,
    213,
    244,
    274,
    305,
    335
];
function unitOutOfRange(unit, value) {
    return new Invalid("unit out of range", "you specified " + value + " (of type " + typeof value + ") as a " + unit + ", which is invalid");
}
function dayOfWeek(year, month, day) {
    var d = new Date(Date.UTC(year, month - 1, day));
    if (year < 100 && year >= 0) d.setUTCFullYear(d.getUTCFullYear() - 1900);
    var js = d.getUTCDay();
    return js === 0 ? 7 : js;
}
function computeOrdinal(year, month, day) {
    return day + (isLeapYear(year) ? leapLadder : nonLeapLadder)[month - 1];
}
function uncomputeOrdinal(year, ordinal) {
    var table = isLeapYear(year) ? leapLadder : nonLeapLadder, month0 = table.findIndex(function(i) {
        return i < ordinal;
    }), day = ordinal - table[month0];
    return {
        month: month0 + 1,
        day: day
    };
}
function isoWeekdayToLocal(isoWeekday, startOfWeek) {
    return (isoWeekday - startOfWeek + 7) % 7 + 1;
}
/**
 * @private
 */ function gregorianToWeek(gregObj, minDaysInFirstWeek, startOfWeek) {
    if (minDaysInFirstWeek === void 0) minDaysInFirstWeek = 4;
    if (startOfWeek === void 0) startOfWeek = 1;
    var year = gregObj.year, month = gregObj.month, day = gregObj.day, ordinal = computeOrdinal(year, month, day), weekday = isoWeekdayToLocal(dayOfWeek(year, month, day), startOfWeek);
    var weekNumber = Math.floor((ordinal - weekday + 14 - minDaysInFirstWeek) / 7), weekYear;
    if (weekNumber < 1) {
        weekYear = year - 1;
        weekNumber = weeksInWeekYear(weekYear, minDaysInFirstWeek, startOfWeek);
    } else if (weekNumber > weeksInWeekYear(year, minDaysInFirstWeek, startOfWeek)) {
        weekYear = year + 1;
        weekNumber = 1;
    } else weekYear = year;
    return _extends({
        weekYear: weekYear,
        weekNumber: weekNumber,
        weekday: weekday
    }, timeObject(gregObj));
}
function weekToGregorian(weekData, minDaysInFirstWeek, startOfWeek) {
    if (minDaysInFirstWeek === void 0) minDaysInFirstWeek = 4;
    if (startOfWeek === void 0) startOfWeek = 1;
    var weekYear = weekData.weekYear, weekNumber = weekData.weekNumber, weekday = weekData.weekday, weekdayOfJan4 = isoWeekdayToLocal(dayOfWeek(weekYear, 1, minDaysInFirstWeek), startOfWeek), yearInDays = daysInYear(weekYear);
    var ordinal = weekNumber * 7 + weekday - weekdayOfJan4 - 7 + minDaysInFirstWeek, year;
    if (ordinal < 1) {
        year = weekYear - 1;
        ordinal += daysInYear(year);
    } else if (ordinal > yearInDays) {
        year = weekYear + 1;
        ordinal -= daysInYear(weekYear);
    } else year = weekYear;
    var _uncomputeOrdinal = uncomputeOrdinal(year, ordinal), month = _uncomputeOrdinal.month, day = _uncomputeOrdinal.day;
    return _extends({
        year: year,
        month: month,
        day: day
    }, timeObject(weekData));
}
function gregorianToOrdinal(gregData) {
    var year = gregData.year, month = gregData.month, day = gregData.day;
    var ordinal = computeOrdinal(year, month, day);
    return _extends({
        year: year,
        ordinal: ordinal
    }, timeObject(gregData));
}
function ordinalToGregorian(ordinalData) {
    var year = ordinalData.year, ordinal = ordinalData.ordinal;
    var _uncomputeOrdinal2 = uncomputeOrdinal(year, ordinal), month = _uncomputeOrdinal2.month, day = _uncomputeOrdinal2.day;
    return _extends({
        year: year,
        month: month,
        day: day
    }, timeObject(ordinalData));
}
/**
 * Check if local week units like localWeekday are used in obj.
 * If so, validates that they are not mixed with ISO week units and then copies them to the normal week unit properties.
 * Modifies obj in-place!
 * @param obj the object values
 */ function usesLocalWeekValues(obj, loc) {
    var hasLocaleWeekData = !isUndefined(obj.localWeekday) || !isUndefined(obj.localWeekNumber) || !isUndefined(obj.localWeekYear);
    if (hasLocaleWeekData) {
        var hasIsoWeekData = !isUndefined(obj.weekday) || !isUndefined(obj.weekNumber) || !isUndefined(obj.weekYear);
        if (hasIsoWeekData) throw new ConflictingSpecificationError("Cannot mix locale-based week fields with ISO-based week fields");
        if (!isUndefined(obj.localWeekday)) obj.weekday = obj.localWeekday;
        if (!isUndefined(obj.localWeekNumber)) obj.weekNumber = obj.localWeekNumber;
        if (!isUndefined(obj.localWeekYear)) obj.weekYear = obj.localWeekYear;
        delete obj.localWeekday;
        delete obj.localWeekNumber;
        delete obj.localWeekYear;
        return {
            minDaysInFirstWeek: loc.getMinDaysInFirstWeek(),
            startOfWeek: loc.getStartOfWeek()
        };
    } else return {
        minDaysInFirstWeek: 4,
        startOfWeek: 1
    };
}
function hasInvalidWeekData(obj, minDaysInFirstWeek, startOfWeek) {
    if (minDaysInFirstWeek === void 0) minDaysInFirstWeek = 4;
    if (startOfWeek === void 0) startOfWeek = 1;
    var validYear = isInteger(obj.weekYear), validWeek = integerBetween(obj.weekNumber, 1, weeksInWeekYear(obj.weekYear, minDaysInFirstWeek, startOfWeek)), validWeekday = integerBetween(obj.weekday, 1, 7);
    if (!validYear) return unitOutOfRange("weekYear", obj.weekYear);
    else if (!validWeek) return unitOutOfRange("week", obj.weekNumber);
    else if (!validWeekday) return unitOutOfRange("weekday", obj.weekday);
    else return false;
}
function hasInvalidOrdinalData(obj) {
    var validYear = isInteger(obj.year), validOrdinal = integerBetween(obj.ordinal, 1, daysInYear(obj.year));
    if (!validYear) return unitOutOfRange("year", obj.year);
    else if (!validOrdinal) return unitOutOfRange("ordinal", obj.ordinal);
    else return false;
}
function hasInvalidGregorianData(obj) {
    var validYear = isInteger(obj.year), validMonth = integerBetween(obj.month, 1, 12), validDay = integerBetween(obj.day, 1, daysInMonth(obj.year, obj.month));
    if (!validYear) return unitOutOfRange("year", obj.year);
    else if (!validMonth) return unitOutOfRange("month", obj.month);
    else if (!validDay) return unitOutOfRange("day", obj.day);
    else return false;
}
function hasInvalidTimeData(obj) {
    var hour = obj.hour, minute = obj.minute, second = obj.second, millisecond = obj.millisecond;
    var validHour = integerBetween(hour, 0, 23) || hour === 24 && minute === 0 && second === 0 && millisecond === 0, validMinute = integerBetween(minute, 0, 59), validSecond = integerBetween(second, 0, 59), validMillisecond = integerBetween(millisecond, 0, 999);
    if (!validHour) return unitOutOfRange("hour", hour);
    else if (!validMinute) return unitOutOfRange("minute", minute);
    else if (!validSecond) return unitOutOfRange("second", second);
    else if (!validMillisecond) return unitOutOfRange("millisecond", millisecond);
    else return false;
}
/**
 * @private
 */ // TYPES
function isUndefined(o) {
    return typeof o === "undefined";
}
function isNumber(o) {
    return typeof o === "number";
}
function isInteger(o) {
    return typeof o === "number" && o % 1 === 0;
}
function isString(o) {
    return typeof o === "string";
}
function isDate(o) {
    return Object.prototype.toString.call(o) === "[object Date]";
}
// CAPABILITIES
function hasRelative() {
    try {
        return typeof Intl !== "undefined" && !!Intl.RelativeTimeFormat;
    } catch (e) {
        return false;
    }
}
function hasLocaleWeekInfo() {
    try {
        return typeof Intl !== "undefined" && !!Intl.Locale && ("weekInfo" in Intl.Locale.prototype || "getWeekInfo" in Intl.Locale.prototype);
    } catch (e) {
        return false;
    }
}
// OBJECTS AND ARRAYS
function maybeArray(thing) {
    return Array.isArray(thing) ? thing : [
        thing
    ];
}
function bestBy(arr, by, compare) {
    if (arr.length === 0) return undefined;
    return arr.reduce(function(best, next) {
        var pair = [
            by(next),
            next
        ];
        if (!best) return pair;
        else if (compare(best[0], pair[0]) === best[0]) return best;
        else return pair;
    }, null)[1];
}
function pick(obj, keys) {
    return keys.reduce(function(a, k) {
        a[k] = obj[k];
        return a;
    }, {});
}
function hasOwnProperty(obj, prop) {
    return Object.prototype.hasOwnProperty.call(obj, prop);
}
function validateWeekSettings(settings) {
    if (settings == null) return null;
    else if (typeof settings !== "object") throw new InvalidArgumentError("Week settings must be an object");
    else {
        if (!integerBetween(settings.firstDay, 1, 7) || !integerBetween(settings.minimalDays, 1, 7) || !Array.isArray(settings.weekend) || settings.weekend.some(function(v) {
            return !integerBetween(v, 1, 7);
        })) throw new InvalidArgumentError("Invalid week settings");
        return {
            firstDay: settings.firstDay,
            minimalDays: settings.minimalDays,
            weekend: Array.from(settings.weekend)
        };
    }
}
// NUMBERS AND STRINGS
function integerBetween(thing, bottom, top) {
    return isInteger(thing) && thing >= bottom && thing <= top;
}
// x % n but takes the sign of n instead of x
function floorMod(x, n) {
    return x - n * Math.floor(x / n);
}
function padStart(input, n) {
    if (n === void 0) n = 2;
    var isNeg = input < 0;
    var padded;
    if (isNeg) padded = "-" + ("" + -input).padStart(n, "0");
    else padded = ("" + input).padStart(n, "0");
    return padded;
}
function parseInteger(string) {
    if (isUndefined(string) || string === null || string === "") return undefined;
    else return parseInt(string, 10);
}
function parseFloating(string) {
    if (isUndefined(string) || string === null || string === "") return undefined;
    else return parseFloat(string);
}
function parseMillis(fraction) {
    // Return undefined (instead of 0) in these cases, where fraction is not set
    if (isUndefined(fraction) || fraction === null || fraction === "") return undefined;
    else {
        var f = parseFloat("0." + fraction) * 1000;
        return Math.floor(f);
    }
}
function roundTo(number, digits, rounding) {
    if (rounding === void 0) rounding = "round";
    var factor = Math.pow(10, digits);
    switch(rounding){
        case "expand":
            return number > 0 ? Math.ceil(number * factor) / factor : Math.floor(number * factor) / factor;
        case "trunc":
            return Math.trunc(number * factor) / factor;
        case "round":
            return Math.round(number * factor) / factor;
        case "floor":
            return Math.floor(number * factor) / factor;
        case "ceil":
            return Math.ceil(number * factor) / factor;
        default:
            throw new RangeError("Value rounding " + rounding + " is out of range");
    }
}
// DATE BASICS
function isLeapYear(year) {
    return year % 4 === 0 && (year % 100 !== 0 || year % 400 === 0);
}
function daysInYear(year) {
    return isLeapYear(year) ? 366 : 365;
}
function daysInMonth(year, month) {
    var modMonth = floorMod(month - 1, 12) + 1, modYear = year + (month - modMonth) / 12;
    if (modMonth === 2) return isLeapYear(modYear) ? 29 : 28;
    else return [
        31,
        null,
        31,
        30,
        31,
        30,
        31,
        31,
        30,
        31,
        30,
        31
    ][modMonth - 1];
}
// convert a calendar object to a local timestamp (epoch, but with the offset baked in)
function objToLocalTS(obj) {
    var d = Date.UTC(obj.year, obj.month - 1, obj.day, obj.hour, obj.minute, obj.second, obj.millisecond);
    // for legacy reasons, years between 0 and 99 are interpreted as 19XX; revert that
    if (obj.year < 100 && obj.year >= 0) {
        d = new Date(d);
        // set the month and day again, this is necessary because year 2000 is a leap year, but year 100 is not
        // so if obj.year is in 99, but obj.day makes it roll over into year 100,
        // the calculations done by Date.UTC are using year 2000 - which is incorrect
        d.setUTCFullYear(obj.year, obj.month - 1, obj.day);
    }
    return +d;
}
// adapted from moment.js: https://github.com/moment/moment/blob/000ac1800e620f770f4eb31b5ae908f6167b0ab2/src/lib/units/week-calendar-utils.js
function firstWeekOffset(year, minDaysInFirstWeek, startOfWeek) {
    var fwdlw = isoWeekdayToLocal(dayOfWeek(year, 1, minDaysInFirstWeek), startOfWeek);
    return -fwdlw + minDaysInFirstWeek - 1;
}
function weeksInWeekYear(weekYear, minDaysInFirstWeek, startOfWeek) {
    if (minDaysInFirstWeek === void 0) minDaysInFirstWeek = 4;
    if (startOfWeek === void 0) startOfWeek = 1;
    var weekOffset = firstWeekOffset(weekYear, minDaysInFirstWeek, startOfWeek);
    var weekOffsetNext = firstWeekOffset(weekYear + 1, minDaysInFirstWeek, startOfWeek);
    return (daysInYear(weekYear) - weekOffset + weekOffsetNext) / 7;
}
function untruncateYear(year) {
    if (year > 99) return year;
    else return year > Settings.twoDigitCutoffYear ? 1900 + year : 2000 + year;
}
// PARSING
function parseZoneInfo(ts, offsetFormat, locale, timeZone) {
    if (timeZone === void 0) timeZone = null;
    var date = new Date(ts), intlOpts = {
        hourCycle: "h23",
        year: "numeric",
        month: "2-digit",
        day: "2-digit",
        hour: "2-digit",
        minute: "2-digit"
    };
    if (timeZone) intlOpts.timeZone = timeZone;
    var modified = _extends({
        timeZoneName: offsetFormat
    }, intlOpts);
    var parsed = new Intl.DateTimeFormat(locale, modified).formatToParts(date).find(function(m) {
        return m.type.toLowerCase() === "timezonename";
    });
    return parsed ? parsed.value : null;
}
// signedOffset('-5', '30') -> -330
function signedOffset(offHourStr, offMinuteStr) {
    var offHour = parseInt(offHourStr, 10);
    // don't || this because we want to preserve -0
    if (Number.isNaN(offHour)) offHour = 0;
    var offMin = parseInt(offMinuteStr, 10) || 0, offMinSigned = offHour < 0 || Object.is(offHour, -0) ? -offMin : offMin;
    return offHour * 60 + offMinSigned;
}
// COERCION
function asNumber(value) {
    var numericValue = Number(value);
    if (typeof value === "boolean" || value === "" || !Number.isFinite(numericValue)) throw new InvalidArgumentError("Invalid unit value " + value);
    return numericValue;
}
function normalizeObject(obj, normalizer) {
    var normalized = {};
    for(var u in obj)if (hasOwnProperty(obj, u)) {
        var v = obj[u];
        if (v === undefined || v === null) continue;
        normalized[normalizer(u)] = asNumber(v);
    }
    return normalized;
}
/**
 * Returns the offset's value as a string
 * @param {number} ts - Epoch milliseconds for which to get the offset
 * @param {string} format - What style of offset to return.
 *                          Accepts 'narrow', 'short', or 'techie'. Returning '+6', '+06:00', or '+0600' respectively
 * @return {string}
 */ function formatOffset(offset, format) {
    var hours = Math.trunc(Math.abs(offset / 60)), minutes = Math.trunc(Math.abs(offset % 60)), sign = offset >= 0 ? "+" : "-";
    switch(format){
        case "short":
            return "" + sign + padStart(hours, 2) + ":" + padStart(minutes, 2);
        case "narrow":
            return "" + sign + hours + (minutes > 0 ? ":" + minutes : "");
        case "techie":
            return "" + sign + padStart(hours, 2) + padStart(minutes, 2);
        default:
            throw new RangeError("Value format " + format + " is out of range for property format");
    }
}
function timeObject(obj) {
    return pick(obj, [
        "hour",
        "minute",
        "second",
        "millisecond"
    ]);
}
/**
 * @private
 */ var monthsLong = [
    "January",
    "February",
    "March",
    "April",
    "May",
    "June",
    "July",
    "August",
    "September",
    "October",
    "November",
    "December"
];
var monthsShort = [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "May",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Oct",
    "Nov",
    "Dec"
];
var monthsNarrow = [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
];
function months(length) {
    switch(length){
        case "narrow":
            return [].concat(monthsNarrow);
        case "short":
            return [].concat(monthsShort);
        case "long":
            return [].concat(monthsLong);
        case "numeric":
            return [
                "1",
                "2",
                "3",
                "4",
                "5",
                "6",
                "7",
                "8",
                "9",
                "10",
                "11",
                "12"
            ];
        case "2-digit":
            return [
                "01",
                "02",
                "03",
                "04",
                "05",
                "06",
                "07",
                "08",
                "09",
                "10",
                "11",
                "12"
            ];
        default:
            return null;
    }
}
var weekdaysLong = [
    "Monday",
    "Tuesday",
    "Wednesday",
    "Thursday",
    "Friday",
    "Saturday",
    "Sunday"
];
var weekdaysShort = [
    "Mon",
    "Tue",
    "Wed",
    "Thu",
    "Fri",
    "Sat",
    "Sun"
];
var weekdaysNarrow = [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
];
function weekdays(length) {
    switch(length){
        case "narrow":
            return [].concat(weekdaysNarrow);
        case "short":
            return [].concat(weekdaysShort);
        case "long":
            return [].concat(weekdaysLong);
        case "numeric":
            return [
                "1",
                "2",
                "3",
                "4",
                "5",
                "6",
                "7"
            ];
        default:
            return null;
    }
}
var meridiems = [
    "AM",
    "PM"
];
var erasLong = [
    "Before Christ",
    "Anno Domini"
];
var erasShort = [
    "BC",
    "AD"
];
var erasNarrow = [
    "B",
    "A"
];
function eras(length) {
    switch(length){
        case "narrow":
            return [].concat(erasNarrow);
        case "short":
            return [].concat(erasShort);
        case "long":
            return [].concat(erasLong);
        default:
            return null;
    }
}
function meridiemForDateTime(dt) {
    return meridiems[dt.hour < 12 ? 0 : 1];
}
function weekdayForDateTime(dt, length) {
    return weekdays(length)[dt.weekday - 1];
}
function monthForDateTime(dt, length) {
    return months(length)[dt.month - 1];
}
function eraForDateTime(dt, length) {
    return eras(length)[dt.year < 0 ? 0 : 1];
}
function formatRelativeTime(unit, count, numeric, narrow) {
    if (numeric === void 0) numeric = "always";
    if (narrow === void 0) narrow = false;
    var units = {
        years: [
            "year",
            "yr."
        ],
        quarters: [
            "quarter",
            "qtr."
        ],
        months: [
            "month",
            "mo."
        ],
        weeks: [
            "week",
            "wk."
        ],
        days: [
            "day",
            "day",
            "days"
        ],
        hours: [
            "hour",
            "hr."
        ],
        minutes: [
            "minute",
            "min."
        ],
        seconds: [
            "second",
            "sec."
        ]
    };
    var lastable = [
        "hours",
        "minutes",
        "seconds"
    ].indexOf(unit) === -1;
    if (numeric === "auto" && lastable) {
        var isDay = unit === "days";
        switch(count){
            case 1:
                return isDay ? "tomorrow" : "next " + units[unit][0];
            case -1:
                return isDay ? "yesterday" : "last " + units[unit][0];
            case 0:
                return isDay ? "today" : "this " + units[unit][0];
        }
    }
    var isInPast = Object.is(count, -0) || count < 0, fmtValue = Math.abs(count), singular = fmtValue === 1, lilUnits = units[unit], fmtUnit = narrow ? singular ? lilUnits[1] : lilUnits[2] || lilUnits[1] : singular ? units[unit][0] : unit;
    return isInPast ? fmtValue + " " + fmtUnit + " ago" : "in " + fmtValue + " " + fmtUnit;
}
function stringifyTokens(splits, tokenToString) {
    var s = "";
    for(var _iterator = _createForOfIteratorHelperLoose(splits), _step; !(_step = _iterator()).done;){
        var token = _step.value;
        if (token.literal) s += token.val;
        else s += tokenToString(token.val);
    }
    return s;
}
var _macroTokenToFormatOpts = {
    D: DATE_SHORT,
    DD: DATE_MED,
    DDD: DATE_FULL,
    DDDD: DATE_HUGE,
    t: TIME_SIMPLE,
    tt: TIME_WITH_SECONDS,
    ttt: TIME_WITH_SHORT_OFFSET,
    tttt: TIME_WITH_LONG_OFFSET,
    T: TIME_24_SIMPLE,
    TT: TIME_24_WITH_SECONDS,
    TTT: TIME_24_WITH_SHORT_OFFSET,
    TTTT: TIME_24_WITH_LONG_OFFSET,
    f: DATETIME_SHORT,
    ff: DATETIME_MED,
    fff: DATETIME_FULL,
    ffff: DATETIME_HUGE,
    F: DATETIME_SHORT_WITH_SECONDS,
    FF: DATETIME_MED_WITH_SECONDS,
    FFF: DATETIME_FULL_WITH_SECONDS,
    FFFF: DATETIME_HUGE_WITH_SECONDS
};
/**
 * @private
 */ var Formatter = /*#__PURE__*/ function() {
    Formatter.create = function create(locale, opts) {
        if (opts === void 0) opts = {};
        return new Formatter(locale, opts);
    };
    Formatter.parseFormat = function parseFormat(fmt) {
        // white-space is always considered a literal in user-provided formats
        // the " " token has a special meaning (see unitForToken)
        var current = null, currentFull = "", bracketed = false;
        var splits = [];
        for(var i = 0; i < fmt.length; i++){
            var c = fmt.charAt(i);
            if (c === "'") {
                // turn '' into a literal signal quote instead of just skipping the empty literal
                if (currentFull.length > 0 || bracketed) splits.push({
                    literal: bracketed || /^\s+$/.test(currentFull),
                    val: currentFull === "" ? "'" : currentFull
                });
                current = null;
                currentFull = "";
                bracketed = !bracketed;
            } else if (bracketed) currentFull += c;
            else if (c === current) currentFull += c;
            else {
                if (currentFull.length > 0) splits.push({
                    literal: /^\s+$/.test(currentFull),
                    val: currentFull
                });
                currentFull = c;
                current = c;
            }
        }
        if (currentFull.length > 0) splits.push({
            literal: bracketed || /^\s+$/.test(currentFull),
            val: currentFull
        });
        return splits;
    };
    Formatter.macroTokenToFormatOpts = function macroTokenToFormatOpts(token) {
        return _macroTokenToFormatOpts[token];
    };
    function Formatter(locale, formatOpts) {
        this.opts = formatOpts;
        this.loc = locale;
        this.systemLoc = null;
    }
    var _proto = Formatter.prototype;
    _proto.formatWithSystemDefault = function formatWithSystemDefault(dt, opts) {
        if (this.systemLoc === null) this.systemLoc = this.loc.redefaultToSystem();
        var df = this.systemLoc.dtFormatter(dt, _extends({}, this.opts, opts));
        return df.format();
    };
    _proto.dtFormatter = function dtFormatter(dt, opts) {
        if (opts === void 0) opts = {};
        return this.loc.dtFormatter(dt, _extends({}, this.opts, opts));
    };
    _proto.formatDateTime = function formatDateTime(dt, opts) {
        return this.dtFormatter(dt, opts).format();
    };
    _proto.formatDateTimeParts = function formatDateTimeParts(dt, opts) {
        return this.dtFormatter(dt, opts).formatToParts();
    };
    _proto.formatInterval = function formatInterval(interval, opts) {
        var df = this.dtFormatter(interval.start, opts);
        return df.dtf.formatRange(interval.start.toJSDate(), interval.end.toJSDate());
    };
    _proto.resolvedOptions = function resolvedOptions(dt, opts) {
        return this.dtFormatter(dt, opts).resolvedOptions();
    };
    _proto.num = function num(n, p, signDisplay) {
        if (p === void 0) p = 0;
        if (signDisplay === void 0) signDisplay = undefined;
        // we get some perf out of doing this here, annoyingly
        if (this.opts.forceSimple) return padStart(n, p);
        var opts = _extends({}, this.opts);
        if (p > 0) opts.padTo = p;
        if (signDisplay) opts.signDisplay = signDisplay;
        return this.loc.numberFormatter(opts).format(n);
    };
    _proto.formatDateTimeFromString = function formatDateTimeFromString(dt, fmt) {
        var _this = this;
        var knownEnglish = this.loc.listingMode() === "en", useDateTimeFormatter = this.loc.outputCalendar && this.loc.outputCalendar !== "gregory", string = function string(opts, extract) {
            return _this.loc.extract(dt, opts, extract);
        }, formatOffset = function formatOffset(opts) {
            if (dt.isOffsetFixed && dt.offset === 0 && opts.allowZ) return "Z";
            return dt.isValid ? dt.zone.formatOffset(dt.ts, opts.format) : "";
        }, meridiem = function meridiem() {
            return knownEnglish ? meridiemForDateTime(dt) : string({
                hour: "numeric",
                hourCycle: "h12"
            }, "dayperiod");
        }, month = function month(length, standalone) {
            return knownEnglish ? monthForDateTime(dt, length) : string(standalone ? {
                month: length
            } : {
                month: length,
                day: "numeric"
            }, "month");
        }, weekday = function weekday(length, standalone) {
            return knownEnglish ? weekdayForDateTime(dt, length) : string(standalone ? {
                weekday: length
            } : {
                weekday: length,
                month: "long",
                day: "numeric"
            }, "weekday");
        }, maybeMacro = function maybeMacro(token) {
            var formatOpts = Formatter.macroTokenToFormatOpts(token);
            if (formatOpts) return _this.formatWithSystemDefault(dt, formatOpts);
            else return token;
        }, era = function era(length) {
            return knownEnglish ? eraForDateTime(dt, length) : string({
                era: length
            }, "era");
        }, tokenToString = function tokenToString(token) {
            // Where possible: https://cldr.unicode.org/translation/date-time/date-time-symbols
            switch(token){
                // ms
                case "S":
                    return _this.num(dt.millisecond);
                case "u":
                // falls through
                case "SSS":
                    return _this.num(dt.millisecond, 3);
                // seconds
                case "s":
                    return _this.num(dt.second);
                case "ss":
                    return _this.num(dt.second, 2);
                // fractional seconds
                case "uu":
                    return _this.num(Math.floor(dt.millisecond / 10), 2);
                case "uuu":
                    return _this.num(Math.floor(dt.millisecond / 100));
                // minutes
                case "m":
                    return _this.num(dt.minute);
                case "mm":
                    return _this.num(dt.minute, 2);
                // hours
                case "h":
                    return _this.num(dt.hour % 12 === 0 ? 12 : dt.hour % 12);
                case "hh":
                    return _this.num(dt.hour % 12 === 0 ? 12 : dt.hour % 12, 2);
                case "H":
                    return _this.num(dt.hour);
                case "HH":
                    return _this.num(dt.hour, 2);
                // offset
                case "Z":
                    // like +6
                    return formatOffset({
                        format: "narrow",
                        allowZ: _this.opts.allowZ
                    });
                case "ZZ":
                    // like +06:00
                    return formatOffset({
                        format: "short",
                        allowZ: _this.opts.allowZ
                    });
                case "ZZZ":
                    // like +0600
                    return formatOffset({
                        format: "techie",
                        allowZ: _this.opts.allowZ
                    });
                case "ZZZZ":
                    // like EST
                    return dt.zone.offsetName(dt.ts, {
                        format: "short",
                        locale: _this.loc.locale
                    });
                case "ZZZZZ":
                    // like Eastern Standard Time
                    return dt.zone.offsetName(dt.ts, {
                        format: "long",
                        locale: _this.loc.locale
                    });
                // zone
                case "z":
                    // like America/New_York
                    return dt.zoneName;
                // meridiems
                case "a":
                    return meridiem();
                // dates
                case "d":
                    return useDateTimeFormatter ? string({
                        day: "numeric"
                    }, "day") : _this.num(dt.day);
                case "dd":
                    return useDateTimeFormatter ? string({
                        day: "2-digit"
                    }, "day") : _this.num(dt.day, 2);
                // weekdays - standalone
                case "c":
                    // like 1
                    return _this.num(dt.weekday);
                case "ccc":
                    // like 'Tues'
                    return weekday("short", true);
                case "cccc":
                    // like 'Tuesday'
                    return weekday("long", true);
                case "ccccc":
                    // like 'T'
                    return weekday("narrow", true);
                // weekdays - format
                case "E":
                    // like 1
                    return _this.num(dt.weekday);
                case "EEE":
                    // like 'Tues'
                    return weekday("short", false);
                case "EEEE":
                    // like 'Tuesday'
                    return weekday("long", false);
                case "EEEEE":
                    // like 'T'
                    return weekday("narrow", false);
                // months - standalone
                case "L":
                    // like 1
                    return useDateTimeFormatter ? string({
                        month: "numeric",
                        day: "numeric"
                    }, "month") : _this.num(dt.month);
                case "LL":
                    // like 01, doesn't seem to work
                    return useDateTimeFormatter ? string({
                        month: "2-digit",
                        day: "numeric"
                    }, "month") : _this.num(dt.month, 2);
                case "LLL":
                    // like Jan
                    return month("short", true);
                case "LLLL":
                    // like January
                    return month("long", true);
                case "LLLLL":
                    // like J
                    return month("narrow", true);
                // months - format
                case "M":
                    // like 1
                    return useDateTimeFormatter ? string({
                        month: "numeric"
                    }, "month") : _this.num(dt.month);
                case "MM":
                    // like 01
                    return useDateTimeFormatter ? string({
                        month: "2-digit"
                    }, "month") : _this.num(dt.month, 2);
                case "MMM":
                    // like Jan
                    return month("short", false);
                case "MMMM":
                    // like January
                    return month("long", false);
                case "MMMMM":
                    // like J
                    return month("narrow", false);
                // years
                case "y":
                    // like 2014
                    return useDateTimeFormatter ? string({
                        year: "numeric"
                    }, "year") : _this.num(dt.year);
                case "yy":
                    // like 14
                    return useDateTimeFormatter ? string({
                        year: "2-digit"
                    }, "year") : _this.num(dt.year.toString().slice(-2), 2);
                case "yyyy":
                    // like 0012
                    return useDateTimeFormatter ? string({
                        year: "numeric"
                    }, "year") : _this.num(dt.year, 4);
                case "yyyyyy":
                    // like 000012
                    return useDateTimeFormatter ? string({
                        year: "numeric"
                    }, "year") : _this.num(dt.year, 6);
                // eras
                case "G":
                    // like AD
                    return era("short");
                case "GG":
                    // like Anno Domini
                    return era("long");
                case "GGGGG":
                    return era("narrow");
                case "kk":
                    return _this.num(dt.weekYear.toString().slice(-2), 2);
                case "kkkk":
                    return _this.num(dt.weekYear, 4);
                case "W":
                    return _this.num(dt.weekNumber);
                case "WW":
                    return _this.num(dt.weekNumber, 2);
                case "n":
                    return _this.num(dt.localWeekNumber);
                case "nn":
                    return _this.num(dt.localWeekNumber, 2);
                case "ii":
                    return _this.num(dt.localWeekYear.toString().slice(-2), 2);
                case "iiii":
                    return _this.num(dt.localWeekYear, 4);
                case "o":
                    return _this.num(dt.ordinal);
                case "ooo":
                    return _this.num(dt.ordinal, 3);
                case "q":
                    // like 1
                    return _this.num(dt.quarter);
                case "qq":
                    // like 01
                    return _this.num(dt.quarter, 2);
                case "X":
                    return _this.num(Math.floor(dt.ts / 1000));
                case "x":
                    return _this.num(dt.ts);
                default:
                    return maybeMacro(token);
            }
        };
        return stringifyTokens(Formatter.parseFormat(fmt), tokenToString);
    };
    _proto.formatDurationFromString = function formatDurationFromString(dur, fmt) {
        var _this2 = this;
        var invertLargest = this.opts.signMode === "negativeLargestOnly" ? -1 : 1;
        var tokenToField = function tokenToField(token) {
            switch(token[0]){
                case "S":
                    return "milliseconds";
                case "s":
                    return "seconds";
                case "m":
                    return "minutes";
                case "h":
                    return "hours";
                case "d":
                    return "days";
                case "w":
                    return "weeks";
                case "M":
                    return "months";
                case "y":
                    return "years";
                default:
                    return null;
            }
        }, tokenToString = function tokenToString(lildur, info) {
            return function(token) {
                var mapped = tokenToField(token);
                if (mapped) {
                    var inversionFactor = info.isNegativeDuration && mapped !== info.largestUnit ? invertLargest : 1;
                    var signDisplay;
                    if (_this2.opts.signMode === "negativeLargestOnly" && mapped !== info.largestUnit) signDisplay = "never";
                    else if (_this2.opts.signMode === "all") signDisplay = "always";
                    else // "auto" and "negative" are the same, but "auto" has better support
                    signDisplay = "auto";
                    return _this2.num(lildur.get(mapped) * inversionFactor, token.length, signDisplay);
                } else return token;
            };
        }, tokens = Formatter.parseFormat(fmt), realTokens = tokens.reduce(function(found, _ref) {
            var literal = _ref.literal, val = _ref.val;
            return literal ? found : found.concat(val);
        }, []), collapsed = dur.shiftTo.apply(dur, realTokens.map(tokenToField).filter(function(t) {
            return t;
        })), durationInfo = {
            isNegativeDuration: collapsed < 0,
            // this relies on "collapsed" being based on "shiftTo", which builds up the object
            // in order
            largestUnit: Object.keys(collapsed.values)[0]
        };
        return stringifyTokens(tokens, tokenToString(collapsed, durationInfo));
    };
    return Formatter;
}();
/*
 * This file handles parsing for well-specified formats. Here's how it works:
 * Two things go into parsing: a regex to match with and an extractor to take apart the groups in the match.
 * An extractor is just a function that takes a regex match array and returns a { year: ..., month: ... } object
 * parse() does the work of executing the regex and applying the extractor. It takes multiple regex/extractor pairs to try in sequence.
 * Extractors can take a "cursor" representing the offset in the match to look at. This makes it easy to combine extractors.
 * combineExtractors() does the work of combining them, keeping track of the cursor through multiple extractions.
 * Some extractions are super dumb and simpleParse and fromStrings help DRY them.
 */ var ianaRegex = /[A-Za-z_+-]{1,256}(?::?\/[A-Za-z0-9_+-]{1,256}(?:\/[A-Za-z0-9_+-]{1,256})?)?/;
function combineRegexes() {
    for(var _len = arguments.length, regexes = new Array(_len), _key = 0; _key < _len; _key++)regexes[_key] = arguments[_key];
    var full = regexes.reduce(function(f, r) {
        return f + r.source;
    }, "");
    return RegExp("^" + full + "$");
}
function combineExtractors() {
    for(var _len2 = arguments.length, extractors = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++)extractors[_key2] = arguments[_key2];
    return function(m) {
        return extractors.reduce(function(_ref, ex) {
            var mergedVals = _ref[0], mergedZone = _ref[1], cursor = _ref[2];
            var _ex = ex(m, cursor), val = _ex[0], zone = _ex[1], next = _ex[2];
            return [
                _extends({}, mergedVals, val),
                zone || mergedZone,
                next
            ];
        }, [
            {},
            null,
            1
        ]).slice(0, 2);
    };
}
function parse(s) {
    if (s == null) return [
        null,
        null
    ];
    for(var _len3 = arguments.length, patterns = new Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++)patterns[_key3 - 1] = arguments[_key3];
    for(var _i = 0, _patterns = patterns; _i < _patterns.length; _i++){
        var _patterns$_i = _patterns[_i], regex = _patterns$_i[0], extractor = _patterns$_i[1];
        var m = regex.exec(s);
        if (m) return extractor(m);
    }
    return [
        null,
        null
    ];
}
function simpleParse() {
    for(var _len4 = arguments.length, keys = new Array(_len4), _key4 = 0; _key4 < _len4; _key4++)keys[_key4] = arguments[_key4];
    return function(match, cursor) {
        var ret = {};
        var i;
        for(i = 0; i < keys.length; i++)ret[keys[i]] = parseInteger(match[cursor + i]);
        return [
            ret,
            null,
            cursor + i
        ];
    };
}
// ISO and SQL parsing
var offsetRegex = /(?:([Zz])|([+-]\d\d)(?::?(\d\d))?)/;
var isoExtendedZone = "(?:" + offsetRegex.source + "?(?:\\[(" + ianaRegex.source + ")\\])?)?";
var isoTimeBaseRegex = /(\d\d)(?::?(\d\d)(?::?(\d\d)(?:[.,](\d{1,30}))?)?)?/;
var isoTimeRegex = RegExp("" + isoTimeBaseRegex.source + isoExtendedZone);
var isoTimeExtensionRegex = RegExp("(?:[Tt]" + isoTimeRegex.source + ")?");
var isoYmdRegex = /([+-]\d{6}|\d{4})(?:-?(\d\d)(?:-?(\d\d))?)?/;
var isoWeekRegex = /(\d{4})-?W(\d\d)(?:-?(\d))?/;
var isoOrdinalRegex = /(\d{4})-?(\d{3})/;
var extractISOWeekData = simpleParse("weekYear", "weekNumber", "weekDay");
var extractISOOrdinalData = simpleParse("year", "ordinal");
var sqlYmdRegex = /(\d{4})-(\d\d)-(\d\d)/; // dumbed-down version of the ISO one
var sqlTimeRegex = RegExp(isoTimeBaseRegex.source + " ?(?:" + offsetRegex.source + "|(" + ianaRegex.source + "))?");
var sqlTimeExtensionRegex = RegExp("(?: " + sqlTimeRegex.source + ")?");
function int(match, pos, fallback) {
    var m = match[pos];
    return isUndefined(m) ? fallback : parseInteger(m);
}
function extractISOYmd(match, cursor) {
    var item = {
        year: int(match, cursor),
        month: int(match, cursor + 1, 1),
        day: int(match, cursor + 2, 1)
    };
    return [
        item,
        null,
        cursor + 3
    ];
}
function extractISOTime(match, cursor) {
    var item = {
        hours: int(match, cursor, 0),
        minutes: int(match, cursor + 1, 0),
        seconds: int(match, cursor + 2, 0),
        milliseconds: parseMillis(match[cursor + 3])
    };
    return [
        item,
        null,
        cursor + 4
    ];
}
function extractISOOffset(match, cursor) {
    var local = !match[cursor] && !match[cursor + 1], fullOffset = signedOffset(match[cursor + 1], match[cursor + 2]), zone = local ? null : FixedOffsetZone.instance(fullOffset);
    return [
        {},
        zone,
        cursor + 3
    ];
}
function extractIANAZone(match, cursor) {
    var zone = match[cursor] ? IANAZone.create(match[cursor]) : null;
    return [
        {},
        zone,
        cursor + 1
    ];
}
// ISO time parsing
var isoTimeOnly = RegExp("^T?" + isoTimeBaseRegex.source + "$");
// ISO duration parsing
var isoDuration = /^-?P(?:(?:(-?\d{1,20}(?:\.\d{1,20})?)Y)?(?:(-?\d{1,20}(?:\.\d{1,20})?)M)?(?:(-?\d{1,20}(?:\.\d{1,20})?)W)?(?:(-?\d{1,20}(?:\.\d{1,20})?)D)?(?:T(?:(-?\d{1,20}(?:\.\d{1,20})?)H)?(?:(-?\d{1,20}(?:\.\d{1,20})?)M)?(?:(-?\d{1,20})(?:[.,](-?\d{1,20}))?S)?)?)$/;
function extractISODuration(match) {
    var s = match[0], yearStr = match[1], monthStr = match[2], weekStr = match[3], dayStr = match[4], hourStr = match[5], minuteStr = match[6], secondStr = match[7], millisecondsStr = match[8];
    var hasNegativePrefix = s[0] === "-";
    var negativeSeconds = secondStr && secondStr[0] === "-";
    var maybeNegate = function maybeNegate(num, force) {
        if (force === void 0) force = false;
        return num !== undefined && (force || num && hasNegativePrefix) ? -num : num;
    };
    return [
        {
            years: maybeNegate(parseFloating(yearStr)),
            months: maybeNegate(parseFloating(monthStr)),
            weeks: maybeNegate(parseFloating(weekStr)),
            days: maybeNegate(parseFloating(dayStr)),
            hours: maybeNegate(parseFloating(hourStr)),
            minutes: maybeNegate(parseFloating(minuteStr)),
            seconds: maybeNegate(parseFloating(secondStr), secondStr === "-0"),
            milliseconds: maybeNegate(parseMillis(millisecondsStr), negativeSeconds)
        }
    ];
}
// These are a little braindead. EDT *should* tell us that we're in, say, America/New_York
// and not just that we're in -240 *right now*. But since I don't think these are used that often
// I'm just going to ignore that
var obsOffsets = {
    GMT: 0,
    EDT: -240,
    EST: -300,
    CDT: -300,
    CST: -360,
    MDT: -360,
    MST: -420,
    PDT: -420,
    PST: -480
};
function fromStrings(weekdayStr, yearStr, monthStr, dayStr, hourStr, minuteStr, secondStr) {
    var result = {
        year: yearStr.length === 2 ? untruncateYear(parseInteger(yearStr)) : parseInteger(yearStr),
        month: monthsShort.indexOf(monthStr) + 1,
        day: parseInteger(dayStr),
        hour: parseInteger(hourStr),
        minute: parseInteger(minuteStr)
    };
    if (secondStr) result.second = parseInteger(secondStr);
    if (weekdayStr) result.weekday = weekdayStr.length > 3 ? weekdaysLong.indexOf(weekdayStr) + 1 : weekdaysShort.indexOf(weekdayStr) + 1;
    return result;
}
// RFC 2822/5322
var rfc2822 = /^(?:(Mon|Tue|Wed|Thu|Fri|Sat|Sun),\s)?(\d{1,2})\s(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)\s(\d{2,4})\s(\d\d):(\d\d)(?::(\d\d))?\s(?:(UT|GMT|[ECMP][SD]T)|([Zz])|(?:([+-]\d\d)(\d\d)))$/;
function extractRFC2822(match) {
    var weekdayStr = match[1], dayStr = match[2], monthStr = match[3], yearStr = match[4], hourStr = match[5], minuteStr = match[6], secondStr = match[7], obsOffset = match[8], milOffset = match[9], offHourStr = match[10], offMinuteStr = match[11], result = fromStrings(weekdayStr, yearStr, monthStr, dayStr, hourStr, minuteStr, secondStr);
    var offset;
    if (obsOffset) offset = obsOffsets[obsOffset];
    else if (milOffset) offset = 0;
    else offset = signedOffset(offHourStr, offMinuteStr);
    return [
        result,
        new FixedOffsetZone(offset)
    ];
}
function preprocessRFC2822(s) {
    // Remove comments and folding whitespace and replace multiple-spaces with a single space
    return s.replace(/\([^()]*\)|[\n\t]/g, " ").replace(/(\s\s+)/g, " ").trim();
}
// http date
var rfc1123 = /^(Mon|Tue|Wed|Thu|Fri|Sat|Sun), (\d\d) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) (\d{4}) (\d\d):(\d\d):(\d\d) GMT$/, rfc850 = /^(Monday|Tuesday|Wednesday|Thursday|Friday|Saturday|Sunday), (\d\d)-(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)-(\d\d) (\d\d):(\d\d):(\d\d) GMT$/, ascii = /^(Mon|Tue|Wed|Thu|Fri|Sat|Sun) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) ( \d|\d\d) (\d\d):(\d\d):(\d\d) (\d{4})$/;
function extractRFC1123Or850(match) {
    var weekdayStr = match[1], dayStr = match[2], monthStr = match[3], yearStr = match[4], hourStr = match[5], minuteStr = match[6], secondStr = match[7], result = fromStrings(weekdayStr, yearStr, monthStr, dayStr, hourStr, minuteStr, secondStr);
    return [
        result,
        FixedOffsetZone.utcInstance
    ];
}
function extractASCII(match) {
    var weekdayStr = match[1], monthStr = match[2], dayStr = match[3], hourStr = match[4], minuteStr = match[5], secondStr = match[6], yearStr = match[7], result = fromStrings(weekdayStr, yearStr, monthStr, dayStr, hourStr, minuteStr, secondStr);
    return [
        result,
        FixedOffsetZone.utcInstance
    ];
}
var isoYmdWithTimeExtensionRegex = combineRegexes(isoYmdRegex, isoTimeExtensionRegex);
var isoWeekWithTimeExtensionRegex = combineRegexes(isoWeekRegex, isoTimeExtensionRegex);
var isoOrdinalWithTimeExtensionRegex = combineRegexes(isoOrdinalRegex, isoTimeExtensionRegex);
var isoTimeCombinedRegex = combineRegexes(isoTimeRegex);
var extractISOYmdTimeAndOffset = combineExtractors(extractISOYmd, extractISOTime, extractISOOffset, extractIANAZone);
var extractISOWeekTimeAndOffset = combineExtractors(extractISOWeekData, extractISOTime, extractISOOffset, extractIANAZone);
var extractISOOrdinalDateAndTime = combineExtractors(extractISOOrdinalData, extractISOTime, extractISOOffset, extractIANAZone);
var extractISOTimeAndOffset = combineExtractors(extractISOTime, extractISOOffset, extractIANAZone);
/*
 * @private
 */ function parseISODate(s) {
    return parse(s, [
        isoYmdWithTimeExtensionRegex,
        extractISOYmdTimeAndOffset
    ], [
        isoWeekWithTimeExtensionRegex,
        extractISOWeekTimeAndOffset
    ], [
        isoOrdinalWithTimeExtensionRegex,
        extractISOOrdinalDateAndTime
    ], [
        isoTimeCombinedRegex,
        extractISOTimeAndOffset
    ]);
}
function parseRFC2822Date(s) {
    return parse(preprocessRFC2822(s), [
        rfc2822,
        extractRFC2822
    ]);
}
function parseHTTPDate(s) {
    return parse(s, [
        rfc1123,
        extractRFC1123Or850
    ], [
        rfc850,
        extractRFC1123Or850
    ], [
        ascii,
        extractASCII
    ]);
}
function parseISODuration(s) {
    return parse(s, [
        isoDuration,
        extractISODuration
    ]);
}
var extractISOTimeOnly = combineExtractors(extractISOTime);
function parseISOTimeOnly(s) {
    return parse(s, [
        isoTimeOnly,
        extractISOTimeOnly
    ]);
}
var sqlYmdWithTimeExtensionRegex = combineRegexes(sqlYmdRegex, sqlTimeExtensionRegex);
var sqlTimeCombinedRegex = combineRegexes(sqlTimeRegex);
var extractISOTimeOffsetAndIANAZone = combineExtractors(extractISOTime, extractISOOffset, extractIANAZone);
function parseSQL(s) {
    return parse(s, [
        sqlYmdWithTimeExtensionRegex,
        extractISOYmdTimeAndOffset
    ], [
        sqlTimeCombinedRegex,
        extractISOTimeOffsetAndIANAZone
    ]);
}
var INVALID$2 = "Invalid Duration";
// unit conversion constants
var lowOrderMatrix = {
    weeks: {
        days: 7,
        hours: 168,
        minutes: 10080,
        seconds: 604800,
        milliseconds: 604800000
    },
    days: {
        hours: 24,
        minutes: 1440,
        seconds: 86400,
        milliseconds: 86400000
    },
    hours: {
        minutes: 60,
        seconds: 3600,
        milliseconds: 3600000
    },
    minutes: {
        seconds: 60,
        milliseconds: 60000
    },
    seconds: {
        milliseconds: 1000
    }
}, casualMatrix = _extends({
    years: {
        quarters: 4,
        months: 12,
        weeks: 52,
        days: 365,
        hours: 8760,
        minutes: 525600,
        seconds: 31536000,
        milliseconds: 31536000000
    },
    quarters: {
        months: 3,
        weeks: 13,
        days: 91,
        hours: 2184,
        minutes: 131040,
        seconds: 7862400,
        milliseconds: 7862400000
    },
    months: {
        weeks: 4,
        days: 30,
        hours: 720,
        minutes: 43200,
        seconds: 2592000,
        milliseconds: 2592000000
    }
}, lowOrderMatrix), daysInYearAccurate = 365.2425, daysInMonthAccurate = 30.436875, accurateMatrix = _extends({
    years: {
        quarters: 4,
        months: 12,
        weeks: daysInYearAccurate / 7,
        days: daysInYearAccurate,
        hours: daysInYearAccurate * 24,
        minutes: daysInYearAccurate * 1440,
        seconds: daysInYearAccurate * 86400,
        milliseconds: daysInYearAccurate * 86400000
    },
    quarters: {
        months: 3,
        weeks: daysInYearAccurate / 28,
        days: daysInYearAccurate / 4,
        hours: daysInYearAccurate * 24 / 4,
        minutes: daysInYearAccurate * 1440 / 4,
        seconds: daysInYearAccurate * 86400 / 4,
        milliseconds: daysInYearAccurate * 86400000 / 4
    },
    months: {
        weeks: daysInMonthAccurate / 7,
        days: daysInMonthAccurate,
        hours: daysInMonthAccurate * 24,
        minutes: daysInMonthAccurate * 1440,
        seconds: daysInMonthAccurate * 86400,
        milliseconds: daysInMonthAccurate * 86400000
    }
}, lowOrderMatrix);
// units ordered by size
var orderedUnits$1 = [
    "years",
    "quarters",
    "months",
    "weeks",
    "days",
    "hours",
    "minutes",
    "seconds",
    "milliseconds"
];
var reverseUnits = orderedUnits$1.slice(0).reverse();
// clone really means "create another instance just like this one, but with these changes"
function clone$1(dur, alts, clear) {
    if (clear === void 0) clear = false;
    // deep merge for vals
    var conf = {
        values: clear ? alts.values : _extends({}, dur.values, alts.values || {}),
        loc: dur.loc.clone(alts.loc),
        conversionAccuracy: alts.conversionAccuracy || dur.conversionAccuracy,
        matrix: alts.matrix || dur.matrix
    };
    return new Duration(conf);
}
function durationToMillis(matrix, vals) {
    var _vals$milliseconds;
    var sum = (_vals$milliseconds = vals.milliseconds) != null ? _vals$milliseconds : 0;
    for(var _iterator = _createForOfIteratorHelperLoose(reverseUnits.slice(1)), _step; !(_step = _iterator()).done;){
        var unit = _step.value;
        if (vals[unit]) sum += vals[unit] * matrix[unit]["milliseconds"];
    }
    return sum;
}
// NB: mutates parameters
function normalizeValues(matrix, vals) {
    // the logic below assumes the overall value of the duration is positive
    // if this is not the case, factor is used to make it so
    var factor = durationToMillis(matrix, vals) < 0 ? -1 : 1;
    orderedUnits$1.reduceRight(function(previous, current) {
        if (!isUndefined(vals[current])) {
            if (previous) {
                var previousVal = vals[previous] * factor;
                var conv = matrix[current][previous];
                // if (previousVal < 0):
                // lower order unit is negative (e.g. { years: 2, days: -2 })
                // normalize this by reducing the higher order unit by the appropriate amount
                // and increasing the lower order unit
                // this can never make the higher order unit negative, because this function only operates
                // on positive durations, so the amount of time represented by the lower order unit cannot
                // be larger than the higher order unit
                // else:
                // lower order unit is positive (e.g. { years: 2, days: 450 } or { years: -2, days: 450 })
                // in this case we attempt to convert as much as possible from the lower order unit into
                // the higher order one
                //
                // Math.floor takes care of both of these cases, rounding away from 0
                // if previousVal < 0 it makes the absolute value larger
                // if previousVal >= it makes the absolute value smaller
                var rollUp = Math.floor(previousVal / conv);
                vals[current] += rollUp * factor;
                vals[previous] -= rollUp * conv * factor;
            }
            return current;
        } else return previous;
    }, null);
    // try to convert any decimals into smaller units if possible
    // for example for { years: 2.5, days: 0, seconds: 0 } we want to get { years: 2, days: 182, hours: 12 }
    orderedUnits$1.reduce(function(previous, current) {
        if (!isUndefined(vals[current])) {
            if (previous) {
                var fraction = vals[previous] % 1;
                vals[previous] -= fraction;
                vals[current] += fraction * matrix[previous][current];
            }
            return current;
        } else return previous;
    }, null);
}
// Remove all properties with a value of 0 from an object
function removeZeroes(vals) {
    var newVals = {};
    for(var _i = 0, _Object$entries = Object.entries(vals); _i < _Object$entries.length; _i++){
        var _Object$entries$_i = _Object$entries[_i], key = _Object$entries$_i[0], value = _Object$entries$_i[1];
        if (value !== 0) newVals[key] = value;
    }
    return newVals;
}
/**
 * A Duration object represents a period of time, like "2 months" or "1 day, 1 hour". Conceptually, it's just a map of units to their quantities, accompanied by some additional configuration and methods for creating, parsing, interrogating, transforming, and formatting them. They can be used on their own or in conjunction with other Luxon types; for example, you can use {@link DateTime#plus} to add a Duration object to a DateTime, producing another DateTime.
 *
 * Here is a brief overview of commonly used methods and getters in Duration:
 *
 * * **Creation** To create a Duration, use {@link Duration.fromMillis}, {@link Duration.fromObject}, or {@link Duration.fromISO}.
 * * **Unit values** See the {@link Duration#years}, {@link Duration#months}, {@link Duration#weeks}, {@link Duration#days}, {@link Duration#hours}, {@link Duration#minutes}, {@link Duration#seconds}, {@link Duration#milliseconds} accessors.
 * * **Configuration** See  {@link Duration#locale} and {@link Duration#numberingSystem} accessors.
 * * **Transformation** To create new Durations out of old ones use {@link Duration#plus}, {@link Duration#minus}, {@link Duration#normalize}, {@link Duration#set}, {@link Duration#reconfigure}, {@link Duration#shiftTo}, and {@link Duration#negate}.
 * * **Output** To convert the Duration into other representations, see {@link Duration#as}, {@link Duration#toISO}, {@link Duration#toFormat}, and {@link Duration#toJSON}
 *
 * There's are more methods documented below. In addition, for more information on subtler topics like internationalization and validity, see the external documentation.
 */ var Duration = /*#__PURE__*/ function(_Symbol$for) {
    /**
   * @private
   */ function Duration(config) {
        var accurate = config.conversionAccuracy === "longterm" || false;
        var matrix = accurate ? accurateMatrix : casualMatrix;
        if (config.matrix) matrix = config.matrix;
        /**
     * @access private
     */ this.values = config.values;
        /**
     * @access private
     */ this.loc = config.loc || Locale.create();
        /**
     * @access private
     */ this.conversionAccuracy = accurate ? "longterm" : "casual";
        /**
     * @access private
     */ this.invalid = config.invalid || null;
        /**
     * @access private
     */ this.matrix = matrix;
        /**
     * @access private
     */ this.isLuxonDuration = true;
    }
    /**
   * Create Duration from a number of milliseconds.
   * @param {number} count of milliseconds
   * @param {Object} opts - options for parsing
   * @param {string} [opts.locale='en-US'] - the locale to use
   * @param {string} opts.numberingSystem - the numbering system to use
   * @param {string} [opts.conversionAccuracy='casual'] - the conversion system to use
   * @return {Duration}
   */ Duration.fromMillis = function fromMillis(count, opts) {
        return Duration.fromObject({
            milliseconds: count
        }, opts);
    };
    Duration.fromObject = function fromObject(obj, opts) {
        if (opts === void 0) opts = {};
        if (obj == null || typeof obj !== "object") throw new InvalidArgumentError("Duration.fromObject: argument expected to be an object, got " + (obj === null ? "null" : typeof obj));
        return new Duration({
            values: normalizeObject(obj, Duration.normalizeUnit),
            loc: Locale.fromObject(opts),
            conversionAccuracy: opts.conversionAccuracy,
            matrix: opts.matrix
        });
    };
    Duration.fromDurationLike = function fromDurationLike(durationLike) {
        if (isNumber(durationLike)) return Duration.fromMillis(durationLike);
        else if (Duration.isDuration(durationLike)) return durationLike;
        else if (typeof durationLike === "object") return Duration.fromObject(durationLike);
        else throw new InvalidArgumentError("Unknown duration argument " + durationLike + " of type " + typeof durationLike);
    };
    Duration.fromISO = function fromISO(text, opts) {
        var _parseISODuration = parseISODuration(text), parsed = _parseISODuration[0];
        if (parsed) return Duration.fromObject(parsed, opts);
        else return Duration.invalid("unparsable", "the input \"" + text + "\" can't be parsed as ISO 8601");
    };
    Duration.fromISOTime = function fromISOTime(text, opts) {
        var _parseISOTimeOnly = parseISOTimeOnly(text), parsed = _parseISOTimeOnly[0];
        if (parsed) return Duration.fromObject(parsed, opts);
        else return Duration.invalid("unparsable", "the input \"" + text + "\" can't be parsed as ISO 8601");
    };
    Duration.invalid = function invalid(reason, explanation) {
        if (explanation === void 0) explanation = null;
        if (!reason) throw new InvalidArgumentError("need to specify a reason the Duration is invalid");
        var invalid = reason instanceof Invalid ? reason : new Invalid(reason, explanation);
        if (Settings.throwOnInvalid) throw new InvalidDurationError(invalid);
        else return new Duration({
            invalid: invalid
        });
    };
    Duration.normalizeUnit = function normalizeUnit(unit) {
        var normalized = {
            year: "years",
            years: "years",
            quarter: "quarters",
            quarters: "quarters",
            month: "months",
            months: "months",
            week: "weeks",
            weeks: "weeks",
            day: "days",
            days: "days",
            hour: "hours",
            hours: "hours",
            minute: "minutes",
            minutes: "minutes",
            second: "seconds",
            seconds: "seconds",
            millisecond: "milliseconds",
            milliseconds: "milliseconds"
        }[unit ? unit.toLowerCase() : unit];
        if (!normalized) throw new InvalidUnitError(unit);
        return normalized;
    };
    Duration.isDuration = function isDuration(o) {
        return o && o.isLuxonDuration || false;
    };
    var _proto = Duration.prototype;
    /**
   * Returns a string representation of this Duration formatted according to the specified format string. You may use these tokens:
   * * `S` for milliseconds
   * * `s` for seconds
   * * `m` for minutes
   * * `h` for hours
   * * `d` for days
   * * `w` for weeks
   * * `M` for months
   * * `y` for years
   * Notes:
   * * Add padding by repeating the token, e.g. "yy" pads the years to two digits, "hhhh" pads the hours out to four digits
   * * Tokens can be escaped by wrapping with single quotes.
   * * The duration will be converted to the set of units in the format string using {@link Duration#shiftTo} and the Durations's conversion accuracy setting.
   * @param {string} fmt - the format string
   * @param {Object} opts - options
   * @param {boolean} [opts.floor=true] - floor numerical values
   * @param {'negative'|'all'|'negativeLargestOnly'} [opts.signMode=negative] - How to handle signs
   * @example Duration.fromObject({ years: 1, days: 6, seconds: 2 }).toFormat("y d s") //=> "1 6 2"
   * @example Duration.fromObject({ years: 1, days: 6, seconds: 2 }).toFormat("yy dd sss") //=> "01 06 002"
   * @example Duration.fromObject({ years: 1, days: 6, seconds: 2 }).toFormat("M S") //=> "12 518402000"
   * @example Duration.fromObject({ days: 6, seconds: 2 }).toFormat("d s", { signMode: "all" }) //=> "+6 +2"
   * @example Duration.fromObject({ days: -6, seconds: -2 }).toFormat("d s", { signMode: "all" }) //=> "-6 -2"
   * @example Duration.fromObject({ days: -6, seconds: -2 }).toFormat("d s", { signMode: "negativeLargestOnly" }) //=> "-6 2"
   * @return {string}
   */ _proto.toFormat = function toFormat(fmt, opts) {
        if (opts === void 0) opts = {};
        // reverse-compat since 1.2; we always round down now, never up, and we do it by default
        var fmtOpts = _extends({}, opts, {
            floor: opts.round !== false && opts.floor !== false
        });
        return this.isValid ? Formatter.create(this.loc, fmtOpts).formatDurationFromString(this, fmt) : INVALID$2;
    };
    _proto.toHuman = function toHuman(opts) {
        var _this = this;
        if (opts === void 0) opts = {};
        if (!this.isValid) return INVALID$2;
        var showZeros = opts.showZeros !== false;
        var l = orderedUnits$1.map(function(unit) {
            var val = _this.values[unit];
            if (isUndefined(val) || val === 0 && !showZeros) return null;
            return _this.loc.numberFormatter(_extends({
                style: "unit",
                unitDisplay: "long"
            }, opts, {
                unit: unit.slice(0, -1)
            })).format(val);
        }).filter(function(n) {
            return n;
        });
        return this.loc.listFormatter(_extends({
            type: "conjunction",
            style: opts.listStyle || "narrow"
        }, opts)).format(l);
    };
    _proto.toObject = function toObject() {
        if (!this.isValid) return {};
        return _extends({}, this.values);
    };
    _proto.toISO = function toISO() {
        // we could use the formatter, but this is an easier way to get the minimum string
        if (!this.isValid) return null;
        var s = "P";
        if (this.years !== 0) s += this.years + "Y";
        if (this.months !== 0 || this.quarters !== 0) s += this.months + this.quarters * 3 + "M";
        if (this.weeks !== 0) s += this.weeks + "W";
        if (this.days !== 0) s += this.days + "D";
        if (this.hours !== 0 || this.minutes !== 0 || this.seconds !== 0 || this.milliseconds !== 0) s += "T";
        if (this.hours !== 0) s += this.hours + "H";
        if (this.minutes !== 0) s += this.minutes + "M";
        if (this.seconds !== 0 || this.milliseconds !== 0) // this will handle "floating point madness" by removing extra decimal places
        // https://stackoverflow.com/questions/588004/is-floating-point-math-broken
        s += roundTo(this.seconds + this.milliseconds / 1000, 3) + "S";
        if (s === "P") s += "T0S";
        return s;
    };
    _proto.toISOTime = function toISOTime(opts) {
        if (opts === void 0) opts = {};
        if (!this.isValid) return null;
        var millis = this.toMillis();
        if (millis < 0 || millis >= 86400000) return null;
        opts = _extends({
            suppressMilliseconds: false,
            suppressSeconds: false,
            includePrefix: false,
            format: "extended"
        }, opts, {
            includeOffset: false
        });
        var dateTime = DateTime.fromMillis(millis, {
            zone: "UTC"
        });
        return dateTime.toISOTime(opts);
    };
    _proto.toJSON = function toJSON() {
        return this.toISO();
    };
    _proto.toString = function toString() {
        return this.toISO();
    };
    _proto[_Symbol$for] = function() {
        if (this.isValid) return "Duration { values: " + JSON.stringify(this.values) + " }";
        else return "Duration { Invalid, reason: " + this.invalidReason + " }";
    };
    _proto.toMillis = function toMillis() {
        if (!this.isValid) return NaN;
        return durationToMillis(this.matrix, this.values);
    };
    _proto.valueOf = function valueOf() {
        return this.toMillis();
    };
    _proto.plus = function plus(duration) {
        if (!this.isValid) return this;
        var dur = Duration.fromDurationLike(duration), result = {};
        for(var _i2 = 0, _orderedUnits = orderedUnits$1; _i2 < _orderedUnits.length; _i2++){
            var k = _orderedUnits[_i2];
            if (hasOwnProperty(dur.values, k) || hasOwnProperty(this.values, k)) result[k] = dur.get(k) + this.get(k);
        }
        return clone$1(this, {
            values: result
        }, true);
    };
    _proto.minus = function minus(duration) {
        if (!this.isValid) return this;
        var dur = Duration.fromDurationLike(duration);
        return this.plus(dur.negate());
    };
    _proto.mapUnits = function mapUnits(fn) {
        if (!this.isValid) return this;
        var result = {};
        for(var _i3 = 0, _Object$keys = Object.keys(this.values); _i3 < _Object$keys.length; _i3++){
            var k = _Object$keys[_i3];
            result[k] = asNumber(fn(this.values[k], k));
        }
        return clone$1(this, {
            values: result
        }, true);
    };
    _proto.get = function get(unit) {
        return this[Duration.normalizeUnit(unit)];
    };
    _proto.set = function set(values) {
        if (!this.isValid) return this;
        var mixed = _extends({}, this.values, normalizeObject(values, Duration.normalizeUnit));
        return clone$1(this, {
            values: mixed
        });
    };
    _proto.reconfigure = function reconfigure(_temp) {
        var _ref = _temp === void 0 ? {} : _temp, locale = _ref.locale, numberingSystem = _ref.numberingSystem, conversionAccuracy = _ref.conversionAccuracy, matrix = _ref.matrix;
        var loc = this.loc.clone({
            locale: locale,
            numberingSystem: numberingSystem
        });
        var opts = {
            loc: loc,
            matrix: matrix,
            conversionAccuracy: conversionAccuracy
        };
        return clone$1(this, opts);
    };
    _proto.as = function as(unit) {
        return this.isValid ? this.shiftTo(unit).get(unit) : NaN;
    };
    _proto.normalize = function normalize() {
        if (!this.isValid) return this;
        var vals = this.toObject();
        normalizeValues(this.matrix, vals);
        return clone$1(this, {
            values: vals
        }, true);
    };
    _proto.rescale = function rescale() {
        if (!this.isValid) return this;
        var vals = removeZeroes(this.normalize().shiftToAll().toObject());
        return clone$1(this, {
            values: vals
        }, true);
    };
    _proto.shiftTo = function shiftTo() {
        for(var _len = arguments.length, units = new Array(_len), _key = 0; _key < _len; _key++)units[_key] = arguments[_key];
        if (!this.isValid) return this;
        if (units.length === 0) return this;
        units = units.map(function(u) {
            return Duration.normalizeUnit(u);
        });
        var built = {}, accumulated = {}, vals = this.toObject();
        var lastUnit;
        for(var _i4 = 0, _orderedUnits2 = orderedUnits$1; _i4 < _orderedUnits2.length; _i4++){
            var k = _orderedUnits2[_i4];
            if (units.indexOf(k) >= 0) {
                lastUnit = k;
                var own = 0;
                // anything we haven't boiled down yet should get boiled to this unit
                for(var ak in accumulated){
                    own += this.matrix[ak][k] * accumulated[ak];
                    accumulated[ak] = 0;
                }
                // plus anything that's already in this unit
                if (isNumber(vals[k])) own += vals[k];
                // only keep the integer part for now in the hopes of putting any decimal part
                // into a smaller unit later
                var i = Math.trunc(own);
                built[k] = i;
                accumulated[k] = (own * 1000 - i * 1000) / 1000;
            // otherwise, keep it in the wings to boil it later
            } else if (isNumber(vals[k])) accumulated[k] = vals[k];
        }
        // anything leftover becomes the decimal for the last unit
        // lastUnit must be defined since units is not empty
        for(var key in accumulated)if (accumulated[key] !== 0) built[lastUnit] += key === lastUnit ? accumulated[key] : accumulated[key] / this.matrix[lastUnit][key];
        normalizeValues(this.matrix, built);
        return clone$1(this, {
            values: built
        }, true);
    };
    _proto.shiftToAll = function shiftToAll() {
        if (!this.isValid) return this;
        return this.shiftTo("years", "months", "weeks", "days", "hours", "minutes", "seconds", "milliseconds");
    };
    _proto.negate = function negate() {
        if (!this.isValid) return this;
        var negated = {};
        for(var _i5 = 0, _Object$keys2 = Object.keys(this.values); _i5 < _Object$keys2.length; _i5++){
            var k = _Object$keys2[_i5];
            negated[k] = this.values[k] === 0 ? 0 : -this.values[k];
        }
        return clone$1(this, {
            values: negated
        }, true);
    };
    _proto.removeZeros = function removeZeros() {
        if (!this.isValid) return this;
        var vals = removeZeroes(this.values);
        return clone$1(this, {
            values: vals
        }, true);
    };
    /**
   * Equality check
   * Two Durations are equal iff they have the same units and the same values for each unit.
   * @param {Duration} other
   * @return {boolean}
   */ _proto.equals = function equals(other) {
        if (!this.isValid || !other.isValid) return false;
        if (!this.loc.equals(other.loc)) return false;
        function eq(v1, v2) {
            // Consider 0 and undefined as equal
            if (v1 === undefined || v1 === 0) return v2 === undefined || v2 === 0;
            return v1 === v2;
        }
        for(var _i6 = 0, _orderedUnits3 = orderedUnits$1; _i6 < _orderedUnits3.length; _i6++){
            var u = _orderedUnits3[_i6];
            if (!eq(this.values[u], other.values[u])) return false;
        }
        return true;
    };
    _createClass(Duration, [
        {
            key: "locale",
            get: function get() {
                return this.isValid ? this.loc.locale : null;
            }
        },
        {
            key: "numberingSystem",
            get: function get() {
                return this.isValid ? this.loc.numberingSystem : null;
            }
        },
        {
            key: "years",
            get: function get() {
                return this.isValid ? this.values.years || 0 : NaN;
            }
        },
        {
            key: "quarters",
            get: function get() {
                return this.isValid ? this.values.quarters || 0 : NaN;
            }
        },
        {
            key: "months",
            get: function get() {
                return this.isValid ? this.values.months || 0 : NaN;
            }
        },
        {
            key: "weeks",
            get: function get() {
                return this.isValid ? this.values.weeks || 0 : NaN;
            }
        },
        {
            key: "days",
            get: function get() {
                return this.isValid ? this.values.days || 0 : NaN;
            }
        },
        {
            key: "hours",
            get: function get() {
                return this.isValid ? this.values.hours || 0 : NaN;
            }
        },
        {
            key: "minutes",
            get: function get() {
                return this.isValid ? this.values.minutes || 0 : NaN;
            }
        },
        {
            key: "seconds",
            get: function get() {
                return this.isValid ? this.values.seconds || 0 : NaN;
            }
        },
        {
            key: "milliseconds",
            get: function get() {
                return this.isValid ? this.values.milliseconds || 0 : NaN;
            }
        },
        {
            key: "isValid",
            get: function get() {
                return this.invalid === null;
            }
        },
        {
            key: "invalidReason",
            get: function get() {
                return this.invalid ? this.invalid.reason : null;
            }
        },
        {
            key: "invalidExplanation",
            get: function get() {
                return this.invalid ? this.invalid.explanation : null;
            }
        }
    ]);
    return Duration;
}(Symbol.for("nodejs.util.inspect.custom"));
var INVALID$1 = "Invalid Interval";
// checks if the start is equal to or before the end
function validateStartEnd(start, end) {
    if (!start || !start.isValid) return Interval.invalid("missing or invalid start");
    else if (!end || !end.isValid) return Interval.invalid("missing or invalid end");
    else if (end < start) return Interval.invalid("end before start", "The end of an interval must be after its start, but you had start=" + start.toISO() + " and end=" + end.toISO());
    else return null;
}
/**
 * An Interval object represents a half-open interval of time, where each endpoint is a {@link DateTime}. Conceptually, it's a container for those two endpoints, accompanied by methods for creating, parsing, interrogating, comparing, transforming, and formatting them.
 *
 * Here is a brief overview of the most commonly used methods and getters in Interval:
 *
 * * **Creation** To create an Interval, use {@link Interval.fromDateTimes}, {@link Interval.after}, {@link Interval.before}, or {@link Interval.fromISO}.
 * * **Accessors** Use {@link Interval#start} and {@link Interval#end} to get the start and end.
 * * **Interrogation** To analyze the Interval, use {@link Interval#count}, {@link Interval#length}, {@link Interval#hasSame}, {@link Interval#contains}, {@link Interval#isAfter}, or {@link Interval#isBefore}.
 * * **Transformation** To create other Intervals out of this one, use {@link Interval#set}, {@link Interval#splitAt}, {@link Interval#splitBy}, {@link Interval#divideEqually}, {@link Interval.merge}, {@link Interval.xor}, {@link Interval#union}, {@link Interval#intersection}, or {@link Interval#difference}.
 * * **Comparison** To compare this Interval to another one, use {@link Interval#equals}, {@link Interval#overlaps}, {@link Interval#abutsStart}, {@link Interval#abutsEnd}, {@link Interval#engulfs}
 * * **Output** To convert the Interval into other representations, see {@link Interval#toString}, {@link Interval#toLocaleString}, {@link Interval#toISO}, {@link Interval#toISODate}, {@link Interval#toISOTime}, {@link Interval#toFormat}, and {@link Interval#toDuration}.
 */ var Interval = /*#__PURE__*/ function(_Symbol$for) {
    /**
   * @private
   */ function Interval(config) {
        /**
     * @access private
     */ this.s = config.start;
        /**
     * @access private
     */ this.e = config.end;
        /**
     * @access private
     */ this.invalid = config.invalid || null;
        /**
     * @access private
     */ this.isLuxonInterval = true;
    }
    /**
   * Create an invalid Interval.
   * @param {string} reason - simple string of why this Interval is invalid. Should not contain parameters or anything else data-dependent
   * @param {string} [explanation=null] - longer explanation, may include parameters and other useful debugging information
   * @return {Interval}
   */ Interval.invalid = function invalid(reason, explanation) {
        if (explanation === void 0) explanation = null;
        if (!reason) throw new InvalidArgumentError("need to specify a reason the Interval is invalid");
        var invalid = reason instanceof Invalid ? reason : new Invalid(reason, explanation);
        if (Settings.throwOnInvalid) throw new InvalidIntervalError(invalid);
        else return new Interval({
            invalid: invalid
        });
    };
    Interval.fromDateTimes = function fromDateTimes(start, end) {
        var builtStart = friendlyDateTime(start), builtEnd = friendlyDateTime(end);
        var validateError = validateStartEnd(builtStart, builtEnd);
        if (validateError == null) return new Interval({
            start: builtStart,
            end: builtEnd
        });
        else return validateError;
    };
    Interval.after = function after(start, duration) {
        var dur = Duration.fromDurationLike(duration), dt = friendlyDateTime(start);
        return Interval.fromDateTimes(dt, dt.plus(dur));
    };
    Interval.before = function before(end, duration) {
        var dur = Duration.fromDurationLike(duration), dt = friendlyDateTime(end);
        return Interval.fromDateTimes(dt.minus(dur), dt);
    };
    Interval.fromISO = function fromISO(text, opts) {
        var _split = (text || "").split("/", 2), s = _split[0], e = _split[1];
        if (s && e) {
            var start, startIsValid;
            try {
                start = DateTime.fromISO(s, opts);
                startIsValid = start.isValid;
            } catch (e) {
                startIsValid = false;
            }
            var end, endIsValid;
            try {
                end = DateTime.fromISO(e, opts);
                endIsValid = end.isValid;
            } catch (e) {
                endIsValid = false;
            }
            if (startIsValid && endIsValid) return Interval.fromDateTimes(start, end);
            if (startIsValid) {
                var dur = Duration.fromISO(e, opts);
                if (dur.isValid) return Interval.after(start, dur);
            } else if (endIsValid) {
                var _dur = Duration.fromISO(s, opts);
                if (_dur.isValid) return Interval.before(end, _dur);
            }
        }
        return Interval.invalid("unparsable", "the input \"" + text + "\" can't be parsed as ISO 8601");
    };
    Interval.isInterval = function isInterval(o) {
        return o && o.isLuxonInterval || false;
    };
    var _proto = Interval.prototype;
    /**
   * Returns the length of the Interval in the specified unit.
   * @param {string} unit - the unit (such as 'hours' or 'days') to return the length in.
   * @return {number}
   */ _proto.length = function length(unit) {
        if (unit === void 0) unit = "milliseconds";
        return this.isValid ? this.toDuration.apply(this, [
            unit
        ]).get(unit) : NaN;
    };
    _proto.count = function count(unit, opts) {
        if (unit === void 0) unit = "milliseconds";
        if (!this.isValid) return NaN;
        var start = this.start.startOf(unit, opts);
        var end;
        if (opts != null && opts.useLocaleWeeks) end = this.end.reconfigure({
            locale: start.locale
        });
        else end = this.end;
        end = end.startOf(unit, opts);
        return Math.floor(end.diff(start, unit).get(unit)) + (end.valueOf() !== this.end.valueOf());
    };
    _proto.hasSame = function hasSame(unit) {
        return this.isValid ? this.isEmpty() || this.e.minus(1).hasSame(this.s, unit) : false;
    };
    _proto.isEmpty = function isEmpty() {
        return this.s.valueOf() === this.e.valueOf();
    };
    _proto.isAfter = function isAfter(dateTime) {
        if (!this.isValid) return false;
        return this.s > dateTime;
    };
    _proto.isBefore = function isBefore(dateTime) {
        if (!this.isValid) return false;
        return this.e <= dateTime;
    };
    _proto.contains = function contains(dateTime) {
        if (!this.isValid) return false;
        return this.s <= dateTime && this.e > dateTime;
    };
    _proto.set = function set(_temp) {
        var _ref = _temp === void 0 ? {} : _temp, start = _ref.start, end = _ref.end;
        if (!this.isValid) return this;
        return Interval.fromDateTimes(start || this.s, end || this.e);
    };
    _proto.splitAt = function splitAt() {
        var _this = this;
        if (!this.isValid) return [];
        for(var _len = arguments.length, dateTimes = new Array(_len), _key = 0; _key < _len; _key++)dateTimes[_key] = arguments[_key];
        var sorted = dateTimes.map(friendlyDateTime).filter(function(d) {
            return _this.contains(d);
        }).sort(function(a, b) {
            return a.toMillis() - b.toMillis();
        }), results = [];
        var s = this.s, i = 0;
        while(s < this.e){
            var added = sorted[i] || this.e, next = +added > +this.e ? this.e : added;
            results.push(Interval.fromDateTimes(s, next));
            s = next;
            i += 1;
        }
        return results;
    };
    _proto.splitBy = function splitBy(duration) {
        var dur = Duration.fromDurationLike(duration);
        if (!this.isValid || !dur.isValid || dur.as("milliseconds") === 0) return [];
        var s = this.s, idx = 1, next;
        var results = [];
        while(s < this.e){
            var added = this.start.plus(dur.mapUnits(function(x) {
                return x * idx;
            }));
            next = +added > +this.e ? this.e : added;
            results.push(Interval.fromDateTimes(s, next));
            s = next;
            idx += 1;
        }
        return results;
    };
    _proto.divideEqually = function divideEqually(numberOfParts) {
        if (!this.isValid) return [];
        return this.splitBy(this.length() / numberOfParts).slice(0, numberOfParts);
    };
    _proto.overlaps = function overlaps(other) {
        return this.e > other.s && this.s < other.e;
    };
    _proto.abutsStart = function abutsStart(other) {
        if (!this.isValid) return false;
        return +this.e === +other.s;
    };
    _proto.abutsEnd = function abutsEnd(other) {
        if (!this.isValid) return false;
        return +other.e === +this.s;
    };
    _proto.engulfs = function engulfs(other) {
        if (!this.isValid) return false;
        return this.s <= other.s && this.e >= other.e;
    };
    _proto.equals = function equals(other) {
        if (!this.isValid || !other.isValid) return false;
        return this.s.equals(other.s) && this.e.equals(other.e);
    };
    _proto.intersection = function intersection(other) {
        if (!this.isValid) return this;
        var s = this.s > other.s ? this.s : other.s, e = this.e < other.e ? this.e : other.e;
        if (s >= e) return null;
        else return Interval.fromDateTimes(s, e);
    };
    _proto.union = function union(other) {
        if (!this.isValid) return this;
        var s = this.s < other.s ? this.s : other.s, e = this.e > other.e ? this.e : other.e;
        return Interval.fromDateTimes(s, e);
    };
    Interval.merge = function merge(intervals) {
        var _intervals$sort$reduc = intervals.sort(function(a, b) {
            return a.s - b.s;
        }).reduce(function(_ref2, item) {
            var sofar = _ref2[0], current = _ref2[1];
            if (!current) return [
                sofar,
                item
            ];
            else if (current.overlaps(item) || current.abutsStart(item)) return [
                sofar,
                current.union(item)
            ];
            else return [
                sofar.concat([
                    current
                ]),
                item
            ];
        }, [
            [],
            null
        ]), found = _intervals$sort$reduc[0], final = _intervals$sort$reduc[1];
        if (final) found.push(final);
        return found;
    };
    Interval.xor = function xor(intervals) {
        var _Array$prototype;
        var start = null, currentCount = 0;
        var results = [], ends = intervals.map(function(i) {
            return [
                {
                    time: i.s,
                    type: "s"
                },
                {
                    time: i.e,
                    type: "e"
                }
            ];
        }), flattened = (_Array$prototype = Array.prototype).concat.apply(_Array$prototype, ends), arr = flattened.sort(function(a, b) {
            return a.time - b.time;
        });
        for(var _iterator = _createForOfIteratorHelperLoose(arr), _step; !(_step = _iterator()).done;){
            var i = _step.value;
            currentCount += i.type === "s" ? 1 : -1;
            if (currentCount === 1) start = i.time;
            else {
                if (start && +start !== +i.time) results.push(Interval.fromDateTimes(start, i.time));
                start = null;
            }
        }
        return Interval.merge(results);
    };
    _proto.difference = function difference() {
        var _this2 = this;
        for(var _len2 = arguments.length, intervals = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++)intervals[_key2] = arguments[_key2];
        return Interval.xor([
            this
        ].concat(intervals)).map(function(i) {
            return _this2.intersection(i);
        }).filter(function(i) {
            return i && !i.isEmpty();
        });
    };
    _proto.toString = function toString() {
        if (!this.isValid) return INVALID$1;
        return "[" + this.s.toISO() + " \u2013 " + this.e.toISO() + ")";
    };
    _proto[_Symbol$for] = function() {
        if (this.isValid) return "Interval { start: " + this.s.toISO() + ", end: " + this.e.toISO() + " }";
        else return "Interval { Invalid, reason: " + this.invalidReason + " }";
    };
    _proto.toLocaleString = function toLocaleString(formatOpts, opts) {
        if (formatOpts === void 0) formatOpts = DATE_SHORT;
        if (opts === void 0) opts = {};
        return this.isValid ? Formatter.create(this.s.loc.clone(opts), formatOpts).formatInterval(this) : INVALID$1;
    };
    _proto.toISO = function toISO(opts) {
        if (!this.isValid) return INVALID$1;
        return this.s.toISO(opts) + "/" + this.e.toISO(opts);
    };
    _proto.toISODate = function toISODate() {
        if (!this.isValid) return INVALID$1;
        return this.s.toISODate() + "/" + this.e.toISODate();
    };
    _proto.toISOTime = function toISOTime(opts) {
        if (!this.isValid) return INVALID$1;
        return this.s.toISOTime(opts) + "/" + this.e.toISOTime(opts);
    };
    _proto.toFormat = function toFormat(dateFormat, _temp2) {
        var _ref3 = _temp2 === void 0 ? {} : _temp2, _ref3$separator = _ref3.separator, separator = _ref3$separator === void 0 ? " \u2013 " : _ref3$separator;
        if (!this.isValid) return INVALID$1;
        return "" + this.s.toFormat(dateFormat) + separator + this.e.toFormat(dateFormat);
    };
    _proto.toDuration = function toDuration(unit, opts) {
        if (!this.isValid) return Duration.invalid(this.invalidReason);
        return this.e.diff(this.s, unit, opts);
    };
    _proto.mapEndpoints = function mapEndpoints(mapFn) {
        return Interval.fromDateTimes(mapFn(this.s), mapFn(this.e));
    };
    _createClass(Interval, [
        {
            key: "start",
            get: function get() {
                return this.isValid ? this.s : null;
            }
        },
        {
            key: "end",
            get: function get() {
                return this.isValid ? this.e : null;
            }
        },
        {
            key: "lastDateTime",
            get: function get() {
                return this.isValid ? this.e ? this.e.minus(1) : null : null;
            }
        },
        {
            key: "isValid",
            get: function get() {
                return this.invalidReason === null;
            }
        },
        {
            key: "invalidReason",
            get: function get() {
                return this.invalid ? this.invalid.reason : null;
            }
        },
        {
            key: "invalidExplanation",
            get: function get() {
                return this.invalid ? this.invalid.explanation : null;
            }
        }
    ]);
    return Interval;
}(Symbol.for("nodejs.util.inspect.custom"));
/**
 * The Info class contains static methods for retrieving general time and date related data. For example, it has methods for finding out if a time zone has a DST, for listing the months in any supported locale, and for discovering which of Luxon features are available in the current environment.
 */ var Info = /*#__PURE__*/ function() {
    function Info() {}
    /**
   * Return whether the specified zone contains a DST.
   * @param {string|Zone} [zone='local'] - Zone to check. Defaults to the environment's local zone.
   * @return {boolean}
   */ Info.hasDST = function hasDST(zone) {
        if (zone === void 0) zone = Settings.defaultZone;
        var proto = DateTime.now().setZone(zone).set({
            month: 12
        });
        return !zone.isUniversal && proto.offset !== proto.set({
            month: 6
        }).offset;
    };
    Info.isValidIANAZone = function isValidIANAZone(zone) {
        return IANAZone.isValidZone(zone);
    };
    Info.normalizeZone = function normalizeZone$1(input) {
        return normalizeZone(input, Settings.defaultZone);
    };
    Info.getStartOfWeek = function getStartOfWeek(_temp) {
        var _ref = _temp === void 0 ? {} : _temp, _ref$locale = _ref.locale, locale = _ref$locale === void 0 ? null : _ref$locale, _ref$locObj = _ref.locObj, locObj = _ref$locObj === void 0 ? null : _ref$locObj;
        return (locObj || Locale.create(locale)).getStartOfWeek();
    };
    Info.getMinimumDaysInFirstWeek = function getMinimumDaysInFirstWeek(_temp2) {
        var _ref2 = _temp2 === void 0 ? {} : _temp2, _ref2$locale = _ref2.locale, locale = _ref2$locale === void 0 ? null : _ref2$locale, _ref2$locObj = _ref2.locObj, locObj = _ref2$locObj === void 0 ? null : _ref2$locObj;
        return (locObj || Locale.create(locale)).getMinDaysInFirstWeek();
    };
    Info.getWeekendWeekdays = function getWeekendWeekdays(_temp3) {
        var _ref3 = _temp3 === void 0 ? {} : _temp3, _ref3$locale = _ref3.locale, locale = _ref3$locale === void 0 ? null : _ref3$locale, _ref3$locObj = _ref3.locObj, locObj = _ref3$locObj === void 0 ? null : _ref3$locObj;
        // copy the array, because we cache it internally
        return (locObj || Locale.create(locale)).getWeekendDays().slice();
    };
    Info.months = function months(length, _temp4) {
        if (length === void 0) length = "long";
        var _ref4 = _temp4 === void 0 ? {} : _temp4, _ref4$locale = _ref4.locale, locale = _ref4$locale === void 0 ? null : _ref4$locale, _ref4$numberingSystem = _ref4.numberingSystem, numberingSystem = _ref4$numberingSystem === void 0 ? null : _ref4$numberingSystem, _ref4$locObj = _ref4.locObj, locObj = _ref4$locObj === void 0 ? null : _ref4$locObj, _ref4$outputCalendar = _ref4.outputCalendar, outputCalendar = _ref4$outputCalendar === void 0 ? "gregory" : _ref4$outputCalendar;
        return (locObj || Locale.create(locale, numberingSystem, outputCalendar)).months(length);
    };
    Info.monthsFormat = function monthsFormat(length, _temp5) {
        if (length === void 0) length = "long";
        var _ref5 = _temp5 === void 0 ? {} : _temp5, _ref5$locale = _ref5.locale, locale = _ref5$locale === void 0 ? null : _ref5$locale, _ref5$numberingSystem = _ref5.numberingSystem, numberingSystem = _ref5$numberingSystem === void 0 ? null : _ref5$numberingSystem, _ref5$locObj = _ref5.locObj, locObj = _ref5$locObj === void 0 ? null : _ref5$locObj, _ref5$outputCalendar = _ref5.outputCalendar, outputCalendar = _ref5$outputCalendar === void 0 ? "gregory" : _ref5$outputCalendar;
        return (locObj || Locale.create(locale, numberingSystem, outputCalendar)).months(length, true);
    };
    Info.weekdays = function weekdays(length, _temp6) {
        if (length === void 0) length = "long";
        var _ref6 = _temp6 === void 0 ? {} : _temp6, _ref6$locale = _ref6.locale, locale = _ref6$locale === void 0 ? null : _ref6$locale, _ref6$numberingSystem = _ref6.numberingSystem, numberingSystem = _ref6$numberingSystem === void 0 ? null : _ref6$numberingSystem, _ref6$locObj = _ref6.locObj, locObj = _ref6$locObj === void 0 ? null : _ref6$locObj;
        return (locObj || Locale.create(locale, numberingSystem, null)).weekdays(length);
    };
    Info.weekdaysFormat = function weekdaysFormat(length, _temp7) {
        if (length === void 0) length = "long";
        var _ref7 = _temp7 === void 0 ? {} : _temp7, _ref7$locale = _ref7.locale, locale = _ref7$locale === void 0 ? null : _ref7$locale, _ref7$numberingSystem = _ref7.numberingSystem, numberingSystem = _ref7$numberingSystem === void 0 ? null : _ref7$numberingSystem, _ref7$locObj = _ref7.locObj, locObj = _ref7$locObj === void 0 ? null : _ref7$locObj;
        return (locObj || Locale.create(locale, numberingSystem, null)).weekdays(length, true);
    };
    Info.meridiems = function meridiems(_temp8) {
        var _ref8 = _temp8 === void 0 ? {} : _temp8, _ref8$locale = _ref8.locale, locale = _ref8$locale === void 0 ? null : _ref8$locale;
        return Locale.create(locale).meridiems();
    };
    Info.eras = function eras(length, _temp9) {
        if (length === void 0) length = "short";
        var _ref9 = _temp9 === void 0 ? {} : _temp9, _ref9$locale = _ref9.locale, locale = _ref9$locale === void 0 ? null : _ref9$locale;
        return Locale.create(locale, null, "gregory").eras(length);
    };
    Info.features = function features() {
        return {
            relative: hasRelative(),
            localeWeek: hasLocaleWeekInfo()
        };
    };
    return Info;
}();
function dayDiff(earlier, later) {
    var utcDayStart = function utcDayStart(dt) {
        return dt.toUTC(0, {
            keepLocalTime: true
        }).startOf("day").valueOf();
    }, ms = utcDayStart(later) - utcDayStart(earlier);
    return Math.floor(Duration.fromMillis(ms).as("days"));
}
function highOrderDiffs(cursor, later, units) {
    var differs = [
        [
            "years",
            function(a, b) {
                return b.year - a.year;
            }
        ],
        [
            "quarters",
            function(a, b) {
                return b.quarter - a.quarter + (b.year - a.year) * 4;
            }
        ],
        [
            "months",
            function(a, b) {
                return b.month - a.month + (b.year - a.year) * 12;
            }
        ],
        [
            "weeks",
            function(a, b) {
                var days = dayDiff(a, b);
                return (days - days % 7) / 7;
            }
        ],
        [
            "days",
            dayDiff
        ]
    ];
    var results = {};
    var earlier = cursor;
    var lowestOrder, highWater;
    /* This loop tries to diff using larger units first.
     If we overshoot, we backtrack and try the next smaller unit.
     "cursor" starts out at the earlier timestamp and moves closer and closer to "later"
     as we use smaller and smaller units.
     highWater keeps track of where we would be if we added one more of the smallest unit,
     this is used later to potentially convert any difference smaller than the smallest higher order unit
     into a fraction of that smallest higher order unit
  */ for(var _i = 0, _differs = differs; _i < _differs.length; _i++){
        var _differs$_i = _differs[_i], unit = _differs$_i[0], differ = _differs$_i[1];
        if (units.indexOf(unit) >= 0) {
            lowestOrder = unit;
            results[unit] = differ(cursor, later);
            highWater = earlier.plus(results);
            if (highWater > later) {
                // we overshot the end point, backtrack cursor by 1
                results[unit]--;
                cursor = earlier.plus(results);
                // if we are still overshooting now, we need to backtrack again
                // this happens in certain situations when diffing times in different zones,
                // because this calculation ignores time zones
                if (cursor > later) {
                    // keep the "overshot by 1" around as highWater
                    highWater = cursor;
                    // backtrack cursor by 1
                    results[unit]--;
                    cursor = earlier.plus(results);
                }
            } else cursor = highWater;
        }
    }
    return [
        cursor,
        results,
        highWater,
        lowestOrder
    ];
}
function _diff(earlier, later, units, opts) {
    var _highOrderDiffs = highOrderDiffs(earlier, later, units), cursor = _highOrderDiffs[0], results = _highOrderDiffs[1], highWater = _highOrderDiffs[2], lowestOrder = _highOrderDiffs[3];
    var remainingMillis = later - cursor;
    var lowerOrderUnits = units.filter(function(u) {
        return [
            "hours",
            "minutes",
            "seconds",
            "milliseconds"
        ].indexOf(u) >= 0;
    });
    if (lowerOrderUnits.length === 0) {
        if (highWater < later) {
            var _cursor$plus;
            highWater = cursor.plus((_cursor$plus = {}, _cursor$plus[lowestOrder] = 1, _cursor$plus));
        }
        if (highWater !== cursor) results[lowestOrder] = (results[lowestOrder] || 0) + remainingMillis / (highWater - cursor);
    }
    var duration = Duration.fromObject(results, opts);
    if (lowerOrderUnits.length > 0) {
        var _Duration$fromMillis;
        return (_Duration$fromMillis = Duration.fromMillis(remainingMillis, opts)).shiftTo.apply(_Duration$fromMillis, lowerOrderUnits).plus(duration);
    } else return duration;
}
var MISSING_FTP = "missing Intl.DateTimeFormat.formatToParts support";
function intUnit(regex, post) {
    if (post === void 0) post = function post(i) {
        return i;
    };
    return {
        regex: regex,
        deser: function deser(_ref) {
            var s = _ref[0];
            return post(parseDigits(s));
        }
    };
}
var NBSP = String.fromCharCode(160);
var spaceOrNBSP = "[ " + NBSP + "]";
var spaceOrNBSPRegExp = new RegExp(spaceOrNBSP, "g");
function fixListRegex(s) {
    // make dots optional and also make them literal
    // make space and non breakable space characters interchangeable
    return s.replace(/\./g, "\\.?").replace(spaceOrNBSPRegExp, spaceOrNBSP);
}
function stripInsensitivities(s) {
    return s.replace(/\./g, "") // ignore dots that were made optional
    .replace(spaceOrNBSPRegExp, " ") // interchange space and nbsp
    .toLowerCase();
}
function oneOf(strings, startIndex) {
    if (strings === null) return null;
    else return {
        regex: RegExp(strings.map(fixListRegex).join("|")),
        deser: function deser(_ref2) {
            var s = _ref2[0];
            return strings.findIndex(function(i) {
                return stripInsensitivities(s) === stripInsensitivities(i);
            }) + startIndex;
        }
    };
}
function offset(regex, groups) {
    return {
        regex: regex,
        deser: function deser(_ref3) {
            var h = _ref3[1], m = _ref3[2];
            return signedOffset(h, m);
        },
        groups: groups
    };
}
function simple(regex) {
    return {
        regex: regex,
        deser: function deser(_ref4) {
            var s = _ref4[0];
            return s;
        }
    };
}
function escapeToken(value) {
    return value.replace(/[\-\[\]{}()*+?.,\\\^$|#\s]/g, "\\$&");
}
/**
 * @param token
 * @param {Locale} loc
 */ function unitForToken(token, loc) {
    var one = digitRegex(loc), two = digitRegex(loc, "{2}"), three = digitRegex(loc, "{3}"), four = digitRegex(loc, "{4}"), six = digitRegex(loc, "{6}"), oneOrTwo = digitRegex(loc, "{1,2}"), oneToThree = digitRegex(loc, "{1,3}"), oneToSix = digitRegex(loc, "{1,6}"), oneToNine = digitRegex(loc, "{1,9}"), twoToFour = digitRegex(loc, "{2,4}"), fourToSix = digitRegex(loc, "{4,6}"), literal = function literal(t) {
        return {
            regex: RegExp(escapeToken(t.val)),
            deser: function deser(_ref5) {
                var s = _ref5[0];
                return s;
            },
            literal: true
        };
    }, unitate = function unitate(t) {
        if (token.literal) return literal(t);
        switch(t.val){
            // era
            case "G":
                return oneOf(loc.eras("short"), 0);
            case "GG":
                return oneOf(loc.eras("long"), 0);
            // years
            case "y":
                return intUnit(oneToSix);
            case "yy":
                return intUnit(twoToFour, untruncateYear);
            case "yyyy":
                return intUnit(four);
            case "yyyyy":
                return intUnit(fourToSix);
            case "yyyyyy":
                return intUnit(six);
            // months
            case "M":
                return intUnit(oneOrTwo);
            case "MM":
                return intUnit(two);
            case "MMM":
                return oneOf(loc.months("short", true), 1);
            case "MMMM":
                return oneOf(loc.months("long", true), 1);
            case "L":
                return intUnit(oneOrTwo);
            case "LL":
                return intUnit(two);
            case "LLL":
                return oneOf(loc.months("short", false), 1);
            case "LLLL":
                return oneOf(loc.months("long", false), 1);
            // dates
            case "d":
                return intUnit(oneOrTwo);
            case "dd":
                return intUnit(two);
            // ordinals
            case "o":
                return intUnit(oneToThree);
            case "ooo":
                return intUnit(three);
            // time
            case "HH":
                return intUnit(two);
            case "H":
                return intUnit(oneOrTwo);
            case "hh":
                return intUnit(two);
            case "h":
                return intUnit(oneOrTwo);
            case "mm":
                return intUnit(two);
            case "m":
                return intUnit(oneOrTwo);
            case "q":
                return intUnit(oneOrTwo);
            case "qq":
                return intUnit(two);
            case "s":
                return intUnit(oneOrTwo);
            case "ss":
                return intUnit(two);
            case "S":
                return intUnit(oneToThree);
            case "SSS":
                return intUnit(three);
            case "u":
                return simple(oneToNine);
            case "uu":
                return simple(oneOrTwo);
            case "uuu":
                return intUnit(one);
            // meridiem
            case "a":
                return oneOf(loc.meridiems(), 0);
            // weekYear (k)
            case "kkkk":
                return intUnit(four);
            case "kk":
                return intUnit(twoToFour, untruncateYear);
            // weekNumber (W)
            case "W":
                return intUnit(oneOrTwo);
            case "WW":
                return intUnit(two);
            // weekdays
            case "E":
            case "c":
                return intUnit(one);
            case "EEE":
                return oneOf(loc.weekdays("short", false), 1);
            case "EEEE":
                return oneOf(loc.weekdays("long", false), 1);
            case "ccc":
                return oneOf(loc.weekdays("short", true), 1);
            case "cccc":
                return oneOf(loc.weekdays("long", true), 1);
            // offset/zone
            case "Z":
            case "ZZ":
                return offset(new RegExp("([+-]" + oneOrTwo.source + ")(?::(" + two.source + "))?"), 2);
            case "ZZZ":
                return offset(new RegExp("([+-]" + oneOrTwo.source + ")(" + two.source + ")?"), 2);
            // we don't support ZZZZ (PST) or ZZZZZ (Pacific Standard Time) in parsing
            // because we don't have any way to figure out what they are
            case "z":
                return simple(/[a-z_+-/]{1,256}?/i);
            // this special-case "token" represents a place where a macro-token expanded into a white-space literal
            // in this case we accept any non-newline white-space
            case " ":
                return simple(/[^\S\n\r]/);
            default:
                return literal(t);
        }
    };
    var unit = unitate(token) || {
        invalidReason: MISSING_FTP
    };
    unit.token = token;
    return unit;
}
var partTypeStyleToTokenVal = {
    year: {
        "2-digit": "yy",
        numeric: "yyyyy"
    },
    month: {
        numeric: "M",
        "2-digit": "MM",
        short: "MMM",
        long: "MMMM"
    },
    day: {
        numeric: "d",
        "2-digit": "dd"
    },
    weekday: {
        short: "EEE",
        long: "EEEE"
    },
    dayperiod: "a",
    dayPeriod: "a",
    hour12: {
        numeric: "h",
        "2-digit": "hh"
    },
    hour24: {
        numeric: "H",
        "2-digit": "HH"
    },
    minute: {
        numeric: "m",
        "2-digit": "mm"
    },
    second: {
        numeric: "s",
        "2-digit": "ss"
    },
    timeZoneName: {
        long: "ZZZZZ",
        short: "ZZZ"
    }
};
function tokenForPart(part, formatOpts, resolvedOpts) {
    var type = part.type, value = part.value;
    if (type === "literal") {
        var isSpace = /^\s+$/.test(value);
        return {
            literal: !isSpace,
            val: isSpace ? " " : value
        };
    }
    var style = formatOpts[type];
    // The user might have explicitly specified hour12 or hourCycle
    // if so, respect their decision
    // if not, refer back to the resolvedOpts, which are based on the locale
    var actualType = type;
    if (type === "hour") {
        if (formatOpts.hour12 != null) actualType = formatOpts.hour12 ? "hour12" : "hour24";
        else if (formatOpts.hourCycle != null) {
            if (formatOpts.hourCycle === "h11" || formatOpts.hourCycle === "h12") actualType = "hour12";
            else actualType = "hour24";
        } else // tokens only differentiate between 24 hours or not,
        // so we do not need to check hourCycle here, which is less supported anyways
        actualType = resolvedOpts.hour12 ? "hour12" : "hour24";
    }
    var val = partTypeStyleToTokenVal[actualType];
    if (typeof val === "object") val = val[style];
    if (val) return {
        literal: false,
        val: val
    };
    return undefined;
}
function buildRegex(units) {
    var re = units.map(function(u) {
        return u.regex;
    }).reduce(function(f, r) {
        return f + "(" + r.source + ")";
    }, "");
    return [
        "^" + re + "$",
        units
    ];
}
function match(input, regex, handlers) {
    var matches = input.match(regex);
    if (matches) {
        var all = {};
        var matchIndex = 1;
        for(var i in handlers)if (hasOwnProperty(handlers, i)) {
            var h = handlers[i], groups = h.groups ? h.groups + 1 : 1;
            if (!h.literal && h.token) all[h.token.val[0]] = h.deser(matches.slice(matchIndex, matchIndex + groups));
            matchIndex += groups;
        }
        return [
            matches,
            all
        ];
    } else return [
        matches,
        {}
    ];
}
function dateTimeFromMatches(matches) {
    var toField = function toField(token) {
        switch(token){
            case "S":
                return "millisecond";
            case "s":
                return "second";
            case "m":
                return "minute";
            case "h":
            case "H":
                return "hour";
            case "d":
                return "day";
            case "o":
                return "ordinal";
            case "L":
            case "M":
                return "month";
            case "y":
                return "year";
            case "E":
            case "c":
                return "weekday";
            case "W":
                return "weekNumber";
            case "k":
                return "weekYear";
            case "q":
                return "quarter";
            default:
                return null;
        }
    };
    var zone = null;
    var specificOffset;
    if (!isUndefined(matches.z)) zone = IANAZone.create(matches.z);
    if (!isUndefined(matches.Z)) {
        if (!zone) zone = new FixedOffsetZone(matches.Z);
        specificOffset = matches.Z;
    }
    if (!isUndefined(matches.q)) matches.M = (matches.q - 1) * 3 + 1;
    if (!isUndefined(matches.h)) {
        if (matches.h < 12 && matches.a === 1) matches.h += 12;
        else if (matches.h === 12 && matches.a === 0) matches.h = 0;
    }
    if (matches.G === 0 && matches.y) matches.y = -matches.y;
    if (!isUndefined(matches.u)) matches.S = parseMillis(matches.u);
    var vals = Object.keys(matches).reduce(function(r, k) {
        var f = toField(k);
        if (f) r[f] = matches[k];
        return r;
    }, {});
    return [
        vals,
        zone,
        specificOffset
    ];
}
var dummyDateTimeCache = null;
function getDummyDateTime() {
    if (!dummyDateTimeCache) dummyDateTimeCache = DateTime.fromMillis(1555555555555);
    return dummyDateTimeCache;
}
function maybeExpandMacroToken(token, locale) {
    if (token.literal) return token;
    var formatOpts = Formatter.macroTokenToFormatOpts(token.val);
    var tokens = formatOptsToTokens(formatOpts, locale);
    if (tokens == null || tokens.includes(undefined)) return token;
    return tokens;
}
function expandMacroTokens(tokens, locale) {
    var _Array$prototype;
    return (_Array$prototype = Array.prototype).concat.apply(_Array$prototype, tokens.map(function(t) {
        return maybeExpandMacroToken(t, locale);
    }));
}
/**
 * @private
 */ var TokenParser = /*#__PURE__*/ function() {
    function TokenParser(locale, format) {
        this.locale = locale;
        this.format = format;
        this.tokens = expandMacroTokens(Formatter.parseFormat(format), locale);
        this.units = this.tokens.map(function(t) {
            return unitForToken(t, locale);
        });
        this.disqualifyingUnit = this.units.find(function(t) {
            return t.invalidReason;
        });
        if (!this.disqualifyingUnit) {
            var _buildRegex = buildRegex(this.units), regexString = _buildRegex[0], handlers = _buildRegex[1];
            this.regex = RegExp(regexString, "i");
            this.handlers = handlers;
        }
    }
    var _proto = TokenParser.prototype;
    _proto.explainFromTokens = function explainFromTokens(input) {
        if (!this.isValid) return {
            input: input,
            tokens: this.tokens,
            invalidReason: this.invalidReason
        };
        else {
            var _match = match(input, this.regex, this.handlers), rawMatches = _match[0], matches = _match[1], _ref6 = matches ? dateTimeFromMatches(matches) : [
                null,
                null,
                undefined
            ], result = _ref6[0], zone = _ref6[1], specificOffset = _ref6[2];
            if (hasOwnProperty(matches, "a") && hasOwnProperty(matches, "H")) throw new ConflictingSpecificationError("Can't include meridiem when specifying 24-hour format");
            return {
                input: input,
                tokens: this.tokens,
                regex: this.regex,
                rawMatches: rawMatches,
                matches: matches,
                result: result,
                zone: zone,
                specificOffset: specificOffset
            };
        }
    };
    _createClass(TokenParser, [
        {
            key: "isValid",
            get: function get() {
                return !this.disqualifyingUnit;
            }
        },
        {
            key: "invalidReason",
            get: function get() {
                return this.disqualifyingUnit ? this.disqualifyingUnit.invalidReason : null;
            }
        }
    ]);
    return TokenParser;
}();
function explainFromTokens(locale, input, format) {
    var parser = new TokenParser(locale, format);
    return parser.explainFromTokens(input);
}
function parseFromTokens(locale, input, format) {
    var _explainFromTokens = explainFromTokens(locale, input, format), result = _explainFromTokens.result, zone = _explainFromTokens.zone, specificOffset = _explainFromTokens.specificOffset, invalidReason = _explainFromTokens.invalidReason;
    return [
        result,
        zone,
        specificOffset,
        invalidReason
    ];
}
function formatOptsToTokens(formatOpts, locale) {
    if (!formatOpts) return null;
    var formatter = Formatter.create(locale, formatOpts);
    var df = formatter.dtFormatter(getDummyDateTime());
    var parts = df.formatToParts();
    var resolvedOpts = df.resolvedOptions();
    return parts.map(function(p) {
        return tokenForPart(p, formatOpts, resolvedOpts);
    });
}
var INVALID = "Invalid DateTime";
var MAX_DATE = 8.64e15;
function unsupportedZone(zone) {
    return new Invalid("unsupported zone", "the zone \"" + zone.name + "\" is not supported");
}
// we cache week data on the DT object and this intermediates the cache
/**
 * @param {DateTime} dt
 */ function possiblyCachedWeekData(dt) {
    if (dt.weekData === null) dt.weekData = gregorianToWeek(dt.c);
    return dt.weekData;
}
/**
 * @param {DateTime} dt
 */ function possiblyCachedLocalWeekData(dt) {
    if (dt.localWeekData === null) dt.localWeekData = gregorianToWeek(dt.c, dt.loc.getMinDaysInFirstWeek(), dt.loc.getStartOfWeek());
    return dt.localWeekData;
}
// clone really means, "make a new object with these modifications". all "setters" really use this
// to create a new object while only changing some of the properties
function clone(inst, alts) {
    var current = {
        ts: inst.ts,
        zone: inst.zone,
        c: inst.c,
        o: inst.o,
        loc: inst.loc,
        invalid: inst.invalid
    };
    return new DateTime(_extends({}, current, alts, {
        old: current
    }));
}
// find the right offset a given local time. The o input is our guess, which determines which
// offset we'll pick in ambiguous cases (e.g. there are two 3 AMs b/c Fallback DST)
function fixOffset(localTS, o, tz) {
    // Our UTC time is just a guess because our offset is just a guess
    var utcGuess = localTS - o * 60000;
    // Test whether the zone matches the offset for this ts
    var o2 = tz.offset(utcGuess);
    // If so, offset didn't change and we're done
    if (o === o2) return [
        utcGuess,
        o
    ];
    // If not, change the ts by the difference in the offset
    utcGuess -= (o2 - o) * 60000;
    // If that gives us the local time we want, we're done
    var o3 = tz.offset(utcGuess);
    if (o2 === o3) return [
        utcGuess,
        o2
    ];
    // If it's different, we're in a hole time. The offset has changed, but the we don't adjust the time
    return [
        localTS - Math.min(o2, o3) * 60000,
        Math.max(o2, o3)
    ];
}
// convert an epoch timestamp into a calendar object with the given offset
function tsToObj(ts, offset) {
    ts += offset * 60000;
    var d = new Date(ts);
    return {
        year: d.getUTCFullYear(),
        month: d.getUTCMonth() + 1,
        day: d.getUTCDate(),
        hour: d.getUTCHours(),
        minute: d.getUTCMinutes(),
        second: d.getUTCSeconds(),
        millisecond: d.getUTCMilliseconds()
    };
}
// convert a calendar object to a epoch timestamp
function objToTS(obj, offset, zone) {
    return fixOffset(objToLocalTS(obj), offset, zone);
}
// create a new DT instance by adding a duration, adjusting for DSTs
function adjustTime(inst, dur) {
    var oPre = inst.o, year = inst.c.year + Math.trunc(dur.years), month = inst.c.month + Math.trunc(dur.months) + Math.trunc(dur.quarters) * 3, c = _extends({}, inst.c, {
        year: year,
        month: month,
        day: Math.min(inst.c.day, daysInMonth(year, month)) + Math.trunc(dur.days) + Math.trunc(dur.weeks) * 7
    }), millisToAdd = Duration.fromObject({
        years: dur.years - Math.trunc(dur.years),
        quarters: dur.quarters - Math.trunc(dur.quarters),
        months: dur.months - Math.trunc(dur.months),
        weeks: dur.weeks - Math.trunc(dur.weeks),
        days: dur.days - Math.trunc(dur.days),
        hours: dur.hours,
        minutes: dur.minutes,
        seconds: dur.seconds,
        milliseconds: dur.milliseconds
    }).as("milliseconds"), localTS = objToLocalTS(c);
    var _fixOffset = fixOffset(localTS, oPre, inst.zone), ts = _fixOffset[0], o = _fixOffset[1];
    if (millisToAdd !== 0) {
        ts += millisToAdd;
        // that could have changed the offset by going over a DST, but we want to keep the ts the same
        o = inst.zone.offset(ts);
    }
    return {
        ts: ts,
        o: o
    };
}
// helper useful in turning the results of parsing into real dates
// by handling the zone options
function parseDataToDateTime(parsed, parsedZone, opts, format, text, specificOffset) {
    var setZone = opts.setZone, zone = opts.zone;
    if (parsed && Object.keys(parsed).length !== 0 || parsedZone) {
        var interpretationZone = parsedZone || zone, inst = DateTime.fromObject(parsed, _extends({}, opts, {
            zone: interpretationZone,
            specificOffset: specificOffset
        }));
        return setZone ? inst : inst.setZone(zone);
    } else return DateTime.invalid(new Invalid("unparsable", "the input \"" + text + "\" can't be parsed as " + format));
}
// if you want to output a technical format (e.g. RFC 2822), this helper
// helps handle the details
function toTechFormat(dt, format, allowZ) {
    if (allowZ === void 0) allowZ = true;
    return dt.isValid ? Formatter.create(Locale.create("en-US"), {
        allowZ: allowZ,
        forceSimple: true
    }).formatDateTimeFromString(dt, format) : null;
}
function _toISODate(o, extended, precision) {
    var longFormat = o.c.year > 9999 || o.c.year < 0;
    var c = "";
    if (longFormat && o.c.year >= 0) c += "+";
    c += padStart(o.c.year, longFormat ? 6 : 4);
    if (precision === "year") return c;
    if (extended) {
        c += "-";
        c += padStart(o.c.month);
        if (precision === "month") return c;
        c += "-";
    } else {
        c += padStart(o.c.month);
        if (precision === "month") return c;
    }
    c += padStart(o.c.day);
    return c;
}
function _toISOTime(o, extended, suppressSeconds, suppressMilliseconds, includeOffset, extendedZone, precision) {
    var showSeconds = !suppressSeconds || o.c.millisecond !== 0 || o.c.second !== 0, c = "";
    switch(precision){
        case "day":
        case "month":
        case "year":
            break;
        default:
            c += padStart(o.c.hour);
            if (precision === "hour") break;
            if (extended) {
                c += ":";
                c += padStart(o.c.minute);
                if (precision === "minute") break;
                if (showSeconds) {
                    c += ":";
                    c += padStart(o.c.second);
                }
            } else {
                c += padStart(o.c.minute);
                if (precision === "minute") break;
                if (showSeconds) c += padStart(o.c.second);
            }
            if (precision === "second") break;
            if (showSeconds && (!suppressMilliseconds || o.c.millisecond !== 0)) {
                c += ".";
                c += padStart(o.c.millisecond, 3);
            }
    }
    if (includeOffset) {
        if (o.isOffsetFixed && o.offset === 0 && !extendedZone) c += "Z";
        else if (o.o < 0) {
            c += "-";
            c += padStart(Math.trunc(-o.o / 60));
            c += ":";
            c += padStart(Math.trunc(-o.o % 60));
        } else {
            c += "+";
            c += padStart(Math.trunc(o.o / 60));
            c += ":";
            c += padStart(Math.trunc(o.o % 60));
        }
    }
    if (extendedZone) c += "[" + o.zone.ianaName + "]";
    return c;
}
// defaults for unspecified units in the supported calendars
var defaultUnitValues = {
    month: 1,
    day: 1,
    hour: 0,
    minute: 0,
    second: 0,
    millisecond: 0
}, defaultWeekUnitValues = {
    weekNumber: 1,
    weekday: 1,
    hour: 0,
    minute: 0,
    second: 0,
    millisecond: 0
}, defaultOrdinalUnitValues = {
    ordinal: 1,
    hour: 0,
    minute: 0,
    second: 0,
    millisecond: 0
};
// Units in the supported calendars, sorted by bigness
var orderedUnits = [
    "year",
    "month",
    "day",
    "hour",
    "minute",
    "second",
    "millisecond"
], orderedWeekUnits = [
    "weekYear",
    "weekNumber",
    "weekday",
    "hour",
    "minute",
    "second",
    "millisecond"
], orderedOrdinalUnits = [
    "year",
    "ordinal",
    "hour",
    "minute",
    "second",
    "millisecond"
];
// standardize case and plurality in units
function normalizeUnit(unit) {
    var normalized = {
        year: "year",
        years: "year",
        month: "month",
        months: "month",
        day: "day",
        days: "day",
        hour: "hour",
        hours: "hour",
        minute: "minute",
        minutes: "minute",
        quarter: "quarter",
        quarters: "quarter",
        second: "second",
        seconds: "second",
        millisecond: "millisecond",
        milliseconds: "millisecond",
        weekday: "weekday",
        weekdays: "weekday",
        weeknumber: "weekNumber",
        weeksnumber: "weekNumber",
        weeknumbers: "weekNumber",
        weekyear: "weekYear",
        weekyears: "weekYear",
        ordinal: "ordinal"
    }[unit.toLowerCase()];
    if (!normalized) throw new InvalidUnitError(unit);
    return normalized;
}
function normalizeUnitWithLocalWeeks(unit) {
    switch(unit.toLowerCase()){
        case "localweekday":
        case "localweekdays":
            return "localWeekday";
        case "localweeknumber":
        case "localweeknumbers":
            return "localWeekNumber";
        case "localweekyear":
        case "localweekyears":
            return "localWeekYear";
        default:
            return normalizeUnit(unit);
    }
}
// cache offsets for zones based on the current timestamp when this function is
// first called. When we are handling a datetime from components like (year,
// month, day, hour) in a time zone, we need a guess about what the timezone
// offset is so that we can convert into a UTC timestamp. One way is to find the
// offset of now in the zone. The actual date may have a different offset (for
// example, if we handle a date in June while we're in December in a zone that
// observes DST), but we can check and adjust that.
//
// When handling many dates, calculating the offset for now every time is
// expensive. It's just a guess, so we can cache the offset to use even if we
// are right on a time change boundary (we'll just correct in the other
// direction). Using a timestamp from first read is a slight optimization for
// handling dates close to the current date, since those dates will usually be
// in the same offset (we could set the timestamp statically, instead). We use a
// single timestamp for all zones to make things a bit more predictable.
//
// This is safe for quickDT (used by local() and utc()) because we don't fill in
// higher-order units from tsNow (as we do in fromObject, this requires that
// offset is calculated from tsNow).
/**
 * @param {Zone} zone
 * @return {number}
 */ function guessOffsetForZone(zone) {
    if (zoneOffsetTs === undefined) zoneOffsetTs = Settings.now();
    // Do not cache anything but IANA zones, because it is not safe to do so.
    // Guessing an offset which is not present in the zone can cause wrong results from fixOffset
    if (zone.type !== "iana") return zone.offset(zoneOffsetTs);
    var zoneName = zone.name;
    var offsetGuess = zoneOffsetGuessCache.get(zoneName);
    if (offsetGuess === undefined) {
        offsetGuess = zone.offset(zoneOffsetTs);
        zoneOffsetGuessCache.set(zoneName, offsetGuess);
    }
    return offsetGuess;
}
// this is a dumbed down version of fromObject() that runs about 60% faster
// but doesn't do any validation, makes a bunch of assumptions about what units
// are present, and so on.
function quickDT(obj, opts) {
    var zone = normalizeZone(opts.zone, Settings.defaultZone);
    if (!zone.isValid) return DateTime.invalid(unsupportedZone(zone));
    var loc = Locale.fromObject(opts);
    var ts, o;
    // assume we have the higher-order units
    if (!isUndefined(obj.year)) {
        for(var _i = 0, _orderedUnits = orderedUnits; _i < _orderedUnits.length; _i++){
            var u = _orderedUnits[_i];
            if (isUndefined(obj[u])) obj[u] = defaultUnitValues[u];
        }
        var invalid = hasInvalidGregorianData(obj) || hasInvalidTimeData(obj);
        if (invalid) return DateTime.invalid(invalid);
        var offsetProvis = guessOffsetForZone(zone);
        var _objToTS = objToTS(obj, offsetProvis, zone);
        ts = _objToTS[0];
        o = _objToTS[1];
    } else ts = Settings.now();
    return new DateTime({
        ts: ts,
        zone: zone,
        loc: loc,
        o: o
    });
}
function diffRelative(start, end, opts) {
    var round = isUndefined(opts.round) ? true : opts.round, rounding = isUndefined(opts.rounding) ? "trunc" : opts.rounding, format = function format(c, unit) {
        c = roundTo(c, round || opts.calendary ? 0 : 2, opts.calendary ? "round" : rounding);
        var formatter = end.loc.clone(opts).relFormatter(opts);
        return formatter.format(c, unit);
    }, differ = function differ(unit) {
        if (opts.calendary) {
            if (!end.hasSame(start, unit)) return end.startOf(unit).diff(start.startOf(unit), unit).get(unit);
            else return 0;
        } else return end.diff(start, unit).get(unit);
    };
    if (opts.unit) return format(differ(opts.unit), opts.unit);
    for(var _iterator = _createForOfIteratorHelperLoose(opts.units), _step; !(_step = _iterator()).done;){
        var unit = _step.value;
        var count = differ(unit);
        if (Math.abs(count) >= 1) return format(count, unit);
    }
    return format(start > end ? -0 : 0, opts.units[opts.units.length - 1]);
}
function lastOpts(argList) {
    var opts = {}, args;
    if (argList.length > 0 && typeof argList[argList.length - 1] === "object") {
        opts = argList[argList.length - 1];
        args = Array.from(argList).slice(0, argList.length - 1);
    } else args = Array.from(argList);
    return [
        opts,
        args
    ];
}
/**
 * Timestamp to use for cached zone offset guesses (exposed for test)
 */ var zoneOffsetTs;
/**
 * Cache for zone offset guesses (exposed for test).
 *
 * This optimizes quickDT via guessOffsetForZone to avoid repeated calls of
 * zone.offset().
 */ var zoneOffsetGuessCache = new Map();
/**
 * A DateTime is an immutable data structure representing a specific date and time and accompanying methods. It contains class and instance methods for creating, parsing, interrogating, transforming, and formatting them.
 *
 * A DateTime comprises of:
 * * A timestamp. Each DateTime instance refers to a specific millisecond of the Unix epoch.
 * * A time zone. Each instance is considered in the context of a specific zone (by default the local system's zone).
 * * Configuration properties that effect how output strings are formatted, such as `locale`, `numberingSystem`, and `outputCalendar`.
 *
 * Here is a brief overview of the most commonly used functionality it provides:
 *
 * * **Creation**: To create a DateTime from its components, use one of its factory class methods: {@link DateTime.local}, {@link DateTime.utc}, and (most flexibly) {@link DateTime.fromObject}. To create one from a standard string format, use {@link DateTime.fromISO}, {@link DateTime.fromHTTP}, and {@link DateTime.fromRFC2822}. To create one from a custom string format, use {@link DateTime.fromFormat}. To create one from a native JS date, use {@link DateTime.fromJSDate}.
 * * **Gregorian calendar and time**: To examine the Gregorian properties of a DateTime individually (i.e as opposed to collectively through {@link DateTime#toObject}), use the {@link DateTime#year}, {@link DateTime#month},
 * {@link DateTime#day}, {@link DateTime#hour}, {@link DateTime#minute}, {@link DateTime#second}, {@link DateTime#millisecond} accessors.
 * * **Week calendar**: For ISO week calendar attributes, see the {@link DateTime#weekYear}, {@link DateTime#weekNumber}, and {@link DateTime#weekday} accessors.
 * * **Configuration** See the {@link DateTime#locale} and {@link DateTime#numberingSystem} accessors.
 * * **Transformation**: To transform the DateTime into other DateTimes, use {@link DateTime#set}, {@link DateTime#reconfigure}, {@link DateTime#setZone}, {@link DateTime#setLocale}, {@link DateTime.plus}, {@link DateTime#minus}, {@link DateTime#endOf}, {@link DateTime#startOf}, {@link DateTime#toUTC}, and {@link DateTime#toLocal}.
 * * **Output**: To convert the DateTime to other representations, use the {@link DateTime#toRelative}, {@link DateTime#toRelativeCalendar}, {@link DateTime#toJSON}, {@link DateTime#toISO}, {@link DateTime#toHTTP}, {@link DateTime#toObject}, {@link DateTime#toRFC2822}, {@link DateTime#toString}, {@link DateTime#toLocaleString}, {@link DateTime#toFormat}, {@link DateTime#toMillis} and {@link DateTime#toJSDate}.
 *
 * There's plenty others documented below. In addition, for more information on subtler topics like internationalization, time zones, alternative calendars, validity, and so on, see the external documentation.
 */ var DateTime = /*#__PURE__*/ function(_Symbol$for) {
    /**
   * @access private
   */ function DateTime(config) {
        var zone = config.zone || Settings.defaultZone;
        var invalid = config.invalid || (Number.isNaN(config.ts) ? new Invalid("invalid input") : null) || (!zone.isValid ? unsupportedZone(zone) : null);
        /**
     * @access private
     */ this.ts = isUndefined(config.ts) ? Settings.now() : config.ts;
        var c = null, o = null;
        if (!invalid) {
            var unchanged = config.old && config.old.ts === this.ts && config.old.zone.equals(zone);
            if (unchanged) {
                var _ref = [
                    config.old.c,
                    config.old.o
                ];
                c = _ref[0];
                o = _ref[1];
            } else {
                // If an offset has been passed and we have not been called from
                // clone(), we can trust it and avoid the offset calculation.
                var ot = isNumber(config.o) && !config.old ? config.o : zone.offset(this.ts);
                c = tsToObj(this.ts, ot);
                invalid = Number.isNaN(c.year) ? new Invalid("invalid input") : null;
                c = invalid ? null : c;
                o = invalid ? null : ot;
            }
        }
        /**
     * @access private
     */ this._zone = zone;
        /**
     * @access private
     */ this.loc = config.loc || Locale.create();
        /**
     * @access private
     */ this.invalid = invalid;
        /**
     * @access private
     */ this.weekData = null;
        /**
     * @access private
     */ this.localWeekData = null;
        /**
     * @access private
     */ this.c = c;
        /**
     * @access private
     */ this.o = o;
        /**
     * @access private
     */ this.isLuxonDateTime = true;
    }
    // CONSTRUCT
    /**
   * Create a DateTime for the current instant, in the system's time zone.
   *
   * Use Settings to override these default values if needed.
   * @example DateTime.now().toISO() //~> now in the ISO format
   * @return {DateTime}
   */ DateTime.now = function now() {
        return new DateTime({});
    };
    DateTime.local = function local() {
        var _lastOpts = lastOpts(arguments), opts = _lastOpts[0], args = _lastOpts[1], year = args[0], month = args[1], day = args[2], hour = args[3], minute = args[4], second = args[5], millisecond = args[6];
        return quickDT({
            year: year,
            month: month,
            day: day,
            hour: hour,
            minute: minute,
            second: second,
            millisecond: millisecond
        }, opts);
    };
    DateTime.utc = function utc() {
        var _lastOpts2 = lastOpts(arguments), opts = _lastOpts2[0], args = _lastOpts2[1], year = args[0], month = args[1], day = args[2], hour = args[3], minute = args[4], second = args[5], millisecond = args[6];
        opts.zone = FixedOffsetZone.utcInstance;
        return quickDT({
            year: year,
            month: month,
            day: day,
            hour: hour,
            minute: minute,
            second: second,
            millisecond: millisecond
        }, opts);
    };
    DateTime.fromJSDate = function fromJSDate(date, options) {
        if (options === void 0) options = {};
        var ts = isDate(date) ? date.valueOf() : NaN;
        if (Number.isNaN(ts)) return DateTime.invalid("invalid input");
        var zoneToUse = normalizeZone(options.zone, Settings.defaultZone);
        if (!zoneToUse.isValid) return DateTime.invalid(unsupportedZone(zoneToUse));
        return new DateTime({
            ts: ts,
            zone: zoneToUse,
            loc: Locale.fromObject(options)
        });
    };
    DateTime.fromMillis = function fromMillis(milliseconds, options) {
        if (options === void 0) options = {};
        if (!isNumber(milliseconds)) throw new InvalidArgumentError("fromMillis requires a numerical input, but received a " + typeof milliseconds + " with value " + milliseconds);
        else if (milliseconds < -MAX_DATE || milliseconds > MAX_DATE) // this isn't perfect because we can still end up out of range because of additional shifting, but it's a start
        return DateTime.invalid("Timestamp out of range");
        else return new DateTime({
            ts: milliseconds,
            zone: normalizeZone(options.zone, Settings.defaultZone),
            loc: Locale.fromObject(options)
        });
    };
    DateTime.fromSeconds = function fromSeconds(seconds, options) {
        if (options === void 0) options = {};
        if (!isNumber(seconds)) throw new InvalidArgumentError("fromSeconds requires a numerical input");
        else return new DateTime({
            ts: seconds * 1000,
            zone: normalizeZone(options.zone, Settings.defaultZone),
            loc: Locale.fromObject(options)
        });
    };
    DateTime.fromObject = function fromObject(obj, opts) {
        if (opts === void 0) opts = {};
        obj = obj || {};
        var zoneToUse = normalizeZone(opts.zone, Settings.defaultZone);
        if (!zoneToUse.isValid) return DateTime.invalid(unsupportedZone(zoneToUse));
        var loc = Locale.fromObject(opts);
        var normalized = normalizeObject(obj, normalizeUnitWithLocalWeeks);
        var _usesLocalWeekValues = usesLocalWeekValues(normalized, loc), minDaysInFirstWeek = _usesLocalWeekValues.minDaysInFirstWeek, startOfWeek = _usesLocalWeekValues.startOfWeek;
        var tsNow = Settings.now(), offsetProvis = !isUndefined(opts.specificOffset) ? opts.specificOffset : zoneToUse.offset(tsNow), containsOrdinal = !isUndefined(normalized.ordinal), containsGregorYear = !isUndefined(normalized.year), containsGregorMD = !isUndefined(normalized.month) || !isUndefined(normalized.day), containsGregor = containsGregorYear || containsGregorMD, definiteWeekDef = normalized.weekYear || normalized.weekNumber;
        // cases:
        // just a weekday -> this week's instance of that weekday, no worries
        // (gregorian data or ordinal) + (weekYear or weekNumber) -> error
        // (gregorian month or day) + ordinal -> error
        // otherwise just use weeks or ordinals or gregorian, depending on what's specified
        if ((containsGregor || containsOrdinal) && definiteWeekDef) throw new ConflictingSpecificationError("Can't mix weekYear/weekNumber units with year/month/day or ordinals");
        if (containsGregorMD && containsOrdinal) throw new ConflictingSpecificationError("Can't mix ordinal dates with month/day");
        var useWeekData = definiteWeekDef || normalized.weekday && !containsGregor;
        // configure ourselves to deal with gregorian dates or week stuff
        var units, defaultValues, objNow = tsToObj(tsNow, offsetProvis);
        if (useWeekData) {
            units = orderedWeekUnits;
            defaultValues = defaultWeekUnitValues;
            objNow = gregorianToWeek(objNow, minDaysInFirstWeek, startOfWeek);
        } else if (containsOrdinal) {
            units = orderedOrdinalUnits;
            defaultValues = defaultOrdinalUnitValues;
            objNow = gregorianToOrdinal(objNow);
        } else {
            units = orderedUnits;
            defaultValues = defaultUnitValues;
        }
        // set default values for missing stuff
        var foundFirst = false;
        for(var _iterator2 = _createForOfIteratorHelperLoose(units), _step2; !(_step2 = _iterator2()).done;){
            var u = _step2.value;
            var v = normalized[u];
            if (!isUndefined(v)) foundFirst = true;
            else if (foundFirst) normalized[u] = defaultValues[u];
            else normalized[u] = objNow[u];
        }
        // make sure the values we have are in range
        var higherOrderInvalid = useWeekData ? hasInvalidWeekData(normalized, minDaysInFirstWeek, startOfWeek) : containsOrdinal ? hasInvalidOrdinalData(normalized) : hasInvalidGregorianData(normalized), invalid = higherOrderInvalid || hasInvalidTimeData(normalized);
        if (invalid) return DateTime.invalid(invalid);
        // compute the actual time
        var gregorian = useWeekData ? weekToGregorian(normalized, minDaysInFirstWeek, startOfWeek) : containsOrdinal ? ordinalToGregorian(normalized) : normalized, _objToTS2 = objToTS(gregorian, offsetProvis, zoneToUse), tsFinal = _objToTS2[0], offsetFinal = _objToTS2[1], inst = new DateTime({
            ts: tsFinal,
            zone: zoneToUse,
            o: offsetFinal,
            loc: loc
        });
        // gregorian data + weekday serves only to validate
        if (normalized.weekday && containsGregor && obj.weekday !== inst.weekday) return DateTime.invalid("mismatched weekday", "you can't specify both a weekday of " + normalized.weekday + " and a date of " + inst.toISO());
        if (!inst.isValid) return DateTime.invalid(inst.invalid);
        return inst;
    };
    DateTime.fromISO = function fromISO(text, opts) {
        if (opts === void 0) opts = {};
        var _parseISODate = parseISODate(text), vals = _parseISODate[0], parsedZone = _parseISODate[1];
        return parseDataToDateTime(vals, parsedZone, opts, "ISO 8601", text);
    };
    DateTime.fromRFC2822 = function fromRFC2822(text, opts) {
        if (opts === void 0) opts = {};
        var _parseRFC2822Date = parseRFC2822Date(text), vals = _parseRFC2822Date[0], parsedZone = _parseRFC2822Date[1];
        return parseDataToDateTime(vals, parsedZone, opts, "RFC 2822", text);
    };
    DateTime.fromHTTP = function fromHTTP(text, opts) {
        if (opts === void 0) opts = {};
        var _parseHTTPDate = parseHTTPDate(text), vals = _parseHTTPDate[0], parsedZone = _parseHTTPDate[1];
        return parseDataToDateTime(vals, parsedZone, opts, "HTTP", opts);
    };
    DateTime.fromFormat = function fromFormat(text, fmt, opts) {
        if (opts === void 0) opts = {};
        if (isUndefined(text) || isUndefined(fmt)) throw new InvalidArgumentError("fromFormat requires an input string and a format");
        var _opts = opts, _opts$locale = _opts.locale, locale = _opts$locale === void 0 ? null : _opts$locale, _opts$numberingSystem = _opts.numberingSystem, numberingSystem = _opts$numberingSystem === void 0 ? null : _opts$numberingSystem, localeToUse = Locale.fromOpts({
            locale: locale,
            numberingSystem: numberingSystem,
            defaultToEN: true
        }), _parseFromTokens = parseFromTokens(localeToUse, text, fmt), vals = _parseFromTokens[0], parsedZone = _parseFromTokens[1], specificOffset = _parseFromTokens[2], invalid = _parseFromTokens[3];
        if (invalid) return DateTime.invalid(invalid);
        else return parseDataToDateTime(vals, parsedZone, opts, "format " + fmt, text, specificOffset);
    };
    DateTime.fromString = function fromString(text, fmt, opts) {
        if (opts === void 0) opts = {};
        return DateTime.fromFormat(text, fmt, opts);
    };
    DateTime.fromSQL = function fromSQL(text, opts) {
        if (opts === void 0) opts = {};
        var _parseSQL = parseSQL(text), vals = _parseSQL[0], parsedZone = _parseSQL[1];
        return parseDataToDateTime(vals, parsedZone, opts, "SQL", text);
    };
    DateTime.invalid = function invalid(reason, explanation) {
        if (explanation === void 0) explanation = null;
        if (!reason) throw new InvalidArgumentError("need to specify a reason the DateTime is invalid");
        var invalid = reason instanceof Invalid ? reason : new Invalid(reason, explanation);
        if (Settings.throwOnInvalid) throw new InvalidDateTimeError(invalid);
        else return new DateTime({
            invalid: invalid
        });
    };
    DateTime.isDateTime = function isDateTime(o) {
        return o && o.isLuxonDateTime || false;
    };
    DateTime.parseFormatForOpts = function parseFormatForOpts(formatOpts, localeOpts) {
        if (localeOpts === void 0) localeOpts = {};
        var tokenList = formatOptsToTokens(formatOpts, Locale.fromObject(localeOpts));
        return !tokenList ? null : tokenList.map(function(t) {
            return t ? t.val : null;
        }).join("");
    };
    DateTime.expandFormat = function expandFormat(fmt, localeOpts) {
        if (localeOpts === void 0) localeOpts = {};
        var expanded = expandMacroTokens(Formatter.parseFormat(fmt), Locale.fromObject(localeOpts));
        return expanded.map(function(t) {
            return t.val;
        }).join("");
    };
    DateTime.resetCache = function resetCache() {
        zoneOffsetTs = undefined;
        zoneOffsetGuessCache.clear();
    };
    var _proto = DateTime.prototype;
    _proto.get = function get(unit) {
        return this[unit];
    };
    /**
   * Get those DateTimes which have the same local time as this DateTime, but a different offset from UTC
   * in this DateTime's zone. During DST changes local time can be ambiguous, for example
   * `2023-10-29T02:30:00` in `Europe/Berlin` can have offset `+01:00` or `+02:00`.
   * This method will return both possible DateTimes if this DateTime's local time is ambiguous.
   * @returns {DateTime[]}
   */ _proto.getPossibleOffsets = function getPossibleOffsets() {
        if (!this.isValid || this.isOffsetFixed) return [
            this
        ];
        var dayMs = 86400000;
        var minuteMs = 60000;
        var localTS = objToLocalTS(this.c);
        var oEarlier = this.zone.offset(localTS - dayMs);
        var oLater = this.zone.offset(localTS + dayMs);
        var o1 = this.zone.offset(localTS - oEarlier * minuteMs);
        var o2 = this.zone.offset(localTS - oLater * minuteMs);
        if (o1 === o2) return [
            this
        ];
        var ts1 = localTS - o1 * minuteMs;
        var ts2 = localTS - o2 * minuteMs;
        var c1 = tsToObj(ts1, o1);
        var c2 = tsToObj(ts2, o2);
        if (c1.hour === c2.hour && c1.minute === c2.minute && c1.second === c2.second && c1.millisecond === c2.millisecond) return [
            clone(this, {
                ts: ts1
            }),
            clone(this, {
                ts: ts2
            })
        ];
        return [
            this
        ];
    };
    /**
   * Returns the resolved Intl options for this DateTime.
   * This is useful in understanding the behavior of formatting methods
   * @param {Object} opts - the same options as toLocaleString
   * @return {Object}
   */ _proto.resolvedLocaleOptions = function resolvedLocaleOptions(opts) {
        if (opts === void 0) opts = {};
        var _Formatter$create$res = Formatter.create(this.loc.clone(opts), opts).resolvedOptions(this), locale = _Formatter$create$res.locale, numberingSystem = _Formatter$create$res.numberingSystem, calendar = _Formatter$create$res.calendar;
        return {
            locale: locale,
            numberingSystem: numberingSystem,
            outputCalendar: calendar
        };
    };
    _proto.toUTC = function toUTC(offset, opts) {
        if (offset === void 0) offset = 0;
        if (opts === void 0) opts = {};
        return this.setZone(FixedOffsetZone.instance(offset), opts);
    };
    _proto.toLocal = function toLocal() {
        return this.setZone(Settings.defaultZone);
    };
    _proto.setZone = function setZone(zone, _temp) {
        var _ref2 = _temp === void 0 ? {} : _temp, _ref2$keepLocalTime = _ref2.keepLocalTime, keepLocalTime = _ref2$keepLocalTime === void 0 ? false : _ref2$keepLocalTime, _ref2$keepCalendarTim = _ref2.keepCalendarTime, keepCalendarTime = _ref2$keepCalendarTim === void 0 ? false : _ref2$keepCalendarTim;
        zone = normalizeZone(zone, Settings.defaultZone);
        if (zone.equals(this.zone)) return this;
        else if (!zone.isValid) return DateTime.invalid(unsupportedZone(zone));
        else {
            var newTS = this.ts;
            if (keepLocalTime || keepCalendarTime) {
                var offsetGuess = zone.offset(this.ts);
                var asObj = this.toObject();
                var _objToTS3 = objToTS(asObj, offsetGuess, zone);
                newTS = _objToTS3[0];
            }
            return clone(this, {
                ts: newTS,
                zone: zone
            });
        }
    };
    _proto.reconfigure = function reconfigure(_temp2) {
        var _ref3 = _temp2 === void 0 ? {} : _temp2, locale = _ref3.locale, numberingSystem = _ref3.numberingSystem, outputCalendar = _ref3.outputCalendar;
        var loc = this.loc.clone({
            locale: locale,
            numberingSystem: numberingSystem,
            outputCalendar: outputCalendar
        });
        return clone(this, {
            loc: loc
        });
    };
    _proto.setLocale = function setLocale(locale) {
        return this.reconfigure({
            locale: locale
        });
    };
    _proto.set = function set(values) {
        if (!this.isValid) return this;
        var normalized = normalizeObject(values, normalizeUnitWithLocalWeeks);
        var _usesLocalWeekValues2 = usesLocalWeekValues(normalized, this.loc), minDaysInFirstWeek = _usesLocalWeekValues2.minDaysInFirstWeek, startOfWeek = _usesLocalWeekValues2.startOfWeek;
        var settingWeekStuff = !isUndefined(normalized.weekYear) || !isUndefined(normalized.weekNumber) || !isUndefined(normalized.weekday), containsOrdinal = !isUndefined(normalized.ordinal), containsGregorYear = !isUndefined(normalized.year), containsGregorMD = !isUndefined(normalized.month) || !isUndefined(normalized.day), containsGregor = containsGregorYear || containsGregorMD, definiteWeekDef = normalized.weekYear || normalized.weekNumber;
        if ((containsGregor || containsOrdinal) && definiteWeekDef) throw new ConflictingSpecificationError("Can't mix weekYear/weekNumber units with year/month/day or ordinals");
        if (containsGregorMD && containsOrdinal) throw new ConflictingSpecificationError("Can't mix ordinal dates with month/day");
        var mixed;
        if (settingWeekStuff) mixed = weekToGregorian(_extends({}, gregorianToWeek(this.c, minDaysInFirstWeek, startOfWeek), normalized), minDaysInFirstWeek, startOfWeek);
        else if (!isUndefined(normalized.ordinal)) mixed = ordinalToGregorian(_extends({}, gregorianToOrdinal(this.c), normalized));
        else {
            mixed = _extends({}, this.toObject(), normalized);
            // if we didn't set the day but we ended up on an overflow date,
            // use the last day of the right month
            if (isUndefined(normalized.day)) mixed.day = Math.min(daysInMonth(mixed.year, mixed.month), mixed.day);
        }
        var _objToTS4 = objToTS(mixed, this.o, this.zone), ts = _objToTS4[0], o = _objToTS4[1];
        return clone(this, {
            ts: ts,
            o: o
        });
    };
    _proto.plus = function plus(duration) {
        if (!this.isValid) return this;
        var dur = Duration.fromDurationLike(duration);
        return clone(this, adjustTime(this, dur));
    };
    _proto.minus = function minus(duration) {
        if (!this.isValid) return this;
        var dur = Duration.fromDurationLike(duration).negate();
        return clone(this, adjustTime(this, dur));
    };
    _proto.startOf = function startOf(unit, _temp3) {
        var _ref4 = _temp3 === void 0 ? {} : _temp3, _ref4$useLocaleWeeks = _ref4.useLocaleWeeks, useLocaleWeeks = _ref4$useLocaleWeeks === void 0 ? false : _ref4$useLocaleWeeks;
        if (!this.isValid) return this;
        var o = {}, normalizedUnit = Duration.normalizeUnit(unit);
        switch(normalizedUnit){
            case "years":
                o.month = 1;
            // falls through
            case "quarters":
            case "months":
                o.day = 1;
            // falls through
            case "weeks":
            case "days":
                o.hour = 0;
            // falls through
            case "hours":
                o.minute = 0;
            // falls through
            case "minutes":
                o.second = 0;
            // falls through
            case "seconds":
                o.millisecond = 0;
                break;
        }
        if (normalizedUnit === "weeks") {
            if (useLocaleWeeks) {
                var startOfWeek = this.loc.getStartOfWeek();
                var weekday = this.weekday;
                if (weekday < startOfWeek) o.weekNumber = this.weekNumber - 1;
                o.weekday = startOfWeek;
            } else o.weekday = 1;
        }
        if (normalizedUnit === "quarters") {
            var q = Math.ceil(this.month / 3);
            o.month = (q - 1) * 3 + 1;
        }
        return this.set(o);
    };
    _proto.endOf = function endOf(unit, opts) {
        var _this$plus;
        return this.isValid ? this.plus((_this$plus = {}, _this$plus[unit] = 1, _this$plus)).startOf(unit, opts).minus(1) : this;
    };
    _proto.toFormat = function toFormat(fmt, opts) {
        if (opts === void 0) opts = {};
        return this.isValid ? Formatter.create(this.loc.redefaultToEN(opts)).formatDateTimeFromString(this, fmt) : INVALID;
    };
    _proto.toLocaleString = function toLocaleString(formatOpts, opts) {
        if (formatOpts === void 0) formatOpts = DATE_SHORT;
        if (opts === void 0) opts = {};
        return this.isValid ? Formatter.create(this.loc.clone(opts), formatOpts).formatDateTime(this) : INVALID;
    };
    _proto.toLocaleParts = function toLocaleParts(opts) {
        if (opts === void 0) opts = {};
        return this.isValid ? Formatter.create(this.loc.clone(opts), opts).formatDateTimeParts(this) : [];
    };
    _proto.toISO = function toISO(_temp4) {
        var _ref5 = _temp4 === void 0 ? {} : _temp4, _ref5$format = _ref5.format, format = _ref5$format === void 0 ? "extended" : _ref5$format, _ref5$suppressSeconds = _ref5.suppressSeconds, suppressSeconds = _ref5$suppressSeconds === void 0 ? false : _ref5$suppressSeconds, _ref5$suppressMillise = _ref5.suppressMilliseconds, suppressMilliseconds = _ref5$suppressMillise === void 0 ? false : _ref5$suppressMillise, _ref5$includeOffset = _ref5.includeOffset, includeOffset = _ref5$includeOffset === void 0 ? true : _ref5$includeOffset, _ref5$extendedZone = _ref5.extendedZone, extendedZone = _ref5$extendedZone === void 0 ? false : _ref5$extendedZone, _ref5$precision = _ref5.precision, precision = _ref5$precision === void 0 ? "milliseconds" : _ref5$precision;
        if (!this.isValid) return null;
        precision = normalizeUnit(precision);
        var ext = format === "extended";
        var c = _toISODate(this, ext, precision);
        if (orderedUnits.indexOf(precision) >= 3) c += "T";
        c += _toISOTime(this, ext, suppressSeconds, suppressMilliseconds, includeOffset, extendedZone, precision);
        return c;
    };
    _proto.toISODate = function toISODate(_temp5) {
        var _ref6 = _temp5 === void 0 ? {} : _temp5, _ref6$format = _ref6.format, format = _ref6$format === void 0 ? "extended" : _ref6$format, _ref6$precision = _ref6.precision, precision = _ref6$precision === void 0 ? "day" : _ref6$precision;
        if (!this.isValid) return null;
        return _toISODate(this, format === "extended", normalizeUnit(precision));
    };
    _proto.toISOWeekDate = function toISOWeekDate() {
        return toTechFormat(this, "kkkk-'W'WW-c");
    };
    _proto.toISOTime = function toISOTime(_temp6) {
        var _ref7 = _temp6 === void 0 ? {} : _temp6, _ref7$suppressMillise = _ref7.suppressMilliseconds, suppressMilliseconds = _ref7$suppressMillise === void 0 ? false : _ref7$suppressMillise, _ref7$suppressSeconds = _ref7.suppressSeconds, suppressSeconds = _ref7$suppressSeconds === void 0 ? false : _ref7$suppressSeconds, _ref7$includeOffset = _ref7.includeOffset, includeOffset = _ref7$includeOffset === void 0 ? true : _ref7$includeOffset, _ref7$includePrefix = _ref7.includePrefix, includePrefix = _ref7$includePrefix === void 0 ? false : _ref7$includePrefix, _ref7$extendedZone = _ref7.extendedZone, extendedZone = _ref7$extendedZone === void 0 ? false : _ref7$extendedZone, _ref7$format = _ref7.format, format = _ref7$format === void 0 ? "extended" : _ref7$format, _ref7$precision = _ref7.precision, precision = _ref7$precision === void 0 ? "milliseconds" : _ref7$precision;
        if (!this.isValid) return null;
        precision = normalizeUnit(precision);
        var c = includePrefix && orderedUnits.indexOf(precision) >= 3 ? "T" : "";
        return c + _toISOTime(this, format === "extended", suppressSeconds, suppressMilliseconds, includeOffset, extendedZone, precision);
    };
    _proto.toRFC2822 = function toRFC2822() {
        return toTechFormat(this, "EEE, dd LLL yyyy HH:mm:ss ZZZ", false);
    };
    _proto.toHTTP = function toHTTP() {
        return toTechFormat(this.toUTC(), "EEE, dd LLL yyyy HH:mm:ss 'GMT'");
    };
    _proto.toSQLDate = function toSQLDate() {
        if (!this.isValid) return null;
        return _toISODate(this, true);
    };
    _proto.toSQLTime = function toSQLTime(_temp7) {
        var _ref8 = _temp7 === void 0 ? {} : _temp7, _ref8$includeOffset = _ref8.includeOffset, includeOffset = _ref8$includeOffset === void 0 ? true : _ref8$includeOffset, _ref8$includeZone = _ref8.includeZone, includeZone = _ref8$includeZone === void 0 ? false : _ref8$includeZone, _ref8$includeOffsetSp = _ref8.includeOffsetSpace, includeOffsetSpace = _ref8$includeOffsetSp === void 0 ? true : _ref8$includeOffsetSp;
        var fmt = "HH:mm:ss.SSS";
        if (includeZone || includeOffset) {
            if (includeOffsetSpace) fmt += " ";
            if (includeZone) fmt += "z";
            else if (includeOffset) fmt += "ZZ";
        }
        return toTechFormat(this, fmt, true);
    };
    _proto.toSQL = function toSQL(opts) {
        if (opts === void 0) opts = {};
        if (!this.isValid) return null;
        return this.toSQLDate() + " " + this.toSQLTime(opts);
    };
    _proto.toString = function toString() {
        return this.isValid ? this.toISO() : INVALID;
    };
    _proto[_Symbol$for] = function() {
        if (this.isValid) return "DateTime { ts: " + this.toISO() + ", zone: " + this.zone.name + ", locale: " + this.locale + " }";
        else return "DateTime { Invalid, reason: " + this.invalidReason + " }";
    };
    _proto.valueOf = function valueOf() {
        return this.toMillis();
    };
    _proto.toMillis = function toMillis() {
        return this.isValid ? this.ts : NaN;
    };
    _proto.toSeconds = function toSeconds() {
        return this.isValid ? this.ts / 1000 : NaN;
    };
    _proto.toUnixInteger = function toUnixInteger() {
        return this.isValid ? Math.floor(this.ts / 1000) : NaN;
    };
    _proto.toJSON = function toJSON() {
        return this.toISO();
    };
    _proto.toBSON = function toBSON() {
        return this.toJSDate();
    };
    _proto.toObject = function toObject(opts) {
        if (opts === void 0) opts = {};
        if (!this.isValid) return {};
        var base = _extends({}, this.c);
        if (opts.includeConfig) {
            base.outputCalendar = this.outputCalendar;
            base.numberingSystem = this.loc.numberingSystem;
            base.locale = this.loc.locale;
        }
        return base;
    };
    _proto.toJSDate = function toJSDate() {
        return new Date(this.isValid ? this.ts : NaN);
    };
    _proto.diff = function diff(otherDateTime, unit, opts) {
        if (unit === void 0) unit = "milliseconds";
        if (opts === void 0) opts = {};
        if (!this.isValid || !otherDateTime.isValid) return Duration.invalid("created by diffing an invalid DateTime");
        var durOpts = _extends({
            locale: this.locale,
            numberingSystem: this.numberingSystem
        }, opts);
        var units = maybeArray(unit).map(Duration.normalizeUnit), otherIsLater = otherDateTime.valueOf() > this.valueOf(), earlier = otherIsLater ? this : otherDateTime, later = otherIsLater ? otherDateTime : this, diffed = _diff(earlier, later, units, durOpts);
        return otherIsLater ? diffed.negate() : diffed;
    };
    _proto.diffNow = function diffNow(unit, opts) {
        if (unit === void 0) unit = "milliseconds";
        if (opts === void 0) opts = {};
        return this.diff(DateTime.now(), unit, opts);
    };
    _proto.until = function until(otherDateTime) {
        return this.isValid ? Interval.fromDateTimes(this, otherDateTime) : this;
    };
    _proto.hasSame = function hasSame(otherDateTime, unit, opts) {
        if (!this.isValid) return false;
        var inputMs = otherDateTime.valueOf();
        var adjustedToZone = this.setZone(otherDateTime.zone, {
            keepLocalTime: true
        });
        return adjustedToZone.startOf(unit, opts) <= inputMs && inputMs <= adjustedToZone.endOf(unit, opts);
    };
    _proto.equals = function equals(other) {
        return this.isValid && other.isValid && this.valueOf() === other.valueOf() && this.zone.equals(other.zone) && this.loc.equals(other.loc);
    };
    _proto.toRelative = function toRelative(options) {
        if (options === void 0) options = {};
        if (!this.isValid) return null;
        var base = options.base || DateTime.fromObject({}, {
            zone: this.zone
        }), padding = options.padding ? this < base ? -options.padding : options.padding : 0;
        var units = [
            "years",
            "months",
            "days",
            "hours",
            "minutes",
            "seconds"
        ];
        var unit = options.unit;
        if (Array.isArray(options.unit)) {
            units = options.unit;
            unit = undefined;
        }
        return diffRelative(base, this.plus(padding), _extends({}, options, {
            numeric: "always",
            units: units,
            unit: unit
        }));
    };
    _proto.toRelativeCalendar = function toRelativeCalendar(options) {
        if (options === void 0) options = {};
        if (!this.isValid) return null;
        return diffRelative(options.base || DateTime.fromObject({}, {
            zone: this.zone
        }), this, _extends({}, options, {
            numeric: "auto",
            units: [
                "years",
                "months",
                "days"
            ],
            calendary: true
        }));
    };
    DateTime.min = function min() {
        for(var _len = arguments.length, dateTimes = new Array(_len), _key = 0; _key < _len; _key++)dateTimes[_key] = arguments[_key];
        if (!dateTimes.every(DateTime.isDateTime)) throw new InvalidArgumentError("min requires all arguments be DateTimes");
        return bestBy(dateTimes, function(i) {
            return i.valueOf();
        }, Math.min);
    };
    DateTime.max = function max() {
        for(var _len2 = arguments.length, dateTimes = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++)dateTimes[_key2] = arguments[_key2];
        if (!dateTimes.every(DateTime.isDateTime)) throw new InvalidArgumentError("max requires all arguments be DateTimes");
        return bestBy(dateTimes, function(i) {
            return i.valueOf();
        }, Math.max);
    };
    DateTime.fromFormatExplain = function fromFormatExplain(text, fmt, options) {
        if (options === void 0) options = {};
        var _options = options, _options$locale = _options.locale, locale = _options$locale === void 0 ? null : _options$locale, _options$numberingSys = _options.numberingSystem, numberingSystem = _options$numberingSys === void 0 ? null : _options$numberingSys, localeToUse = Locale.fromOpts({
            locale: locale,
            numberingSystem: numberingSystem,
            defaultToEN: true
        });
        return explainFromTokens(localeToUse, text, fmt);
    };
    DateTime.fromStringExplain = function fromStringExplain(text, fmt, options) {
        if (options === void 0) options = {};
        return DateTime.fromFormatExplain(text, fmt, options);
    };
    DateTime.buildFormatParser = function buildFormatParser(fmt, options) {
        if (options === void 0) options = {};
        var _options2 = options, _options2$locale = _options2.locale, locale = _options2$locale === void 0 ? null : _options2$locale, _options2$numberingSy = _options2.numberingSystem, numberingSystem = _options2$numberingSy === void 0 ? null : _options2$numberingSy, localeToUse = Locale.fromOpts({
            locale: locale,
            numberingSystem: numberingSystem,
            defaultToEN: true
        });
        return new TokenParser(localeToUse, fmt);
    };
    DateTime.fromFormatParser = function fromFormatParser(text, formatParser, opts) {
        if (opts === void 0) opts = {};
        if (isUndefined(text) || isUndefined(formatParser)) throw new InvalidArgumentError("fromFormatParser requires an input string and a format parser");
        var _opts2 = opts, _opts2$locale = _opts2.locale, locale = _opts2$locale === void 0 ? null : _opts2$locale, _opts2$numberingSyste = _opts2.numberingSystem, numberingSystem = _opts2$numberingSyste === void 0 ? null : _opts2$numberingSyste, localeToUse = Locale.fromOpts({
            locale: locale,
            numberingSystem: numberingSystem,
            defaultToEN: true
        });
        if (!localeToUse.equals(formatParser.locale)) throw new InvalidArgumentError("fromFormatParser called with a locale of " + localeToUse + ", " + ("but the format parser was created for " + formatParser.locale));
        var _formatParser$explain = formatParser.explainFromTokens(text), result = _formatParser$explain.result, zone = _formatParser$explain.zone, specificOffset = _formatParser$explain.specificOffset, invalidReason = _formatParser$explain.invalidReason;
        if (invalidReason) return DateTime.invalid(invalidReason);
        else return parseDataToDateTime(result, zone, opts, "format " + formatParser.format, text, specificOffset);
    };
    _createClass(DateTime, [
        {
            key: "isValid",
            get: function get() {
                return this.invalid === null;
            }
        },
        {
            key: "invalidReason",
            get: function get() {
                return this.invalid ? this.invalid.reason : null;
            }
        },
        {
            key: "invalidExplanation",
            get: function get() {
                return this.invalid ? this.invalid.explanation : null;
            }
        },
        {
            key: "locale",
            get: function get() {
                return this.isValid ? this.loc.locale : null;
            }
        },
        {
            key: "numberingSystem",
            get: function get() {
                return this.isValid ? this.loc.numberingSystem : null;
            }
        },
        {
            key: "outputCalendar",
            get: function get() {
                return this.isValid ? this.loc.outputCalendar : null;
            }
        },
        {
            key: "zone",
            get: function get() {
                return this._zone;
            }
        },
        {
            key: "zoneName",
            get: function get() {
                return this.isValid ? this.zone.name : null;
            }
        },
        {
            key: "year",
            get: function get() {
                return this.isValid ? this.c.year : NaN;
            }
        },
        {
            key: "quarter",
            get: function get() {
                return this.isValid ? Math.ceil(this.c.month / 3) : NaN;
            }
        },
        {
            key: "month",
            get: function get() {
                return this.isValid ? this.c.month : NaN;
            }
        },
        {
            key: "day",
            get: function get() {
                return this.isValid ? this.c.day : NaN;
            }
        },
        {
            key: "hour",
            get: function get() {
                return this.isValid ? this.c.hour : NaN;
            }
        },
        {
            key: "minute",
            get: function get() {
                return this.isValid ? this.c.minute : NaN;
            }
        },
        {
            key: "second",
            get: function get() {
                return this.isValid ? this.c.second : NaN;
            }
        },
        {
            key: "millisecond",
            get: function get() {
                return this.isValid ? this.c.millisecond : NaN;
            }
        },
        {
            key: "weekYear",
            get: function get() {
                return this.isValid ? possiblyCachedWeekData(this).weekYear : NaN;
            }
        },
        {
            key: "weekNumber",
            get: function get() {
                return this.isValid ? possiblyCachedWeekData(this).weekNumber : NaN;
            }
        },
        {
            key: "weekday",
            get: function get() {
                return this.isValid ? possiblyCachedWeekData(this).weekday : NaN;
            }
        },
        {
            key: "isWeekend",
            get: function get() {
                return this.isValid && this.loc.getWeekendDays().includes(this.weekday);
            }
        },
        {
            key: "localWeekday",
            get: function get() {
                return this.isValid ? possiblyCachedLocalWeekData(this).weekday : NaN;
            }
        },
        {
            key: "localWeekNumber",
            get: function get() {
                return this.isValid ? possiblyCachedLocalWeekData(this).weekNumber : NaN;
            }
        },
        {
            key: "localWeekYear",
            get: function get() {
                return this.isValid ? possiblyCachedLocalWeekData(this).weekYear : NaN;
            }
        },
        {
            key: "ordinal",
            get: function get() {
                return this.isValid ? gregorianToOrdinal(this.c).ordinal : NaN;
            }
        },
        {
            key: "monthShort",
            get: function get() {
                return this.isValid ? Info.months("short", {
                    locObj: this.loc
                })[this.month - 1] : null;
            }
        },
        {
            key: "monthLong",
            get: function get() {
                return this.isValid ? Info.months("long", {
                    locObj: this.loc
                })[this.month - 1] : null;
            }
        },
        {
            key: "weekdayShort",
            get: function get() {
                return this.isValid ? Info.weekdays("short", {
                    locObj: this.loc
                })[this.weekday - 1] : null;
            }
        },
        {
            key: "weekdayLong",
            get: function get() {
                return this.isValid ? Info.weekdays("long", {
                    locObj: this.loc
                })[this.weekday - 1] : null;
            }
        },
        {
            key: "offset",
            get: function get() {
                return this.isValid ? +this.o : NaN;
            }
        },
        {
            key: "offsetNameShort",
            get: function get() {
                if (this.isValid) return this.zone.offsetName(this.ts, {
                    format: "short",
                    locale: this.locale
                });
                else return null;
            }
        },
        {
            key: "offsetNameLong",
            get: function get() {
                if (this.isValid) return this.zone.offsetName(this.ts, {
                    format: "long",
                    locale: this.locale
                });
                else return null;
            }
        },
        {
            key: "isOffsetFixed",
            get: function get() {
                return this.isValid ? this.zone.isUniversal : null;
            }
        },
        {
            key: "isInDST",
            get: function get() {
                if (this.isOffsetFixed) return false;
                else return this.offset > this.set({
                    month: 1,
                    day: 1
                }).offset || this.offset > this.set({
                    month: 5
                }).offset;
            }
        },
        {
            key: "isInLeapYear",
            get: function get() {
                return isLeapYear(this.year);
            }
        },
        {
            key: "daysInMonth",
            get: function get() {
                return daysInMonth(this.year, this.month);
            }
        },
        {
            key: "daysInYear",
            get: function get() {
                return this.isValid ? daysInYear(this.year) : NaN;
            }
        },
        {
            key: "weeksInWeekYear",
            get: function get() {
                return this.isValid ? weeksInWeekYear(this.weekYear) : NaN;
            }
        },
        {
            key: "weeksInLocalWeekYear",
            get: function get() {
                return this.isValid ? weeksInWeekYear(this.localWeekYear, this.loc.getMinDaysInFirstWeek(), this.loc.getStartOfWeek()) : NaN;
            }
        }
    ], [
        {
            key: "DATE_SHORT",
            get: function get() {
                return DATE_SHORT;
            }
        },
        {
            key: "DATE_MED",
            get: function get() {
                return DATE_MED;
            }
        },
        {
            key: "DATE_MED_WITH_WEEKDAY",
            get: function get() {
                return DATE_MED_WITH_WEEKDAY;
            }
        },
        {
            key: "DATE_FULL",
            get: function get() {
                return DATE_FULL;
            }
        },
        {
            key: "DATE_HUGE",
            get: function get() {
                return DATE_HUGE;
            }
        },
        {
            key: "TIME_SIMPLE",
            get: function get() {
                return TIME_SIMPLE;
            }
        },
        {
            key: "TIME_WITH_SECONDS",
            get: function get() {
                return TIME_WITH_SECONDS;
            }
        },
        {
            key: "TIME_WITH_SHORT_OFFSET",
            get: function get() {
                return TIME_WITH_SHORT_OFFSET;
            }
        },
        {
            key: "TIME_WITH_LONG_OFFSET",
            get: function get() {
                return TIME_WITH_LONG_OFFSET;
            }
        },
        {
            key: "TIME_24_SIMPLE",
            get: function get() {
                return TIME_24_SIMPLE;
            }
        },
        {
            key: "TIME_24_WITH_SECONDS",
            get: function get() {
                return TIME_24_WITH_SECONDS;
            }
        },
        {
            key: "TIME_24_WITH_SHORT_OFFSET",
            get: function get() {
                return TIME_24_WITH_SHORT_OFFSET;
            }
        },
        {
            key: "TIME_24_WITH_LONG_OFFSET",
            get: function get() {
                return TIME_24_WITH_LONG_OFFSET;
            }
        },
        {
            key: "DATETIME_SHORT",
            get: function get() {
                return DATETIME_SHORT;
            }
        },
        {
            key: "DATETIME_SHORT_WITH_SECONDS",
            get: function get() {
                return DATETIME_SHORT_WITH_SECONDS;
            }
        },
        {
            key: "DATETIME_MED",
            get: function get() {
                return DATETIME_MED;
            }
        },
        {
            key: "DATETIME_MED_WITH_SECONDS",
            get: function get() {
                return DATETIME_MED_WITH_SECONDS;
            }
        },
        {
            key: "DATETIME_MED_WITH_WEEKDAY",
            get: function get() {
                return DATETIME_MED_WITH_WEEKDAY;
            }
        },
        {
            key: "DATETIME_FULL",
            get: function get() {
                return DATETIME_FULL;
            }
        },
        {
            key: "DATETIME_FULL_WITH_SECONDS",
            get: function get() {
                return DATETIME_FULL_WITH_SECONDS;
            }
        },
        {
            key: "DATETIME_HUGE",
            get: function get() {
                return DATETIME_HUGE;
            }
        },
        {
            key: "DATETIME_HUGE_WITH_SECONDS",
            get: function get() {
                return DATETIME_HUGE_WITH_SECONDS;
            }
        }
    ]);
    return DateTime;
}(Symbol.for("nodejs.util.inspect.custom"));
function friendlyDateTime(dateTimeish) {
    if (DateTime.isDateTime(dateTimeish)) return dateTimeish;
    else if (dateTimeish && dateTimeish.valueOf && isNumber(dateTimeish.valueOf())) return DateTime.fromJSDate(dateTimeish);
    else if (dateTimeish && typeof dateTimeish === "object") return DateTime.fromObject(dateTimeish);
    else throw new InvalidArgumentError("Unknown datetime argument: " + dateTimeish + ", of type " + typeof dateTimeish);
}
var VERSION = "3.7.2";
exports.DateTime = DateTime;
exports.Duration = Duration;
exports.FixedOffsetZone = FixedOffsetZone;
exports.IANAZone = IANAZone;
exports.Info = Info;
exports.Interval = Interval;
exports.InvalidZone = InvalidZone;
exports.Settings = Settings;
exports.SystemZone = SystemZone;
exports.VERSION = VERSION;
exports.Zone = Zone;

},{}]},["ca6OP","bxZDA"], "bxZDA", "parcelRequire94c2", {})

//# sourceMappingURL=member_display.js.map
